$ !
$ ! MKPRODCT.COM
$ ! 
$ !---------------------------------------------------------------------
$ ! Abstract:
$ !  
$ ! Create object libraries and executables depending on what types of
$ ! files are in the current directory.
$ !
$ !---------------------------------------------------------------------
$ ! Change History:
$ ! 
$ ! WLT    11-DEC-1995
$ !
$ ! The compile option OPTS was defined (as seen below) but all of
$ ! the compile commands used the option OPT.  This has been fixed.
$ !
$ ! WLT    24-APR-1996
$ ! 
$ !=====================================================================
$ ! 
$ !  If the execution of this procedure is interrupted, exit.
$ !
$          on control_y then goto EXIT 
$          on warning then continue
$ !
$ !  Set the compile options for this environment
$ !
$   OPTS = "/nolist/warning=declarations/float=D_FLOAT/check=(bounds,overflow)"
$ ! 
$ MAINS:
$ ! 
$ !  Do any subroutine files exist in this directory?
$ !
$           files = f$search ("[]*.pgm")
$           if ( "''files'" .eqs. "" )
$           then 
$              write sys$output " "
$              write sys$output "There are no .pgm files present. This"
$              write sys$output "product is a library."
$              write sys$output " "
$              goto MKLIBRARY
$           else 
$              goto MKEXES
$           endif
$ !
$ MKLIBRARY:
$ !
$ !  If the execution of this procedure is interrupted, be sure to 
$ !  delete the directory listing file. 
$ !
$          on control_y then goto SUBERROR
$ ! 
$ !  We are only going to create a library and quit.  But we need
$ !  the name of the library to create first.
$ !  
$      THISDIR   == f$directory()
$      THISDIRM  == f$element(1,"[", THISDIR  )
$      THISDIRMM == f$element(0,"]", THISDIRM )
$      LAST  == 0
$      THIS  == 1
$!
$      FINDIT:
$!
$      if ( f$element( 'THIS',".","''THISDIRMM'") .eqs. "." ) THEN goto GOTIT
$         LAST == THIS
$         THIS == LAST + 1
$      goto FINDIT
$!
$      GOTIT:
$      MYDIR == f$element('LAST', ".", "''THISDIRMM'" )
$      MYLIB == "[-.-.lib]''MYDIR'.OLB"
$      write sys$output "   Library to create "
$      write sys$output "   ''MYLIB'
$      write sys$output " "
$ !
$ !
$ !  We now have the name of the library we are going to create.  The
$ !  only thing left to do is compile all the source code in this
$ !  directory and place the object modules into the library.
$ !      
$      library/create/log 'MYLIB'
$ !
$      MKLIBLOOP:
$ !
$           on error then goto LIBERROR
$ !
$           file     = f$search("[]*.for")
$ !
$           if ( file .eqs. "" ) then goto MKLIBDONE
$ !  
$              name = f$parse("''file'",,,"NAME") 
$              write sys$output "   ''name'"
$ !
$              fortran'OPTS'/object=*.obj   'file'  
$              library/replace 'MYLIB' 'name'.obj;
$              delete/nolog            'name'.obj;
$              goto MKLIBLOOP
$ !  
$      MKLIBDONE:
$      goto EXIT
$ !  
$ !  
$ MKEXES:
$ ! 
$ !  Create the library.
$ ! 
$      file     = f$search("[]*.for")
$      if ( file .eqs. "" ) then goto MKLOCLIBDONE
$      write sys$output "Creating Local Library."
$      write sys$output "======================="
$      write sys$output " "
$      library/create LOCALLIB.OLB
$       
$      MKLOCLIB:
$ !
$           on error then goto locliberror
$ !
$ !
$           if file .eqs. "" then goto MKLOCLIBDONE
$ !  
$              name = f$parse("''file'",,,"NAME") 
$              write sys$output "   ''name'"
$ !
$              fortran'OPTS'/object=*.obj   'file'  
$              library/replace LOCALLIB.OLB 'name'.obj;
$              delete/nolog                 'name'.obj;
$              file     = f$search("[]*.for")
$              goto MKLOCLIB
$ !  
$      MKLOCLIBDONE:
$ !
$ !  Ok, now the any libraries that need to be created have been formed.
$ !  Now we simply compile every .pgm in the current directory.
$ ! 
$
$ MAINLOOP:
$ ! 
$ !  Read the files from the list one by one. Compile and link the 
$ !  objects with the appropriate toolkit libraries.
$ ! 
$           on error then continue
$ !
$           write sys$output " "
$           write sys$output "Creating Executables"
$           write sys$output "======================="
$           write sys$output " "
$           libs     = f$search("[]*.olb")
$           file     = f$search("[]*.pgm")
$ BUILDIT:
$           if (file .eqs. "") then goto MAINCLOSE
$ 
$                name = f$parse("''file'",,,"NAME")
$                write sys$output "Compiling main program: ''name'"
$     
$                on error then goto MAINERROR
$
$                fortran'OPTS'/object=*.obj   'file'  
$!
$                if ( "''libs'" .eqs. "" )
$                then
$                   link/nomap/exe=[-.-.exe]'name'.exe 'name'.obj, -
                               [-.-.LIB]SUPPORT/LIB,               -
                               [-.-.LIB]SPICELIB/LIB
$                else 
$                   link/nomap/exe=[-.-.exe]'name'.exe 'name'.obj, -
                               []LOCALLIB/LIB,                     -
                               [-.-.LIB]SUPPORT/LIB,               -
                               [-.-.LIB]SPICELIB/LIB
$                endif
$   
$                delete/nolog 'name'.obj;*
$                file = f$search("[]*.pgm")
$                goto BUILDIT
$ !
$ !  
$ MAINCLOSE:
$ !
$ !  Cleanup any debris that might be left lying around.
$ ! 
$    libs = f$search ("[]*.olb")
$    if ( "''libs'" .nes. "" ) then delete/nolog locallib.olb;
$    goto EXIT
$ !  
$ !  
$ LIBERROR:
$ !  
$ !  If an error occurred in the subroutine part of the procedure, 
$ !  close the file, delete the directory listing and exit.
$ !
$           write sys$output " "
$           write sys$output "An error occurred while attempting to build"
$           write sys$output "''MYLIB'"
$           write sys$output " "
$           files = f$search ("''MYLIB")
$           if ( "''files'" .nes. "" ) then delete 'MYLIB';
$
$           goto EXIT
$ !
$ LOCLIBERROR:
$ !  
$ !  If an error occurred in the subroutine part of the procedure, 
$ !  close the file, delete the directory listing and exit.
$ !
$           write sys$output " "
$           write sys$output "An error occurred while attempting to build"
$           write sys$output "LOCALLIB.OLB"
$           write sys$output " "
$           files = f$search ("[]LOCALLIB.OLB")
$           if ( "''files'" .nes. "" ) then delete LOCALLIB.OLB;
$           goto EXIT
$ !
$ MAINERROR:
$ !
$ !  If an error occurred in the main programs part of the procedure, 
$ !  close the file, delete the directory listing and exit.
$ !
$           write sys$output " "
$           write sys$output "An error occurred while attempting to build ''name'"
$           write sys$output " "
$           files = f$search ("[]LOCALLIB.OLB")
$           if ( "''files'" .nes. "" ) then delete LOCALLIB.OLB;
$
$           goto EXIT
$ !
$ !
$ EXIT:
$ !
$ !  Save the object library if it's a product. Save the executables, 
$ !  but delete the objects that we might have created.
$ ! 
$           files = f$search ("[]*.OBJ")
$           if ( "''files'" .nes. "" ) then delete *.OBJ;
$
$           exit