 
C
C     This routine formats time strings.
C
C-    Version 2.0.0  29-FEB-2000 (WLT)
C
C        Added the call to SCTRAN to handle more SCLKs than just
C        MO and GLL.
C
 
      SUBROUTINE FMTTIM ( ET, FORMAT, STRING )
      IMPLICIT NONE
 
 
      DOUBLE PRECISION      ET
      CHARACTER*(*)         FORMAT
      CHARACTER*(*)         STRING
 
 
      INTEGER               RTRIM
      LOGICAL               EQSTR
 
 
      LOGICAL               SCLK
      LOGICAL               FOUND
 
      INTEGER               ID
      INTEGER               I
      INTEGER               OUTLEN
 
      CHARACTER*(80)        KERVAR
 
      CHARACTER*(132)       TMPSTR
 
 
 
      CALL CHKIN ( 'FMTTIM' )
 
C
C     Is the desired output an SCLK string? If it is, which spacecraft
C     are we dealing with?
C
      IF ( EQSTR( FORMAT, 'MOSCLK' ) ) THEN
 
         ID   = -94
         SCLK = .TRUE.
 
      ELSE IF ( EQSTR( FORMAT, 'GLLSCLK' ) ) THEN
 
         ID   = -77
         SCLK = .TRUE.
 
      ELSE
 
         CALL SCN2ID ( FORMAT, ID, SCLK )
 
      END IF
 
 
C
C     If we want an SCLK string, check to see if an SCLK kernel has been
C     loaded. If not, signal an error, otherwise compute the SCLK
C     string.
C
      IF ( SCLK ) THEN
 
         KERVAR = 'SCLK_DATA_TYPE_#'
         CALL REPMI  ( KERVAR, '#', -ID, KERVAR )
 
         CALL EXPOOL ( KERVAR, FOUND )
 
         IF ( .NOT. FOUND ) THEN
 
            CALL SETMSG ( 'The SCLK kernel file for body # was not ' //
     .                    'loaded. Please load it. '                  )
            CALL ERRINT ( '#', ID                                     )
            CALL SIGERR ( 'SPICE(KERNELNOTLOADED)'                    )
            CALL CHKOUT ( 'FMTTIM'                                    )
            RETURN
 
         ELSE
 
            CALL   SCE2S ( ID, ET, TMPSTR )
            CALL   LJUST ( TMPSTR, TMPSTR )
            OUTLEN = LEN ( STRING )
 
            IF ( RTRIM( TMPSTR ) .GT. OUTLEN ) THEN
               DO I = 1, OUTLEN
                  STRING(I:I) = '*'
               END DO
            ELSE
               STRING = TMPSTR
            END IF
 
 
         END IF
 
      ELSE
C
C        We have a "normal" time string conversion to compute. Check
C        to see if the leapseconds kernel file has been loaded. If not,
C        it's an error.
C
         CALL EXPOOL ( 'DELTET/DELTA_AT', FOUND )
 
         IF ( .NOT. FOUND ) THEN
 
               CALL SETMSG ( 'The leapseconds kernel file was not '  //
     .                       'loaded.'                                )
               CALL SIGERR ( 'SPICE(NOKERNELLOADED)'                  )
               CALL CHKOUT ( 'FMTTIM'                                 )
               RETURN
 
         END IF
 
C
C        For some requested time formats we'll just use a format that
C        we know is correct.
C
         IF ( EQSTR( FORMAT, 'UTC' )) THEN
 
              CALL TIMOUT ( ET, 'YYYY-MON-DD HR:MN:SC ::RND', TMPSTR )
 
         ELSE IF ( EQSTR( FORMAT, 'JED' )) THEN
 
              CALL TIMOUT ( ET, 'JD.##### ::TDB ::RND', TMPSTR )
 
         ELSE IF ( EQSTR( FORMAT, 'ISO' )) THEN
 
              CALL TIMOUT ( ET, 'YYYY-MM-DDTHR:MN:SC ::RND', TMPSTR )
 
         ELSE IF ( EQSTR( FORMAT, 'ISODOY' )) THEN
 
              CALL TIMOUT ( ET, 'YYYY-DOYTHR:MN:SC ::RND', TMPSTR )
 
         ELSE
 
              CALL TIMOUT ( ET, FORMAT, TMPSTR )
 
         END IF
 
 
         CALL LJUST  ( TMPSTR, TMPSTR )
         OUTLEN = LEN( STRING )
 
         IF ( RTRIM( TMPSTR ) .GT. OUTLEN ) THEN
            DO I = 1, OUTLEN
               STRING(I:I) = '*'
            END DO
         ELSE
            STRING = TMPSTR
         END IF
 
      END IF
 
 
 
      CALL CHKOUT ( 'FMTTIM' )
      RETURN
      END
 
 
 
 
