C$Procedure      PREP ( Preprocess the input SUBTeX buffer )
 
      SUBROUTINE PREP ( BUFFER )
 
C$ Abstract
C
C     Preprocess a SUBTeX buffer. That is, replace tab characters
C     with spaces and remove all other non-printing characters.
C     Also remove index lines.
C
C$ Required_Reading
C
C     SUBTeX
C
C$ Keywords
C
C     SUBTeX
C
C$ Declarations
 
      INTEGER               LBCELL
      PARAMETER           ( LBCELL = -5 )
 
      CHARACTER*(*)         BUFFER  ( LBCELL:* )
 
C$ Detailed_Input
C
C     BUFFER      on input contains lines of SUBTeX source text.
C
C$ Detailed_Output
C
C     BUFFER      on output contains the same source text, with
C                 all tab characters replaced by spaces, and with
C                 all other non-printing characters removed.
C                 Index lines are also removed.
C
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     BUFFER    I/O  Input source, output source.
C
C$ Files
C
C     None.
C
C$ Exceptions
C
C     None.
C
C$ Particulars
C
C
C
C$ Examples
C
C
C
C
C$ Version
C
C     Beta Version 1.0.0, 11-JUN-1988 (IMU)
C
C-&
 
 
C
C     Entry points
C
 
C
C     SPICELIB functions
C
      INTEGER               CARDC
      LOGICAL               MATCHW
      LOGICAL               RETURN
 
C
C     Local variables
C
      INTEGER               NUL
      INTEGER               TAB
      INTEGER               US
      INTEGER               DEL
 
      PARAMETER           ( NUL  =   0 )
      PARAMETER           ( TAB  =   9 )
      PARAMETER           ( US   =  31 )
      PARAMETER           ( DEL  = 127 )
 
      INTEGER               CARD
      INTEGER               I
 
 
C
C     Standard SPICE error handling
C
      IF ( RETURN() ) THEN
         RETURN
      ELSE
         CALL CHKIN ( 'PREP' )
      END IF
 
C
C     Replace tabs first, else they'll be stripped. Replace index
C     lines by blank lines.
C
      CARD = CARDC ( BUFFER )
 
      DO I = 1, CARD
 
         CALL REPLCH ( BUFFER(I), CHAR(TAB), ' ',       BUFFER(I) )
         CALL ASTRIP ( BUFFER(I), CHAR(NUL), CHAR(US),  BUFFER(I) )
         CALL ASTRIP ( BUFFER(I), CHAR(DEL), CHAR(DEL), BUFFER(I) )
 
         IF ( MATCHW ( BUFFER(I), '@Index*', '*', '%' ) ) THEN
            BUFFER(I) = ' '
         END IF
 
      END DO
 
C
C     Remove trailing blank lines.
C
      DO WHILE ( BUFFER(CARD) .EQ. ' ' )
         CARD = CARD - 1
      END DO
 
      CALL SCARDC ( CARD, BUFFER )
 
      CALL CHKOUT ( 'PREP' )
      RETURN
      END
 
 
