C$Procedure      GETCHR ( Prompting for a character string value )

      SUBROUTINE GETCHR ( PRMPT, VALUE, GOTVAL, ERROR, ERRMSG )

C$ Abstract
C
C     This routine provides a portable means for interactively
C     obtaining a character string value.
C
C$ Required_Reading
C
C     None.
C
C$ Keywords
C
C     UTILITY
C
C$ Declarations
C
      CHARACTER*(*)         PRMPT
      CHARACTER*(*)         VALUE
      LOGICAL               GOTVAL
      LOGICAL               ERROR
      CHARACTER*(*)         ERRMSG

C$ Brief_I/O
C
C     Variable  I/O  Description
C     --------  ---  --------------------------------------------------
C      PRMPT     I    The prompt to be used for the desired value.
C      VALUE     O    Value entered, or unchanged, depending on GOTVAL.
C      GOTVAL    O    Flag indicating that a value was entered
C      ERROR     O    Flag indicating an error occurred.
C      ERRMSG    O    Descriptive error message
C
C$ Detailed_Input
C
C     PRMPT    The prompt to be used for the desired value.
C
C$ Detailed_Output
C
C     VALUE    The new value, if the flag GOTVAL = .TRUE., otherwise
C              nothing meaningful.
C     
C     GOTVAL   A logical flag indicating that a value has been
C              entered.
C              
C     ERROR    A logical flag indicating that an input error occurred.
C              
C     ERRMSG   A descriptive error message when an error occurs,
C              blank otherwise.
C
C$ Parameters
C
C     None.
C
C$ Exceptions
C
C     None.
C
C$ Files
C
C     None.
C
C$ Particulars
C
C     This routine provides an easy to use portable interface for
C     obtaining variable values in an interactive fashion with error
C     information.
C     
C     This is one in a family of routines, one for each data type:
C     
C        GETCHR -- Obtain a character string value
C        GETDP  -- Obtain a double precision value
C        GETINT -- Obtain an integer value
C
C$ Examples
C   
C     The following code fragment for obtaining the date
C     
C         CALL GETCHR ( 'Date? ', VALUE, GOTVAL, ERROR, ERRMSG )
C     
C     would display on the terminal screen
C     
C        Date? _
C        
C     Type in an appropriate character string value.
C
C$ Restrictions
C
C     None.
C
C$ Literature_References
C
C     None.
C
C$ Author_and_Institution
C
C     K.R. Gehringer (JPL)
C
C$ Version
C
C-    Beta Version 1.0.0, 29-MAY-1992 (KRG)
C
C-&

C$ Index_Entries
C
C      prompt for a character string value
C
C-&

C
C     SPICELIB functions
C
      INTEGER               FRSTNB
      INTEGER               LASTNB
      LOGICAL               RETURN
C
C     Local parameters
C
      INTEGER               LINLEN
      PARAMETER           ( LINLEN = 255 )
C
C     Local variables
C
      CHARACTER*(LINLEN)    LINE
      INTEGER               INPLEN
      INTEGER               INPBEG
      INTEGER               INPEND
      INTEGER               LENGTH
C
C     Standard SPICE error handling.
C
      IF ( RETURN () ) THEN
         RETURN
      ELSE
         CALL CHKIN ( 'GETCHR' )
      END IF
C
C     Set the initial values
C     
      LENGTH = LEN ( VALUE )
      GOTVAL = .FALSE.
      ERRMSG = ' '
C
C     Get the new value
C     
      IF ( PRMPT .NE. ' ' ) THEN
         CALL PROMPT( PRMPT, LINE )
      ELSE
         CALL PROMPT( 'Value: ', LINE )
      END IF
      
      CALL LJUST ( LINE, LINE )
      
      IF ( LINE .NE. ' ' ) THEN
      
         INPBEG = FRSTNB ( LINE )
         INPEND = LASTNB ( LINE )
         INPLEN = INPEND - INPBEG + 1

         IF ( LENGTH .GE. INPLEN ) THEN
         
            VALUE  = LINE(INPBEG:INPEND)
            GOTVAL = .TRUE.
            
         ELSE
            
            ERROR  = .TRUE.
            ERRMSG = 'ERROR: Input string was too long,'//
     .               ' only # characters are allowed.'
            CALL REPMI ( ERRMSG, '#', LENGTH, ERRMSG )
            
         END IF
         
      END IF
      
      CALL CHKOUT ( 'GETCHR' )
      RETURN
      END
