
C$Procedure      GETINT ( Prompt for an integer value )

      SUBROUTINE GETINT ( PRMPT, VALUE, GOTVAL, ERROR, ERRMSG )

C$ Abstract
C
C     This routine provides a portable means for interactively
C     obtaining an integer value.
C
C$ Required_Reading
C
C     None.
C
C$ Keywords
C
C     UTILITY
C
C$ Declarations
C
      CHARACTER*(*)         PRMPT
      INTEGER               VALUE
      LOGICAL               GOTVAL
      LOGICAL               ERROR
      CHARACTER*(*)         ERRMSG

C$ Brief_I/O
C
C     Variable  I/O  Description
C     --------  ---  --------------------------------------------------
C      PRMPT     I    The prompt to be used for the desired value.
C      VALUE     O    The value entered.
C      GOTVAL    O    Flag indicating that a value was entered
C      ERROR     O    Flag indicating an error occurred.
C      ERRMSG    O    Descriptive error message
C
C$ Detailed_Input
C
C     PRMPT    The prompt to be used for the desired value.
C
C$ Detailed_Output
C
C     VALUE    The new value, if the flag GOTVAL = .TRUE., otherwise
C              nothing meaningful.
C     
C     GOTVAL   A logical flag indicating that a value has been
C              entered.
C              
C     ERROR    A logical flag indicating that an input error occurred.
C              
C              
C     ERRMSG   A descriptive error message when an error occurs,
C              blank otherwise.
C
C$ Parameters
C
C     None.
C
C$ Exceptions
C
C     None.
C
C$ Files
C
C     None.
C
C$ Particulars
C
C     This routine provides an easy to use portable interface for
C     obtaining variable values in an interactive fashion; error
C     information is returned.
C     
C     This is one in a family of routines, one for each data type:
C     
C           GETCHR -- Obtain a character string value 
C           GETDP  -- Obtain a double precision value 
C           GETINT -- Obtain an integer value
C
C$ Examples
C   
C     The following code fragment
C     
C     CALL GETINT ( 'Number? ', VALUE, GOTVAL, ERROR, ERRMSG )
C     
C     would display on the terminal screen
C        
C        Number? _
C        
C     And a user would then type in an integer value.
C
C$ Restrictions
C
C     None.
C
C$ Literature_References
C
C     None.
C
C$ Author_and_Institution
C
C     K.R. Gehringer (JPL)
C
C$ Version
C
C-    Beta Version 1.0.0, 29-MAY-1992 (KRG)
C
C-&

C$ Index_Entries
C
C      prompt for an integer value
C
C-&

C
C     SPICELIB functions
C
      LOGICAL               RETURN

C
C     Other functions
C     
      LOGICAL               BEINT
C
C     Local parameters
C
      INTEGER               LINLEN
      PARAMETER           ( LINLEN = 255 )
C
C     Local variables
C
      CHARACTER*(LINLEN)    LINE
      INTEGER               ERRPTR
C
C     Standard SPICE error handling.
C
      IF ( RETURN () ) THEN
         RETURN
      ELSE
         CALL CHKIN ( 'GETINT' )
      END IF
C
C     Set the initial values
C     
      GOTVAL = .FALSE.
      ERROR  = .FALSE.
      ERRMSG = ' '
C
C     Get the new value
C     
      IF ( PRMPT .NE. ' ' ) THEN
         CALL PROMPT( PRMPT, LINE )
      ELSE
         CALL PROMPT( 'Value: ', LINE )
      END IF
      
      IF ( LINE .NE. ' ' ) THEN
      
         IF ( BEINT( LINE ) ) THEN
         
            CALL NPARSI( LINE, VALUE, ERRMSG, ERRPTR )
            GOTVAL = .TRUE.
            
         ELSE
            
            ERROR  = .TRUE.
            ERRMSG = 'ERROR: ''#'' is not an integer.'
            CALL REPMC ( ERRMSG, '#', LINE, ERRMSG )
            
         END IF
         
      END IF
      
      CALL CHKOUT ( 'GETINT' )
      RETURN
      END
