C$Procedure      APPNDC ( Append an item to a character cell )
 
      SUBROUTINE APPNDC ( ITEM, CELL )
 
C$ Abstract
C
C      Append an item to a character cell.
C
C$ Copyright
C
C     Copyright (1995), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     CELLS
C
C$ Keywords
C
C     CELLS
C
C$ Declarations
 
      INTEGER               LBCELL
      PARAMETER           ( LBCELL = -5 )
 
      CHARACTER*(*)         ITEM
      CHARACTER*(*)         CELL ( LBCELL:* )
 
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     ITEM       I   The item to append.
C     CELL      I/O  The cell to which ITEM will be appended.
C
C$ Detailed_Input
C
C     ITEM       is a character string which is to be appended to CELL.
C
C     CELL       is a character cell to which ITEM will be appended.
C
C$ Detailed_Output
C
C     CELL       is a character cell in which the last element is ITEM.
C
C$ Parameters
C
C      None.
C
C$ Files
C
C     None.
C
C$ Exceptions
C
C     1) If the cell is not large enough to accommodate the addition
C        of a new element, the error SPICE(CELLTOOSMALL) is signalled.
C
C     2) If the length of the item is longer than the length of the
C        cell, ITEM is truncated on the right.
C
C$ Particulars
C
C     None.
C
C$ Examples
C
C      In the following example, the item 'PLUTO' is appended to
C      the character cell PLANETS.
C
C      Before appending 'PLUTO', the cell contains:
C
C      PLANETS (1) = 'MERCURY'
C      PLANETS (2) = 'VENUS'
C      PLANETS (3) = 'EARTH'
C      PLANTES (4) = 'MARS'
C      PLANETS (5) = 'JUPITER'
C      PLANETS (6) = 'SATURN'
C      PLANETS (7) = 'URANUS'
C      PLANETS (8) = 'NEPTUNE'
C
C      The call
C
C        CALL APPNDC ( 'PLUTO', PLANETS )
C
C      appends the element 'PLUTO' at the location PLANETS (9), and the
C      cardinality is updated.
C
C      If the cell is not big enough to accomodate the addition of
C      the item, an error is signalled. In this case, the cell is not
C      altered.
C
C$ Restrictions
C
C     None.
C
C$ Literature_References
C
C     None.
C
C$ Author_and_Institution
C
C     H.A. Neilan     (JPL)
C
C$ Version
C
C-    SPICELIB Version 1.0.1, 10-MAR-1992 (WLT)
C
C        Comment section for permuted index source lines was added
C        following the header.
C
C-    SPICELIB Version 1.0.0, 31-JAN-1990 (HAN)
C
C-&
 
C$ Index_Entries
C
C     append an item to a character cell
C
C-&
 
 
 
 
C
C     SPICELIB functions
C
      LOGICAL               RETURN
      INTEGER               CARDC
      INTEGER               SIZEC
 
C
C     Local variables
C
      INTEGER               NWCARD
 
 
 
 
 
C
C     Standard SPICE error handling.
C
      IF ( RETURN () ) THEN
         RETURN
      ELSE
         CALL CHKIN ( 'APPNDC' )
      END IF
 
C
C     Check to see if the cell can accomodate the addition of a
C     new item. If there is room, append the item to the cell and
C     reset the cardinality. If the cell cannot accomodate the
C     addition of a new item, signal an error.
C
 
      NWCARD = CARDC (CELL) + 1
 
      IF (  ( NWCARD )  .LE.  ( SIZEC (CELL) )  ) THEN
 
         CELL (NWCARD) = ITEM
         CALL SCARDC ( NWCARD, CELL )
 
      ELSE
 
        CALL SETMSG ( 'The cell cannot accomodate the '     //
     .                'addition of the item *.'                 )
 
        CALL ERRCH  ( '*', ITEM )
        CALL SIGERR ( 'SPICE(CELLTOOSMALL)' )
 
      END IF
 
 
      CALL CHKOUT ( 'APPNDC' )
      RETURN
      END
