C$Procedure            APPROX ( Approximate equality )
 
      LOGICAL FUNCTION APPROX ( X, Y, TOL )
 
C$ Abstract
C
C     True if two double precision numbers are equal to within some
C     tolerance.
C
C$ Copyright
C
C     Copyright (1995), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     None.
C
C$ Keywords
C
C     COMPARE
C     NUMBERS
C
C$ Declarations
 
 
      DOUBLE PRECISION      X
      DOUBLE PRECISION      Y
      DOUBLE PRECISION      TOL
 
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     X,
C     Y          I   Double precision numbers.
C     TOL        I   Tolerance.
C
C     The function is true whenever |X - Y| < TOL.
C                                           -
C
C$ Detailed_Input
C
C     X,
C     Y           are arbitrary double precision numbers.
C
C     TOL         is a tolerance. X and Y are considered to be equal
C                 if they differ by no more than this amount. If TOL
C                 is negative, X and Y are never considered equal.
C
C$ Detailed_Output
C
C     The function is true whenever |X - Y| < TOL, and is false
C     otherwise.                            -
C
C$ Parameters
C
C     None.
C
C$ Exceptions
C
C      Error free.
C
C$ Files
C
C     None.
C
C$ Particulars
C
C     None.
C
C$ Examples
C
C     C
C     C     If the eccentricity is near one, this a parabola.
C     C
C           IF ( APPROX ( ECC, 1.D0, 10.D-12 ) ) THEN
C              TYPE = 'PARABOLA'
C
C           ELSE IF ( ECC .LT. 1 ) THEN
C              TYPE = 'ELLIPSE'
C
C           ELSE
C              TYPE = 'HYPERBOLA'
C           END IF
C
C$ Restrictions
C
C     None.
C
C$ Literature_References
C
C     None.
C
C$ Author_and_Institution
C
C     I.M. Underwood  (JPL)
C
C$ Version
C
C-     SPICELIB Version 1.0.1, 10-MAR-1992 (WLT)
C
C         Comment section for permuted index source lines was added
C         following the header.
C
C-     SPICELIB Version 1.0.0, 31-JAN-1990  (IMU)
C
C-&
 
C$ Index_Entries
C
C     approximate equality
C
C-&
 
 
 
C
C     Just shorthand, really.
C
      APPROX = ( ABS ( X - Y ) .LE. TOL )
 
      RETURN
      END
