C$Procedure                     B1950 ( Besselian Date 1950.0 )
 
      DOUBLE PRECISION FUNCTION B1950 ( )
 
C$ Abstract
C
C     Return the Julian Date corresponding to Besselian Date 1950.0.
C
C$ Copyright
C
C     Copyright (1995), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     None.
C
C$ Keywords
C
C     CONSTANTS
C
C$ Declarations
C
C     None.
C
C$ Brief_I/O
C
C     The function returns the Julian Date corresponding to Besselian
C     date 1950.0.
C
C$ Detailed_Input
C
C     None.
C
C$ Detailed_Output
C
C     The function returns 2433282.423, the Julian Date corresponding
C     to Besselian Date 1950.0.
C
C$ Parameters
C
C     None.
C
C$ Exceptions
C
C      Error free.
C
C$ Files
C
C     None.
C
C$ Particulars
C
C     The function always returns the constant value shown above.
C
C$ Examples
C
C     The following code fragment illustrates the use of B1950.
C
C        C
C        C     Convert Julian Date to UTC seconds past the reference
C        C     epoch (B1950).
C        C
C              SPREF = ( JD - B1950() ) * SPD()
C
C$ Restrictions
C
C     None.
C
C$ Literature_References
C
C     [1] Jay Lieske, ``Precession Matrix Based on IAU (1976)
C         System of Astronomical Constants,'' Astron. Astrophys.
C         73, 282-284 (1979).
C
C$ Author_and_Institution
C
C     W.L. Taber      (JPL)
C     I.M. Underwood  (JPL)
C
C$ Version
C
C-     SPICELIB Version 2.0.0, 30-JUL-1993 (WLT)
C
C         The value of B1950 was updated to reflect the value given
C         by Lieske in [1]
C
C-     SPICELIB Version 1.0.1, 10-MAR-1992 (WLT)
C
C         Comment section for permuted index source lines was added
C         following the header.
C
C-     SPICELIB Version 1.0.0, 31-JAN-1990 (WLT) (IMU)
C
C-&
 
C$ Index_Entries
C
C     besselian date 1950.0
C
C-&
 
 
      B1950 = 2433282.42345905D0
      RETURN
      END
