C$Procedure      BYEBYE ( Exit a program indicating an error status )
 
      SUBROUTINE BYEBYE ( STATUS )
 
C$ Abstract
C
C     Exit an executing program returning a success or failure status
C     to the operating system, if this capability is supported, or
C     simply exit the program.
C
C$ Copyright
C
C     Copyright (1996), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     None.
C
C$ Keywords
C
C     UTILITY
C
C$ Declarations
 
      CHARACTER*(*)         STATUS
 
C$ Brief_I/O
C
C     Variable  I/O  Description
C     --------  ---  --------------------------------------------------
C     STATUS     I   A string indicating the exit status of a program.
C
C$ Detailed_Input
C
C     STATUS  This is a character string which indicates the status
C             to use when exiting a program. The two status values
C             currently supported are 'SUCCESS' and 'FAILURE', which
C             have their obvious meanings. The case of the input is
C             not important, i.e., 'Success' or 'failure' are accepted.
C
C             If STATUS has a value of 'SUCCESS', then the calling
C             program will be terminated with a status that indicates
C             success.
C
C             If STATUS has a value of 'FAILURE', then the calling
C             program will be terminated with a status that indicates
C             failure.
C
C             If STATUS has a value that is not recognized, the calling
C             program will be terminated with a status that indicates
C             failure.
C
C             For environments which do not support the passage of a
C             status indicator to the operating system the value of
C             STATUS is not significant; an executing program will be
C             terminated using the Fortran STOP statement.
C
C             See the value of the parameter STLEN declared in the
C             Local Parameters section for the maximum significant
C             length of an exit status string.
C
C$ Detailed_Output
C
C     None.
C
C$ Parameters
C
C     None.
C
C$ Exceptions
C
C     Error free.
C
C$ Files
C
C     None.
C
C$ Particulars
C
C     This subroutine is called by SIGERR to exit a program
C     returning a success or failure indication to the operating
C     system when this is possible. If returning a status
C     indication to the operating system is not possible, this
C     subroutine simply executes a Fortran STOP statement.
C
C$ Examples
C
C     To exit a program indicating success:
C
C        CALL BYEBYE ( 'SUCCESS' )
C
C     To exit a program indicating failure:
C
C        CALL BYEBYE ( 'FAILURE' )
C
C$ Restrictions
C
C     None.
C
C$ Literature_References
C
C     None.
C
C$ Author_and_Institution
C
C     K.R. Gehringer     (JPL)
C
C$ Version
C
C-    SPICELIB Version 2.1.0, 03-JAN-2005 (BVS)
C
C        Updated for PC-CYGWIN.
C
C-    SPICELIB Version 2.0.5, 17-JUL-2002 (BVS)
C
C        Added MAC-OSX environments.
C
C-    SPICELIB Version 2.0.4, 28-AUG-2000 (EDW)
C
C        Included PROMPT call for MAC Absoft environment.
C        Without something to pause execution, the output window
C        collapses at program end.
C
C-    SPICELIB Version 2.0.3, 08-OCT-1999 (WLT)
C
C        The environment lines were expanded so that the supported
C        environments are now explicitely given.  New
C        environments are WIN-NT
C
C-    SPICELIB Version 2.0.2, 28-JUL-1999 (WLT)
C
C        The environment lines were expanded so that the supported
C        environments are now explicitely given.  New
C        environments are PC-DIGITAL, SGI-O32 and SGI-N32.
C
C        The success flag for SGI-N32 is '0', failure '1'.  These
C        were simply 0 and 1 respectively when the environment was
C        just SGI.
C
C-    SPICELIB Version 2.0.1, 18-MAR-1999 (WLT)
C
C        The environment lines were expanded so that the supported
C        environments are now explicitely given.  Previously,
C        environments such as SUN-SUNOS and SUN-SOLARIS were implied
C        by the environment label SUN.
C
C-    SPICELIB Version 2.0.0, 05-APR-1998 (NJB)
C
C        Added the PC-LINUX environment.
C
C-    SPICELIB Version 1.0.0, 25-APR-1996 (KRG)
C
C-&
 
C$ Index_Entries
C
C     gracefully exit a program
C
C-&
 
C$ Revisions
C
C-    SPICELIB Version 2.0.0, 05-APR-1998 (NJB)
C
C        Added the PC-LINUX environment.
C
C-&
 
 
C
C     Local Parameters
C
C     Define the maximum length for the usable portion of a status
C     string.
C
      INTEGER               STLEN
      PARAMETER           ( STLEN = 7 )
C
C     Define the notion of 'SUCCESS' and 'FAILURE'.
C
      INTEGER               FAILUR
      PARAMETER           ( FAILUR = 0 )
 
      INTEGER               SUCCES
      PARAMETER           ( SUCCES = 1 )
 
 
      CHARACTER*(STLEN)     CHSTAT
 
      LOGICAL               MYSTAT
 
      CALL LJUST ( STATUS, CHSTAT )
      CALL UCASE ( CHSTAT, CHSTAT )
 
      IF ( CHSTAT .EQ. 'SUCCESS' ) THEN
         MYSTAT = .TRUE.
      ELSE
         MYSTAT = .FALSE.
      END IF
 
      IF ( MYSTAT ) THEN
         CALL EXIT ( SUCCES )
      ELSE
         CALL EXIT ( FAILUR )
      END IF
 
C
C     We never really get here, but for pedantic reasons we must
C     have a RETURN statement in a subroutine.
C
      RETURN
 
      END
