C$Procedure CLIGHT ( C, Speed of light in a vacuum )
 
      DOUBLE PRECISION FUNCTION CLIGHT ( )
 
C$ Abstract
C
C     Return the speed of light in a vacuum (IAU official
C     value, in km/sec).
C
C$ Copyright
C
C     Copyright (1995), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     None.
C
C$ Keywords
C
C     CONSTANTS
C
C$ Declarations
C
C     None.
C
C$ Brief_I/O
C
C     The function returns the speed of light in vacuo (km/sec).
C
C$ Detailed_Input
C
C     None.
C
C$ Detailed_Output
C
C     The function returns the IAU official value for the speed of light
C     in vacuo: 299792.458 km/sec.
C
C$ Parameters
C
C     None.
C
C$ Exceptions
C
C      Error free.
C
C$ Files
C
C     None.
C
C$ Particulars
C
C     The function always returns the constant value shown above.
C
C$ Examples
C
C     The following example uses CLIGHT to determine the one-way
C     light-time (TAU) to an object whose position relative to an
C     observer is contained in POS. The light-time is then used
C     to antedate a request for data from the kernel pool:
C
C           DOUBLE PRECISION      CLIGHT
C           DOUBLE PRECISION      VNORM
C
C           DOUBLE PRECISION      POS     ( 3 )
C           DOUBLE PRECISION      TAU
C           DOUBLE PRECISION      TRANS   ( 3,3 )
C
C           INTEGER               BODY
C            .
C            .
C
C           TAU = VNORM ( POS ) / CLIGHT ()
C           CALL BODMAT ( BODY, EPOCH - TAU, TRANS )
C
C     Note that the SPK readers SPKEZ and SPKAPP return the one-way
C     light time as an output,
C
C           CALL SPKEZ  ( ..., TAU )
C           CALL SPKAPP ( ..., TAU )
C
C$ Restrictions
C
C     None.
C
C$ Literature_References
C
C     None.
C
C$ Author_and_Institution
C
C     W.L. Taber      (JPL)
C     I.M. Underwood  (JPL)
C
C$ Version
C
C-     SPICELIB Version 1.0.1, 10-MAR-1992 (WLT)
C
C         Comment section for permuted index source lines was added
C         following the header.
C
C-     SPICELIB Version 1.0.0, 31-JAN-1990 (WLT) (IMU)
C
C-&
 
C$ Index_Entries
C
C     c speed of light in a vacuum
C
C-&
 
 
C
C     Just like it says.
C
      CLIGHT = 299792.458D0
 
      RETURN
      END
