C$Procedure      CMPRSS ( Compress a character string )
 
      SUBROUTINE CMPRSS ( DELIM, N, INPUT, OUTPUT )
 
C$ Abstract
C
C      Compress a character string by removing occurrences of
C      more than N consecutive occurrences of a specified
C      character.
C
C$ Copyright
C
C     Copyright (1995), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     None.
C
C$ Keywords
C
C      ASCII,  CHARACTER,  STRING
C
C$ Declarations
 
      CHARACTER*1         DELIM
      INTEGER             N
      CHARACTER*(*)       INPUT
      CHARACTER*(*)       OUTPUT
 
C$ Brief_I/O
C
C      VARIABLE  I/O  DESCRIPTION
C      --------  ---  --------------------------------------------------
C      DELIM      I      Delimiter to be compressed.
C      N          I      Maximum consecutive occurrences of DELIM.
C      INPUT      I      Input string.
C      OUTPUT     O      Compressed string.
C
C$ Detailed_Input
C
C      DELIM       is the delimiter to be compressed out of the string.
C                  This may be any ASCII character.
C
C      N           is the maximum number of consecutive occurrences
C                  of DELIM that will be allowed to remain in the
C                  output string.
C
C      INPUT       is the input string.
C
C$ Detailed_Output
C
C      OUTPUT      is the output string. This is the input string
C                  with all occurrences of more than N consecutive
C                  delimiters removed.
C
C                  If OUTPUT is not large enough to hold the
C                  compressed string, it is truncated on the right.
C
C                  OUTPUT may overwrite INPUT.
C
C$ Parameters
C
C     None.
C
C$ Particulars
C
C      Occurrences of more than N consecutive delimiters are removed
C      from the input string as it is copied to the output string.
C      If the output string is not large enough to hold the compressed
C      string, it is truncated on the right.
C
C$ Examples
C
C      Let DELIM = '.', and N = 2. Then
C
C         'ABC...DE.F...',           becomes   'ABC..DE.F..'
C         ' ...........'                       ' ..'
C         '.. ..AB....CD'                      '.. ..AB..CD'
C
C      Let DELIM = ' ', and N = 0. Then
C
C         ' DISK:[USER.  SUB  ]'     becomes   'DISK:[USER.SUB]'
C
C$ Restrictions
C
C      None.
C
C$ Exceptions
C
C      Error free.
C
C$ Files
C
C      None.
C
C$ Author_and_Institution
C
C     W.L. Taber      (JPL)
C     I.M. Underwood  (JPL)
C
C$ Literature_References
C
C      None.
C
C$ Version
C
C-     SPICELIB Version 1.0.1, 10-MAR-1992 (WLT)
C
C         Comment section for permuted index source lines was added
C         following the header.
C
C-     SPICELIB Version 1.0.0, 31-JAN-1990 (WLT) (IMU)
C
C-&
 
C$ Index_Entries
C
C     compress a character_string
C
C-&
 
 
 
C
C
C     Local Variables
C
      INTEGER          I
      INTEGER          J
      INTEGER          COUNT
 
      INTEGER          INLEN
      INTEGER          OUTLEN
 
 
C
C     Find out how much space there is in the INPUT and OUTPUT strings
C     and initialize the delimiter counter and output place holder.
C
      INLEN  = LEN(INPUT)
      OUTLEN = LEN(OUTPUT)
 
      COUNT  = 0
      J      = 0
 
      DO I = 1, INLEN
 
C
C        Check each character to see if it is a delimiter or not.
C
         IF ( INPUT(I:I) .EQ. DELIM ) THEN
 
            COUNT = COUNT + 1
 
C
C           Copy delimiters until enough consecutive delimiters
C           have been accumulated.  When enough consecutive delimiters
C           have accumulated, we no longer copy them.
C
            IF ( COUNT .LE. N ) THEN
               J           = J + 1
               OUTPUT(J:J) = INPUT(I:I)
            END IF
 
         ELSE
 
C
C           We don't have a delimiter here so we just copy the
C           character and set the delimiter counter to zero.
C
            COUNT       = 0
            J           = J + 1
            OUTPUT(J:J) = INPUT(I:I)
 
         END IF
 
         IF ( J .EQ. OUTLEN ) THEN
            RETURN
         END IF
 
      END DO
 
C
C     Pad any left over space in the output string with blanks.
C
      IF ( J .LT. OUTLEN ) THEN
         OUTPUT(J+1:) = ' '
      END IF
 
      RETURN
      END
 
 
