 
C$Procedure DAFPS ( DAF, pack summary )
 
      SUBROUTINE DAFPS ( ND, NI, DC, IC, SUM )
 
C$ Abstract
C
C     Pack (assemble) an array summary from its double precision and
C     integer components.
C
C$ Copyright
C
C     Copyright (1995), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     DAF
C
C$ Keywords
C
C     CONVERSION
C     FILES
C
C$ Declarations
 
      INTEGER               ND
      INTEGER               NI
      DOUBLE PRECISION      DC       ( * )
      INTEGER               IC       ( * )
      DOUBLE PRECISION      SUM      ( * )
 
C$ Brief_I/O
C
C     Variable  I/O  Description
C     --------  ---  --------------------------------------------------
C     ND         I   Number of double precision components.
C     NI         I   Number of integer components.
C     DC         I   Double precision components.
C     IC         I   Integer components.
C     SUM        O   Array summary.
C
C$ Detailed_Input
C
C     ND          is the number of double precision components in
C                 the summary to be packed.
C
C     NI          is the number of integer components in the summary.
C
C     DC          are the double precision components of the summary.
C
C     IC          are the integer components of the summary.
C
C$ Detailed_Output
C
C     SUM         is an array summary containing the components in DC
C                 and IC. This identifies the contents and location of
C                 a single array within a DAF.
C
C$ Parameters
C
C      None.
C
C$ Files
C
C     None.
C
C$ Exceptions
C
C     Error free.
C
C     1) If ND is zero or negative, no DP components are stored.
C
C     2) If NI is zero or negative, no integer components are stored.
C
C     3) If the total size of the summary is greater than 125 double
C        precision words, some components may not be stored.
C
C$ Particulars
C
C     The components of array summaries are packed into double
C     precision arrays for reasons outlined in [1]. Two routines,
C     DAFPS (pack summary) and DAFUS (unpack summary) are provided
C     for packing and unpacking summaries.
C
C     The total size of the summary is
C
C             (NI - 1)
C        ND + -------- + 1
C                 2
C
C     double precision words (where ND, NI are nonnegative).
C
C$ Examples
C
C     Maybe later.
C
C$ Restrictions
C
C     None.
C
C$ Literature_References
C
C     NAIF Document 167.0, "Double Precision Array Files (DAF)
C     Specification and User's Guide"
C
C$ Author_and_Institution
C
C     I.M. Underwood  (JPL)
C
C$ Version
C
C-    SPICELIB Version 1.0.2, 10-MAR-1992 (WLT)
C
C        Comment section for permuted index source lines was added
C        following the header.
C
C-    SPICELIB Version 1.0.1, 22-MAR-1990 (HAN)
C
C        Literature references added to the header.
C
C-    SPICELIB Version 1.0.0, 31-JAN-1990 (IMU)
C
C-&
 
C$ Index_Entries
C
C     pack daf summary
C
C-&
 
 
C
C     Local variables
C
      DOUBLE PRECISION      DEQUIV   ( 125 )
      INTEGER               IEQUIV   ( 250 )
 
      INTEGER               N
      INTEGER               M
 
C
C     Equivalences
C
      EQUIVALENCE         ( DEQUIV, IEQUIV )
 
C
C     Here's the deal: the DP components always precede the integer
C     components, avoiding alignment problems. The DP components can
C     be stored directly.
C
      N = MIN ( 125, MAX ( 0, ND ) )
 
      CALL MOVED ( DC, N, SUM )
 
C
C     The integer components must detour through an equivalence.
C
      M = MIN ( 250 - 2 * N, MAX ( 0, NI ) )
 
      CALL MOVEI ( IC,          M,              IEQUIV   )
      CALL MOVED ( DEQUIV,     (M - 1) / 2 + 1, SUM(N+1) )
 
      RETURN
 
 
 
C$Procedure DAFUS ( DAF, unpack summary )
 
      ENTRY DAFUS ( SUM, ND, NI, DC, IC )
 
C$ Abstract
C
C     Unpack an array summary into its double precision and integer
C     components.
C
C$ Copyright
C
C     Copyright (1995), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     DAF
C
C$ Keywords
C
C     CONVERSION
C     FILES
C
C$ Declarations
C
C     DOUBLE PRECISION      SUM      ( * )
C     INTEGER               ND
C     INTEGER               NI
C     DOUBLE PRECISION      DC       ( * )
C     INTEGER               IC       ( * )
C
C$ Brief_I/O
C
C     Variable  I/O  Description
C     --------  ---  --------------------------------------------------
C     SUM        I   Array summary.
C     ND         I   Number of double precision components.
C     NI         I   Number of integer components.
C     DC         O   Double precision components.
C     IC         O   Integer components.
C
C$ Detailed_Input
C
C     SUM         is an array summary. This identifies the contents and
C                 location of a single array within a DAF.
C
C     ND          is the number of double precision components in
C                 the summary.
C
C     NI          is the number of integer components in the summary.
C
C$ Detailed_Output
C
C     DC          are the double precision components of the summary.
C
C     IC          are the integer components of the summary.
C
C$ Parameters
C
C      None.
C
C$ Files
C
C     None.
C
C$ Exceptions
C
C     Error free.
C
C     1) If ND is zero or negative, no double precision components
C        are returned.
C
C     2) If NI is zero or negative, no integer components are returned.
C
C     3) If the total size of the summary is greater than 125 double
C        precision words, some components may not be returned.
C
C$ Particulars
C
C     The components of array summaries are packed into double
C     precision arrays for reasons outlined in [1]. Two routines,
C     DAFPS (pack summary) and DAFUS (unpack summary) are provided
C     for packing and unpacking summaries.
C
C     The total size of the summary is
C
C             (NI - 1)
C        ND + -------- + 1
C                 2
C
C     double precision words (where ND, NI are nonnegative).
C
C$ Examples
C
C     Maybe later.
C
C$ Restrictions
C
C     None.
C
C$ Literature_References
C
C     NAIF Document 167.0, "Double Precision Array Files (DAF)
C     Specification and User's Guide"
C
C$ Author_and_Institution
C
C     I.M. Underwood  (JPL)
C
C$ Version
C
C-    SPICELIB Version 1.0.2, 10-MAR-1992 (WLT)
C
C        Comment section for permuted index source lines was added
C        following the header.
C
C-    SPICELIB Version 1.0.1, 22-MAR-1990 (HAN)
C
C        Literature references added to the header.
C
C-    SPICELIB Version 1.0.0, 31-JAN-1990 (IMU)
C
C-&
 
C$ Index_Entries
C
C     unpack daf summary
C
C-&
 
 
C
C     Just undo whatever DAFPS did.
C
      N = MIN ( 125, MAX ( 0, ND ) )
 
      CALL MOVED ( SUM, N, DC )
 
      M = MIN ( 250 - 2 * N, MAX ( 0, NI ) )
 
      CALL MOVED ( SUM(N+1), (M - 1) / 2 + 1, DEQUIV )
      CALL MOVEI ( IEQUIV,    M,              IC     )
 
      RETURN
      END
 
