C$Procedure  DCBRT ( Double precision cube root )
 
      DOUBLE PRECISION FUNCTION  DCBRT ( X )
 
C$ Abstract
C
C      Return the cube root of a double precision number.
C
C$ Copyright
C
C     Copyright (1995), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     None.
C
C$ Keywords
C
C      MATH,  ROOT
C
C$ Declarations
 
      DOUBLE PRECISION   X
 
C$ Brief_I/O
C
C      VARIABLE  I/O  DESCRIPTION
C      --------  ---  --------------------------------------------------
C       X         I     Number whose cube root is desired.
C
C$ Detailed_Input
C
C      X   may be any double precision value.
C
C$ Detailed_Output
C
C      DCBRT   is the cube root of the input value.
C
C$ Parameters
C
C     None.
C
C$ Particulars
C
C      DCBRT calculates the cube root of the input value by using the
C      exponentiation operator to raise the input value to the 1/3
C      power.  This operation, however, is performed on the absolute
C      value of the input variable, and then the sign of the input
C      is transferred to the output value.
C
C      All values of the input variable X should be acceptible to the
C      DCBRT.
C
C$ Examples
C
C      The following table gives sample values of the variable X and
C      DCBRT(X)
C
C       X                        DCBRT(X)
C      --------------------------------------------------------------
C       0.0D0                    0.0D0
C       8.0D0                    2.0D0
C      -1.0D3                   -1.0D1
C
C$ Restrictions
C
C      None
C
C$ Exceptions
C
C      Error free.
C
C$ Files
C
C      None
C
C$ Author_and_Institution
C
C      W.M. Owen       (JPL)
C
C$ Literature_References
C
C      None
C
C$ Version
C
C-     SPICELIB Version 1.0.1, 10-MAR-1992 (WLT)
C
C         Comment section for permuted index source lines was added
C         following the header.
C
C-     SPICELIB Version 1.0.0, 31-JAN-1990 (WMO)
C
C-&
 
C$ Index_Entries
C
C     d.p. cube root
C
C-&
 
      DOUBLE PRECISION THIRD
      PARAMETER (THIRD = 1.D0/3.D0)
C
      DCBRT = DSIGN (DABS(X)**THIRD, X)
C
      RETURN
      END
