C$Procedure                     DPR ( Degrees per radian )
 
      DOUBLE PRECISION FUNCTION DPR ( )
 
C$ Abstract
C
C     Return the number of degrees per radian.
C
C$ Copyright
C
C     Copyright (1995), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     None.
C
C$ Keywords
C
C     CONSTANTS
C
C$ Declarations
C
C     None.
C
C$ Brief_I/O
C
C     The function returns the number of degrees per radian.
C
C$ Detailed_Input
C
C     None.
C
C$ Detailed_Output
C
C     The function returns the number of degrees per radian: 180/pi.
C     The value of pi is determined by the ACOS function. That is,
C
C           DPR = 180.D0 / ACOS ( -1.D0 )
C
C$ Parameters
C
C     None.
C
C$ Exceptions
C
C      Error free.
C
C$ Files
C
C     None.
C
C$ Particulars
C
C     The first time the function is referenced, the value is computed
C     as shown above. The value is saved, and returned directly upon
C     subsequent reference.
C
C$ Examples
C
C     The code fragment below illustrates the use of DPR.
C
C        C
C        C     Convert all angles to degrees for output.
C        C
C              CLOCK = CLOCK * DPR()
C              CONE  = CONE  * DPR()
C              TWIST = TWIST * DPR()
C
C     or equivalently,
C
C        C
C        C     Convert all input angles to radians.
C        C
C              CALL VPACK  ( CLOCK, CONE, CCTWIST, ALBTGAM )
C              CALL VSCL   ( DPR(), ALBTGAM, ALBTGAM )
C              CALL VUPACK ( ALBTGAM, CLOCK, CONE, CCTWIST )
C
C$ Restrictions
C
C     None.
C
C$ Literature_References
C
C     None.
C
C$ Author_and_Institution
C
C     W.L. Taber      (JPL)
C     I.M. Underwood  (JPL)
C
C$ Version
C
C-     SPICELIB Version 1.0.1, 10-MAR-1992 (WLT)
C
C         Comment section for permuted index source lines was added
C         following the header.
C
C-     SPICELIB Version 1.0.0, 31-JAN-1990 (WLT) (IMU)
C
C-&
 
C$ Index_Entries
C
C     degrees per radian
C
C-&
 
 
 
 
C
C     Local variables
C
      DOUBLE PRECISION      VALUE
      SAVE                  VALUE
 
C
C     Initial values
C
      DATA                  VALUE      / 0.D0 /
 
 
C
C     What is there to say?
C
      IF ( VALUE .EQ. 0.D0 ) THEN
         VALUE = 180.D0 / ACOS ( -1.D0 )
      END IF
 
      DPR = VALUE
 
      RETURN
      END
 
