C
C     Include Section:  EK Data Page Parameters
C
C        ekfilpar.inc  Version 1  03-APR-1995 (NJB)
C
C     These parameters apply to EK files using architecture 4.
C     These files use a paged DAS file as their underlying file
C     structure.
C
C     In paged DAS EK files, data pages are structured:  they contain
C     metadata as well as data.  The metadata is located in the last
C     few addresses of each page, so as to interfere as little as
C     possible with calculation of data addresses.
C
C     Each data page belongs to exactly one segment.  Some bookkeeping
C     information, such as record pointers, is also stored in data
C     pages.
C
C     Each page contains a forward pointer that allows rapid lookup
C     of data items that span multiple pages.  Each page also keeps
C     track of the current number of links from its parent segment
C     to the page.  Link counts enable pages to `know' when they
C     are no longer in use by a segment; unused pages are deallocated
C     and returned to the free list.
C
C     The parameters in this include file depend on the parameters
C     declared in the include file ekpage.inc.  If those parameters
C     change, this file must be updated.  The specified parameter
C     declarations we need from that file are:
C
C        INTEGER               PGSIZC
C        PARAMETER           ( PGSIZC = 1024 )
C
C        INTEGER               PGSIZD
C        PARAMETER           ( PGSIZD = 128 )
C
C        INTEGER               PGSIZI
C        PARAMETER           ( PGSIZI = 256 )
C
C
C
C     Character pages use an encoding mechanism to represent integer
C     metadata.  Each integer is encoded in five consecutive
C     characters.
C
C
C     Character data page parameters:
C
C
C     Size of encoded integer:
C
      INTEGER               ENCSIZ
      PARAMETER           ( ENCSIZ = 5 )
 
C
C     Usable page size:
C
      INTEGER               CPSIZE
      PARAMETER           ( CPSIZE = 1014 )
 
C
C     Location of character forward pointer:
C
      INTEGER               CFPIDX
      PARAMETER           ( CFPIDX = CPSIZE + 1)
 
 
C
C     Location of character link count:
C
      INTEGER               CLCIDX
      PARAMETER           ( CLCIDX = CFPIDX + ENCSIZ )
 
 
C
C     Double precision data page parameters:
C
C     Usable page size:
C
      INTEGER               DPSIZE
      PARAMETER           ( DPSIZE = 126 )
 
C
C     Location of d.p. forward pointer:
C
      INTEGER               DFPIDX
      PARAMETER           ( DFPIDX = DPSIZE + 1)
 
 
C
C     Location of d.p. link count:
C
      INTEGER               DLCIDX
      PARAMETER           ( DLCIDX = DFPIDX + 1 )
 
 
C
C     Integer data page parameters:
C
C     Usable page size:
C
      INTEGER               IPSIZE
      PARAMETER           ( IPSIZE = 254 )
 
C
C     Location of integer forward pointer:
C
      INTEGER               IFPIDX
      PARAMETER           ( IFPIDX = IPSIZE + 1)
 
 
C
C     Location of integer link count:
C
      INTEGER               ILCIDX
      PARAMETER           ( ILCIDX = IFPIDX + 1 )
 
 
C
C     End Include Section:  EK Data Page Parameters
C
