C$Procedure      EKNSEG ( EK, number of segments in file )
 
      INTEGER FUNCTION EKNSEG ( HANDLE )
 
C$ Abstract
C
C     Return the number of segments in a specified EK.
C
C$ Copyright
C
C     Copyright (1995), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     EK
C
C$ Keywords
C
C     EK
C     UTILITY
C
C$ Declarations
 
      INCLUDE 'ekfilpar.inc'
 
      INTEGER               HANDLE
 
C$ Brief_I/O
C
C     Variable  I/O  Description
C     --------  ---  --------------------------------------------------
C     HANDLE     I   EK file handle.
C
C     The function returns the number of segments in the specified
C     E-kernel.
C
C$ Detailed_Input
C
C     HANDLE         is the handle of an EK file opened for read
C                    access.
C
C$ Detailed_Output
C
C     The function returns the number of segments in the specified
C     E-kernel.
C
C$ Parameters
C
C     None.
C
C$ Exceptions
C
C     1)  If HANDLE is invalid, the error will be diagnosed by routines
C         called by this routine.  EKNSEG will return the value zero.
C
C     2)  If an I/O error occurs while trying to read the EK, the error
C         will be diagnosed by routines called by this routine.
C         EKNSEG will return the value zero.
C
C$ Files
C
C     See the description of HANDLE in $Detailed_Input.
C
C$ Particulars
C
C     This routine is used to support the function of summarizing an
C     EK file.  Given the number of segments in the file, a program
C     can use EKSSUM in a loop to summarize each of them.
C
C$ Examples
C
C     1)  Open an EK file and count the segments in it.
C
C            CALL EKOPR ( EKNAME, HANDLE )
C            N = EKNSEG  ( HANDLE )
C
C$ Restrictions
C
C     None.
C
C$ Literature_References
C
C     None.
C
C$ Author_and_Institution
C
C     N.J. Bachman   (JPL)
C
C$ Version
C
C-    Beta Version 1.0.0, 26-SEP-1995 (NJB)
C
C-&
 
C$ Index_Entries
C
C     return number of segments in an E-kernel
C
C-&
 
C
C     SPICELIB functions
C
      LOGICAL               FAILED
      LOGICAL               RETURN
 
C
C     Non-SPICELIB functions
C
      INTEGER               ZZEKTRBS
      INTEGER               ZZEKTRSZ
 
C
C     Local variables
C
      INTEGER               BASE
      INTEGER               TREE
 
C
C     Set a default value for EKNSEG.
C
      EKNSEG  =  0
 
C
C     Standard SPICE error handling.
C
      IF ( RETURN () ) THEN
         RETURN
      ELSE
         CALL CHKIN ( 'EKNSEG' )
      END IF
 
C
C     Make sure this is a paged DAS EK.
C
      CALL ZZEKPGCH ( HANDLE, 'READ' )
 
      IF ( FAILED() ) THEN
         CALL CHKOUT ( 'EKNSEG' )
         RETURN
      END IF
 
C
C     Obtain the base address of the first integer page.
C
      BASE = ZZEKTRBS ( 1 )
 
C
C     Look up the head node of the segment tree.
C
      CALL DASRDI ( HANDLE, BASE+SGTIDX, BASE+SGTIDX, TREE )
 
C
C     Get the entry count for the segment tree.
C
      EKNSEG  =  ZZEKTRSZ ( HANDLE, TREE )
 
      CALL CHKOUT ( 'EKNSEG' )
      RETURN
      END
