C$Procedure                     EXACT ( Round to exact value )
 
      DOUBLE PRECISION FUNCTION EXACT ( NUMBER, VALUE, TOL )
 
C$ Abstract
C
C     Round an input double precision number to a specified exact value
C     if the number and the value are equal to within some tolerance.
C
C$ Copyright
C
C     Copyright (1995), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     None.
C
C$ Keywords
C
C     COMPARE
C     NUMBERS
C
C$ Declarations
 
 
      DOUBLE PRECISION      NUMBER
      DOUBLE PRECISION      VALUE
      DOUBLE PRECISION      TOL
 
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     NUMBER     I   Double precision number.
C     VALUE      I   Target value.
C     TOL        I   Tolerance.
C
C     The function returns VALUE whenever |NUMBER - VALUE| < TOL.
C                                                          -
C
C$ Detailed_Input
C
C     NUMBER      is an arbitrary double precision number.
C
C     VALUE       is a target value.
C
C     TOL         is a tolerance. NUMBER and VALUE are considered to
C                 be equal if they differ by no more than this amount.
C                 If TOL is negative, they are never considered equal.
C
C$ Detailed_Output
C
C     The function returns VALUE whenever |NUMBER - VALUE| < TOL, and
C     otherwise returns NUMBER.                            -
C
C$ Parameters
C
C     None.
C
C$ Exceptions
C
C      Error free.
C
C$ Files
C
C     None.
C
C$ Particulars
C
C     None.
C
C$ Examples
C
C     C
C     C     If the eccentricity is near one, make this a parabola.
C     C
C           ECC = EXACT ( ECC, 1.D0, 10.D-12 )
C
C$ Restrictions
C
C     None.
C
C$ Literature_References
C
C     None.
C
C$ Author_and_Institution
C
C     I.M. Underwood  (JPL)
C
C$ Version
C
C-     SPICELIB Version 1.0.1, 10-MAR-1992 (WLT)
C
C         Comment section for permuted index source lines was added
C         following the header.
C
C-     SPICELIB Version 1.0.0, 31-JAN-1990 (IMU)
C
C-&
 
C$ Index_Entries
C
C     round to exact value
C
C-&
 
 
 
C
C     Just shorthand, really.
C
      IF ( ABS ( NUMBER - VALUE ) .LE. TOL ) THEN
         EXACT = VALUE
 
      ELSE
         EXACT = NUMBER
      END IF
 
      RETURN
      END
