C$Procedure      FRAMEX (Frame Expert)
 
      SUBROUTINE FRAMEX ( CNAME, FRNAME, FRCODE, CENT,
     .                    CLASS, CLSSID, FOUND )
 
C$ Abstract
C
C     This is an umbrella routine for the entry points available
C     for manipulating different reference frames. It should not
C     be called directly.
C
C$ Copyright
C
C     Copyright (1997), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     None.
C
C$ Keywords
C
C     FRAMES
C
C$ Declarations
 
      IMPLICIT NONE
      INCLUDE              'ninert.inc'
      INCLUDE              'nninrt.inc'
      INCLUDE              'frmtyp.inc'
      CHARACTER*(*)         CNAME
      CHARACTER*(*)         FRNAME
      INTEGER               FRCODE
      INTEGER               CENT
      INTEGER               CLASS
      INTEGER               CLSSID
      LOGICAL               FOUND
 
C$ Brief_I/O
C
C     VARIABLE  I/O  ENTRY POINT
C     --------  ---  --------------------------------------------------
C     CNAME      I   CNMFRM
C     FRNAME    I/O  NAMFRM, FRMNAM
C     FRCODE    I/O  NAMFRM, FRMNAM, FRINFO, CIDFRM
C     CENT      I/O  FRINFO, CIDFRM
C     CLASS      O   FRINFO
C     CLSSID     O   FRINFO
C     FOUND      O   FRINFO
C
C
C$ Detailed_Input
C
C     See individual entry points for details concerning inputs.
C
C$ Detailed_Output
C
C     See individual entry points for details concerning inputs.
C
C$ Parameters
C
C     None.
C
C$ Files
C
C     None.
C
C$ Exceptions
C
C     1) If this routine is called directly the error
C       'SPICE(BOGUSENTRY)' will be signalled.
C
C$ Particulars
C
C     This is an umbrella routine that comprises the SPICE
C     interface to the reference frame transformation software.
C
C     There are 5 entry points.
C
C     NAMFRM  converts string to the id-codes used by low level
C             SPICE software
C
C     FRMNAM  converts frame id-codes to the more familiar names
C             used to describe various reference frames.
C
C     FRINFO  returns the center associated with a reference frame.
C
C     CIDFRM  given the id-code of an object, returns the bodyfixed
C             frame associated with it.
C
C     CNMFRM  given the name of an object, returns the bodyfixed
C             frame associated with it.
C
C$ Examples
C
C     Suppose that you needed to transform between two reference
C     frames on the basis of their names and that you wanted to
C     correct for light time to the center of the second frame
C     as seen from an observer with idcode OBS.
C
C     The code fragment below illustrates how you could use the
C     entry points gathered in this routine to retrieve the
C     state transformation matrix.
C
C
C        First convert names to frame id codes.
C
C        CHARACTER*(32)        NAME1
C        CHARACTER*(32)        NAME2
C
C        INTEGER               FRAME1
C        INTEGER               FRAME2
C        INTEGER               CENT
C        INTEGER               OBS
C
C        DOUBLE PRECISION      ET
C        DOUBLE PRECISION      LT
C
C        DOUBLE PRECISION      STATE ( 6 )
C        DOUBLE PRECISION      XFORM ( 6, 6 )
C
C
C        First we use the entry points NAMFRM to convert the frame
C        names to id codes.
C
C        CALL NAMFRM ( NAME1, FRAME1 )
C        CALL NAMFRM ( NAME2, FRAME2 )
C
C        Next we determine the center of the second frame
C
C        CALL FRINFO ( FRAME2, CENT, CLASS, CLSSID, FOUND )
C
C        Determine the light time to the center of the second frame.
C
C        CALL SPKGEO ( CENT,  ET, 'J2000',  OBS, STATE, LT )
C
C        Finally get the state transformation from FRAME1 to FRAME2
C        at time ET - LT
C
C        CALL FRMCHG ( FRAME1, FRAME2, ET-LT, XFORM )
C
C
C$ Restrictions
C
C     None.
C
C$ Author_and_Institution
C
C     N.J. Bachman    (JPL)
C     B.V. Semenov    (JPL)
C     W.L. Taber      (JPL)
C
C$ Literature_References
C
C     None.
C
C$ Version
C
C-    SPICELIB Version 3.2.0, 20-DEC-2004 (BVS)
C
C        Added parameter incorporating maximum body name length and set
C        it to the same value as MAXL from zzbodtrn.inc. Used this
C        parameter to declare local variable that holds frame center 
C        name (LCNAME).
C
C        In FRINFO entry: removed special handling of the frame IDs
C        less than -999. If they cannot be ``resolved'' using kernel
C        pool keywords, the frame is NOT declared CK-based with center
C        ID derived by dividing frame ID by a 1000 and class ID
C        assigned the frame ID anymore. In the current practice with
C        multitude of TK frames with IDs set instrument IDs this
C        default behavior is simply not valid.
C
C-    SPICELIB Version 3.1.0, 28-NOV-2002 (NJB)
C
C        Bug fix: updated CNMFRM so a TK frame specified by name and
C        designated as an object's preferred frame via kernel pool
C        assignments is found, and so that the correct name of this
C        frame is returned. 
C
C-    SPICELIB Version 3.0.1, 25-JUN-1999 (WLT)
C
C        Extended documentation of entry point CNMFRM and
C        corrected example for that entry point.
C
C-    SPICELIB Version 3.0.0, 03-JUN-1997 (WLT)
C
C        The entry points CIDFRM and CNMFRM were added so that
C        user's may determine the frame-id and name to associated
C        with a planetary object.
C
C-    SPICELIB Version 2.0.0, 04-APR-1997 (WLT)
C
C        The routine was upgraded to reflect that a block of
C        frame idcodes have been reserved for use by the DSN.
C        Id-codes 13001 to 13999 have been set aside for DSN
C        models for the orientation of the earth.  These frames
C        are all PCK frames.  Moreover, the PCK id-code to
C        use with these frames is simply the Frame-Code minus 10000.
C        All of these frames are centered at the earth (body 399).
C
C-    SPICELIB Version 1.1.0, 14-OCT-1996 (WLT)
C
C       The values NINERT and NNINRT are included instead of
C       being declared locally.
C
C-    SPICELIB Version 1.0.0, 18-SEP-1995 (WLT)
C
C-&
 
C$ Index_Entries
C
C     Frame Transformation
C
C-&
 
 
C$ Revisions
C
C-    SPICELIB Version 3.1.0, 28-NOV-2002 (NJB)
C
C        Bug fix: updated CNMFRM so a TK frame specified by name and
C        designated as an object's preferred frame via kernel pool
C        assignments is found, and so that the correct name of this
C        frame is returned. 
C
C-    SPICELIB Version 2.0.0, 04-APR-1997 (WLT)
C
C        The routine was upgraded to reflect that a block of
C        frame idcodes have been reserved for use by the DSN.
C        Id-codes 13001 to 13999 have been set aside for DSN
C        models for the orientation of the earth.  These frames
C        are all PCK frames.  Moreover, the PCK id-code to
C        use with these frames is simply the Frame-Code minus 10000.
C        All of these frames are centered at the earth (body 399).
C
C        Accompanying documentation is provided in the appendix
C        ``DSN Frames'' of the SPICE document FRAMES.REQ.
C
C-&
 
C
C     SPICELIB Functions
C
      INTEGER               BSCHOI
      INTEGER               BSCHOC
      LOGICAL               RETURN
 
C
C     Parameters
C
      INTEGER               WDSIZE
      PARAMETER           ( WDSIZE = 32 )
 
 
      INTEGER               NON
      PARAMETER           ( NON    = NNINRT )
 
      INTEGER               NCOUNT
      PARAMETER           ( NCOUNT = NINERT + NON )
 
      INTEGER               ROOM
      PARAMETER           ( ROOM = 8 )
 
      INTEGER               LNSIZE
      PARAMETER           ( LNSIZE = 80 )

C
C     Body name length. The value BDNMLN used here must be the 
C     same as the value of MAXL defined in the INCLUDE file
C
C        zzbodtrn.inc
C
C     Current value of MAXL = 36.
C
      INTEGER               BDNMLN
      PARAMETER           ( BDNMLN = 36 )
 
C
C     Local Variables
C
      CHARACTER*(WDSIZE)    NAME   ( NCOUNT )
      CHARACTER*(WDSIZE)    PNAME
      CHARACTER*(WDSIZE)    QYNAME (    3 )
      CHARACTER*(WDSIZE)    LOOKUP
      CHARACTER*(LNSIZE)    LINE   ( ROOM )
 
      CHARACTER*(BDNMLN)    LCNAME

      CHARACTER*(1)         DATTYP
 
      INTEGER               VALUES ( ROOM )
      INTEGER               I
 
      INTEGER               CENTRD ( NCOUNT )
      INTEGER               CENTER ( NCOUNT )
      INTEGER               CORDER ( NCOUNT )
      INTEGER               ID
      INTEGER               IDCODE ( NCOUNT )
      INTEGER               ITEM
      INTEGER               N
      INTEGER               NORDER ( NCOUNT )
      INTEGER               TYPE   ( NCOUNT )
      INTEGER               TYPEID ( NCOUNT )
      LOGICAL               FIRST
      LOGICAL               GOTIT
C
C     Because we need to save almost everything we save everything
C     rather than taking a chance and accidently leaving something
C     of the list.
C
      SAVE
 
 
      DATA                  FIRST  / .TRUE. /
 
      CALL CHKIN  ( 'FRAMEX' )
      CALL SETMSG ( 'A call has been made to the umbrella '
     .//            'routine FRAMEX.  This routine doesn''t do '
     .//            'anything.  It acts only as an umbrella '
     .//            'routine for its entry points.  This call '
     .//            'probably indicates a misunderstanding in '
     .//            'programming. ' )
      CALL SIGERR ( 'SPICE(BOGUSENTRY)' )
      CALL CHKOUT ( 'FRAMEX' )
      RETURN
 
 
 
C$Procedure      NAMFRM (Name to frame)
 
      ENTRY NAMFRM ( FRNAME, FRCODE )
 
C$ Abstract
C
C     Look up the frame id code associated with a string.
C
C$ Copyright
C
C     Copyright (1997), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     None.
C
C$ Keywords
C
C     FRAME
C
C$ Declarations
C
C     CHARACTER*(*)         FRNAME
C     INTEGER               FRCODE
C
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     FRNAME     I   The name of some reference frame
C     FRCODE     O   The SPICE id code of the frame.
C
C$ Detailed_Input
C
C     FRNAME      is a character string that stands for some
C                 reference frame (either inertial or non-inertial).
C
C                 Leading blanks in FRNAME are ignored. And the
C                 case of the letters in FRNAME are insignificant.
C
C                 Note that all legitimate frame names contain
C                 32 or fewer characters.
C
C$ Detailed_Output
C
C     FRCODE      is the SPICE integer code used for internal
C                 representation of the named reference frame.
C
C                 If the name input through FRNAME is not recognized
C                 FRCODE will be returned with a value of zero.
C
C$ Parameters
C
C     None.
C
C$ Files
C
C     None.
C
C$ Exceptions
C
C     1) If the input name is not recognized, FRCODE will be
C        returned with a value of 0.
C
C$ Particulars
C
C     This is a low level interface routine intended primarily for
C     use within the SPK and CK systems to assist in the transformation
C     to user specified reference frames.
C
C     The routine first consults a stored list of reference frame
C     names in an attempt to determine the appropriate reference
C     frame code.
C
C     If this search is unsuccessful, the routine then examines the
C     kernel pool to determine whether or not a variable of the
C     form
C
C        'FRAME_' // FRNAME
C
C        (where leading blanks of FRNAME are ignored)
C
C     is present.  If it is and the number of values associated with the
C     name is 1, this value is taken to be the frame id code.
C
C     Note:  It is NOT possible to override the default names and
C     id codes stored locally in this routine by placing an
C     appropriately  variable in the kernel pool with a different
C     id code.  The predefined values always take precedence.
C
C     Consult the FRAMES required reading document for more details
C     about constructing your own frame definitions.
C
C$ Examples
C
C     Suppose that you needed to find the SPICE id code for the
C     bodyfixed reference frame for Mars as modeled by the
C     IAU cartographic working group.  Use the following code
C     to perform this task.
C
C        CALL NAMFRM ( 'IAU_MARS', FRCODE )
C
C        WRITE (*,*) 'The SPICE code for the Mars bodyfixed frame is: ',
C       .             FRCODE.
C
C
C$ Restrictions
C
C     None.
C
C$ Author_and_Institution
C
C     W.L. Taber      (JPL)
C
C$ Literature_References
C
C     None.
C
C$ Version
C
C-    SPICELIB Version 3.0.1, 25-JUN-1999 (WLT)
C
C        Extended documentation of entry point CNMFRM and
C        corrected example for that entry point.
C
C-    SPICELIB Version 3.0.0, 03-JUN-1997 (WLT)
C
C        The entry points CIDFRM and CNMFRM were added so that
C        user's may determine the frame-id and name to associated
C        with a planetary object.
C
C-    SPICELIB Version 2.0.0, 04-APR-1997 (WLT)
C
C        The routine was upgraded to reflect that a block of
C        frame idcodes have been reserved for use by the DSN.
C        Id-codes 13001 to 13999 have been set aside for DSN
C        models for the orientation of the earth.  These frames
C        are all PCK frames.  Moreover, the PCK id-code to
C        use with these frames is simply the Frame-Code minus 10000.
C        All of these frames are centered at the earth (body 399).
C
C-    SPICELIB Version 1.1.0, 14-OCT-1996 (WLT)
C
C       The values NINERT and NNINRT are included instead of
C       being declared locally.
C
C-    SPICELIB Version 1.0.0, 18-SEP-1995 (WLT)
C
C-&
 
C$ Index_Entries
C
C     Frame name to frame idcode translation
C
C-&
 
      FRCODE = 0
C
C     Standard SPICE error handling.
C
      IF ( RETURN() ) THEN
         RETURN
      END IF
 
      CALL CHKIN ( 'NAMFRM' )
 
C
C     Perform any needed first pass initializations.
C
      IF ( FIRST ) THEN
 
         FIRST = .FALSE.
 
         CALL ZZFDAT ( NCOUNT, NAME,   IDCODE, CENTER, TYPE, TYPEID,
     .                 NORDER, CORDER, CENTRD )
      END IF
C
C     Determine the location of the requested item in the array
C     of names.
C
      CALL LJUST ( FRNAME, PNAME )
      CALL UCASE ( PNAME,  PNAME )
 
      ITEM = BSCHOC ( PNAME, NCOUNT, NAME, NORDER )
C
C     If the name is in our list, we can just look up its idcode in
C     the parallel array.
C
      IF ( ITEM .GT. 0 ) THEN
 
         FRCODE = IDCODE (  ITEM    )
 
      ELSE
C
C        The items wasn't in the list, see if it's in the kernel pool.
C
         CALL PREFIX ( 'FRAME_', 0,                  PNAME )
         CALL GIPOOL (  PNAME,   1, ROOM, N, VALUES, GOTIT )
 
         IF ( N .EQ. 1 .AND. GOTIT ) THEN
 
            FRCODE = VALUES(1)
 
         ELSE
 
            FRCODE = 0
 
         END IF
 
      END IF
 
      CALL CHKOUT ( 'NAMFRM' )
      RETURN
 
 
C$Procedure      FRMNAM (Frame to Name)
 
      ENTRY FRMNAM ( FRCODE, FRNAME )
 
C$ Abstract
C
C     Retrieve the name of a reference frame associated with
C     a SPICE id code.
C
C$ Copyright
C
C     Copyright (1997), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     None.
C
C$ Keywords
C
C     FRAMES
C
C$ Declarations
C
C     INTEGER               FRCODE
C     CHARACTER*(*)         FRNAME
C
C
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     FRCODE     I   an integer code for a reference frame
C     FRNAME     O   the name associated with the reference frame.
C
C$ Detailed_Input
C
C     FRCODE      is an integer code for a reference frame.
C
C$ Detailed_Output
C
C     FRNAME      is the name associated with the reference frame.
C                 It will be returned left justified.
C
C                 If FRCODE is not recognized as the name of a
C                 known reference frame FRNAME will be returned
C                 as a blank.
C
C                 If FRNAME is not sufficiently long to hold the
C                 name, it will be truncated on the right.
C
C                 All reference frame names are 32 or fewer characters
C                 in length.  Thus declaring FRNAME to be CHARACTER*(32)
C                 will ensure that the returned name will not be
C                 truncated.
C
C$ Parameters
C
C     None.
C
C$ Files
C
C     None.
C
C$ Exceptions
C
C     1) If FRCODE is not recognized as the name of a
C        known reference frame FRNAME will be returned
C        as a blank.
C
C     2) If FRNAME is not sufficiently long to hold the
C        name, it will be truncated on the right.
C
C$ Particulars
C
C     This routine retrieves the name of a reference frame associated
C     with a SPICE frame id code.
C
C     The id codes stored locally are scanned for a match with FRCODE.
C     If a match is found, the name stored locally will be returned
C     as the name for the frame.
C
C     If FRCODE is not a member of the list of internally stored
C     id codes, the kernel pool will be examined to see if the
C     variable
C
C        FRAME_idcode_NAME
C
C     is present (where idcode is the decimal character equivalent
C     of FRCODE).  If the variable is located and it has both
C     character type and dimension 1, the string value of the
C     kernel pool variable is returned as the name of the reference
C     frame.
C
C     Note that because the local information is always examined
C     first and searches of the kernel pool are performed only
C     after exhausting local information, it is not possible to
C     override the local name for any reference frame that is
C     known by this routine.
C
C$ Examples
C
C     Suppose you needed to create a message concerning a reference
C     frame and wish to use the name of the frame in the message.
C     Suppose further that you have only the frame id code at your
C     disposal.  You can capture the frame name using this routine
C     as shown here.
C
C        CHARACTER*(32)        FRNAME
C
C        CALL FRMNAM ( FRCODE, FRNAME )
C
C        IF ( FRNAME .EQ. ' ' ) THEN
C           CALL INTSTR ( FRCODE, FRNAME )
C        END IF
C
C        WRITE (*,*) 'Concerning reference frame:', FRNAME
C
C        print the rest of your message.
C
C$ Restrictions
C
C     None.
C
C$ Author_and_Institution
C
C     W.L. Taber      (JPL)
C
C$ Literature_References
C
C     None.
C
C$ Version
C
C-    SPICELIB Version 3.0.1, 25-JUN-1999 (WLT)
C
C        Extended documentation of entry point CNMFRM and
C        corrected example for that entry point.
C
C-    SPICELIB Version 3.0.0, 03-JUN-1997 (WLT)
C
C        The entry points CIDFRM and CNMFRM were added so that
C        user's may determine the frame-id and name to associated
C        with a planetary object.
C
C-    SPICELIB Version 2.0.0, 04-APR-1997 (WLT)
C
C        The routine was upgraded to reflect that a block of
C        frame idcodes have been reserved for use by the DSN.
C        Id-codes 13001 to 13999 have been set aside for DSN
C        models for the orientation of the earth.  These frames
C        are all PCK frames.  Moreover, the PCK id-code to
C        use with these frames is simply the Frame-Code minus 10000.
C        All of these frames are centered at the earth (body 399).
C
C-    SPICELIB Version 1.1.0, 14-OCT-1996 (WLT)
C
C       The values NINERT and NNINRT are included instead of
C       being declared locally.
C
C-    SPICELIB Version 1.0.0, 18-SEP-1995 (WLT)
C
C-&
 
C$ Index_Entries
C
C     Frame idcode to frame name translation
C
C-&
 
C
C     Standard SPICE error handling.
C
      FRNAME = ' '
 
      IF ( RETURN() ) THEN
         RETURN
      END IF
 
      CALL CHKIN ( 'FRMNAM' )
 
C
C     Perform any needed first pass initializations.
C
      IF ( FIRST ) THEN
 
         FIRST = .FALSE.
 
         CALL ZZFDAT ( NCOUNT, NAME,   IDCODE, CENTER, TYPE, TYPEID,
     .                 NORDER, CORDER, CENTRD )
      END IF
 
      ITEM = BSCHOI ( FRCODE, NCOUNT, IDCODE, CORDER )
 
      IF ( ITEM .NE. 0 ) THEN
 
         FRNAME = NAME(ITEM)
 
      ELSE
 
         PNAME      = 'FRAME_#_NAME'
         CALL REPMI (  PNAME, '#', FRCODE, PNAME )
 
         CALL GCPOOL ( PNAME, 1, ROOM, N, LINE, GOTIT )
 
         IF ( N .EQ. 1 .AND. GOTIT ) THEN
 
            CALL LJUST ( LINE(1), FRNAME )
         ELSE
 
            FRNAME = ' '
 
         END IF
 
      END IF
 
      CALL CHKOUT ( 'FRMNAM' )
      RETURN
 
 
 
C$Procedure      FRINFO ( Frame Information )
 
      ENTRY FRINFO ( FRCODE, CENT, CLASS, CLSSID, FOUND )
 
C$ Abstract
C
C     Retrieve the minimal attributes associated with a frame
C     needed for converting transformations to and from it.
C
C$ Copyright
C
C     Copyright (1997), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     None.
C
C$ Keywords
C
C     FRAMES
C
C$ Declarations
C
C     IMPLICIT NONE
C     INTEGER               FRCODE
C     INTEGER               CENT
C     LOGICAL               FOUND
C
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     FRCODE     I   the idcode for some frame
C     CENT       O   the center of the frame
C     CLASS      O   the class (type) of the frame
C     CLSSID     O   the idcode for the frame within its class.
C     FOUND      O   TRUE if the requested information is available.
C
C$ Detailed_Input
C
C     FRCODE      is the id code for some reference frame.
C
C$ Detailed_Output
C
C     CENT        is the body id code for the center of the reference
C                 frame (if such an id code is appropriate).
C
C     CLASS       is the class or type of the frame.  This identifies
C                 which subsystem will be used to perform frame
C                 transformations.
C
C     CLSSID      is the id-code used for the frame within its class.
C                 This may be different from the frame id-code.
C
C     FOUND       is TRUE if CENT, CLASS and CCODE are available.
C                 Otherwise, FOUND is returned with the value FALSE.
C
C$ Parameters
C
C      None.
C
C$ Files
C
C      None.
C
C$ Exceptions
C
C     None.
C
C$ Particulars
C
C     This is a low level routine needed by state transformation
C     software to transform states and attitudes between different
C     reference frames.
C
C     The routine first examines local "hard-coded" information about
C     reference frames to see if the requested frame belongs to this
C     set.  If it does that information is returned.
C
C     If the requested information is not stored locally, the routine
C     then examines the kernel pool to see if the requested information
C     is stored there.  If it is and has the expected format, the data
C     is retrieved and returned.
C
C$ Examples
C
C     Suppose that you needed to determine the center of some
C     reference frame.  The following code fragment illustrates
C     how to use this routine to determine this information.
C
C        CALL FRINFO ( FRCODE, CENT, CLASS, CLSSID, FOUND )
C
C        IF ( FOUND ) THEN
C
C           WRITE (*,*) 'The center of reference frame ', FRCODE
C           WRITE (*,*) 'has body id code : ', CENT
C
C        ELSE
C
C           WRITE (*,*) 'There is insufficient data for frame ', FRCODE
C
C        END IF
C
C$ Restrictions
C
C     None.
C
C$ Author_and_Institution
C
C      W.L. Taber      (JPL)
C
C$ Literature_References
C
C      None.
C
C$ Version
C
C-    SPICELIB Version 3.1.0, 20-DEC-2004 (BVS)
C
C        Removed special handling of the frame IDs less than -999. If
C        they cannot be ``resolved'' using kernel pool keywords, the
C        frame is NOT declared CK-based with center ID derived by
C        dividing frame ID by a 1000 and class ID assigned the frame ID
C        anymore. In the current practice with multitude of TK frames
C        with IDs set instrument IDs this default behavior is simply
C        not valid.
C
C-    SPICELIB Version 3.0.1, 25-JUN-1999 (WLT)
C
C        Extended documentation of entry point CNMFRM and
C        corrected example for that entry point.
C
C-    SPICELIB Version 3.0.0, 03-JUN-1997 (WLT)
C
C        The entry points CIDFRM and CNMFRM were added so that
C        user's may determine the frame-id and name to associated
C        with a planetary object.
C
C-    SPICELIB Version 2.0.0, 04-APR-1997 (WLT)
C
C        The routine was upgraded to reflect that a block of
C        frame idcodes have been reserved for use by the DSN.
C        Id-codes 13001 to 13999 have been set aside for DSN
C        models for the orientation of the earth.  These frames
C        are all PCK frames.  Moreover, the PCK id-code to
C        use with these frames is simply the Frame-Code minus 10000.
C        All of these frames are centered at the earth (body 399).
C
C-    SPICELIB Version 1.1.0, 14-OCT-1996 (WLT)
C
C       The values NINERT and NNINRT are included instead of
C       being declared locally.
C
C-    SPICELIB Version 1.0.0, 18-SEP-1995 (WLT)
C
C-&
 
C$ Index_Entries
C
C     Fetch reference frame attributes
C
C-&
 
C
C     Standard SPICE error handling.
C
      IF ( RETURN() ) THEN
         RETURN
      END IF
 
      CALL CHKIN ( 'FRINFO' )
 
C
C     Perform any needed first pass initializations.
C
      IF ( FIRST ) THEN
 
         FIRST = .FALSE.
 
         CALL ZZFDAT ( NCOUNT, NAME,   IDCODE, CENTER, TYPE, TYPEID,
     .                 NORDER, CORDER, CENTRD )
      END IF
C
C     Determine the location of the requested item in the array
C     of idcodes.
C
 
      ITEM = BSCHOI ( FRCODE, NCOUNT, IDCODE, CORDER )
C
C     If the name is in our list, we can just look up its idcode in
C     the parallel array.
C
      IF ( ITEM .GT. 0 ) THEN
 
         CENT   =  CENTER(ITEM)
         CLASS  =  TYPE  (ITEM)
         CLSSID =  TYPEID(ITEM)
         FOUND  = .TRUE.
 
      ELSE
C
C        The items wasn't in the list, see if it's in the kernel pool.
C
 
         QYNAME(1) =  'FRAME_#_CENTER'
         QYNAME(2) =  'FRAME_#_CLASS'
         QYNAME(3) =  'FRAME_#_CLASS_ID'
 
         FOUND = .TRUE.
 
         I = 0
 
         DO WHILE ( FOUND .AND. I .LT. 3 )
 
            I     = I + 1
            PNAME = QYNAME(I)
 
            CALL REPMI  ( PNAME, '#',  FRCODE, PNAME             )
            CALL GIPOOL ( PNAME,  1,   2,   N, VALUES(I),  FOUND )
 
            FOUND =  FOUND .AND. N .EQ. 1
 
         END DO
 
         CENT   = VALUES(1)
         CLASS  = VALUES(2)
         CLSSID = VALUES(3)
 
C
C        In support of the DSN, NAIF has reserved a block of
C        ID-codes for DSN specific frames  from 13000 to 13999.
C        These are always PCK based frames for the earth.
C        The PCK idcode is just FRCODE - 10000.
C
         IF      ( .NOT. FOUND
     .             .AND. FRCODE .GE. 13000
     .             .AND. FRCODE .LT. 14000 ) THEN
 
            CENT   = 399
            CLASS  = PCK
            CLSSID = FRCODE - 10000
            FOUND  = .TRUE.
 
         END IF
 
      END IF
 
      CALL CHKOUT ( 'FRINFO' )
      RETURN
 
 
 
C$Procedure CIDFRM ( center SPK id  frame )
 
      ENTRY CIDFRM ( CENT, FRCODE, FRNAME, FOUND )
 
C$ Abstract
C
C     Retrieve frame idcode and name to associate with a frame center.
C
C$ Copyright
C
C     Copyright (1997), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     None.
C
C$ Keywords
C
C     FRAMES
C
C$ Declarations
C
C     IMPLICIT NONE
C     INTEGER               CENT
C     INTEGER               FRCODE
C     CHARACTER*(*)         FRNAME
C     LOGICAL               FOUND
C
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     CENT       I   an object to associate a frame with.
C     FRCODE     O   the idcode of the frame associated with CENT
C     FRNAME     O   the name of the frame with id FRCODE
C     FOUND      O   TRUE if the requested information is available.
C
C$ Detailed_Input
C
C     CENT        is the id code for object for which there is a
C                 preferred reference frame.
C
C$ Detailed_Output
C
C     FRCODE      is the frame id-code to associate with a the object
C                 specified by CENT.
C
C     FRNAME      is the name of the frame that should be associated
C                 with the object specified by CNAME. FRNAME should be
C                 declared as CHARACTER*(32) to ensure that it can
C                 contain the full name of the frame.  If FRNAME does
C                 not have enough room to hold the full name of the
C                 frame, the name will be truncated on the right.
C
C     FOUND       is TRUE if the appropriate frame id-code and frame
C                 name can be determined.  Otherwise FOUND is returned
C                 with the value FALSE.
C
C$ Parameters
C
C      None.
C
C$ Files
C
C      None.
C
C$ Exceptions
C
C     1) If FRNAME is not have room to contain the frame name, the name
C        will be truncated on the right. ( Declaring FRNAME to be
C        CHARACTER*(32) will ensure that the name will not be
C        truncated.
C
C$ Particulars
C
C     This routine allows the user to determine the frame that should
C     be associated with a particular object.   For example, if you
C     need the frame to associate with the Io, you can call CIDFRM
C     to determine the frame name and id-code for the bodyfixed frame
C     of Io.
C
C     The preferred frame to use with an object is specified via one
C     of the kernel pool variables:
C
C         OBJECT_<cent>_FRAME
C
C     where <cent> is the decimal representation of the integer CENT.
C
C     For those PCK objects that have "built-in" frame names this
C     routine returns the corresponding "IAU" frame and frame idcode.
C
C$ Examples
C
C     Suppose that you want to determine the state of a target
C     in the preferred reference frame of some observer.  This
C     routine can be used in conjunction with SPKEZ to compute
C     the state.
C
C        CALL CIDFRM ( OBS, FRCODE, FRNAME, FOUND )
C
C        IF ( .NOT. FOUND ) THEN
C
C           WRITE (*,*) 'The bodyfixed frame for object ', OBS
C           WRITE (*,*) 'could not be identified.'
C           STOP
C
C        END IF
C
C        CALL SPKEZ ( TARG, ET, FRNAME, ABCORR, OBS, STATE, LT )
C
C$ Restrictions
C
C     None.
C
C$ Author_and_Institution
C
C      W.L. Taber      (JPL)
C
C$ Literature_References
C
C      None.
C
C$ Version
C
C-    SPICELIB Version 3.0.1, 25-JUN-1999 (WLT)
C
C        Extended documentation of entry point CNMFRM and
C        corrected example for that entry point.
C
C-    SPICELIB Version 3.0.0, 03-JUN-1997 (WLT)
C
C        The entry points CIDFRM and CNMFRM were added so that
C        user's may determine the frame-id and name to associated
C        with a planetary object.
C
C-    SPICELIB Version 2.0.0, 04-APR-1997 (WLT)
C
C        The routine was upgraded to reflect that a block of
C        frame idcodes have been reserved for use by the DSN.
C        Id-codes 13001 to 13999 have been set aside for DSN
C        models for the orientation of the earth.  These frames
C        are all PCK frames.  Moreover, the PCK id-code to
C        use with these frames is simply the Frame-Code minus 10000.
C        All of these frames are centered at the earth (body 399).
C
C-    SPICELIB Version 1.1.0, 14-OCT-1996 (WLT)
C
C       The values NINERT and NNINRT are included instead of
C       being declared locally.
C
C-    SPICELIB Version 1.0.0, 18-SEP-1995 (WLT)
C
C-&
 
C$ Index_Entries
C
C     Find the bodyfixed frame associated with an object
C
C-&
 
C
C     Standard SPICE error handling.
C
      IF ( RETURN() ) THEN
         RETURN
      END IF
 
      CALL CHKIN ( 'CIDFRM' )
 
C
C     Perform any needed first pass initializations.
C
      IF ( FIRST ) THEN
 
         FIRST = .FALSE.
 
         CALL ZZFDAT ( NCOUNT, NAME,   IDCODE, CENTER, TYPE, TYPEID,
     .                 NORDER, CORDER, CENTRD )
      END IF
C
C     First look up in the kernel pool the frame associated with this
C     center.
C
      LOOKUP = 'OBJECT_#_FRAME'
 
      CALL REPMI  ( LOOKUP, '#',   CENT, LOOKUP )
      CALL DTPOOL ( LOOKUP, GOTIT, N,    DATTYP )
C
C     If we didn't find this object in the form OBJECT_<number>_FRAME
C     maybe it is present in the form OBJECT_<name>_FRAME.  It's
C     worth a try.
C
      IF ( .NOT. GOTIT ) THEN
C
C        See if we can get the name for this center's id-code.
C
         CALL BODC2N ( CENT, LCNAME, GOTIT )
 
         IF ( GOTIT ) THEN
C
C           Construct and look up the alternative name in the
C           kernel pool.
C
            LOOKUP = 'OBJECT_#_FRAME'
 
            CALL REPMC  ( LOOKUP, '#', LCNAME, LOOKUP )
            CALL UCASE  ( LOOKUP,              LOOKUP )
            CALL DTPOOL ( LOOKUP, GOTIT, N,    DATTYP )
 
         END IF
 
      END IF
C
C     There are two cases.  The user may specify either a name
C     or id-code for the frame to use to model the orientation of
C     an object.  We assume they'll opt for the character string
C     form so we test that case first.
C
      IF ( GOTIT ) THEN
 
         IF ( DATTYP .EQ. 'C' ) THEN
 
            CALL GCPOOL ( LOOKUP, 1, 1, N,  PNAME, GOTIT )
C
C           We've got the name:  See if we have this in our handy list
C           of built-in names.
C
            ITEM = BSCHOC ( PNAME, NCOUNT, NAME, NORDER )
 
            IF ( ITEM .GT. 0 ) THEN
 
               FRNAME = PNAME
               FRCODE = IDCODE ( ITEM )
               FOUND  = .TRUE.
 
            ELSE
C
C              Nope.  look in the kernel pool for the data associated
C              with this frame.
C
               FRNAME = PNAME
 
               CALL PREFIX ( 'FRAME_', 0,                  PNAME )
               CALL GIPOOL (  PNAME,   1, ROOM, N, VALUES, GOTIT )
 
               IF ( N .EQ. 1 .AND. GOTIT ) THEN
 
                  FRCODE = VALUES(1)
                  FOUND  = .TRUE.
 
               ELSE
 
                  FRCODE = 0
                  FRNAME = ' '
                  FOUND  = .FALSE.
 
               END IF
 
            END IF
 
 
         ELSE IF ( DATTYP .EQ. 'N' ) THEN
C
C           Ok.  They decided to use the numeric form to specify
C           the frame id.  We need to figure out the name of the frame.
C           First we retrieve the frame id they've loaded into the
C           kernel pool.
C
            CALL GIPOOL ( LOOKUP, 1, 1, N, VALUES, GOTIT )
 
C
C           We've got the frame ID, see if we already know about this
C           id-code.
C
            ITEM = BSCHOI ( VALUES(1), NCOUNT, CENTER, CENTRD )
 
            IF ( ITEM .NE. 0 ) THEN
C
C              Just look up the name and set the frame code.
C
               FRNAME = NAME  (ITEM)
               FRCODE = VALUES(1)
               FOUND  = .TRUE.
 
            ELSE
C
C              Hmmm. Not on the built-in list.  See if it's in the
C              kernel pool somewhere.
C
               PNAME      = 'FRAME_#_NAME'
               CALL REPMI (  PNAME, '#', VALUES(1),   PNAME )
               CALL GCPOOL ( PNAME, 1, ROOM, N, LINE, GOTIT )
 
               IF ( N .EQ. 1 .AND. GOTIT ) THEN
 
                  CALL LJUST ( LINE(1), FRNAME )
                  FRCODE = VALUES(1)
                  FOUND  = .TRUE.
 
               ELSE
 
                  FRCODE = VALUES(1)
                  FRNAME = ' '
                  FOUND  = .FALSE.
 
               END IF
 
            END IF
 
 
         END IF
C
C        One way or the other we've filled in the values at this
C        point.  Nothing left to do but check out and return.
C
         CALL CHKOUT ( 'CIDFRM' )
         RETURN
 
      END IF
C
C     The only way to reach this point is if the user did not
C     specify via the kernel pool a frame to use for this center.
C
C     We have a special case for EARTH.
C
      IF ( CENT .EQ. 399 ) THEN
 
         FRCODE = 10013
         FRNAME = 'IAU_EARTH'
         FOUND  = .TRUE.
         CALL CHKOUT ( 'CIDFRM' )
         RETURN
 
      END IF
 
C
C     Determine the location of the requested item in the array
C     of centers.
C
      ITEM = BSCHOI ( CENT, NCOUNT, CENTER, CENTRD )
 
C
C     If the name is in our list, we can just look up its idcode and
C     name in the parallel array.
C
      IF ( ITEM .GT. 0 ) THEN
 
         FRCODE =  IDCODE(ITEM)
         FRNAME =  NAME  (ITEM)
         FOUND  = .TRUE.
 
      ELSE
C
C        There's nothing we can do now.  We don't know what frame
C        might be associated with this object.
C
         FRNAME = ' '
         FRCODE =  0
         FOUND  = .FALSE.
 
      END IF
 
      CALL CHKOUT ( 'CIDFRM' )
      RETURN
 
 
 
C$Procedure CNMFRM ( Center name to associated frame )
 
      ENTRY CNMFRM ( CNAME, FRCODE, FRNAME, FOUND )
 
C$ Abstract
C
C     Retrieve frame idcode and name to associate with an object.
C
C$ Copyright
C
C     Copyright (1997), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     None.
C
C$ Keywords
C
C     FRAMES
C
C$ Declarations
C
C     IMPLICIT NONE
C     CHARACTER*(*)         CNAME
C     INTEGER               FRCODE
C     CHARACTER*(*)         FRNAME
C     LOGICAL               FOUND
C
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     CNAME      I   name of the object to find a frame for
C     FRCODE     O   the idcode of the frame associated with CNAME
C     FRNAME     O   the name of the frame with id FRCODE
C     FOUND      O   TRUE if the requested information is available.
C
C$ Detailed_Input
C
C     CNAME       is the name for object for which there is a
C                 preferred reference frame
C
C$ Detailed_Output
C
C     FRCODE      is the frame id-code to associate with a the object
C                 specified by CNAME.
C
C     FRNAME      is the name of the frame that should be associated
C                 with the object specified by CNAME. FRNAME should be
C                 declared as CHARACTER*(32) to ensure that it can
C                 contain the full name of the frame.  If FRNAME does
C                 not have enough room to hold the full name of the
C                 frame, the name will be truncated on the right.
C
C     FOUND       is TRUE if the appropriate frame id-code and frame
C                 name can be determined.  Otherwise FOUND is returned
C                 with the value FALSE.
C
C$ Parameters
C
C      None.
C
C$ Files
C
C      None.
C
C$ Exceptions
C
C     1) If FRNAME is not have room to contain the frame name, the name
C        will be truncated on the right. ( Declaring FRNAME to be
C        CHARACTER*(32) will ensure that the name will not be
C        truncated.
C
C$ Particulars
C
C     This routine allows the user to determine the frame that should
C     be associated with a particular object.   For example, if you
C     need the frame to associate with the Io, you can call CNMFRM
C     to determine the frame name and id-code for the bodyfixed frame
C     of Io.
C
C     The preferred frame to use with an object is specified via one
C     of the kernel pool variables:
C
C         OBJECT_<cname>_FRAME
C
C     where <cname> is the non-blank portion of the string CNAME.
C
C     For those PCK objects that have "built-in" frame names this
C     routine returns the corresponding "IAU" frame and frame idcode.
C
C$ Examples
C
C     Suppose that you want to determine the state of a target
C     in the preferred reference frame of some observer.  This
C     routine can be used in conjunction with SPKEZR to compute
C     the state.
C
C        CALL CNMFRM ( OBSNAM, FRCODE, FRNAME, FOUND )
C
C        IF ( .NOT. FOUND ) THEN
C
C           WRITE (*,*) 'The bodyfixed frame for object ', OBSNAM
C           WRITE (*,*) 'could not be identified.'
C           STOP
C
C        END IF
C
C        CALL SPKEZR ( TARGET, ET, FRNAME, ABCORR, OBSNAM, STATE, LT )
C
C$ Restrictions
C
C     None.
C
C$ Author_and_Institution
C
C      W.L. Taber      (JPL)
C
C$ Literature_References
C
C      None.
C
C$ Version
C
C-    SPICELIB Version 3.1.0, 28-NOV-2002 (NJB)
C
C        Bug fix: updated this routine so a TK frame specified by name
C        and designated as an object's preferred frame via kernel pool
C        assignments is found, and so that the correct name of this
C        frame is returned.
C
C-    SPICELIB Version 3.0.1, 25-JUN-1999 (WLT)
C
C        Extended documentation of entry point CNMFRM and
C        corrected example for that entry point.
C
C-    SPICELIB Version 3.0.0, 03-JUN-1997 (WLT)
C
C        The entry points CIDFRM and CNMFRM were added so that
C        user's may determine the frame-id and name to associated
C        with a planetary object.
C
C-    SPICELIB Version 2.0.0, 04-APR-1997 (WLT)
C
C        The routine was upgraded to reflect that a block of
C        frame idcodes have been reserved for use by the DSN.
C        Id-codes 13001 to 13999 have been set aside for DSN
C        models for the orientation of the earth.  These frames
C        are all PCK frames.  Moreover, the PCK id-code to
C        use with these frames is simply the Frame-Code minus 10000.
C        All of these frames are centered at the earth (body 399).
C
C
C-    SPICELIB Version 1.1.0, 14-OCT-1996 (WLT)
C
C       The values NINERT and NNINRT are included instead of
C       being declared locally.
C
C-    SPICELIB Version 1.0.0, 18-SEP-1995 (WLT)
C
C-&
 
C$ Index_Entries
C
C     Find the bodyfixed frame associated with an object
C
C-&

C$ Revisions
C 
C-    SPICELIB Version 3.1.0, 28-NOV-2002 (NJB)
C
C        Bug fix: updated this routine so a TK frame specified by name
C        and designated as an object's preferred frame via kernel pool
C        assignments is found, and so that the correct name of this
C        frame is returned.
C
C-&

C
C     Standard SPICE error handling.
C
      IF ( RETURN() ) THEN
         RETURN
      END IF
 
      CALL CHKIN ( 'CNMFRM' )
 
C
C     Perform any needed first pass initializations.
C
      IF ( FIRST ) THEN
 
         FIRST = .FALSE.
 
         CALL ZZFDAT ( NCOUNT, NAME,   IDCODE, CENTER, TYPE, TYPEID,
     .                 NORDER, CORDER, CENTRD )
      END IF
C
C     First look up in the kernel pool the frame associated with this
C     center.
C
      LOOKUP = 'OBJECT_#_FRAME'
 
      CALL REPMC  ( LOOKUP, '#',   CNAME, LOOKUP )
      CALL UCASE  ( LOOKUP,               LOOKUP )
      CALL DTPOOL ( LOOKUP, GOTIT, N,     DATTYP )
 
C
C     If we didn't find this object in the form OBJECT_<name>_FRAME
C     maybe it is present in the form OBJECT_<number>_FRAME.  It's
C     worth a try.
C
      IF ( .NOT. GOTIT ) THEN
C
C        See if we can get the name for this center's id-code.
C
         CALL BODN2C ( CNAME, ID, GOTIT )
 
         IF ( GOTIT ) THEN
C
C           Construct and look up the alternative name in the
C           kernel pool.
C
            LOOKUP = 'OBJECT_#_FRAME'
 
            CALL REPMI  ( LOOKUP, '#',   ID, LOOKUP )
            CALL DTPOOL ( LOOKUP, GOTIT, N,  DATTYP )
 
         END IF
 
      END IF
 
C
C     There are two cases.  The user may specify either a name
C     or id-code for the frame to use to model the orientation of
C     an object.  We assume they'll opt for the character string
C     form so we test that case first.
C
      IF ( GOTIT ) THEN
 
         IF ( DATTYP .EQ. 'C' ) THEN
 
            CALL GCPOOL ( LOOKUP, 1, 1, N,  PNAME, GOTIT )
C
C           We've got the name:  See if we have this in our handy list
C           of built-in names.
C
            ITEM = BSCHOC ( PNAME, NCOUNT, NAME, NORDER )
 
            IF ( ITEM .GT. 0 ) THEN
 
               FRNAME = PNAME
               FRCODE = IDCODE ( ITEM )
               FOUND  = .TRUE.
 
            ELSE
C
C              Nope.  look in the kernel pool for the data associated
C              with this frame.
C
C              Capture the frame name now, since we're going to modify
C              PNAME.
C              
               FRNAME = PNAME

               CALL PREFIX ( 'FRAME_', 0,                  PNAME )
               CALL GIPOOL (  PNAME,   1, ROOM, N, VALUES, GOTIT )
 
               IF ( N .EQ. 1 .AND. GOTIT ) THEN
 
                  FRCODE = VALUES(1)
                  FOUND  = .TRUE.
 
               ELSE
 
                  FRCODE = 0
                  FRNAME = ' '
                  FOUND  = .FALSE.
 
               END IF
 
            END IF
 
 
         ELSE IF ( DATTYP .EQ. 'N' ) THEN
C
C           Ok.  They decided to use the numeric form to specify
C           the frame id.  We need to figure out the name of the frame.
C           First we retrieve the frame id they've loaded into the
C           kernel pool.
C
            CALL GIPOOL ( LOOKUP, 1, 1, N, VALUES, GOTIT )
 
C
C           We've got the frame ID, see if we already know about this
C           id-code.
C
            ITEM = BSCHOI ( VALUES(1), NCOUNT, IDCODE, CORDER )
 
            IF ( ITEM .NE. 0 ) THEN
C
C              Just look up the name and set the frame code.
C
               FRNAME = NAME  (ITEM)
               FRCODE = VALUES(1)
               FOUND  = .TRUE.
 
            ELSE
C
C              Hmmm. Not on the built-in list.  See if it's in the
C              kernel pool somewhere.
C
               PNAME      = 'FRAME_#_NAME'
               CALL REPMI (  PNAME, '#', VALUES(1),   PNAME )
               CALL GCPOOL ( PNAME, 1, ROOM, N, LINE, GOTIT )
 
               IF ( N .EQ. 1 .AND. GOTIT ) THEN
 
                  CALL LJUST ( LINE(1), FRNAME )
                  FRCODE = VALUES(1)
                  FOUND  = .TRUE.
 
               ELSE
 
                  FRCODE = VALUES(1)
                  FRNAME = ' '
                  FOUND  = .FALSE.
 
               END IF
 
            END IF
 
 
         END IF
C
C        One way or the other we've filled in the values at this
C        point.  Nothing left to do but check out and return.
C
         CALL CHKOUT ( 'CNMFRM' )
         RETURN
 
      END IF
C
C     The only way to reach this point is if the user did not
C     specify via the kernel pool a frame to use for this center.
C
C
      FRNAME = 'IAU_#'
      CALL REPMC ( FRNAME, '#', CNAME, FRNAME )
      CALL UCASE ( FRNAME,             FRNAME )
 
 
C
C     Determine the location of the requested item in the array
C     of centers.
C
      ITEM = BSCHOC ( FRNAME, NCOUNT, NAME, NORDER )
 
C
C     If the name is in our list, we can just look up its idcode and
C     name in the parallel array.
C
      IF ( ITEM .GT. 0 ) THEN
 
         FRCODE =  IDCODE(ITEM)
         FOUND  = .TRUE.
 
      ELSE
C
C        There's nothing we can do now.  We don't know what frame
C        might be associated with this object.
C
         FRCODE =  0
         FOUND  = .FALSE.
 
      END IF
 
      CALL CHKOUT ( 'CNMFRM' )
      RETURN
 
 
      END
