C$ Abstract
C
C     The parameters below form an enumerated list of the recognized
C     frame types.  They are: INERTL, PCK, CK, TK, DYN.  The meanings
C     are outlined below.
C
C$ Copyright
C
C     Copyright (1996), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C
C$ Parameters
C
C     INERTL      an inertial frame that is listed in the routine
C                 CHGIRF and that requires no external file to
C                 compute the transformation from or to any other
C                 inertial frame.
C
C     PCK         is a frame that is specified relative to some
C                 INERTL frame and that has an IAU model that
C                 may be retrieved from the PCK system via a call
C                 to the routine TISBOD.
C
C     CK          is a frame defined by a C-kernel.
C
C     TK          is a "text kernel" frame.  These frames are offset
C                 from their associated "relative" frames by a
C                 constant rotation.
C
C     DYN         is a "dynamic" frame.  These currently are
C                 parameterized, built-in frames where the full frame
C                 definition depends on parameters supplied via a 
C                 frame kernel.
C
C$ Author_and_Institution
C
C     N.J. Bachman    (JPL)
C     W.L. Taber      (JPL)
C
C$ Literature_References
C
C     None.
C
C$ Version
C
C-    SPICELIB Version 3.0.0, 28-MAY-2004 (NJB)
C
C       The parameter DYN was added to support the dynamic frame class.
C
C-    SPICELIB Version 2.0.0, 12-DEC-1996 (WLT)
C
C        Various unused frames types were removed and the
C        frame time TK was added.
C
C-    SPICELIB Version 1.0.0, 10-DEC-1995 (WLT)
C
C-&
 
 
 
      INTEGER               INERTL
      PARAMETER           ( INERTL = 1 )
 
      INTEGER               PCK
      PARAMETER           ( PCK    = INERTL + 1 )
 
      INTEGER               CK
      PARAMETER           ( CK     = PCK    + 1 )
 
      INTEGER               TK
      PARAMETER           ( TK     = CK     + 1 )
 
      INTEGER               DYN
      PARAMETER           ( DYN    = TK     + 1 )
