C$Procedure            FRSTNB ( First non-blank character )
 
      INTEGER FUNCTION FRSTNB ( STRING )
 
C$ Abstract
C
C      Return the index of the first non-blank character in
C      a character string.
C
C$ Copyright
C
C     Copyright (1995), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     None.
C
C$ Keywords
C
C      ASCII,  CHARACTER,  SEARCH
C
C$ Declarations
 
      CHARACTER*(*)    STRING
 
C$ Brief_I/O
C
C      VARIABLE  I/O  DESCRIPTION
C      --------  ---  --------------------------------------------------
C      STRING     I   Input character string.
C      FRSTNB     O   Index of the first non-blank character in STRING.
C
C$ Detailed_Input
C
C      STRING      is the input character string.
C
C$ Detailed_Output
C
C      FRSTNB      is the index if the first non-blank character
C                  in the input string. If there are no non-blank
C                  characters in the string, FRSTNB is zero.
C
C$ Parameters
C
C     None.
C
C$ Particulars
C
C      If the string is blank, return zero. Otherwise, step through
C      the string one character at a time until something other than
C      a blank is found. Return the index of that something within
C      the string.
C
C$ Examples
C
C      The following examples illustrate the use of FRSTNB.
C
C            FRSTNB ( 'ABCDE'         )   = 1
C            FRSTNB ( 'AN EXAMPLE'    )   = 1
C            FRSTNB ( '   AN EXAMPLE' )   = 4
C            FRSTNB ( '             ' )   = 0
C
C$ Restrictions
C
C      None.
C
C$ Exceptions
C
C      Error free.
C
C$ Files
C
C      None.
C
C$ Author_and_Institution
C
C      K.R. Gehringer  (JPL)
C      I.M. Underwood  (JPL)
C
C$ Literature_References
C
C      None.
C
C$ Version
C
C-     SPICELIB Version 2.0.0, 12-MAR-1996 (KRG)
C
C         Modified the comparison to use integer values and the ICHAR()
C         function. This improves the performance of the subroutine.
C
C-     SPICELIB Version 1.0.1, 10-MAR-1992 (WLT)
C
C         Comment section for permuted index source lines was added
C         following the header.
C
C-     SPICELIB Version 1.0.0, 31-JAN-1990 (IMU)
C
C-&
 
C$ Index_Entries
C
C     first non-blank character
C
C-&

C
C     Local parameters
C
      INTEGER               ISPACE
      PARAMETER           ( ISPACE = 32 )

C
C     Local variables
C
      INTEGER          I

C
C     Just like it says in the header.
C
      IF ( STRING .EQ. ' ' ) THEN
         FRSTNB = 0
 
      ELSE
         DO I = 1, LEN ( STRING )
 
            IF ( ICHAR(STRING(I:I)) .NE. ISPACE ) THEN
               FRSTNB = I
               RETURN
            END IF
 
         END DO
      END IF
 
      RETURN
      END
