C$Procedure                     HALFPI ( Half the value of pi )
 
      DOUBLE PRECISION FUNCTION HALFPI ( )
 
C$ Abstract
C
C     Return half the value of pi (the ratio of the circumference of
C     a circle to its diameter).
C
C$ Copyright
C
C     Copyright (1995), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     None.
C
C$ Keywords
C
C     CONSTANTS
C
C$ Declarations
C
C     None.
C
C$ Brief_I/O
C
C     The function returns half the value of pi.
C
C$ Detailed_Input
C
C     None.
C
C$ Detailed_Output
C
C     The function returns half the value of pi (the ratio of
C     a circle's circumference to its diameter), determined by
C     the ACOS function. That is,
C
C           HALFPI = ACOS ( -1.D0 ) * 0.5D0
C
C$ Parameters
C
C     None.
C
C$ Exceptions
C
C      Error free.
C
C$ Files
C
C     None.
C
C$ Particulars
C
C     The first time the function is referenced, the value is computed
C     as shown above. The value is saved, and returned directly upon
C     subsequent reference.
C
C$ Examples
C
C     The subroutine shown below illustrates the use of HALFPI.
C
C                 SUBROUTINE BFTRAN ( RA, DEC, W, TIPM )
C
C           C
C           C     Compute the transformation from inertial to body
C           C     fixed coordinates, given the directions of the north
C           C     pole and prime meridian of the body.
C           C
C                 DOUBLE PRECISION    RA
C                 DOUBLE PRECISION    DEC
C                 DOUBLE PRECISION    W
C                 DOUBLE PRECISION    TIPM ( 3,3 )
C
C           C
C     SPICELIB functions
C           C
C                 DOUBLE PRECISION      HALFPI
C
C           C
C           C     The transformation is defined by the compund
C           C     rotation
C           C
C           C        [W] [pi/2 - Dec] [RA + pi/2]
C           C           3            1           3
C           C
C                 CALL ROTATE (       RA + HALFPI(),  3, TIPM)
C                 CALL ROTMAT (TIPM,  HALFPI() - DEC, 1, TIPM)
C                 CALL ROTMAT (TIPM,  W,              3, TIPM)
C
C                 RETURN
C                 END
C
C$ Restrictions
C
C     None.
C
C$ Literature_References
C
C     None.
C
C$ Author_and_Institution
C
C     W.L. Taber      (JPL)
C     I.M. Underwood  (JPL)
C
C$ Version
C
C-     SPICELIB Version 1.0.1, 10-MAR-1992 (WLT)
C
C         Comment section for permuted index source lines was added
C         following the header.
C
C-     SPICELIB Version 1.0.0, 31-JAN-1990 (WLT) (IMU)
C
C-&
 
C$ Index_Entries
C
C     half the value of pi
C
C-&
 
 
 
 
C
C     Local variables
C
      DOUBLE PRECISION      VALUE
      SAVE                  VALUE
 
C
C     Initial values
C
      DATA                  VALUE      / 0.D0 /
 
 
C
C     What is there to say?
C
      IF ( VALUE .EQ. 0.D0 ) THEN
         VALUE = ACOS ( -1.D0 ) * 0.5D0
      END IF
 
      HALFPI = VALUE
 
      RETURN
      END
