C$Procedure      IDENT (Return the 3x3 identity matrix)
 
      SUBROUTINE IDENT ( MATRIX )
 
C$ Abstract
C
C    This routine returns the 3x3 identity matrix.
C
C$ Copyright
C
C     Copyright (1995), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     None.
C
C$ Keywords
C
C     MATRIX
C
C$ Declarations
 
      IMPLICIT NONE
      DOUBLE PRECISION      MATRIX ( 3, 3 )
 
 
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     MATRIX     O   is the 3x3 identity matrix
C
C$ Detailed_Input
C
C     None.
C
C$ Detailed_Output
C
C     MATRIX     is the 3x3 Identity matrix.  That is MATRIX is
C                the following
C                  _                       _
C                 |  1.0D0   0.0D0   0.0D0  |
C                 |  0.0D0   1.0D0   0.0D0  |
C                 |  0.0D0   0.0D0   1.0D0  |
C                  -                       -
C$ Parameters
C
C     None.
C
C$ Files
C
C     None.
C
C$ Exceptions
C
C     Error free.
C
C$ Particulars
C
C     This is a utility routine for obtaining the 3x3 identity matrix
C     so that you may avoid having to write the loop or assignments
C     needed to get the matrix.
C
C$ Examples
C
C     Suppose that you need to construct the matrix sum
C
C        I + OMEGA
C
C     where OMEGA is some matrix you have already computed.
C
C     The code fragment below shows how you could accomplish this
C     with this routine.
C
C        First get the Identity matrix
C
C        DOUBLE PRECISION      I ( 3, 3 )
C
C        CALL IDENT( I  )
C        CALL VSUMG( I, OMEGA, 9, SUM )
C
C
C$ Restrictions
C
C     None.
C
C$ Author_and_Institution
C
C     W.L. Taber      (JPL)
C
C$ Literature_References
C
C     None.
C
C$ Version
C
C-    SPICELIB Version 1.0.0, 5-FEB-1996 (WLT)
C
C
C-&
 
C$ Index_Entries
C
C     Get the 3x3 identity matrix
C
C-&
 
      MATRIX ( 1, 1 ) = 1.0D0
      MATRIX ( 2, 1 ) = 0.0D0
      MATRIX ( 3, 1 ) = 0.0D0
 
      MATRIX ( 1, 2 ) = 0.0D0
      MATRIX ( 2, 2 ) = 1.0D0
      MATRIX ( 3, 2 ) = 0.0D0
 
      MATRIX ( 1, 3 ) = 0.0D0
      MATRIX ( 2, 3 ) = 0.0D0
      MATRIX ( 3, 3 ) = 1.0D0
 
      RETURN
      END
