 
C$Procedure             ISOPEN ( Is a file currently open? )
 
      LOGICAL FUNCTION ISOPEN ( FILE )
 
C$ Abstract
C
C     Determine whether a named file is currently open.
C
C$ Copyright
C
C     Copyright (1995), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     None.
C
C$ Keywords
C
C     FILES
C
C$ Declarations
 
      CHARACTER*(*)    FILE
 
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     FILE       I   Name of the file in question.
C
C     The function returns the value TRUE if the file is open, FALSE
C     otherwise.
C
C$ Detailed_Input
C
C     FILE        is the name of the file in question.
C
C$ Detailed_Output
C
C     The function returns the value TRUE if the file is open, FALSE
C     otherwise.
C
C$ Parameters
C
C     None.
C
C$ Exceptions
C
C     1) If the filename is blank, the error SPICE(BLANKFILENAME) will
C        be signalled.
C
C     2) If an error occurs during the execution of the Fortran INQUIRE
C        statement, the error SPICE(INQUIREFAILED) is signalled.
C
C$ Files
C
C     None.
C
C$ Particulars
C
C     Use the Fortran INQUIRE statement to determine the open status
C     of FILE.
C
C$ Examples
C
C     The following code fragment illustrates the use of ISOPEN.
C
C           IF ( .NOT. ISOPEN ( FILE ) ) THEN
C              Open the file here
C           ELSE
C              ERROR = 'Input file is already open.'
C           END IF
C
C$ Restrictions
C
C     None.
C
C$ Author_and_Institution
C
C     K.R. Gehringer  (JPL)
C
C$ Literature_References
C
C     None.
C
C$ Version
C
C-     SPICELIB Version 1.1.0, 29-FEB-1996 (KRG)
C
C         Added a local logical variable that is used as temporary
C         storage for the results from the INQUIRE statement rather
C         than using the function name. This solved a problem on the
C         macintosh.
C
C-    SPICELIB Version 1.0.0, 05-OCT-1994 (KRG)
C
C-&
 
C$ Index_Entries
C
C     test for file already open
C     is a file open
C
C-&
 
C
C     SPICELIB functions
C
      LOGICAL               RETURN
 
C
C     Local variables
C
      INTEGER               IOSTAT
 
      LOGICAL               EXISTS
      LOGICAL               MYOPEN
 
C
C     Standard SPICE error handling.
C
      IF ( RETURN () ) THEN
         ISOPEN = .FALSE.
         RETURN
      ELSE
         CALL CHKIN ( 'ISOPEN' )
      END IF
 
C
C     First we test to see if the filename is blank.
C
      IF ( FILE .EQ. ' ' ) THEN
 
         ISOPEN = .FALSE.
         CALL SETMSG ( 'The file name is blank. ' )
         CALL SIGERR ( 'SPICE(BLANKFILENAME)'     )
         CALL CHKOUT ( 'ISOPEN'                   )
         RETURN
 
      END IF
 
C
C     So simple, it defies explanation.
C
      INQUIRE ( FILE   = FILE,
     .          EXIST  = EXISTS,
     .          OPENED = MYOPEN,
     .          IOSTAT = IOSTAT  )
 
      IF ( IOSTAT .NE. 0 ) THEN
 
         ISOPEN = .FALSE.
         CALL SETMSG ( 'Value of IOSTAT was *.' )
         CALL ERRINT ( '*', IOSTAT              )
         CALL SIGERR ( 'SPICE(INQUIREFAILED)'   )
         CALL CHKOUT ( 'ISOPEN'                 )
         RETURN
 
      END IF
C
C     A file cannot be open if it does not exist. We do actually need to
C     check this because some operating environments return .TRUE. for
C     the value of OPENED if a file does not exist.
C
      IF ( .NOT. EXISTS ) THEN
 
         MYOPEN = .FALSE.
 
      END IF
C
C     Set the function value, check out, and return.
C
 
      ISOPEN = MYOPEN

      CALL CHKOUT ( 'ISOPEN' )
      RETURN
      END
