C$Procedure      JYEAR ( Seconds per julian year )
 
      DOUBLE PRECISION FUNCTION JYEAR ()
 
C$ Abstract
C
C     Return the number of seconds in a julian year.
C
C$ Copyright
C
C     Copyright (1995), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C  None.
C
C$ Keywords
C
C      CONSTANTS
C
C$ Declarations
C
C     None.
C
C$ Brief_I/O
C
C      VARIABLE  I/O              DESCRIPTION
C      --------  ---  --------------------------------------------------
C      JYEAR       O   The number of seconds/julian year
C
C$ Detailed_Input
C
C     None.
C
C$ Detailed_Output
C
C     The function returns the number of seconds per julian
C     year.
C
C$ Parameters
C
C     None.
C
C$ Particulars
C
C     The julian year is often used as a fundamental unit
C     of time when dealing with ephemeris data.  For this
C     reason its value in terms of ephemeris seconds is
C     recorded in this function.
C
C$ Examples
C
C     Suppose you wish to compute the number of julian centuries
C     that have elapsed since the ephemeris epoch J1950 (beginning
C     of the julian year 1950) at a particular ET epoch.  The
C     following line of code will do the trick.
C
C
C        CENTRY = ( ET - UNITIM ( J1950(), 'JED', 'ET' ) )
C       .       / ( 100.0D0 * JYEAR() )
C
C
C$ Restrictions
C
C      None.
C
C$ Exceptions
C
C     Error free.
C
C$ Files
C
C      None.
C
C$ Author_and_Institution
C
C      W.L. Taber      (JPL)
C
C$ Literature_References
C
C      Explanatory Supplement to the Astronomical Almanac.
C      Page 8. University Science Books, 20 Edgehill Road,
C      Mill Valley, CA 94941
C
C$ Version
C
C-    SPICELIB Version 1.0.0, 13-JUL-1993 (WLT)
C
C-&
 
C$ Index_Entries
C
C     Number of seconds per julian year
C
C-&
 
      JYEAR = 31557600.0D0
 
      RETURN
      END
 
 
