C$Procedure             LASTPC ( Last printable character )
 
      INTEGER FUNCTION  LASTPC ( STRING )
 
C$ Abstract
C
C     Return the index of the last printable character in a character
C     string. ASCII characters 33-126 are printable. (Blanks are not
C     considered printable.)
C
C$ Copyright
C
C     Copyright (1995), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     None.
C
C$ Keywords
C
C      ASCII,  CHARACTER,  SEARCH
C
C$ Declarations
 
      CHARACTER*(*)    STRING
 
C$ Brief_I/O
C
C      VARIABLE  I/O  DESCRIPTION
C      --------  ---  --------------------------------------------------
C      STRING     I   Input character string.
C      LASTPC     O   Index of the last printable character in STRING.
C
C$ Detailed_Input
C
C      STRING      is the input character string.
C
C$ Detailed_Output
C
C      LASTPC      is the index of the last printable character
C                  in the input string. Characters 33-126 are
C                  considered to be printable characters. Blanks
C                  are not considered printable characters. If
C                  the input string contains no printable characters,
C                  LASTPC is zero.
C
C$ Parameters
C
C      None.
C
C$ Particulars
C
C      This works exactly like LASTNB, except that it skips
C      non-printable characters (ASCII control characters) as
C      well as blanks.
C
C$ Examples
C
C      The program
C
C         INTEGER         FRSTNB
C         INTEGER         FRSTPC
C         INTEGER         LASTNB
C         INTEGER         LASTPC
C
C         CHARACTER*10    S
C
C         S( 1: 1) = ' '
C         S( 2: 2) = CHAR (  2 )
C         S( 3: 3) = CHAR (  3 )
C         S( 4: 4) = 'A'
C         S( 5: 5) = 'B'
C         S( 6: 6) = 'C'
C         S( 7: 7) = CHAR (  7 )
C         S( 8: 8) = CHAR (  8 )
C         S( 9: 9) = CHAR (  9 )
C         S(10:10) = ' '
C
C         WRITE (*,*) 'Non-blank from ', FRSTNB(S), ' to ', LASTNB(S)
C         WRITE (*,*) 'Printable from ', FRSTPC(S), ' to ', LASTPC(S)
C
C         END
C
C      produces te following output:
C
C         Non-blank from 2 to 9.
C         Printable from 4 to 6.
C
C$ Restrictions
C
C      None.
C
C$ Exceptions
C
C     Error free.
C
C$ Files
C
C      None.
C
C$ Author_and_Institution
C
C      I.M. Underwood  (JPL)
C
C$ Literature_References
C
C      None.
C
C$ Version
C
C-    SPICELIB Version 1.0.1, 10-MAR-1992 (WLT)
C
C        Comment section for permuted index source lines was added
C        following the header.
C
C-    SPICELIB Version 1.0.0, 31-JAN-1990 (IMU)
C
C-&
 
C$ Index_Entries
C
C     last printable character
C
C-&
 
 
 
 
C$ Revisions
C
C-    Beta Version 1.0.1, 27-JAN-1989 (IMU)
C
C        Examples section completed.
C
C-&
 
 
 
C
C     Local variables
C
      INTEGER          I
 
 
 
C
C     Look for the last character in the range [33,126], and return
C     its index.
C
      DO I = LEN ( STRING ), 1, -1
 
         IF (       (ICHAR ( STRING(I:I) ) .GE.  33)
     .        .AND. (ICHAR ( STRING(I:I) ) .LE. 126) ) THEN
 
            LASTPC = I
            RETURN
         END IF
 
      END DO
 
C
C     Still here? No printable characters. Return zero.
C
      LASTPC = 0
 
      RETURN
      END
 
