C$Procedure      LATSPH ( Latitudinal to spherical coordinates )
 
      SUBROUTINE LATSPH ( RADIUS, LONG, LAT,  RHO, COLAT, LONGS )
 
C$ Abstract
C
C     Convert from latitudinal coordinates to spherical coordinates.
C
C$ Copyright
C
C     Copyright (1995), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     None.
C
C$ Keywords
C
C      CONVERSION,  COORDINATES
C
C$ Declarations
 
      DOUBLE PRECISION   RADIUS
      DOUBLE PRECISION   LONG
      DOUBLE PRECISION   LAT
      DOUBLE PRECISION   RHO
      DOUBLE PRECISION   COLAT
      DOUBLE PRECISION   LONGS
 
C$ Brief_I/O
C
C      VARIABLE  I/O  DESCRIPTION
C      --------  ---  --------------------------------------------------
C      RADIUS     I   Distance of a point from the origin.
C      LONG       I   Angle of the point from the XZ plane in radians.
C      LAT        I   Angle of the point from the XY plane in radians.
C      RHO        O   Distance of the point from the origin.
C      COLAT      O   Angle of the point from positive Z axis (radians).
C      LONGS      O   Angle of the point from the XZ plane (radians).
C
C$ Detailed_Input
C
C      RADIUS     Distance of a point from the origin.
C
C      LONG       Angle of the point from the XZ plane in radians.
C
C      LAT        Angle of the point from the XY plane in radians.
C
C$ Detailed_Output
C
C      RHO        Distance of the point from the origin.
C
C      COLAT      Angle between the vector from the origin to the point
C                 and the positive Z axis in radians.
C
C      LONGS      Angle of the point from the XZ plane (radians).
C
C$ Parameters
C
C      None.
C
C$ Particulars
C
C      This routine returns the spherical coordinates of a point
C      whose position is input in latitudinal coordinates.
C
C      Latitudinal coordinates are defined by a distance from a central
C      reference point, an angle from a reference meridian, and an angle
C      above the equator of a sphere centered at the central reference
C      point.
C
C      Spherical coordinates are defined by a distance from a central
C      reference point, an angle from a reference meridian, and an angle
C      from the z-axis.
C
C$ Examples
C
C      Co-latitude is obtained by subtracting latitude from HALFPI()
C      Radius and longitude mean the same thing in both latitudinal
C      and spherical coordinates.  The table below lists LAT
C      corresponding COLAT in terms of degrees.
C
C             LAT            COLAT
C            ------         ------
C              0             90
C             20             70
C             45             45
C            -30            120
C             90              0
C            -45            135
C
C$ Restrictions
C
C      None.
C
C$ Exceptions
C
C     Error free.
C
C$ Files
C
C      None.
C
C$ Author_and_Institution
C
C      W.L. Taber      (JPL)
C
C$ Literature_References
C
C      None.
C
C$ Version
C
C-    SPICELIB Version 1.0.1, 10-MAR-1992 (WLT)
C
C        Comment section for permuted index source lines was added
C        following the header.
C
C-    SPICELIB Version 1.0.0, 31-JAN-1990 (WLT)
C
C-&
 
C$ Index_Entries
C
C     latitudinal to spherical coordinates
C
C-&
 
 
C$ Revisions
C
C-     Beta Version 1.0.1, 1-Feb-1989 (WLT)
C
C      Example section of header upgraded.
C
C-&
 
C
C     SPICELIB functions
C
      DOUBLE PRECISION      HALFPI
 
C
C     Local Variables
C
      DOUBLE PRECISION TH
      DOUBLE PRECISION PH
 
C
C     Convert to spherical coordinates, storing the results in
C     temporary variables
C
      TH = HALFPI() - LAT
      PH = LONG
 
C
C     Move results to output variables
C
      RHO   = RADIUS
      COLAT = TH
      LONGS = PH
 
      RETURN
      END
