C$Procedure      LJUST ( Left justify a character string )
 
      SUBROUTINE LJUST ( INPUT, OUTPUT )
 
C$ Abstract
C
C      Left justify a character string.
C
C$ Copyright
C
C     Copyright (1995), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C      None.
C
C$ Keywords
C
C      ASCII,  CHARACTER,  STRING
C
C$ Declarations
 
      CHARACTER*(*)    INPUT
      CHARACTER*(*)    OUTPUT
 
C$ Brief_I/O
C
C      VARIABLE  I/O  DESCRIPTION
C      --------  ---  --------------------------------------------------
C      INPUT      I   Input character string.
C      OUTPUT     O   Output character string, left justified.
C
C$ Detailed_Input
C
C      INPUT       is the input character string.
C
C$ Detailed_Output
C
C      OUTPUT      is the output character string, left justified.
C
C                  OUTPUT may overwrite INPUT.
C
C$ Parameters
C
C     None.
C
C$ Exceptions
C
C      Error free.
C
C$ Particulars
C
C      Leading blanks are removed from the input character string.
C      If the output string is not large enough to hold the left
C      justified string, it is truncated on the right.
C
C$ Examples
C
C      The following examples illustrate the use of LJUST.
C
C            'ABCDE'             becomes   'ABCDE'
C            'AN EXAMPLE'                  'AN EXAMPLE'
C            '   AN EXAMPLE  '             'AN EXAMPLE'
C            '               '             ' '
C
C$ Restrictions
C
C      None.
C
C$ Files
C
C      None.
C
C$ Author_and_Institution
C
C      I.M. Underwood  (JPL)
C
C$ Literature_References
C
C      None.
C
C$ Version
C
C-      SPICELIB Version 1.0.1, 10-MAR-1992 (WLT)
C
C          Comment section for permuted index source lines was added
C          following the header.
C
C-      SPICELIB Version 1.0.0, 31-JAN-1990 (IMU)
C
C-&
 
C$ Index_Entries
C
C     left justify a character_string
C
C-&
 
 
C
C     Local variables
C
      INTEGER               LI
      INTEGER               LO
      INTEGER               I
      INTEGER               J
      INTEGER               POS
 
 
C
C     Blank string?
C
      IF ( INPUT .EQ. ' ' ) THEN
         OUTPUT = ' '
 
C
C     Get the first non-blank character. Start OUTPUT at that point.
C
      ELSE
 
         LI = LEN    ( INPUT )
         LO = LEN    ( OUTPUT)
 
         J  = 1
 
C
C        Set I equal to position of first non-blank character of
C        INPUT:
C
         I   = 0
         POS = 1
 
         DO WHILE ( I .EQ. 0 )
 
            IF ( INPUT(POS:POS) .NE. ' ' )  THEN
               I    =  POS
            ELSE
               POS  =  POS + 1
            END IF
 
         END DO
C
C        I is now the index of the first non-blank character of INPUT;
C        I is zero if INPUT is blank.
C
 
         DO WHILE  ( ( I .LE. LI ) .AND. ( J .LE. LO ) )
            OUTPUT(J:J) = INPUT(I:I)
            J           = J + 1
            I           = I + 1
         END DO
 
         IF ( J .LE. LO ) THEN
            OUTPUT(J:) = ' '
         END IF
 
      END IF
 
      RETURN
      END
