C$Procedure   LTRIM ( Left trim )
 
      INTEGER FUNCTION LTRIM ( STRING )
 
C$ Abstract
C
C     Return the maximum of 1 and the location of the first non-blank
C     character in the string.
C
C$ Copyright
C
C     Copyright (1995), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     None.
C
C$ Keywords
C
C     CHARACTER
C     STRING
C
C$ Declarations
 
      CHARACTER*(*)         STRING
 
C$ Brief_I/O
C
C     Variable  I/O  Description
C     --------  ---  --------------------------------------------------
C
C     STRING     I   String to be trimmed.
C
C     The function returns the maximum of 1 and the location of the
C     first non-blank character in STRING.
C
C$ Detailed_Input
C
C     STRING         is a string to be trimmed:  the location of the
C                    first non-blank character is desired.
C
C$ Detailed_Output
C
C     The function returns the maximum of 1 and the location of the
C     first non-blank character in STRING.
C
C     In particular, when STRING is blank, the function returns the
C     value 1.
C
C$ Parameters
C
C     None.
C
C$ Files
C
C     None.
C
C$ Exceptions
C
C     Error free.
C
C$ Particulars
C
C     When writing a character string to a file, we may wish to omit
C     leading blanks.  We'd like to use FRSTNB as a lower substring
C     bound, but we have to handle the case where FRSTNB returns 0,
C     so we write:
C
C
C        WRITE ( UNIT, '(A)' ),  STRING ( MAX (1, FRSTNB (STRING)) : )
C
C
C     This can be simplified using LTRIM:
C
C
C        WRITE ( UNIT, '(A)' ),  STRING ( LTRIM (STRING) : )
C
C
C     This routine has a counterpart, RTRIM, which finds the maximum of
C     1 and the position of the last non-blank character of a string.
C
C$ Examples
C
C     1)  Write the non-blank portion of each element of a character
C         cell to file SPUD.DAT:
C
C            DO I = 1,  CARDC (CELL)
C
C               CALL WRLINE ( 'SPUD.DAT',
C           .                  CELL(I) ( LTRIM (CELL) : RTRIM (CELL) ) )
C
C            END DO
C
C         When CELL(I) is blank, the string ' ' will be written.
C
C$ Restrictions
C
C     None.
C
C$ Literature_References
C
C     None.
C
C$ Author_and_Institution
C
C     N.J. Bachman   (JPL)
C
C$ Version
C
C-    SPICELIB Version 1.0.1, 10-MAR-1992 (WLT)
C
C        Comment section for permuted index source lines was added
C        following the header.
C
C-    SPICELIB Version 1.0.0, 02-MAY-1990  (NJB)
C
C-&
 
C$ Index_Entries
C
C     left trim
C
C-&
 
 
 
C
C     SPICELIB functions
C
      INTEGER               FRSTNB
 
C
C     `Just do it'.
C
      LTRIM = MAX ( 1, FRSTNB (STRING) )
 
      END
