C$Procedure  MOVEC  ( Move a character array to another )
 
      SUBROUTINE MOVEC ( ARRFRM, NDIM, ARRTO )
 
C$ Abstract
C
C      Copy the elements of one character array into another
C      array.
C
C$ Copyright
C
C     Copyright (1995), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     None.
C
C$ Keywords
C
C      ARRAY
C
C$ Declarations
 
      CHARACTER*(*)   ARRFRM ( * )
      INTEGER         NDIM
      CHARACTER*(*)   ARRTO  ( * )
 
C$ Brief_I/O
C
C      VARIABLE  I/O              DESCRIPTION
C      --------  ---  --------------------------------------------------
C      ARRFRM     I     Character array to be moved.
C      NDIM       I     Number of elements to copy, i.e. the dimension
C                       of ARRFRM and ARRTO.
C      ARRTO      O     Destination array.
C
C$ Detailed_Input
C
C      ARRFRM     Array from which to copy items.
C
C      NDIM       Number of items to copy.
C
C$ Detailed_Output
C
C      ARRTO      Array to which items should be copied.
C
C$ Parameters
C
C      None.
C
C$ Particulars
C
C      This routine is simply shorthand for the following 3 lines of
C      code.
C
C              DO I = 1, NDIM
C                 ARRTO(I) = ARRFRM(I)
C              END DO
C
C$ Examples
C
C      Often one needs to make a temporary copy of an array so that
C      it can be manipulated without altering the original array.
C      As pointed out in particulars, you could just do this within
C      the code that needs the copy.  However, if you have several
C      arrays to copy, you can cut the number of lines of code that
C      are needed by a third.
C
C      For example:
C
C           DO I = 1, 19
C              TEMPA(I) = A(I)
C           END DO
C
C           DO I = 1, 38
C              TEMPB(I) = B(I)
C           END DO
C
C     Can be rewritten as
C
C           CALL MOVEC ( A, 19, TEMPA )
C           CALL MOVEC ( B, 38, TEMPB )
C
C$ Restrictions
C
C      None.
C
C$ Exceptions
C
C     Error free.
C
C$ Files
C
C      None.
C
C$ Author_and_Institution
C
C      W.M. Owen       (JPL)
C      W.L. Taber      (JPL)
C
C$ Literature_References
C
C      None.
C
C$ Version
C
C-    SPICELIB Version 1.0.1, 10-MAR-1992 (WLT)
C
C        Comment section for permuted index source lines was added
C        following the header.
C
C-    SPICELIB Version 1.0.0, 31-JAN-1990 (WMO)
C
C-&
 
C$ Index_Entries
C
C     move a character array to another character array
C
C-&
 
 
C$ Revisions
C
C-     Beta Version 1.0.1, 4-FEB-1989 (WLT)
C
C      Header fully filled out.
C
C-&
 
C
C     Local variables
C
      INTEGER I
 
 
      DO I = 1, NDIM
        ARRTO(I) = ARRFRM(I)
      END DO
 
 
      RETURN
      END
