C$Procedure            OPSGND ( Opposite Sign Double Precision Numbers )
 
      LOGICAL FUNCTION OPSGND  ( X, Y )
 
C$ Abstract
C
C      Function: true if the input arguments have opposite signs.
C
C$ Copyright
C
C     Copyright (1995), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     None.
C
C$ Keywords
C
C      NUMBERS
C
C$ Declarations
 
      DOUBLE PRECISION   X
      DOUBLE PRECISION   Y
 
C$ Brief_I/O
C
C      VARIABLE  I/O  DESCRIPTION
C      --------  ---  --------------------------------------------------
C      X          I   A double precision number
C      Y          I   A double precision number
C
C$ Detailed_Input
C
C      X      is any double precision number.
C
C      Y      is any double precision number.
C
C$ Detailed_Output
C
C      OPSGND is returned as .TRUE. if one of the pair X,Y is positive
C             and the other is negative.
C
C$ Parameters
C
C     None.
C
C$ Particulars
C
C      This routine returns the value:
C
C            (      (( X .GT. 0) .AND. (Y .LT. 0))
C              .OR. (( X .LT. 0) .AND. (Y .GT. 0)) )
C
C      This is a more stable value than
C
C            ( X*Y .LT. 0 )
C
C      Note that if either of the two values is zero, OPSGND will be
C      false.
C
C$ Examples
C
C      This routine can be used whenever a decision depends upon two
C      Double Precision values having opposite signs.
C
C      IF ( OPSGND ( F(X1), F(X2) ) ) THEN
C            .
C            .
C         find a root of F lying between X1 and X2
C            .
C            .
C      ELSE
C            .
C            .
C         do something
C            .
C            .
C      END IF
C
C$ Restrictions
C
C      None.
C
C$ Exceptions
C
C      Error free.
C
C$ Files
C
C      None.
C
C$ Author_and_Institution
C
C      W.L. Taber      (JPL)
C
C$ Literature_References
C
C      None.
C
C$ Version
C
C-     SPICELIB Version 1.0.1, 10-MAR-1992 (WLT)
C
C         Comment section for permuted index source lines was added
C         following the header.
C
C-     SPICELIB Version 1.0.0, 31-JAN-1990 (WLT)
C
C-&
 
C$ Index_Entries
C
C     opposite sign d.p. numbers
C
C-&
 
 
      OPSGND = (      (( X .GT. 0 ) .AND. ( Y .LT. 0 ))
     .           .OR. (( X .LT. 0 ) .AND. ( Y .GT. 0 ))
     .         )
 
      RETURN
      END
