C$Procedure PRODAD ( Product of a double precision array )
 
      DOUBLE PRECISION FUNCTION  PRODAD ( ARRAY, N )
 
C$ Abstract
C
C      Return the product of the elements of a double precision array.
C
C$ Copyright
C
C     Copyright (1995), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     None.
C
C$ Keywords
C
C      ARRAY,  MATH,  UTILITY
C
C$ Declarations
 
      DOUBLE PRECISION   ARRAY ( * )
      INTEGER            N
 
C$ Brief_I/O
C
C      VARIABLE  I/O  DESCRIPTION
C      --------  ---  --------------------------------------------------
C      ARRAY      I   Input array.
C      N          I   Number of elements in ARRAY.
C      PRODAD     O   Product of the elements of ARRAY.
C
C$ Detailed_Input
C
C      ARRAY       is the input array.
C
C      N           is the number of elements in the array.
C
C$ Detailed_Output
C
C      PRODAD      is the product of the elements of the input array.
C                  That is,
C
C                     PRODAD = ARRAY(1) * ARRAY(2) * ... * ARRAY(N)
C
C                  If N is zero or negative, PRODAD is one.
C
C$ Parameters
C
C     None.
C
C$ Particulars
C
C      The value of the function is initially set to one. The elements
C      of the array are then multiplied. If the number of elements is
C      zero or negative, PRODAD is one.
C
C$ Examples
C
C      Let ARRAY contain the following elements.
C
C            ARRAY(1) = 12.D0
C            ARRAY(2) =  2.D0
C            ARRAY(3) =  4.D0
C            ARRAY(4) = 75.D0
C            ARRAY(5) = 18.D0
C
C      Then
C
C            PRODAD ( ARRAY,   -3 )       =      1.D0
C            PRODAD ( ARRAY,    0 )       =      1.D0
C            PRODAD ( ARRAY,    1 )       =     12.D0
C            PRODAD ( ARRAY,    2 )       =     24.D0
C            PRODAD ( ARRAY,    5 )       = 129600.D0
C            PRODAD ( ARRAY(3), 3 )       =   5400.D0
C
C
C$ Restrictions
C
C      PRODAD does not check for overflow.
C
C$ Exceptions
C
C      Error free.
C
C$ Files
C
C      None.
C
C$ Author_and_Institution
C
C      I.M. Underwood  (JPL)
C
C$ Literature_References
C
C      None.
C
C$ Version
C
C-     SPICELIB Version 1.0.1, 10-MAR-1992 (WLT)
C
C         Comment section for permuted index source lines was added
C         following the header.
C
C-     SPICELIB Version 1.0.0, 31-JAN-1990 (IMU)
C
C-&
 
C$ Index_Entries
C
C     product of a d.p. array
C
C-&
 
 
 
 
C
C     Local variables
C
      DOUBLE PRECISION PROD
      INTEGER          I
 
 
C
C     Begin at one.
C
      PROD = 1.D0
 
C
C     Multiply the elements. If N is zero or negative, nothing happens.
C
      DO I = 1, N
         PROD = PROD * ARRAY(I)
      END DO
 
C
C     Return the product.
C
      PRODAD = PROD
 
      RETURN
      END
