C$Procedure   PRSDP   ( Parse d.p. number with error checking )
 
      SUBROUTINE PRSDP ( STRING, DPVAL )
      IMPLICIT NONE
 
C$ Abstract
C
C     Parse a string as a double precision number, encapsulating error
C     handling.
C
C$ Copyright
C
C     Copyright (1996), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     None.
C
C$ Keywords
C
C     NUMBER
C     PARSING
C
C$ Declarations
 
      CHARACTER*(*)         STRING
      DOUBLE PRECISION      DPVAL
 
C$ Brief_I/O
C
C     Variable  I/O  Description
C     --------  ---  --------------------------------------------------
C     STRING     I   String representing a d.p. number.
C     DPVAL      O   D.p. value obtained by parsing STRING.
C
C$ Detailed_Input
C
C     STRING         is a string representing a double precision
C                    number.  Any string acceptable to the SPICELIB
C                    routine NPARSD is allowed.
C
C$ Detailed_Output
C
C     DPVAL          is the double precision number obtained by parsing
C                    STRING.
C
C$ Parameters
C
C     None.
C
C$ Exceptions
C
C     1) If the input string cannot be parsed, the error
C        SPICE(NOTADPNUMBER) is signalled.
C
C$ Files
C
C     None.
C
C$ Particulars
C
C     The purpose of this routine is to enable safe parsing of double
C     precision numbers without the necessity of in-line error checking.
C     This routine is based on the SPICELIB routine NPARSD.
C
C$ Examples
C
C     See the routine NPARSD for an examples of allowed strings.
C
C$ Restrictions
C
C     None.
C
C$ Literature_References
C
C     None.
C
C$ Author_and_Institution
C
C     N.J. Bachman       (JPL)
C
C$ Version
C
C-    SPICELIB Version 1.1.0, 15-SEP-1997 (NJB)
C
C        Bug fix:  output argument declaration changed from INTEGER
C        to DOUBLE PRECISION.
C
C-    SPICELIB Version 1.0.0, 22-JUL-1997 (NJB)
C
C-&
 
C$ Index_Entries
C
C     parse d.p. number with encapsulated error handling
C
C-&


C
C     Local parameters
C
      INTEGER               MSGLEN
      PARAMETER           ( MSGLEN = 320 )
 
C
C     Local variables
C
      CHARACTER*(MSGLEN)    ERRMSG
      INTEGER               PTR
 
 
C
C     Use discovery check-in.
C
      CALL NPARSD ( STRING, DPVAL, ERRMSG, PTR )
 
      IF ( ERRMSG .NE. ' ' ) THEN
 
         CALL CHKIN  ( 'PRSDP'               )
         CALL SETMSG ( ERRMSG                )
         CALL SIGERR ( 'SPICE(NOTADPNUMBER)' )
         CALL CHKOUT ( 'PRSDP'               )
         RETURN
 
      END IF
 
      RETURN
      END
