C$Procedure   PRSINT   ( Parse integer with error checking )
 
      SUBROUTINE PRSINT ( STRING, INTVAL )
      IMPLICIT NONE
 
C$ Abstract
C
C     Parse a string as an integer, encapsulating error handling.
C
C$ Copyright
C
C     Copyright (1996), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     None.
C
C$ Keywords
C
C     INTEGER
C     PARSING
C
C$ Declarations
 
      CHARACTER*(*)         STRING
      INTEGER               INTVAL
 
C$ Brief_I/O
C
C     Variable  I/O  Description
C     --------  ---  --------------------------------------------------
C     STRING     I   String representing an integer.
C     INTVAL     O   Integer value obtained by parsing STRING.
C
C$ Detailed_Input
C
C     STRING         is a string representing an integer.  Any string
C                    acceptable to the SPICELIB routine NPARSI is
C                    allowed.
C
C$ Detailed_Output
C
C     INTVAL         is the integer obtained by parsing STRING.
C
C$ Parameters
C
C     None.
C
C$ Exceptions
C
C     1) If the input string cannot be parsed, the error
C        SPICE(NOTANINTEGER) is signalled.
C
C$ Files
C
C     None.
C
C$ Particulars
C
C     The purpose of this routine is to enable safe parsing of integers
C     without the necessity of in-line error checking.  This routine is
C     based on the SPICELIB routine NPARSI.
C
C$ Examples
C
C     See the routine NPARSI for an examples of allowed strings.
C
C$ Restrictions
C
C     None.
C
C$ Literature_References
C
C     None.
C
C$ Author_and_Institution
C
C     N.J. Bachman       (JPL)
C
C$ Version
C
C-    SPICELIB Version 1.0.0, 22-JUL-1997 (NJB)
C
C-&
 
C$ Index_Entries
C
C     parse integer with encapsulated error handling
C
C-&
 
C
C     Local parameters
C
      INTEGER               MSGLEN
      PARAMETER           ( MSGLEN = 320 )
 
C
C     Local variables
C
      CHARACTER*(MSGLEN)    ERRMSG
      INTEGER               PTR
 
C
C     Use discovery check-in.
C
      CALL NPARSI ( STRING, INTVAL, ERRMSG, PTR )
 
      IF ( ERRMSG .NE. ' ' ) THEN
 
         CALL CHKIN  ( 'PRSINT'               )
         CALL SETMSG ( ERRMSG                 )
         CALL SIGERR ( 'SPICE(NOTANINTEGER)'  )
         CALL CHKOUT ( 'PRSINT'               )
         RETURN
 
      END IF
 
      RETURN
      END
