C$Procedure      PUTDEV ( Store Error Output Device Specification )
 
      SUBROUTINE PUTDEV ( DEVICE )
 
C$ Abstract
C
C     PUTDEV is a low-level data structure access routine which stores
C     the error output device specification.  DO NOT CALL THIS ROUTINE.
C     USE ERRDEV, NOT PUTDEV, TO CHOOSE THE ERROR OUTPUT DEVICE.
C
C$ Copyright
C
C     Copyright (1995), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     ERROR
C
C$ Keywords
C
C     ERROR
C
C$ Declarations
 
      CHARACTER*(*)          DEVICE
 
      INTEGER                FILEN
      PARAMETER            ( FILEN = 128 )
 
C$ Brief_I/O
C
C      VARIABLE  I/O  DESCRIPTION
C      --------  ---  --------------------------------------------------
C      DEVICE     I   The error output device specification.
C      FILEN      P   The maximum length of a file name.
C
C$ Detailed_Input
C
C      DEVICE         The new value of the error output device
C                     specification.  This value will be saved.
C
C$ Detailed_Output
C
C      None.
C
C$ Parameters
C
C      FILEN          The maximum length of a file name.
C
C$ Exceptions
C
C      None.
C
C$ Files
C
C      None.
C
C$ Particulars
C
C      DO NOT CALL THIS ROUTINE.
C
C      This is a data structure access routine for the SPICELIB
C      error output device specification.  This routine should
C      be used for no other purpose; in particular, it should
C      not be used by non-toolkit routines to specify the error
C      error output device to be used by the toolkit.  Use ERRDEV
C      for that.
C
C$ Examples
C
C      None.
C
C$ Restrictions
C
C      DO NOT CALL THIS ROUTINE.
C
C      Calls to this routine by routines other than the
C      SPICELIB error handling routines may interfere
C      with error processing.
C
C$ Literature_References
C
C      None.
C
C$ Author_and_Institution
C
C      N.J. Bachman    (JPL)
C      H.A. Neilan     (JPL)
C
C$ Version
C
C-    SPICELIB Version 3.2.0, 03-JAN-2005 (BVS)
C
C        Updated for PC-CYGWIN_C.
C
C-    SPICELIB Version 3.1.0, 03-JAN-2005 (BVS)
C
C        Updated for PC-CYGWIN.
C
C-    SPICELIB Version 3.0.5, 17-JUL-2002 (BVS)
C
C        Added MAC-OSX environments.
C
C-    SPICELIB Version 3.0.4, 08-OCT-1999 (WLT)
C
C        The environment lines were expanded so that the supported
C        environments are now explicitely given.  New
C        environments are WIN-NT
C
C-    SPICELIB Version 3.0.3, 24-SEP-1999 (NJB)
C
C        CSPICE environments were added.  Some typos were corrected.
C
C-    SPICELIB Version 3.0.2, 28-JUL-1999 (WLT)
C
C        The environment lines were expanded so that the supported
C        environments are now explicitly given.  New
C        environments are PC-DIGITAL, SGI-O32 and SGI-N32.
C
C-    SPICELIB Version 3.0.1, 18-MAR-1999 (WLT)
C
C        The environment lines were expanded so that the supported
C        environments are now explicitly given.  Previously,
C        environments such as SUN-SUNOS and SUN-SOLARIS were implied
C        by the environment label SUN.
C
C-    SPICELIB Version 3.0.0, 07-APR-1998 (NJB)
C
C        Module was updated for the PC-LINUX platform.
C
C-     SPICELIB Version 2.1.0, 5-JAN-1995 (HAN)
C
C         Module was updated to include one declaration for
C         the variable FILEN for the Macintosh environment.
C
C-     SPICELIB Version 2.0.0, 9-NOV-1993 (HAN)
C
C         Module was updated to include the value for FILEN
C         for the Silicon Graphics, DEC Alpha-OSF/1, and
C         NeXT platforms. Also, the previous value of 256 for
C         Unix platforms was changed to 255.
C
C-     SPICELIB Version 1.1.0, 12-OCT-1992 (HAN)
C
C         Updated module for multiple environments.
C
C         The code was also reformatted so that a utility program can
C         create the source file for a specific environment given a
C         master source file.
C
C-     SPICELIB Version 1.0.1, 10-MAR-1992 (WLT)
C
C         Comment section for permuted index source lines was added
C         following the header.
C
C-     SPICELIB Version 1.0.0, 31-JAN-1990 (NJB)
C
C-&
 
C$ Index_Entries
C
C     None.
C
C-&
 
 
 
C$ Revisions
C
C-    SPICELIB Version 3.0.0, 07-APR-1998 (NJB)
C
C        Module was updated for the PC-LINUX platform.
C
C-     SPICELIB Version 2.0.0, 9-NOV-1993 (HAN)
C
C         Module was updated to include the value for FILEN
C         for the Silicon Graphics, DEC Alpha-OSF/1, and
C         NeXT platforms. Also, the previous value of 256 for
C         Unix platforms was changed to 255.
C
C-     SPICELIB Version 1.1.0, 12-OCT-1992 (HAN)
C
C         Updated module for multiple environments.
C
C         The code was also reformatted so that a utility program can
C         create the source file for a specific environment given a
C         master source file.
C
C-     Beta Version 1.0.1, 08-FEB-1989 (NJB)
C
C         Warnings added to discourage use of this routine in
C         non-error-handling code.  Parameters section added.
C         Parameter declarations moved to "Declarations" section.
C
C-&
 
 
 
C
C     Local Variables:
C
 
C
C     The current error output device specification:
C
 
      CHARACTER*(FILEN)     SAVDEV
 
      SAVE                  SAVDEV
 
C
C     Initial values:
C
 
      DATA    SAVDEV      / 'SCREEN' /
 
 
 
C
C     Executable Code:
C
 
 
      SAVDEV = DEVICE
 
      RETURN
 
 
 
 
C$Procedure      GETDEV ( Get Error Output Device Specification )
 
       ENTRY GETDEV ( DEVICE )
 
C$ Abstract
C
C      Return the value of the current error output device
C      specification.
C
C$ Copyright
C
C     Copyright (1995), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C      ERROR
C
C$ Keywords
C
C      ERROR
C
C$ Declarations
C
C      CHARACTER*(*)          DEVICE
C
C$ Brief_I/O
C
C      VARIABLE  I/O  DESCRIPTION
C      --------  ---  --------------------------------------------------
C
C      DEVICE     O   The error output device specification.
C
C$ Detailed_Input
C
C      None.
C
C$ Detailed_Output
C
C      DEVICE    is the current error output device specification.
C                See the "required reading" file for a detailed
C                discussion of the error output device.
C
C$ Parameters
C
C      None.
C
C$ Exceptions
C
C      None.
C
C      However, this routine is part of the SPICELIB error
C      handling mechanism.
C
C$ Files
C
C      None.
C
C$ Particulars
C
C      None.
C
C$ Examples
C
C      None.
C
C$ Restrictions
C
C      None.
C
C$ Literature_References
C
C      None.
C
C$ Author_and_Institution
C
C      N.J. Bachman    (JPL)
C
C$ Version
C
C-    SPICELIB Version 3.0.5, 17-JUL-2002 (BVS)
C
C        Added MAC-OSX environments.
C
C-    SPICELIB Version 3.0.4, 08-OCT-1999 (WLT)
C
C        The environment lines were expanded so that the supported
C        environments are now explicitely given.  New
C        environments are WIN-NT
C
C-    SPICELIB Version 3.0.3, 24-SEP-1999 (NJB)
C
C        CSPICE environments were added.  Some typos were corrected.
C
C-    SPICELIB Version 3.0.2, 28-JUL-1999 (WLT)
C
C        The environment lines were expanded so that the supported
C        environments are now explicitly given.  New
C        environments are PC-DIGITAL, SGI-O32 and SGI-N32.
C
C-    SPICELIB Version 3.0.1, 18-MAR-1999 (WLT)
C
C        The environment lines were expanded so that the supported
C        environments are now explicitly given.  Previously,
C        environments such as SUN-SUNOS and SUN-SOLARIS were implied
C        by the environment label SUN.
C
C-     SPICELIB Version 1.0.1, 10-MAR-1992 (WLT)
C
C         Comment section for permuted index source lines was added
C         following the header.
C
C-     SPICELIB Version 1.0.0, 31-JAN-1990 (NJB)
C
C-&
 
C$ Index_Entries
C
C     None.
C
C-&
 
 
 
 
 
C
C     Executable Code:
C
 
C
C     Grab saved error output device specification:
C
 
      DEVICE = SAVDEV
 
      END
 
