C$Procedure      RMDUPC ( Remove duplicates from a character array )
 
      SUBROUTINE RMDUPC ( NELT, ARRAY )
 
C$ Abstract
C
C      Remove duplicate elements from a character array.
C
C$ Copyright
C
C     Copyright (1995), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     None.
C
C$ Keywords
C
C      ARRAY
C
C$ Declarations
 
      INTEGER          NELT
      CHARACTER*(*)    ARRAY   (*)
 
C$ Brief_I/O
C
C      VARIABLE  I/O  DESCRIPTION
C      --------  ---  --------------------------------------------------
C      NELT      I/O  Number of elements in the array.
C      ARRAY     I/O  Input/output array.
C
C$ Detailed_Input
C
C      NELT        on input is the number of elements in the input
C                  array.
C
C      ARRAY       on input contains zero or more elements, from which
C                  all duplicate elements are to be removed.
C
C$ Detailed_Output
C
C      NELT        on output is the number of elements in the output
C                  array.
C
C      ARRAY       on output contains the distinct elements of the
C                  input array, sorted in increasing order. (Character
C                  arrays are sorted according to the ASCII collating
C                  sequence).
C
C$ Parameters
C
C     None.
C
C$ Particulars
C
C      None.
C
C$ Examples
C
C      Let the arrays C and I contain the following elements.
C
C            NC   = 7                NI   =   5
C            C(1) = 'Miranda'        I(1) =  13
C            C(2) = 'Ariel'          I(2) = -13
C            C(3) = 'Umbriel'        I(3) =   0
C            C(4) = 'Titania'        I(4) =   1
C            C(5) = 'Miranda'        I(5) =   0
C            C(6) = 'Oberon'
C            C(7) = 'Umbriel'
C
C      Then following the calls
C
C            CALL RMDUPC ( NC, C )
C            CALL RMDUPI ( NI, I )
C
C      C and I contain the following.
C
C            NC   = 5                NI   =   4
C            C(1) = 'Ariel'          I(1) = -13
C            C(2) = 'Miranda'        I(2) =   0
C            C(3) = 'Oberon'         I(3) =   1
C            C(4) = 'Titania'        I(4) =  13
C            C(5) = 'Umbriel'
C
C$ Restrictions
C
C      None.
C
C$ Exceptions
C
C      Error free.
C
C$ Files
C
C      None.
C
C$ Literature_References
C
C      None.
C
C$ Author_and_Institution
C
C      I.M. Underwood  (JPL)
C
C$ Version
C
C-     SPICELIB Version 1.0.1, 10-MAR-1992 (WLT)
C
C         Comment section for permuted index source lines was added
C         following the header.
C
C-     SPICELIB Version 1.0.0, 31-JAN-1990 (IMU)
C
C-&
 
C$ Index_Entries
C
C     remove duplicates from a character array
C
C-&
 
 
 
 
C
C     Local variables
C
      INTEGER          I
      INTEGER          J
 
 
 
C
C     Proceed only if the array actualy contains more than one element.
C
      IF ( NELT .GT. 1 ) THEN
 
C
C        Sort the array in place.
C
         CALL SHELLC ( NELT, ARRAY )
 
C
C        Drop duplicate entries. Compare adjacent entries, and move
C        duplicates forward. (Duplicates are now adjacent, because of
C        sorting.)
C
         J = 1
 
         DO I = 2, NELT
 
            IF ( ARRAY(I) .NE. ARRAY(I-1) ) THEN
               J        = J + 1
               ARRAY(J) = ARRAY(I)
            END IF
 
        END DO
 
        NELT = J
 
      END IF
 
      RETURN
      END
