C$Procedure      SHARPR ( Sharpen a rotation )
 
      SUBROUTINE SHARPR ( ROT )
 
C$ Abstract
C
C     Given a matrix that is "nearly" a rotation, adjust the columns
C     (from left to right in the usual printed presentation of a matrix)
C     so that the columns are numerically unit length and orthogonal.
C
C$ Copyright
C
C     Copyright (1998), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     None.
C
C$ Keywords
C
C     MATRIX
C
C$ Declarations
 
      IMPLICIT NONE
      DOUBLE PRECISION      ROT ( 3, 3 )
 
 
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     ROT       I/O  The rotation matrix to be sharpened.
C
C$ Detailed_Input
C
C     ROT       a 3x3 matrix that is nearly a rotation matrix.
C
C$ Detailed_Output
C
C     ROT       the input after sharpening the the columns.
C
C$ Parameters
C
C     None.
C
C$ Files
C
C     None.
C
C$ Exceptions
C
C     Error free.
C
C$ Particulars
C
C     This routine "sharpens" the orthogonality of a potential
C     rotation matrix.  It is intended for use in those situations
C     in which you have a rotation matrix that may be derived
C     from single precision inputs or that may have experienced
C     round off errors in its construction.
C
C$ Examples
C
C     Suppose that you have a rotation matrix that needs to be
C     converted to a quaternion.  The SPICE matrix to quaternion
C     conversion routine M2Q performs error checks on the input
C     matrix and signals an error if it does not meet the checks
C     for a quaternion.  By calling this routine you can ensure that
C     your rotation matrix (provided it's non-singular) will pass
C     the restrictions imposed by M2Q.
C
C         CALL SHARPR ( ROT )
C         CALL M2Q    ( ROT, Q )
C
C$ Restrictions
C
C     None.
C
C$ Author_and_Institution
C
C     W.L. Taber      (JPL)
C
C$ Literature_References
C
C     None.
C
C$ Version
C
C-    SPICELIB Version 1.0.0, 16-SEP-1999 (WLT)
C
C
C-&
 
C$ Index_Entries
C
C     Sharpen the orhogonality of the columns of a rotation
C
C-&
 
      DOUBLE PRECISION      TEMP(3,3)
 
      CALL VHAT ( ROT(1,1),  TEMP(1,1) )
      CALL UCRSS( TEMP(1,1), ROT(1,2),  TEMP(1,3) )
      CALL UCRSS( TEMP(1,3), TEMP(1,1), TEMP(1,2) )
 
      CALL MOVED( TEMP, 9, ROT )
 
      RETURN
      END
