C$Procedure      SOMFLS ( Some entries false? )
 
      LOGICAL FUNCTION SOMFLS ( LOGCLS, N )
 
C$ Abstract
C
C     Determine if some of the entries in an array of logicals are
C     .FALSE.
C
C$ Copyright
C
C     Copyright (1995), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     None.
C
C$ Keywords
C
C     UTILITY
C
C$ Declarations
 
      LOGICAL               LOGCLS ( * )
      INTEGER               N
 
C$ Brief_I/O
C
C     Variable  I/O  Description
C     --------  ---  --------------------------------------------------
C     LOGCLS     I   An array of logicals.
C     N          I   Number of elements in the array LOGCLS.
C
C     The function returns .TRUE. if some of the values in the array
C     LOGCLS are false.
C
C$ Detailed_Input
C
C     LOGCLS     is an array of logicals.
C
C     N          is the number of elements in the array LOGCLS
C
C$ Detailed_Output
C
C     The function returns true if the value of some entry of LOGCLS
C     is .FALSE.
C
C$ Parameters
C
C     None.
C
C$ Exceptions
C
C     Error free.
C
C     If N is less than 1, the function returns a value of .FALSE.
C
C$ Files
C
C     None.
C
C$ Particulars
C
C     This function examines each element of LOGCLS until
C     a .FALSE. value is found or until all values have been
C     examined.
C
C$ Examples
C
C     Suppose you need to confirm that a character set
C     WORDS does not contain at least one of the words in the phrase
C
C       'EVERY GOOD BOY DOES FINE'
C
C     You might execute the following block of code.
C
C           FOUND(1) = ELEMC  ( 'EVERY', WORDS )
C           FOUND(2) = ELEMC  ( 'GOOD',  WORDS )
C           FOUND(3) = ELEMC  ( 'BOY',   WORDS )
C           FOUND(4) = ELEMC  ( 'DOES',  WORDS )
C           FOUND(5) = ELEMC  ( 'FINE',  WORDS )
C
C           OK       = SOMFLS ( FOUND,   5     )
C
C$ Restrictions
C
C     None.
C
C$ Literature_References
C
C     None.
C
C$ Author_and_Institution
C
C     W.L. Taber     (JPL)
C
C$ Version
C
C-    SPICELIB Version 1.0.1, 10-MAR-1992 (WLT)
C
C        Comment section for permuted index source lines was added
C        following the header.
C
C-    SPICELIB Version 1.0.0, 12-JUL-1991 (WLT)
C
C-&
 
C$ Index_Entries
C
C     test whether some logicals in an array are false
C
C-&
 
      INTEGER               I
 
C
C     Just do it.
C
 
      DO I = 1, N
 
         IF ( .NOT. LOGCLS(I) ) THEN
 
            SOMFLS = .TRUE.
            RETURN
 
         END IF
 
      END DO
 
      SOMFLS = .FALSE.
      RETURN
 
 
      END
 
