C$Procedure      SUFFIX (Suffix a character string)
 
      SUBROUTINE SUFFIX ( SUFF, SPACES, STRING )
 
C$ Abstract
C
C      Add a suffix to a character string.
C
C$ Copyright
C
C     Copyright (1995), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     None.
C
C$ Keywords
C
C      ASSIGNMENT,  CHARACTER,  STRING
C
C$ Declarations
 
      CHARACTER*(*)    SUFF
      INTEGER          SPACES
      CHARACTER*(*)    STRING
 
C$ Brief_I/O
C
C      VARIABLE  I/O  DESCRIPTION
C      --------  ---  --------------------------------------------------
C      SUFF       I   Suffix.
C      SPACES     I   Number of spaces separating prefix and suffix.
C      STRING    I/O  Prefix on input, string on output.
C
C$ Detailed_Input
C
C      SUFF        is the suffix to be added to the string.
C                  Leading blanks are significant. (A blank
C                  suffix is interpreted as a null suffix.)
C
C      SPACES      is the number of spaces (blanks) in the output
C                  string separating the last non-blank character
C                  of the prefix from the first (blank or non-blank)
C                  character of the suffix. Typically, this will be
C                  zero or one. If not positive, SPACES defaults to
C                  zero.
C
C      STRING      on input is the prefix to which the suffix is
C                  to be added. Leading blanks are significant.
C                  Trailing blanks are ignored.
C
C$ Detailed_Output
C
C      STRING      on output is the suffixed string. If STRING
C                  is not large enough to contain the output string,
C                  the output string is truncated on the right.
C
C                  STRING may NOT overwrite SUFF.
C
C$ Parameters
C
C     None.
C
C$ Particulars
C
C      The suffix is added to the right of the last non-blank character
C      of the prefix. (Any necessary truncation is done automatically.)
C
C$ Examples
C
C      The following examples illustrate the use of SUFFIX.
C
C            SUFF         STRING (input)   SPACES    STRING (output)
C            ----------   --------------   ------    ---------------
C            'abc     '   'def    '             0    'defabc '
C            'abc     '   'def    '             1    'def abc'
C            'abc     '   ' def   '             0    ' defabc'
C            'abc     '   ' def   '             1    ' def ab'
C            ' abc    '   'def    '             0    'def abc'
C            ' abc    '   'def    '             1    'def  ab'
C            ' abc    '   ' def   '            -1    ' def ab'
C            '        '   'def    '             0    'def    '
C            '        '   'def    '             1    'def    '
C            ' abc    '   '       '             0    ' abc   '
C            ' abc    '   '       '             1    '  abc  '
C
C$ Restrictions
C
C      SUFF and STRING must be distinct.
C
C$ Exceptions
C
C      Error free.
C
C$ Files
C
C      None.
C
C$ Author_and_Institution
C
C      W.L. Taber      (JPL)
C      I.M. Underwood  (JPL)
C
C$ Literature_References
C
C      None.
C
C$ Version
C
C-     SPICELIB Version 1.0.1, 10-MAR-1992 (WLT)
C
C         Comment section for permuted index source lines was added
C         following the header.
C
C-     SPICELIB Version 1.0.0, 31-JAN-1990 (WLT) (IMU)
C
C-&
 
C$ Index_Entries
C
C     suffix a character_string
C
C-&
 
 
 
 
C
C     SPICELIB functions
C
      INTEGER          LASTNB
 
C
C     Local variables
C
      INTEGER          L
      INTEGER          SLEN
      INTEGER          END
 
 
 
C
C     SLEN is the allocated length of the string. L is the location of
C     the last non-blank character of the prefix.
C
      SLEN = LEN    ( STRING )
      L    = LASTNB ( STRING )
 
C
C     Put the suffix at the end of the string. The spaces will fill
C     themselves in.
C
      END = L + MAX ( SPACES, 0 )
 
      IF ( END .LT. SLEN ) THEN
         STRING(END+1: ) = SUFF
      END IF
 
      RETURN
      END
