C$Procedure SUMAD ( Sum of a double precision array )
 
      DOUBLE PRECISION FUNCTION SUMAD ( ARRAY, N )
 
C$ Abstract
C
C      Return the sum of the elements of a double precision array.
C
C$ Copyright
C
C     Copyright (1995), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     None.
C
C$ Keywords
C
C      ARRAY,  MATH,  UTILITY
C
C$ Declarations
 
      DOUBLE PRECISION   ARRAY  ( * )
      INTEGER            N
 
C$ Brief_I/O
C
C      VARIABLE  I/O  DESCRIPTION
C      --------  ---  --------------------------------------------------
C      ARRAY      I   Input array.
C      N          I   Number of elements in ARRAY.
C      SUMAI      O   Sum of the elements of ARRAY.
C
C$ Detailed_Input
C
C      ARRAY       is the input array.
C
C      N           is the number of elements in the array.
C
C$ Detailed_Output
C
C      SUMAD       is the sum of the elements of the input array.
C                  That is,
C
C                     SUMAD = ARRAY(1) + ARRAY(2) + ... + ARRAY(N)
C
C                  If N is zero or negative, SUMAD is zero.
C
C$ Parameters
C
C     None.
C
C$ Particulars
C
C      The value of the function is initially set to zero. The elements
C      of the array are then added. If the number of elements is
C      zero or negative, SUMAD is zero.
C
C$ Examples
C
C      Let ARRAY contain the following elements.
C
C            ARRAY(1) = 12.D0
C            ARRAY(2) =  1.D0
C            ARRAY(3) =  4.D0
C            ARRAY(4) = 75.D0
C            ARRAY(5) = 18.D0
C
C      Then
C
C            SUMAD ( ARRAY,   -3 )       =   0.D0
C            SUMAD ( ARRAY,    0 )       =   0.D0
C            SUMAD ( ARRAY,    1 )       =  12.D0
C            SUMAD ( ARRAY,    2 )       =  13.D0
C            SUMAD ( ARRAY,    5 )       = 110.D0
C            SUMAD ( ARRAY(3), 3 )       =  97.D0
C
C
C$ Restrictions
C
C      SUMAD does not check for overflow.
C
C$ Exceptions
C
C      Error free.
C
C$ Files
C
C      None.
C
C$ Author_and_Institution
C
C      I.M. Underwood  (JPL)
C
C$ Literature_References
C
C      None.
C
C$ Version
C
C-     SPICELIB Version 1.0.1, 10-MAR-1992 (WLT)
C
C         Comment section for permuted index source lines was added
C         following the header.
C
C-     SPICELIB Version 1.0.0, 31-JAN-1990 (IMU)
C
C-&
 
C$ Index_Entries
C
C     sum of a d.p. array
C
C-&
 
 
 
 
C
C     Local variables
C
      DOUBLE PRECISION SUM
      INTEGER          I
 
 
C
C     Begin at zero.
C
      SUM = 0.D0
 
C
C     Sum the elements. If N is zero or negative, nothing happens.
C
      DO I = 1, N
         SUM = SUM + ARRAY(I)
      END DO
 
C
C     Return the sum.
C
      SUMAD = SUM
 
      RETURN
      END
