C$Procedure      TOUCHD ( Touch a variable )
 
      DOUBLE PRECISION FUNCTION TOUCHD ( DP )
 
C$ Abstract
C
C     Return the value of a double precision number.
C
C$ Copyright
C
C     Copyright (2004), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C      None.
C
C$ Keywords
C
C       UTILITY
C
C$ Declarations
 
      IMPLICIT NONE
      DOUBLE PRECISION      DP
 
 
C$ Brief_I/O
C
C      VARIABLE  I/O  DESCRIPTION
C      --------  ---  --------------------------------------------------
C      DP        I   any double precision number
C
C       The function returns the value of DP.
C
C$ Detailed_Input
C
C      DP          is any double precision number
C
C$ Detailed_Output
C
C     The function returns the input d.p.
C
C$ Parameters
C
C      None.
C
C$ Files
C
C      None.
C
C$ Exceptions
C
C     Error free.
C
C
C$ Particulars
C
C     This is a utility routine so that formal arguments to a routine
C     that are never used can be given the appearance of being used
C     to a compiler.  In this way it is possible to leave "hooks" in
C     a calling sequence even if those variables are for the moment
C     unused.  Similarly, variables declared for future use can be left
C     in place so that they don't need to be commented out
C
C$ Examples
C
C     Suppose that a routine takes as an argument a
C     fortran structure implemented as a set of parallel arrays.
C     But that one of the arrays is not needed for the purposes of
C     the routine.  This routine allows you to touch that array
C     without changing it.
C
C
C        SUBROUTINE INCPTR ( N, PTR, VALUES )
C
C        This routine increments the current pointer into a circular
C        array of double precision numbers.
C
C        INTEGER               N
C        INTEGER               PTR
C        DOUBLE PRECISION      VALUES ( * )
C
C        Even though we don't need to do anything with the values
C        array, it's passed for the sake of uniformity in calling
C        sequences.  Touch the VALUES array so that the compiler
C        will think it's been used.
C
C        VALUES(1) = TOUCHD ( VALUES(1) )
C
C        PTR = PTR + 1
C
C        IF ( PTR .GT. N ) THEN
C           PTR = 1
C        END IF
C        RETURN
C
C
C
C$ Restrictions
C
C     If you use this routine, it would be a very good idea to
C     write down why you are using it in the calling routine.
C
C$ Author_and_Institution
C
C      W.L. Taber      (JPL)
C
C$ Literature_References
C
C      None.
C
C$ Version
C
C-    SPICELIB Version 1.0.0, 6-MAy-1994 (WLT)
C
C
C-&
 
C$ Index_Entries
C
C     touch a d.p. number
C
C-&
 
      TOUCHD = DP
      RETURN
      END
