C$Procedure                      TRACE ( Trace of a 3x3 matrix )
 
      DOUBLE PRECISION FUNCTION  TRACE ( MATRIX )
 
C$ Abstract
C
C      Return the trace of a 3x3 matrix.
C
C$ Copyright
C
C     Copyright (1995), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     None.
C
C$ Keywords
C
C      MATRIX
C
C$ Declarations
 
      DOUBLE PRECISION   MATRIX ( 3,3 )
 
C$ Brief_I/O
C
C      VARIABLE  I/O  DESCRIPTION
C      --------  ---  --------------------------------------------------
C      MATRIX     I     3x3 matrix of double precision numbers.
C      TRACE      O     The trace of MATRIX.
C
C$ Detailed_Input
C
C      MATRIX  is a double precision 3x3 matrix.
C
C$ Detailed_Output
C
C      TRACE   is the trace of MATRIX, i.e. it is the sum of the
C              diagonal elements of MATRIX.
C
C$ Parameters
C
C     None.
C
C$ Particulars
C
C      TRACE simply executes in FORTRAN code the following loop:
C
C      TRACE = Summation from I = 1 to 3 of MATRIX(I,I)
C
C      No error detection or correction is implemented within this
C      function.
C
C$ Examples
C
C                            | 3   5   7 |
C      Suppose that MATRIX = | 0  -2   8 |  , then
C                            | 4   0  -1 |
C
C      TRACE (MATRIX) = 0.  (which is the sum of 3, -2 and -1).
C
C$ Restrictions
C
C      No checking is performed to guard against floating point overflow
C      or underflow.  This routine should probably not be used if the
C      input matrix is expected to have large double precision numbers
C      along the diagonal.
C
C$ Exceptions
C
C      Error free.
C
C$ Files
C
C      None
C
C$ Author_and_Institution
C
C      W.L. Taber      (JPL)
C
C$ Literature_References
C
C      None
C
C$ Version
C
C-     SPICELIB Version 1.0.1, 10-MAR-1992 (WLT)
C
C         Comment section for permuted index source lines was added
C         following the header.
C
C-     SPICELIB Version 1.0.0, 31-JAN-1990 (WLT)
C
C-&
 
C$ Index_Entries
C
C     trace of a 3x3_matrix
C
C-&
 
 
      TRACE = MATRIX(1,1) + MATRIX(2,2) + MATRIX(3,3)
C
      RETURN
      END
