C$Procedure  TRACEG ( Trace of a matrix, general dimension )
 
      DOUBLE PRECISION FUNCTION  TRACEG ( MATRIX, NDIM )
 
C$ Abstract
C
C      Return the trace of a square matrix of arbitrary dimension.
C
C$ Copyright
C
C     Copyright (1995), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     None.
C
C$ Keywords
C
C      MATRIX
C
C$ Declarations
 
      INTEGER            NDIM
      DOUBLE PRECISION   MATRIX ( NDIM,NDIM )
 
C$ Brief_I/O
C
C      VARIABLE  I/O  DESCRIPTION
C      --------  ---  --------------------------------------------------
C      MATRIX     I     NDIM x NDIM matrix of double precision numbers.
C      NDIM       I     Dimension of the matrix.
C      TRACEG     O     The trace of MATRIX.
C
C$ Detailed_Input
C
C      MATRIX  is a double precision square matrix of arbitrary
C              dimension.  The input matrix must be square or else
C              the concept is meaningless.
C
C      NDIM    is the dimension of MATRIX.
C
C$ Detailed_Output
C
C      TRACEG  is the trace of MATRIX, i.e. it is the sum of the
C              diagonal elements of MATRIX.
C
C$ Parameters
C
C     None.
C
C$ Particulars
C
C      TRACEG simply executes in FORTRAN code the following loop:
C
C      TRACEG = Summation from I = 1 to NDIM of MATRIX(I,I)
C
C      No error detection or correction is implemented within this
C      function.
C
C$ Examples
C
C                            | 3   5   7 |
C      Suppose that MATRIX = | 0  -2   8 |  (with NDIM = 3), then
C                            | 3   0  -1 |
C
C      TRACEG (MATRIX, 3) = 0.  (which is the sum of 3, -2 and -1).
C
C$ Restrictions
C
C      No checking is performed to guard against floating point overflow
C      or underflow.  This routine should probably not be used if the
C      input matrix is expected to have large double precision numbers
C      along the diagonal.
C
C$ Exceptions
C
C      Error free.
C
C$ Files
C
C      None.
C
C$ Author_and_Institution
C
C      W.L. Taber      (JPL)
C
C$ Literature_References
C
C      None.
C
C$ Version
C
C-     SPICELIB Version 1.0.1, 10-MAR-1992 (WLT)
C
C         Comment section for permuted index source lines was added
C         following the header.
C
C-     SPICELIB Version 1.0.0, 31-JAN-1990 (WLT)
C
C-&
 
C$ Index_Entries
C
C     trace of a nxn_matrix
C
C-&
 
      INTEGER         I
 
      TRACEG = 0.0D0
      DO I = 1,NDIM
         TRACEG = TRACEG + MATRIX(I,I)
      END DO
 
      RETURN
      END
