C$Procedure                     TWOPI ( Twice the value of pi )
 
      DOUBLE PRECISION FUNCTION TWOPI ( )
 
C$ Abstract
C
C     Return twice the value of pi (the ratio of the circumference of
C     a circle to its diameter).
C
C$ Copyright
C
C     Copyright (1995), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     None.
C
C$ Keywords
C
C     CONSTANTS
C
C$ Declarations
C
C     None.
C
C$ Brief_I/O
C
C     The function returns twice the value of pi.
C
C$ Detailed_Input
C
C     None.
C
C$ Detailed_Output
C
C     The function returns twice the value of pi (the ratio of
C     a circle's circumference to its diameter), determined by
C     the ACOS function. That is,
C
C           TWOPI = ACOS ( -1.D0 ) * 2.D0
C
C$ Parameters
C
C     None.
C
C$ Exceptions
C
C      Error free.
C
C$ Files
C
C     None.
C
C$ Particulars
C
C     The first time the function is referenced, the value is computed
C     as shown above. The value is saved, and returned directly upon
C     subsequent reference.
C
C$ Examples
C
C     The code fragment below illustrates the use of TWOPI.
C
C        C
C        C      The longitude of the ascending node is the angle
C        C      between the x-axis and the node vector, n.
C        C                                              -
C        C
C               NODE = ACOS ( N(1) / VNORM(N) )
C
C               IF ( NODE .LT. 0.D0 ) THEN
C                  NODE = NODE + TWOPI()
C               END IF
C
C$ Restrictions
C
C     None.
C
C$ Literature_References
C
C     None.
C
C$ Author_and_Institution
C
C     W.L. Taber      (JPL)
C     I.M. Underwood  (JPL)
C
C$ Version
C
C-     SPICELIB Version 1.0.2, 28-AUG-1997 (WLT)
C
C         Fixed the description in the detailed output section
C         of the header.
C
C-     SPICELIB Version 1.0.1, 10-MAR-1992 (WLT)
C
C         Comment section for permuted index source lines was added
C         following the header.
C
C-     SPICELIB Version 1.0.0, 31-JAN-1990 (WLT) (IMU)
C
C-&
 
C$ Index_Entries
C
C     twice the value of pi
C
C-&
 
 
 
 
C
C     Local variables
C
      DOUBLE PRECISION      VALUE
      SAVE                  VALUE
 
C
C     Initial values
C
      DATA                  VALUE      / 0.D0 /
 
 
C
C     What is there to say?
C
      IF ( VALUE .EQ. 0.D0 ) THEN
         VALUE = ACOS ( -1.D0 ) * 2.D0
      END IF
 
      TWOPI = VALUE
 
      RETURN
      END
