C$Procedure      TYEAR ( Seconds per tropical year )
 
      DOUBLE PRECISION FUNCTION TYEAR ()
 
C$ Abstract
C
C     Return the number of seconds in a tropical year.
C
C$ Copyright
C
C     Copyright (1995), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C  None.
C
C$ Keywords
C
C      CONSTANTS
C
C$ Declarations
C
C     None.
C
C$ Brief_I/O
C
C      VARIABLE  I/O              DESCRIPTION
C      --------  ---  --------------------------------------------------
C      TYEAR       O   The number of seconds/tropical year
C
C$ Detailed_Input
C
C     None.
C
C$ Detailed_Output
C
C     The function returns the number of seconds per tropical
C     year.  This value is taken from the 1992 Explanatory Supplement
C     to the Astronomical Almanac.
C
C$ Parameters
C
C     None.
C
C$ Particulars
C
C     The tropical year is often used as a fundamental unit
C     of time when dealing with older ephemeris data.  For this
C     reason its value in terms of ephemeris seconds is
C     recorded in this function.
C
C$ Examples
C
C     Suppose you wish to compute the number of tropical centuries
C     that have elapsed since the ephemeris epoch B1950 (beginning
C     of the Besselian year 1950) at a particular ET epoch.  The
C     following line of code will do the trick.
C
C
C        CENTRY = ( ET - UNITIM ( B1950(), 'JED', 'ET' ) )
C       .       / ( 100.0D0 * TYEAR() )
C
C
C$ Restrictions
C
C      None.
C
C$ Exceptions
C
C     Error free.
C
C$ Files
C
C      None.
C
C$ Author_and_Institution
C
C      W.L. Taber      (JPL)
C
C$ Literature_References
C
C      Explanatory Supplement to the Astronomical Almanac.
C      Page 80. University Science Books, 20 Edgehill Road,
C      Mill Valley, CA 94941
C
C$ Version
C
C-    SPICELIB Version 1.0.0, 13-JUL-1993 (WLT)
C
C-&
 
C$ Index_Entries
C
C     Number of seconds per tropical year
C
C-&
 
      TYEAR = 31556925.9747D0
      RETURN
      END
 
 
