C$Procedure      VADDG ( Vector addition, general dimension )
 
      SUBROUTINE VADDG ( V1, V2, NDIM, VOUT )
 
C$ Abstract
C
C      Add two vectors of arbitrary dimension.
C
C$ Copyright
C
C     Copyright (1995), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     None.
C
C$ Keywords
C
C      VECTOR
C
C$ Declarations
 
      INTEGER             NDIM
      DOUBLE PRECISION    V1   ( NDIM )
      DOUBLE PRECISION    V2   ( NDIM )
      DOUBLE PRECISION    VOUT ( NDIM )
 
C$ Brief_I/O
C
C      VARIABLE  I/O  DESCRIPTION
C      --------  ---  --------------------------------------------------
C       V1        I     First vector to be added.
C       V2        I     Second vector to be added.
C       NDIM      I     Dimension of V1, V2, and VOUT.
C       VOUT      O     Sum vector, V1 + V2.
C                       VOUT can overwrite either V1 or V2.
C
C$ Detailed_Input
C
C      V1      This may be any double precision vector of arbitrary
C              dimension.
C
C      V2      Likewise.
C
C      NDIM    is the dimension of V1, V2 and VOUT.
C
C$ Detailed_Output
C
C      VOUT   This is vector sum of V1 and V2. VOUT may overwrite either
C             V1 or V2.
C
C$ Parameters
C
C     None.
C
C$ Particulars
C
C      This routine simply performs addition between components of V1
C      and V2.  No checking is performed to determine whether floating
C      point overflow has occurred.
C
C$ Examples
C
C      The following table shows the output VOUT as a function of the
C      the input V1 and V2 from the subroutine VADD.
C
C      V1                  V2                  NDIM   VOUT
C      -----------------------------------------------------------------
C      (1.0, 2.0, 3.0)     (4.0, 5.0, 6.0)     3      (5.0,  7.0,  9.0)
C      (1D-7,1D23)         (1D24, 1D23)        2      (1D24, 2D23)
C
C$ Restrictions
C
C      The user is required to determine that the magnitude each
C      component of the vectors is within the appropriate range so as
C      not to cause floating point overflow.
C
C$ Exceptions
C
C      Error free.
C
C$ Files
C
C      None.
C
C$ Author_and_Institution
C
C      W.M. Owen       (JPL)
C
C$ Literature_References
C
C      None.
C
C$ Version
C
C-     SPICELIB Version 1.0.2, 07-NOV-2003 (EDW)
C
C         Corrected a mistake in the second example's value
C         for VOUT, i.e. replaced (1D24, 2D23, 0.0) with
C         (1D24, 2D23).
C
C-     SPICELIB Version 1.0.1, 10-MAR-1992 (WLT)
C
C         Comment section for permuted index source lines was added
C         following the header.
C
C-     SPICELIB Version 1.0.0, 31-JAN-1990 (WMO)
C
C-&
 
C$ Index_Entries
C
C     n-dimensional vector addition
C
C-&
 
      INTEGER I
C
      DO I = 1, NDIM
         VOUT(I) = V1(I) + V2(I)
      END DO
 
      RETURN
      END
