C$Procedure      VDOT  ( Vector dot product, 3 dimensions )
 
      DOUBLE PRECISION FUNCTION VDOT ( V1, V2 )
 
C$ Abstract
C
C      Compute the dot product of two double precision, 3-dimensional
C      vectors.
C
C$ Copyright
C
C     Copyright (1995), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C      None.
C
C$ Keywords
C
C      VECTOR
C
C$ Declarations
 
      DOUBLE PRECISION   V1 ( 3 )
      DOUBLE PRECISION   V2 ( 3 )
 
C$ Brief_I/O
C
C      VARIABLE  I/O  DESCRIPTION
C      --------  ---  --------------------------------------------------
C       V1        I     First vector in the dot product.
C       V2        I     Second vector in the dot product.
C
C       The function returns the value of the dot product of V1 and V2.
C
C$ Detailed_Input
C
C      V1      This may be any 3-dimensional, double precision vector.
C
C      V2      This may be any 3-dimensional, double precision vector.
C
C$ Detailed_Output
C
C      The function returns the value of the dot product of V1 and V2.
C
C$ Parameters
C
C      None.
C
C$ Particulars
C
C      VDOT calculates the dot product of V1 and V2 by a simple
C      application of the definition.  No error checking is
C      performed to prevent numeric overflow.
C
C$ Examples
C
C      Suppose that given two position vectors, we want to change
C      one of the positions until the two vectors are perpendicular.
C      The following code fragment demonstrates the use of VDOT to do
C      so.
C
C      DOT = VDOT ( V1, V2 )
C
C      DO WHILE ( DOT .NE. 0.0D0 )
C         change one of the position vectors
C         DOT = VDOT ( V1, V2 )
C      END DO
C
C$ Restrictions
C
C      The user is responsible for determining that the vectors V1 and
C      V2 are not so large as to cause numeric overflow.  In most cases
C      this won't present a problem.
C
C$ Exceptions
C
C     Error free.
C
C$ Files
C
C      None.
C
C$ Author_and_Institution
C
C      W.M. Owen       (JPL)
C
C$ Literature_References
C
C      None.
C
C$ Version
C
C-    SPICELIB Version 1.0.1, 10-MAR-1992 (WLT)
C
C        Comment section for permuted index source lines was added
C        following the header.
C
C-    SPICELIB Version 1.0.0, 31-JAN-1990 (WMO)
C
C-&
 
C$ Index_Entries
C
C     dot product 3-dimensional vectors
C
C-&
 
 
      VDOT = V1(1)*V2(1) + V1(2)*V2(2) + V1(3)*V2(3)
C
      RETURN
      END
