C$Procedure      VEQU ( Vector equality, 3 dimensions )
 
      SUBROUTINE VEQU ( VIN, VOUT )
 
C$ Abstract
C
C      Make one double precision 3-dimensional vector equal to
C      another.
C
C$ Copyright
C
C     Copyright (1995), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C      None.
C
C$ Keywords
C
C      ASSIGNMENT,  VECTOR
C
C$ Declarations
 
      DOUBLE PRECISION  VIN   ( 3 )
      DOUBLE PRECISION  VOUT  ( 3 )
 
C$ Brief_I/O
C
C      VARIABLE  I/O  DESCRIPTION
C      --------  ---  --------------------------------------------------
C       VIN       I   3-dimensional double precision vector.
C       VOUT      O   3-dimensional double precision vector set equal
C                     to VIN.
C
C$ Detailed_Input
C
C      VIN      This may be ANY 3-dimensional double precision vector.
C
C$ Detailed_Output
C
C      VOUT    This 3-dimensional double precision vector is set equal
C              to VIN.
C
C$ Parameters
C
C      None.
C
C$ Particulars
C
C      VEQU simply sets each component of VOUT in turn equal to VIN.  No
C      error checking is performed because none is needed.
C
C$ Examples
C
C     Let  STATE be a state vector. The angular momentum vector is
C     determined by the cross product of the position vector and the
C     velocity vector.
C
C      CALL VEQU ( STATE(1), R )
C      CALL VEQU ( STATE(4), V )
C
C      CALL VCRSS ( R, V, H )
C
C
C$ Restrictions
C
C      None.
C
C$ Exceptions
C
C     Error free.
C
C$ Files
C
C      None.
C
C$ Author_and_Institution
C
C      W.M. Owen       (JPL)
C
C$ Literature_References
C
C      None.
C
C$ Version
C
C-    SPICELIB Version 1.0.1, 10-MAR-1992 (WLT)
C
C        Comment section for permuted index source lines was added
C        following the header.
C
C-    SPICELIB Version 1.0.0, 31-JAN-1990 (WMO)
C
C-&
 
C$ Index_Entries
C
C     assign a 3-dimensional vector to another
C
C-&
 
      VOUT(1) = VIN(1)
      VOUT(2) = VIN(2)
      VOUT(3) = VIN(3)
C
      RETURN
      END
