C$Procedure      VEQUG ( Vector equality, general dimension )
 
      SUBROUTINE VEQUG ( VIN, NDIM, VOUT )
 
C$ Abstract
C
C      Make one double precision vector of arbitrary dimension equal
C      to another.
C
C$ Copyright
C
C     Copyright (1995), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     None.
C
C$ Keywords
C
C      ASSIGNMENT,  VECTOR
C
C$ Declarations
 
      INTEGER            NDIM
      DOUBLE PRECISION   VIN   ( NDIM )
      DOUBLE PRECISION   VOUT  ( NDIM )
 
C$ Brief_I/O
C
C      VARIABLE  I/O  DESCRIPTION
C      --------  ---  --------------------------------------------------
C       VIN       I   NDIM-dimensional double precision vector.
C       NDIM      I   Dimension of VIN (and also VOUT).
C       VOUT      O   NDIM-dimensional double precision vector set
C                     equal to VIN.
C
C$ Detailed_Input
C
C      VIN      is a double precision vector of arbitrary dimension.
C
C      NDIM     is the number of components of VIN.
C
C$ Detailed_Output
C
C      VOUT    is a double precision vector set equal to VIN.
C
C$ Parameters
C
C      None.
C
C$ Particulars
C
C      The code simply sets each component of VOUT equal to the
C      corresponding component of VIN.
C
C$ Examples
C
C      Let STATE be a state vector. Set ABSTAT equal to STATE, and
C      correct ABSTAT for stellar aberration.
C
C      CALL VEQUG  ( STATE,           6, ABSTAT )
C      CALL STELAB ( STATE(1), STATE(4), ABSPOS )
C      CALL VEQU   ( ABSPOS,   ABSTAT(1)        )
C
C
C      Note that this routine may be used in place of MOVED, which
C      sets each output array element equal to the corresponding
C      input array element.
C
C$ Restrictions
C
C      None.
C
C$ Exceptions
C
C     Error free.
C
C$ Files
C
C      None.
C
C$ Author_and_Institution
C
C      W.M. Owen       (JPL)
C
C$ Literature_References
C
C      None.
C
C$ Version
C
C-    SPICELIB Version 1.0.1, 10-MAR-1992 (WLT)
C
C        Comment section for permuted index source lines was added
C        following the header.
C
C-    SPICELIB Version 1.0.0, 31-JAN-1990 (WMO)
C
C-&
 
C$ Index_Entries
C
C     assign an n-dimensional vector to another
C
C-&
 
      INTEGER I
 
      DO I=1,NDIM
         VOUT(I) = VIN(I)
      END DO
 
      RETURN
      END
