C$Procedure      VLCOMG ( Vector linear combination, general dimension )
 
      SUBROUTINE VLCOMG ( N, A, V1, B, V2, SUM )
 
C$ Abstract
C
C      Compute a vector linear combination of two double precision
C      vectors of arbitrary dimension.
C
C$ Copyright
C
C     Copyright (1995), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     None.
C
C$ Keywords
C
C      VECTOR
C
C$ Declarations
 
      INTEGER            N
      DOUBLE PRECISION   A
      DOUBLE PRECISION   V1  ( N )
      DOUBLE PRECISION   B
      DOUBLE PRECISION   V2  ( N )
      DOUBLE PRECISION   SUM ( N )
 
C$ Brief_I/O
C
C      VARIABLE  I/O  DESCRIPTION
C      --------  ---  --------------------------------------------------
C      N          I   Dimension of vector space
C      A          I   Coefficient of V1
C      V1         I   Vector in N-space
C      B          I   Coefficient of V2
C      V2         I   Vector in N-space
C      SUM        O   Linear Vector Combination A*V1 + B*V2
C
C$ Detailed_Input
C
C      N   This variable contains the dimension of the V1, V2 and SUM.
C      A   This double precision variable multiplies V1.
C      V1  This is an arbitrary, double precision N-dimensional vector.
C      B   This double precision variable multiplies V2.
C      V2  This is an arbitrary, double precision N-dimensional vector.
C
C$ Detailed_Output
C
C      SUM   is an arbitrary, double precision N-dimensional vector
C            which contains the linear combination A*V1 + B*V2.
C
C$ Parameters
C
C      None.
C
C$ Particulars
C
C      For each index from 1 to N, this routine implements in FORTRAN
C      code the expression:
C
C      SUM(I) = A*V1(I) + B*V2(I)
C
C      No error checking is performed to guard against numeric overflow.
C
C$ Examples
C
C      We can easily use this routine to perform vector projections
C      to 2-planes in N-space.  Let X be an arbitray N-vector
C      and let U and V be orthonormal N-vectors spanning the plane
C      of interest.  The projection of X onto this 2-plane, PROJUV can
C      be obtained by the following code fragment.
C
C         CALL VLCOMG ( N, VDOT(X,U,N), U,   VDOT(X,V,N), V,   PROJUV )
C
C$ Restrictions
C
C      No error checking is performed to guard against numeric overflow
C      or underflow.  The user is responsible for insuring that the
C      input values are reasonable.
C
C$ Exceptions
C
C     Error free.
C
C$ Files
C
C      None
C
C$ Author_and_Institution
C
C      W.L. Taber      (JPL)
C
C$ Literature_References
C
C      None
C
C$ Version
C
C-    SPICELIB Version 1.0.1, 10-MAR-1992 (WLT)
C
C        Comment section for permuted index source lines was added
C        following the header.
C
C-    SPICELIB Version 1.0.0, 31-JAN-1990 (WLT)
C
C-&
 
C$ Index_Entries
C
C     linear combination of two n-dimensional vectors
C
C-&
 
 
C$ Revisions
C
C-     Beta Version 1.0.1, 1-Feb-1989 (WLT)
C
C      Example section of header upgraded.
C
C-&
 
      INTEGER        I
 
      DO I = 1,N
         SUM(I) = A*V1(I) + B*V2(I)
      END DO
 
      RETURN
      END
