C$Procedure      VMINUG ( Minus V, "-V", general dimension )
 
      SUBROUTINE VMINUG ( VIN, NDIM, VOUT )
 
C$ Abstract
C
C      Negate a double precision vector of arbitrary dimension.
C
C$ Copyright
C
C     Copyright (1995), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C      None.
C
C$ Keywords
C
C      VECTOR
C
C$ Declarations
 
      INTEGER            NDIM
      DOUBLE PRECISION   VIN   ( NDIM )
      DOUBLE PRECISION   VOUT  ( NDIM )
 
C$ Brief_I/O
C
C      VARIABLE  I/O  DESCRIPTION
C      --------  ---  --------------------------------------------------
C       VIN       I   NDIM-dimensional double precision vector to
C                     be negated.
C       NDIM      I   Dimension of VIN (and also VOUT).
C       VOUT      O   NDIM-dimensional double precision vector equal to
C                     -VIN.
C
C$ Detailed_Input
C
C      VIN      is double precision vector of arbitrary size.
C
C      NDIM     is the dimension of VIN and VOUT.
C
C$ Detailed_Output
C
C      VOUT    is a double precision vector which contains the negation
C              of VIN. VOUT may overwrite VIN.
C
C$ Parameters
C
C      None.
C
C$ Particulars
C
C      For each value of the index I from 1 to NDIM, VMINUG negates VIN
C      by the expression:
C
C      VOUT(I) = - VIN(I)
C
C$ Examples
C
C      Let VIN = ( -10.0D0, 15.0D0, -5.0D0, 20.0D0 )
C
C      The call
C
C      CALL VMINUG ( VIN, 4, VIN )
C
C      negates all of the components of the vector VIN, and overwrites
C      the original components. The vector VIN then contains the
C      components
C
C      VIN = ( 10.0D0, -15.0D0, 5.0D0, -20.0D0 )
C
C$ Restrictions
C
C      None.
C
C$ Exceptions
C
C     Error free.
C
C$ Files
C
C      None.
C
C$ Author_and_Institution
C
C      W.M. Owen       (JPL)
C
C$ Literature_References
C
C      None.
C
C$ Version
C
C-    SPICELIB Version 1.0.1, 10-MAR-1992 (WLT)
C
C        Comment section for permuted index source lines was added
C        following the header.
C
C-    SPICELIB Version 1.0.0, 31-JAN-1990 (WMO)
C
C-&
 
C$ Index_Entries
C
C     negate an n-dimensional vector
C
C-&
 
      INTEGER I
C
      DO I = 1, NDIM
         VOUT(I) = -VIN(I)
      END DO
 
      RETURN
      END
