C$Procedure      VMINUS ( Minus V, "-V", 3 dimensions )
 
      SUBROUTINE VMINUS ( V1, VOUT )
 
C$ Abstract
C
C      Negate a double precision 3-dimensional vector.
C
C$ Copyright
C
C     Copyright (1995), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     None.
C
C$ Keywords
C
C      VECTOR
C
C$ Declarations
 
      DOUBLE PRECISION  V1   ( 3 )
      DOUBLE PRECISION  VOUT ( 3 )
 
C$ Brief_I/O
C
C      VARIABLE  I/O  DESCRIPTION
C      --------  ---  --------------------------------------------------
C       V1        I     Vector to be negated.
C       VOUT      O     Negated vector -V1. VOUT can overwrite V1.
C
C
C$ Detailed_Input
C
C      V1      This may be any 3-dimensional, double precision vector.
C
C$ Detailed_Output
C
C      VOUT    This will be the negation (additive inverse) of V1.  It
C              is a 3-dimensional, double precision vector.  VOUT may
C              overwrite V1.
C
C$ Parameters
C
C     None.
C
C$ Particulars
C
C      VMINUS implements (by components) the expression VMINUS = -V1.
C      No error checking is performed since overflow can occur ONLY if
C      the dynamic range of positive floating point numbers is not the
C      same size as the dynamic range of negative floating point
C      numbers AND at least one component of V1 falls outside the
C      common range.  The likelihood of this occuring is so small as to
C      be of no concern.
C
C$ Examples
C
C      The following table shows the output VOUT as a function of the
C      the input V1 from the subroutine VMINUS.
C
C      V1                     VOUT
C      -------------------------------------------------------
C      (1D0, -2D0, 0D0)       (-1D0, 2D0, 0D0)
C      (0D0, 0D0, 0D0)        (0D0, 0D0, 0D0)
C
C$ Restrictions
C
C      None.
C
C$ Exceptions
C
C      Error free.
C
C$ Files
C
C      None.
C
C$ Author_and_Institution
C
C      W.M. Owen       (JPL)
C
C$ Literature_References
C
C      None.
C
C$ Version
C
C-     SPICELIB Version 1.0.1, 10-MAR-1992 (WLT)
C
C         Comment section for permuted index source lines was added
C         following the header.
C
C-     SPICELIB Version 1.0.0, 31-JAN-1990 (WMO)
C
C-&
 
C$ Index_Entries
C
C     negate a 3-dimensional vector
C
C-&
 
      VOUT(1) = -V1(1)
      VOUT(2) = -V1(2)
      VOUT(3) = -V1(3)
C
      RETURN
      END
