C$Procedure      VPACK ( Pack three scalar components into a vector )
 
      SUBROUTINE VPACK ( X, Y, Z, V )
 
C$ Abstract
C
C      Pack three scalar components into a vector.
C
C$ Copyright
C
C     Copyright (1995), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     None.
C
C$ Keywords
C
C      VECTOR
C
C$ Declarations
 
      DOUBLE PRECISION X
      DOUBLE PRECISION Y
      DOUBLE PRECISION Z
      DOUBLE PRECISION V ( 3 )
 
C$ Brief_I/O
C
C      VARIABLE  I/O  DESCRIPTION
C      --------  ---  --------------------------------------------------
C      X,
C      Y,
C      Z          I   Scalar components of a vector.
C      V          O   Equivalent vector.
C
C$ Detailed_Input
C
C      X,
C      Y,
C      Z           are the scalar components of a 3-vector.
C
C$ Detailed_Output
C
C      V           is the equivalent vector, such that V(1) = X
C                                                      V(2) = Y
C                                                      V(3) = Z
C
C$ Parameters
C
C     None.
C
C$ Particulars
C
C      Basically, this is just shorthand notation for the common
C      sequence
C
C            V(1) = X
C            V(2) = Y
C            V(3) = Z
C
C      The routine is useful largely for two reasons. First, it
C      reduces the chance that the programmer will make a "cut and
C      paste" mistake, like
C
C            V(1) = X
C            V(1) = Y
C            V(1) = Z
C
C      Second, it makes conversions between equivalent units simpler,
C      and clearer. For instance, the sequence
C
C            V(1) = X * RPD
C            V(2) = Y * RPD
C            V(3) = Z * RPD
C
C      can be replaced by the (nearly) equivalent sequence
C
C            CALL VPACK ( X, Y, Z, V )
C            CALL VSCL  ( RPD,  V, V )
C
C$ Examples
C
C      See: Detailed_Description.
C
C$ Restrictions
C
C      None.
C
C$ Exceptions
C
C      Error free.
C
C$ Files
C
C      None.
C
C$ Author_and_Institution
C
C      I.M. Underwood  (JPL)
C
C$ Literature_References
C
C      None.
C
C$ Version
C
C-     SPICELIB Version 1.0.1, 10-MAR-1992 (WLT)
C
C         Comment section for permuted index source lines was added
C         following the header.
C
C-     SPICELIB Version 1.0.0, 31-JAN-1990 (IMU)
C
C-&
 
C$ Index_Entries
C
C     pack three scalar components into a vector
C
C-&
 
 
 
 
C
C     Just shorthand, like it says above.
C
      V(1) = X
      V(2) = Y
      V(3) = Z
 
      RETURN
      END
