C$Procedure      VSCLG ( Vector scaling, general dimension )
 
      SUBROUTINE VSCLG ( S, V1, NDIM, VOUT )
 
C$ Abstract
C
C      Multiply a scalar and a double precision vector of arbitrary
C      dimension.
C
C$ Copyright
C
C     Copyright (1995), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     None.
C
C$ Keywords
C
C      VECTOR
C
C$ Declarations
 
      INTEGER            NDIM
      DOUBLE PRECISION   S
      DOUBLE PRECISION   V1   ( NDIM )
      DOUBLE PRECISION   VOUT ( NDIM )
 
C$ Brief_I/O
C
C      VARIABLE  I/O  DESCRIPTION
C      --------  ---  --------------------------------------------------
C       S         I     Scalar to multiply a vector.
C       V1        I     Vector to be multiplied.
C       NDIM      I     Dimension of V1 (and also VOUT).
C       VOUT      O     Product vector, S*V1. VOUT can overwrite V1.
C
C$ Detailed_Input
C
C      S      is a double precision scalar.
C
C      V1     is a double precision vector of arbitrary dimension.
C
C      NDIM   is the dimension of V1 (and VOUT).
C
C$ Detailed_Output
C
C      VOUT   is a double precision vector of arbitrary dimension
C             containing the product of the scalar with the vector V1.
C             VOUT may overwrite V1.
C
C$ Parameters
C
C     None.
C
C$ Particulars
C
C      For each value of the index I from 1 to NDIM, this subroutine
C      performs the following multiplication
C
C         VOUT(I) = S * V1(I)
C
C      No error checking is performed to guard against numeric overflow
C      or underflow.  VOUT may overwrite V1.
C
C$ Examples
C
C      The following table shows the results of VSCLG from various
C      inputs.
C
C      V1                 S           NDIM        VOUT
C      -----------------------------------------------------------------
C      (1, 2, -3, 4)      3            4         ( 3,  6, -9, 12)
C      (1, 2, -3, 4)      0            4         ( 0,  0,  0,  0)
C      (1, 2, -3, 4)     -1            4         (-3, -6,  9,-12)
C
C$ Restrictions
C
C      No error checking is performed to guard against numeric overflow.
C      The programmer is thus required to insure that the values in V1
C      and S are reasonable and will not cause overflow.
C
C$ Exceptions
C
C      Error free.
C
C$ Files
C
C      None.
C
C$ Author_and_Institution
C
C      W.M. Owen       (JPL)
C
C$ Literature_References
C
C      None.
C
C$ Version
C
C-     SPICELIB Version 1.0.1, 10-MAR-1992 (WLT)
C
C         Comment section for permuted index source lines was added
C         following the header.
C
C-     SPICELIB Version 1.0.0, 31-JAN-1990 (WMO)
C
C-&
 
C$ Index_Entries
C
C     n-dimensional vector scaling
C
C-&
 
 
      INTEGER I
 
      DO I=1,NDIM
         VOUT(I) = S * V1(I)
      END DO
 
      RETURN
      END
