C$Procedure  VTMV ( Vector transpose times matrix times vector, 3 dim )
 
      DOUBLE PRECISION FUNCTION VTMV ( V1, MATRIX, V2 )
 
C$ Abstract
C
C      Multiply the transpose of a 3-dimensional column vector,
C      a 3x3 matrix, and a 3-dimensional column vector.
C
C$ Copyright
C
C     Copyright (1995), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C      None.
C
C$ Keywords
C
C      MATRIX,  VECTOR
C
C$ Declarations
 
      DOUBLE PRECISION   V1     (   3 )
      DOUBLE PRECISION   MATRIX ( 3,3 )
      DOUBLE PRECISION   V2     (   3 )
 
C$ Brief_I/O
C
C      VARIABLE  I/O  DESCRIPTION
C      --------  ---  --------------------------------------------------
C       V1        I     3 dimensional double precision column vector.
C       MATRIX    I     3x3 double precision matrix.
C       V2        I     3 dimensional double precision column vector.
C
C       The function returns the result of (V1**T * MATRIX * V2 ).
C
C$ Detailed_Input
C
C      V1         This may be any 3-dimensional, double precision
C                 column vector.
C
C      MATRIX     This may be any 3x3, double precision matrix.
C
C      V2         This may be any 3-dimensional, double precision
C                 column vector.
C
C$ Detailed_Output
C
C      The function returns the double precision value of the equation
C      (V1**T * MATRIX * V2 ).
C
C      Notice that VTMV is actually the dot product of the vector
C      resulting from multiplying the transpose of V1 and MATRIX and the
C      vector V2.
C
C$ Parameters
C
C      None.
C
C$ Particulars
C
C      This routine implements the following vector/matrix/vector
C      multiplication:
C
C                      T
C         VTMV = |   V1   | |          |  |  |
C                           |  MATRIX  |  |V2|
C                           |          |  |  |
C
C      V1 is a column vector which becomes a row vector when transposed.
C      V2 is a column vector.
C
C      No checking is performed to determine whether floating point
C      overflow has occurred.
C
C$ Examples
C
C      If  V1 = | 2.0D0 |   MATRIX = |  0.0D0  1.0D0  0.0D0 |
C               |       |            |                      |
C               | 4.0D0 |            | -1.0D0  0.0D0  0.0D0 |
C               |       |            |                      |
C               | 6.0D0 |            |  0.0D0  0.0D0  1.0D0 |
C
C          V2 = | 1.0D0 |
C               |       |
C               | 1.0D0 |
C               |       |
C               | 1.0D0 |
C
C      then function value is equal to 4.0D0.
C
C$ Restrictions
C
C      None.
C
C$ Exceptions
C
C     Error free.
C
C$ Files
C
C      None.
C
C$ Author_and_Institution
C
C      W.M. Owen       (JPL)
C
C$ Literature_References
C
C      None.
C
C$ Version
C
C-    SPICELIB Version 1.0.1, 10-MAR-1992 (WLT)
C
C        Comment section for permuted index source lines was added
C        following the header.
C
C-    SPICELIB Version 1.0.0, 31-JAN-1990 (WMO)
C
C-&
 
C$ Index_Entries
C
C     3-dimensional vector_transpose times matrix times vector
C
C-&
 
      INTEGER K,L
 
      VTMV = 0.D0
      DO K=1,3
         DO L=1,3
            VTMV = VTMV + V1(K) * MATRIX(K,L) * V2(L)
         END DO
      END DO
 
      RETURN
      END
