C$Procedure            WDCNT ( Word Count )
 
      INTEGER FUNCTION WDCNT ( STRING )
 
C$ Abstract
C
C      Return the number of words in a string.
C
C$ Copyright
C
C     Copyright (1995), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     None.
C
C$ Keywords
C
C      STRING,  WORD
C
C$ Declarations
 
      CHARACTER*(*)    STRING
 
C$ Brief_I/O
C
C      VARIABLE  I/O  DESCRIPTION
C      --------  ---  --------------------------------------------------
C      STRING     I   Input character string.
C      WDCNT      O   The number of words in string.
C
C$ Detailed_Input
C
C      STRING      is the input string to be parsed. It contains
C                  some number of words, where a word is any string
C                  of consecutive non-blank characters delimited
C                  by a blank or by either end of the string.
C
C$ Detailed_Output
C
C      WDCNT       is the number of words in the input character
C                  string.
C
C$ Parameters
C
C     None.
C
C$ Exceptions
C
C      Error free.
C
C$ Files
C
C      None.
C
C$ Particulars
C
C      WDCNT, like NTHWD and NEXTWD, is useful primarily for parsing
C      input commands consisting of one or more words, where a word is
C      defined to be any sequence of consecutive non-blank characters
C      delimited by either a blank or by either end of the string.
C
C$ Examples
C
C      The following examples illustrate the use of WDCNT.
C
C            WDCNT ( 'Now is the time'  )   = 4
C            WDCNT ( '  for all  '      )   = 2
C            WDCNT ( 'good,men.to_come' )   = 1
C            WDCNT ( ' '                )   = 0
C
C$ Restrictions
C
C      None.
C
C$ Literature_References
C
C      None.
C
C$ Author_and_Institution
C
C      I.M. Underwood  (JPL)
C
C$ Version
C
C-     SPICELIB Version 1.0.1, 10-MAR-1992 (WLT)
C
C         Comment section for permuted index source lines was added
C         following the header.
C
C-     SPICELIB Version 1.0.0, 31-JAN-1990 (IMU)
C
C-&
 
C$ Index_Entries
C
C     word count
C
C-&
 
 
 
 
 
C
C     Local variables
C
      INTEGER          N
      INTEGER          LOC
      INTEGER          LENGTH
 
 
 
C
C     This is just NTHWD, except that it keeps looking until
C     it finds the last word.
C
 
C
C     Trivial case first.
C
      IF ( STRING .EQ. ' ' ) THEN
 
         WDCNT = 0
         RETURN
 
      ELSE
 
         LENGTH = LEN ( STRING )
 
      END IF
 
C
C     Skip leading blanks.
C
      LOC = 1
 
      DO WHILE ( STRING(LOC:LOC) .EQ. ' ' )
         LOC = LOC + 1
      END DO
 
C
C     Keep stepping through STRING, counting words as we go.
C     (The current word is ended whenever a blank is encountered.)
C     Quit when the end of the string is reached.
C
C     N is the number of words found so far.
C     LOC is the current location in STRING.
C
      N = 1
 
      DO WHILE ( LOC .LT. LENGTH )
 
         LOC = LOC + 1
 
C
C        Blank signals end of the current word.
C
         IF ( STRING(LOC:LOC) .EQ. ' ' ) THEN
 
C
C           Skip ahead to the next word.
C
            DO WHILE ( LOC .LE. LENGTH .AND. STRING(LOC:LOC) .EQ. ' ' )
               LOC = LOC + 1
            END DO
 
C
C           If not at the end of the string, we have another word.
C
            IF ( LOC .LE. LENGTH ) THEN
               N = N + 1
            END IF
 
         END IF
 
      END DO
 
C
C     Return the number of words found.
C
      WDCNT = N
 
      RETURN
      END
 
 
