C$Procedure      WNFETD ( Fetch an interval from a DP window )
 
      SUBROUTINE WNFETD ( WINDOW, N, LEFT, RIGHT )
 
C$ Abstract
C
C     Fetch a particular interval from a double precision window.
C
C$ Copyright
C
C     Copyright (1995), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C      WINDOWS
C
C$ Keywords
C
C     WINDOWS
C
C$ Declarations
 
      INTEGER               LBCELL
      PARAMETER           ( LBCELL = -5 )
 
      DOUBLE PRECISION      WINDOW      ( LBCELL:* )
      INTEGER               N
      DOUBLE PRECISION      LEFT
      DOUBLE PRECISION      RIGHT
 
C$ Brief_I/O
C
C      VARIABLE  I/O  DESCRIPTION
C      --------  ---  --------------------------------------------------
C      WINDOW     I   Input window.
C      N          I   Index of interval to be fetched.
C      LEFT,
C      RIGHT      O   Left, right endpoints of the Nth interval.
C
C$ Detailed_Input
C
C      WINDOW      is a window containing zero or more intervals.
C
C      N           is the index of a particular interval within the
C                  window.
C
C$ Detailed_Output
C
C      LEFT,
C      RIGHT       are the left and right endpoints of the Nth interval
C                  in the input window. If the interval is not found,
C                  LEFT and RIGHT are not defined.
C
C$ Parameters
C
C     None.
C
C$ Particulars
C
C      None.
C
C$ Examples
C
C      Let A contain the intervals
C
C            [ 1, 3 ]  [ 7, 11 ]  [ 23, 27 ]
C
C      Then the following calls
C
C            CALL WNFETD ( A, -1, LEFT, RIGHT )       [1]
C            CALL WNFETD ( A,  2, LEFT, RIGHT )       [2]
C            CALL WNFETD ( A,  5, LEFT, RIGHT )       [3]
C
C      yield the following values of LEFT and RIGHT
C
C            LEFT         RIGHT
C            ---------    ---------
C            Undefined    Undefined
C            7            11
C            Undefined    Undefined
C
C$ Exceptions
C
C     1. If N is less than one, the error SPICE(NOINTERVAL) is
C        signalled.
C
C     2. If the interval does not exist, the error SPICE(NOINTERVAL)
C        is signalled.
C
C$ Files
C
C      None.
C
C$ Restrictions
C
C      None.
C
C$ Literature_References
C
C      None.
C
C$ Author_and_Institution
C
C      W.L. Taber      (JPL)
C      I.M. Underwood  (JPL)
C
C$ Version
C
C-     SPICELIB Version 1.0.1, 10-MAR-1992 (WLT)
C
C         Comment section for permuted index source lines was added
C         following the header.
C
C-     SPICELIB Version 1.0.0, 31-JAN-1990 (WLT) (IMU)
C
C-&
 
C$ Index_Entries
C
C     fetch an interval from a d.p. window
C
C-&
 
 
 
 
C
C     SPICELIB functions
C
      INTEGER               CARDD
      LOGICAL               RETURN
 
C
C     Local variables
C
      INTEGER               CARD
      INTEGER               END
 
 
 
 
C
C     Set up the error processing.
C
      IF ( RETURN () ) RETURN
      CALL CHKIN ( 'WNFETD' )
 
C
C
C     How many endpoints in the window? Enough? Normally, endpoints
C     of the Nth interval are stored in elements 2N and 2N-1.
C
      CARD = CARDD ( WINDOW )
      END  = 2*N
 
      IF ( N .LT. 1  .OR.  CARD .LT. END ) THEN
         CALL SETMSG ( 'WNFETD: No such interval.' )
         CALL SIGERR ( 'SPICE(NOINTERVAL)' )
      ELSE
         LEFT  = WINDOW(END-1)
         RIGHT = WINDOW(END  )
      END IF
 
      CALL CHKOUT ( 'WNFETD' )
 
      RETURN
      END
