C$Procedure      WRITLN ( Write a text line to a logical unit )
 
      SUBROUTINE WRITLN ( LINE, UNIT )
 
C$ Abstract
C
C     Write a single line of text to the Fortran logical unit UNIT.
C
C$ Copyright
C
C     Copyright (1995), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     None.
C
C$ Keywords
C
C     ASCII
C     TEXT
C     FILES
C
C$ Declarations
 
      CHARACTER*(*)      LINE
      INTEGER            UNIT
 
C$ Brief_I/O
C
C     Variable  I/O  Description
C     --------  ---  --------------------------------------------------
C     LINE       I   The line which is to be written to UNIT.
C     UNIT       I   The Fortran unit number to use for output.
C
C$ Detailed_Input
C
C     LINE     This contains the text line which is to be written
C              to UNIT.
C
C              The value of this variable is not modified.
C
C     UNIT     The Fortran unit number for the output. This may be
C              either the unit number for the terminal, or the unit
C              number of a previously opened text file.
C
C$ Detailed_Output
C
C     None.
C
C$ Parameters
C
C     None.
C
C$ Exceptions
C
C     1)   If an error occurs while attempting to write to the text
C          file attached to UNIT, the error SPICE(FILEWRITEFAILED) will
C          be signalled.
C
C     This routine only checks in with the error handler in the event
C     that an error occurred. (Discovery check in)
C
C$ Files
C
C     None.
C
C$ Particulars
C
C     This routine will write a single text line to the device
C     specified by UNIT. UNIT may be the terminal, or it may be
C     a logical unit number obtained from a Fortran OPEN or INQUIRE
C     statement. When written, the line will have trailing spaces
C     removed.
C
C$ Examples
C
C     CALL WRITLN( LINE, UNIT )
C
C     You have now written a line of text to unit UNIT.
C
C$ Restrictions
C
C     None.
C
C$ Literature_References
C
C     None.
C
C$ Author_and_Institution
C
C     K.R. Gehringer (JPL)
C
C$ Version
C
C-    SPICELIB Version 2.2.0, 03-JAN-2005 (BVS)
C
C        Updated for PC-CYGWIN_C.
C
C-    SPICELIB Version 2.1.0, 03-JAN-2005 (BVS)
C
C        Updated for PC-CYGWIN.
C
C-    SPICELIB Version 2.0.5, 17-JUL-2002 (BVS)
C
C        Added MAC-OSX environments.
C
C-    SPICELIB Version 2.0.4, 08-OCT-1999 (WLT)
C
C        The environment lines were expanded so that the supported
C        environments are now explicitely given.  New
C        environments are WIN-NT
C
C-    SPICELIB Version 2.0.3, 16-SEP-1999 (NJB)
C
C        CSPICE environments were added.  Some typos were corrected.
C
C-    SPICELIB Version 2.0.2, 28-JUL-1999 (WLT)
C
C        The environment lines were expanded so that the supported
C        environments are now explicitly given.  New
C        environments are PC-DIGITAL, SGI-O32 and SGI-N32.
C
C-    SPICELIB Version 2.0.1, 18-MAR-1999 (WLT)
C
C        The environment lines were expanded so that the supported
C        environments are now explicitly given.  Previously,
C        environments such as SUN-SUNOS and SUN-SOLARIS were implied
C        by the environment label SUN.
C
C-    SPICELIB Version 2.0.0, 08-APR-1998 (NJB)
C
C        Module was updated for the PC-LINUX platform.
C
C-    SPICELIB Version 1.1.1, 20-AUG-1996 (WLT)
C
C        Corrected the heading for the C$ Index_Entries section.
C
C-    SPICELIB Version 1.1.0, 29-FEB-1996 (KRG)
C
C        For the Macintosh, we need to use real Fortran I/O, i.e.,
C        using the first column for carriage control. The change
C        was to move the MAC environment indicator from one
C        environment case to the other.
C
C        Also, for UNIX environments, the parameter STDOUT is no
C        longer defined. This only appears for platforms that
C        need it to differentiate between writing to a file and
C        the terminal screen (standard output), currently: VAX,
C        PC-LAHEY, PC-MS, and MAC.
C
C-    SPICELIB Version 1.0.0, 20-DEC-1995 (KRG)
C
C        The routine graduated
C
C-    Beta Version 3.1.0, 18-AUG-1995 (KRG)
C
C        Moved the PC-LAHEY environment indicator from one environment
C        case to the other. The Lahey compiler on the PC does treat text
C        files and the standard output device differently.
C
C-    Beta Version 3.0.1, 01-JAN-1995 (KRG)
C
C        Moved the description of the input variable UNIT from the $
C        Detailed_Output section of the header to the correct location
C        in the $ Detailed_Input section of the header.
C
C-    Beta Version 3.0.0, 11-JUL-1994 (HAN)
C
C        Edited master source file to correct the code for the
C        PC/Microsoft FORTRAN PowerStation environment. It should use
C        the same code as the VAX, not the PC/Lahey Fortran code. Also,
C        code was included for the DEC Alpha OpenVMS/DEC Fortran and
C        Sun Solaris/Sun Fortran environments.
C
C-    Beta Version 2.0.0, 30-MAR-1994 (HAN)
C
C        Edited master source file to include new environments:
C        Silicon Graphics IRIX/Silicon Graphics Fortran,
C        DEC Alpha-OSF/1, and NeXT/Absoft Fortran.
C
C-    Beta Version 1.0.0, 17-DEC-1992 (KRG)
C
C-&
 
C$ Index_Entries
C
C     write a text line to a logical unit
C
C-&
 
C$ Revisions
C
C-    SPICELIB Version 2.0.0, 08-APR-1998 (NJB)
C
C        Module was updated for the PC-LINUX platform.
C
C-    SPICELIB Version 1.1.0, 29-FEB-1996 (KRG)
C
C        For the Macintosh, we need to use real Fortran I/O, i.e.,
C        using the first column for carriage control. The change
C        was to move the MAC environment indicator from one
C        environment case to the other.
C
C        Also, for UNIX environments, the parameter STDOUT is no
C        longer defined. This only appears for platforms that
C        need it to differentiate between writing to a file and
C        the terminal screen (standard output), currently: VAX,
C        PC-LAHEY, PC-MS, and MAC.
C
C-    SPICELIB Version 1.0.0, 20-DEC-1995 (KRG)
C
C        The routine graduated
C
C-    Beta Version 3.1.0, 18-AUG-1995 (KRG)
C
C        Moved the PC-LAHEY environment indicator from one environment
C        case to the other. The Lahey compiler on the PC does treat text
C        files and the standard output device differently.
C
C-    Beta Version 3.0.1, 01-JAN-1995 (KRG)
C
C        Moved the description of the input variable UNIT from the $
C        Detailed_Output section of the header to the correct location
C        in the $ Detailed_Input section of the header.
C
C-    Beta Version 3.0.0, 11-JUL-1994 (HAN)
C
C        Edited master source file to correct the code for the
C        PC/Microsoft FORTRAN PowerStation environment. It should use
C        the same code as the VAX, not the PC/Lahey Fortran code. Also,
C        code was included for the DEC Alpha OpenVMS/DEC Fortran and
C        Sun Solaris/Sun Fortran environments.
C
C-    Beta Version 2.0.0, 30-MAR-1994 (HAN)
C
C        Edited master source file to include new environments:
C        Silicon Graphics IRIX/Silicon Graphics Fortran,
C        DEC Alpha-OSF/1, and NeXT/Absoft Fortran.
C
C-    Beta Version 1.0.0, 17-DEC-1992 (KRG)
C
C-&
 
C
C     SPICELIB functions
C
      INTEGER               RTRIM
 
C
C     Local Parameters
C
C     Set a value for the logical unit which represents the standard
C     output device, commonly a terminal. A value of 6 is widely used,
C     but the Fortran standard does not specify a value, so it may be
C     different for different fortran implementations.
C
      INTEGER               STDOUT
      PARAMETER           ( STDOUT = 6 )
C
C     Local variables
C
      INTEGER               IOSTAT
 
C
C     Some environments make a distinction between a text file and the
C     terminal screen when writing to a logical unit using list directed
C     writes of character strings or the FMT='(A)' format specifier. The
C     difference has to do with the interpretation of the first
C     character in the output string which is supposed to control the
C     vertical spacing. This control character is required for writing
C     to the standard output device, but not for writing to a text file.
C     This is a pretty dumb thing to do, but we have to live with it.
C
C     So, we check to see if we are writing to the standard output unit
C     and perform a list directed write, otherwise we use the format
C     specifier FMT='(A)', which does not use any vertical carriage
C     control characters.
C
       IF ( UNIT .EQ. STDOUT ) THEN
          WRITE ( UNIT, *, IOSTAT=IOSTAT ) LINE(:RTRIM(LINE))
       ELSE
          WRITE ( UNIT, FMT='(A)', IOSTAT=IOSTAT ) LINE(:RTRIM(LINE))
       END IF
C
C     Check to see if we got a write error, and signal it if we did.
C     Also check in and check out.
C
      IF ( IOSTAT .NE. 0  ) THEN
 
         CALL CHKIN  ( 'WRITLN'                                  )
         CALL SETMSG ( 'Error Writing to file: #. IOSTAT = #.'   )
         CALL ERRFNM ( '#', UNIT                                 )
         CALL ERRINT ( '#', IOSTAT                               )
         CALL SIGERR ( 'SPICE(FILEWRITEFAILED)'                  )
         CALL CHKOUT ( 'WRITLN'                                  )
         RETURN
 
      END IF
 
      RETURN
      END
 
