C$Procedure      XPOSE ( Transpose a matrix, 3x3 )
 
      SUBROUTINE XPOSE ( M1, MOUT )
 
C$ Abstract
C
C      Transpose a 3x3 matrix.
C
C$ Copyright
C
C     Copyright (1995), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     None.
C
C$ Keywords
C
C      MATRIX
C
C$ Declarations
 
      DOUBLE PRECISION  M1   ( 3,3 )
      DOUBLE PRECISION  MOUT ( 3,3 )
 
C$ Brief_I/O
C
C      VARIABLE  I/O  DESCRIPTION
C      --------  ---  --------------------------------------------------
C       M1        I     Matrix to be transposed.
C       MOUT      O     Transposed matrix (M1)**T.
C                       MOUT can overwrite M1.
C
C$ Detailed_Input
C
C      M1      This variable may contain any double precision 3x3
C              matrix.
C
C$ Detailed_Output
C
C      MOUT    This variable is a double precision, 3x3 matrix which
C              contains the transpose of M1. MOUT may overwrite M1.
C
C$ Parameters
C
C     None.
C
C$ Particulars
C
C      XPOSE first copies the diagonal elements of M1 to MOUT.  Then
C      the off-diagonal elements are transpose using a temporary
C      variable in the following order: (1,2) <---> (2,1),
C      (1,3) <---> (3,1) and finally (2,3) <---> (3,2).  Since a
C      temporary variable is used, it is possible to transpose a matrix
C      in place.  In other words, MOUT may overwrite M1.
C
C$ Examples
C
C      Given below is one example of a matrix M1 with the output matrix
C      MOUT which is implied by M1.
C
C           | 1  2  3 |                | 1  0  0 |
C      M1 = | 0  4  5 |   then  MOUT = | 2  4  6 |
C           | 0  6  0 |                | 3  5  0 |
C
C$ Restrictions
C
C      None.
C
C$ Exceptions
C
C      Error free.
C
C$ Files
C
C      None.
C
C$ Author_and_Institution
C
C      W.M. Owen       (JPL)
C
C$ Literature_References
C
C      None.
C
C$ Version
C
C-     SPICELIB Version 1.0.1, 10-MAR-1992 (WLT)
C
C         Comment section for permuted index source lines was added
C         following the header.
C
C-     SPICELIB Version 1.0.0, 31-JAN-1990 (WMO)
C
C-&
 
C$ Index_Entries
C
C     transpose a 3x3_matrix
C
C-&
 
      DOUBLE PRECISION TEMP
C
C  Move the three diagonal elements from M1 to MOUT
C
      MOUT(1,1) = M1(1,1)
      MOUT(2,2) = M1(2,2)
      MOUT(3,3) = M1(3,3)
C
C  Switch the three pairs of off-diagonal elements
C
      TEMP = M1(1,2)
      MOUT(1,2) = M1(2,1)
      MOUT(2,1) = TEMP
C
      TEMP = M1(1,3)
      MOUT(1,3) = M1(3,1)
      MOUT(3,1) = TEMP
C
      TEMP = M1(2,3)
      MOUT(2,3) = M1(3,2)
      MOUT(3,2) = TEMP
C
      RETURN
      END
