C$Procedure ZZDDHGSD ( Private --- DDH Get String Definitions )
 
      SUBROUTINE ZZDDHGSD ( CLASS, ID, LABEL )
 
C$ Abstract
C
C     SPICE Private routine intended solely for the support of SPICE
C     routines.  Users should not call this routine directly due
C     to the volatile nature of this routine.
C
C     Retrieve string definitions for various CLASS and ID pairs.
C
C$ Copyright
C
C     Copyright (2001), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     None.
C
C$ Keywords
C
C     PRIVATE
C
C$ Declarations
 
      IMPLICIT NONE
 
      INCLUDE              'zzddhman.inc'
 
      CHARACTER*(*)         CLASS
      INTEGER               ID
      CHARACTER*(*)         LABEL
 
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     CLASS      I   String indicating the class of label requested.
C     ID         I   Integer ID desired for the decoding.
C     LABEL      O   Corresponding label for the CLASS/ID pair.
C
C$ Detailed_Input
C
C     CLASS      is the class of the input ID code.  Acceptable
C                values are:
C
C                   'METHOD' - File access method
C                   'ARCH'   - File architecture
C                   'BFF'    - Binary file format
C
C     ID         is a integer value that is defined in the include
C                file 'zzddhman.inc'.
C
C$ Detailed_Output
C
C     LABEL      is the 'decoded' ID value that describes a particular
C                CLASS/ID pair. In the event that CLASS and ID do not
C                correspond to parameters in the include file, the
C                routine simply returns a blank string.
C
C$ Parameters
C
C     None.
C
C$ Files
C
C     None.
C
C$ Exceptions
C
C     1) If the CLASS/ID pair is not known, then this routine
C        simply returns a blank label.
C
C$ Particulars
C
C     This routine is designed to consolidate label definitions for
C     parameters in the include file 'zzddhman.inc'.  These labels
C     are to be used in error messages and user level subroutines.
C
C$ Examples
C
C     See ZZDDHMAN for sample usage.
C
C$ Restrictions
C
C     This routine must be kept compatible with the contents of
C     'zzddhman.inc' as its functionality is heavily dependent
C     on its contents.
C
C$ Author_and_Institution
C
C     F.S. Turner     (JPL)
C
C$ Literature_References
C
C     None.
C
C$ Version
C
C-    SPICELIB Version 1.0.0, 07-JUN-2001 (FST)
C
C
C-&
 
C
C     SPICELIB Functions
C
      INTEGER               ISRCHC
 
C
C     Local Parameters
C
      INTEGER               LOCSIZ
      PARAMETER           ( LOCSIZ = 8 )
 
C
C     Number of classes of label/ID pairs of which this routine is
C     aware.
C
      INTEGER               NUMCLS
      PARAMETER           ( NUMCLS = 3 )
 
C
C     Integer codes for the currently supported classes.
C
      INTEGER               METHOD
      PARAMETER           ( METHOD = 1 )
 
      INTEGER               ARCH
      PARAMETER           ( ARCH   = METHOD + 1 )
 
      INTEGER               BFF
      PARAMETER           ( BFF    = ARCH   + 1 )
 
C
C     Local Variables
C
      CHARACTER*(LOCSIZ)    CLSLST ( NUMCLS )
      CHARACTER*(STRSIZ)    STRAMH ( NUMAMH )
      CHARACTER*(STRSIZ)    STRARC ( NUMARC )
      CHARACTER*(STRSIZ)    STRBFF ( NUMBFF )
      CHARACTER*(LOCSIZ)    TMPSTR
 
      INTEGER               CLSID
 
C
C     Saved Variables
C
      SAVE                  CLSLST
      SAVE                  STRAMH
      SAVE                  STRARC
      SAVE                  STRBFF
 
C
C     Data Statements
C
      DATA                  CLSLST / 'METHOD', 'ARCH', 'BFF' /
 
      DATA                  STRAMH / 'READ',     'WRITE',
     .                               'SCRATCH',  'NEW'       /
 
      DATA                  STRARC / 'DAF',      'DAS'       /
 
      DATA                  STRBFF / 'BIG-IEEE', 'LTL-IEEE',
     .                               'VAX-GFLT', 'VAX-DFLT'  /
 
C
C     Left justify and convert the input to upper case.
C
      CALL LJUST ( CLASS,  TMPSTR )
      CALL UCASE ( TMPSTR, TMPSTR )
 
      CLSID = ISRCHC ( TMPSTR, NUMCLS, CLSLST )
 
C
C     Initialize LABEL to the default response.
C
      LABEL = ' '
 
C
C     Branch on CLSID and return the appropriate label as requested
C     by ID.
C
      IF      (       ( CLSID .EQ. METHOD )
     .          .AND. (    ID .GE. 1      )
     .          .AND. (    ID .LE. NUMAMH ) ) THEN
 
         LABEL = STRAMH ( ID )
 
      ELSE IF (       ( CLSID .EQ. ARC  H )
     .          .AND. (    ID .GE. 1      )
     .          .AND. (    ID .LE. NUMARC ) ) THEN
 
         LABEL = STRARC ( ID )
 
      ELSE IF (       ( CLSID .EQ. BFF    )
     .          .AND. (    ID .GE. 1      )
     .          .AND. (    ID .LE. NUMBFF ) ) THEN
 
         LABEL = STRBFF ( ID )
 
      END IF
 
      RETURN
      END
