C$Procedure      ZZEKGRCP ( EK, get record companion pointer )
 
      SUBROUTINE ZZEKGRCP ( HANDLE, RECPTR, PTR )
 
C$ Abstract
C
C     Get the companion pointer of a specified EK record.
C
C$ Copyright
C
C     Copyright (1995), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     EK
C
C$ Keywords
C
C     EK
C     PRIVATE
C
C$ Declarations
 
      INCLUDE 'eksegdsc.inc'
      INCLUDE 'ekrecptr.inc'
 
      INTEGER               HANDLE
      INTEGER               RECPTR
      INTEGER               PTR
 
C$ Brief_I/O
C
C     Variable  I/O  Description
C     --------  ---  --------------------------------------------------
C     HANDLE     I   File handle.
C     RECPTR     I   Record pointer.
C     PTR        O   Pointer to companion of specified EK record.
C
C$ Detailed_Input
C
C     HANDLE         is a file handle of an EK open for read or write
C                    access.
C
C     RECPTRC        is a pointer to the record whose companion pointer
C                    is desired.
C
C$ Detailed_Output
C
C     PTR            is a pointer to the companion record of the
C                    specified input record.  If the input record
C                    belongs to a shadowed EK, the companion record
C                    is the corresponding backup record.  If the input
C                    record is a backup record, the companion record
C                    is the corresponding source record.
C
C$ Parameters
C
C     None.
C
C$ Exceptions
C
C     1)  If HANDLE is invalid, the error will be diagnosed by routines
C         called by this routine.
C
C     2)  If an I/O error occurs while reading the indicated file, the
C         error will be diagnosed by routines called by this routine.
C
C$ Files
C
C     See the EK Required Reading for a discussion of the EK file
C     format.
C
C$ Particulars
C
C     This routine sets the companion record pointer of a specified EK
C     record.
C
C$ Examples
C
C     See EKROLL.
C
C$ Restrictions
C
C     None.
C
C$ Literature_References
C
C     None.
C
C$ Author_and_Institution
C
C     N.J. Bachman   (JPL)
C
C$ Version
C
C-    Beta Version 1.0.0, 10-OCT-1995 (NJB)
C
C-&
 
C
C     SPICELIB functions
C
      LOGICAL               FAILED
 
C
C     Local variables
C
      INTEGER               LOC
 
C
C     Use discovery check-in.
C
C
C     Is this file handle valid--is the file open for paged write
C     access?  Signal an error if not.
C
      CALL ZZEKPGCH ( HANDLE, 'WRITE' )
 
      IF ( FAILED() ) THEN
         RETURN
      END IF
 
C
C     Compute the companion pointer and set the pointer.
C
      LOC  =  RECPTR + RCPIDX
 
      CALL DASRDI ( HANDLE, LOC, LOC, PTR )
 
      RETURN
      END
