C$Procedure ZZEKIIC1 ( EK, insert into index, character, type 1 )
 
      SUBROUTINE ZZEKIIC1 ( HANDLE, SEGDSC, COLDSC, CKEY, RECPTR, NULL )
 
C$ Abstract
C
C     Insert into a type 1 EK index a record pointer associated with a
C     character key.  The key and record pointer determine the insertion
C     point via dictionary ordering on (value, record pointer) pairs.
C
C$ Copyright
C
C     Copyright (1995), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     None.
C
C$ Keywords
C
C     EK
C     PRIVATE
C
C$ Declarations
 
 
      INCLUDE 'ekbool.inc'
      INCLUDE 'ekcnamsz.inc'
      INCLUDE 'ekcoldsc.inc'
      INCLUDE 'ekopcd.inc'
      INCLUDE 'eksegdsc.inc'
      INCLUDE 'ektype.inc'
 
      INTEGER               HANDLE
      INTEGER               SEGDSC ( SDSCSZ )
      INTEGER               COLDSC ( CDSCSZ )
      CHARACTER*(*)         CKEY
      INTEGER               RECPTR
      LOGICAL               NULL
 
C$ Brief_I/O
C
C     Variable  I/O  Description
C     --------  ---  --------------------------------------------------
C     HANDLE     I   File handle.
C     SEGDSC     I   Segment descriptor.
C     COLDSC     I   Column descriptor.
C     CKEY       I   Character key.
C     RECPTR     I   Record pointer.
C     NULL       I   Null flag.
C
C$ Detailed_Input
C
C     HANDLE         is a file handle of an EK open for write access.
C
C     SEGDSC         is the segment descriptor of the segment
C                    containing the column specified by COLDSC.
C
C     COLDSC         is the column descriptor of the column to
C                    which the index corresponds.
C
C     CKEY           is a character string key.
C
C     RECPTR         is a record pointer associated with the input key.
C
C     NULL           is a logical flag indicating whether the input
C                    value is null.
C
C$ Detailed_Output
C
C     None.  This routine operates by side effects.  See $Particulars
C     for a description of the effect of this routine.
C
C$ Parameters
C
C     None.
C
C$ Exceptions
C
C     1)  If HANDLE is invalid, the error will be diagnosed by routines
C         called by this routine.
C
C     2)  If the data type of the input column is not character,
C         the error SPICE(INVALIDTYPE) is signalled.
C
C     3)  If the input column is not indexed, the error
C         SPICE(NOTINDEXED) is signalled.
C
C     4)  If the index type of the input column is not recognized,
C         the error SPICE(INVALIDTYPE) is signalled.
C
C     5)  If an I/O error occurs while reading or writing the indicated
C         file, the error will be diagnosed by routines called by this
C         routine.
C
C$ Files
C
C     See the EK Required Reading for a discussion of the EK file
C     format.
C
C$ Particulars
C
C     This routine updates the index of an EK segment to reflect the
C     addition of a record to the segment.  The index must be
C     associated with a character, scalar column.  The type of the
C     index must be 1.
C
C     The ordinal position of the new item is determined by the key
C     CKEY.  The new item will follow the last item already present
C     in the column having a value less than or equal to CKEY.
C
C     In order to support the capability of creating an index for a
C     column that has already been populated with data, this routine
C     does not require that number of elements referenced by the
C     input column's index match the number of elements in the column;
C     the index is allowed to reference fewer elements.  However,
C     every record referenced by the index must be populated with data.
C
C$ Examples
C
C     See ZZEKAD03.
C
C$ Restrictions
C
C     None.
C
C$ Literature_References
C
C     None.
C
C$ Author_and_Institution
C
C     N.J. Bachman   (JPL)
C
C$ Version
C
C-    SPICELIB Version 1.1.0, 18-JUN-1999 (WLT)
C
C        Removed an unbalanced call to CHKOUT
C
C-    Beta Version 1.0.0, 10-OCT-1995 (NJB)
C
C-&
 
 
C
C     SPICELIB functions
C
      LOGICAL               FAILED
 
C
C     Local variables
C
      CHARACTER*(CNAMSZ)    COLUMN
 
      INTEGER               DTYPE
      INTEGER               ITYPE
      INTEGER               PRVIDX
      INTEGER               PRVPTR
      INTEGER               TREE
 
      LOGICAL               INDEXD
 
C
C     Use discovery check-in.
C
      IF ( FAILED() ) THEN
         RETURN
      END IF
 
 
C
C     If the column's not indexed, we have no business being here.
C
      INDEXD  =  COLDSC(IXTIDX) .NE. IFALSE
 
      IF ( .NOT. INDEXD ) THEN
 
         CALL ZZEKCNAM ( HANDLE, COLDSC, COLUMN )
 
         CALL CHKIN  ( 'ZZEKIIC1'                 )
         CALL SETMSG ( 'Column # is not indexed.' )
         CALL ERRCH  ( '#',  COLUMN               )
         CALL SIGERR ( 'SPICE(NOTINDEXED)'        )
         CALL CHKOUT ( 'ZZEKIIC1'                 )
         RETURN
 
      END IF
 
 
C
C     Check the column's data type.
C
      DTYPE  =  COLDSC(TYPIDX)
 
      IF ( DTYPE .NE. CHR ) THEN
 
         CALL ZZEKCNAM ( HANDLE, COLDSC, COLUMN )
 
         CALL CHKIN  ( 'ZZEKIIC1'                               )
         CALL SETMSG ( 'Column # should be CHR but has type #.' )
         CALL ERRCH  ( '#',  COLUMN                             )
         CALL ERRINT ( '#',  DTYPE                              )
         CALL SIGERR ( 'SPICE(INVALIDTYPE)'                     )
         CALL CHKOUT ( 'ZZEKIIC1'                               )
         RETURN
 
      END IF
 
 
      ITYPE  =  COLDSC(IXTIDX)
 
 
      IF ( ITYPE .EQ. 1 ) THEN
C
C        Get the tree pointer from the column descriptor.
C
         TREE  =  COLDSC(IXPIDX)
 
C
C        Locate the predecessor of the input key, record pair.
C
         CALL ZZEKLERC (  HANDLE,  SEGDSC,  COLDSC,  CKEY,
     .                    RECPTR,  NULL,    PRVIDX,  PRVPTR  )
 
C
C        Insert the new record number right after the item we've found.
C
         CALL ZZEKTRIN ( HANDLE, TREE, PRVIDX+1, RECPTR )
 
 
      ELSE
 
         CALL ZZEKCNAM ( HANDLE, SEGDSC, COLUMN )
 
         CALL CHKIN  ( 'ZZEKIIC1'                   )
         CALL SETMSG ( 'Column # has index type #.' )
         CALL ERRCH  ( '#',  COLUMN                 )
         CALL ERRINT ( '#',  ITYPE                  )
         CALL SIGERR ( 'SPICE(INVALIDTYPE)'         )
         CALL CHKOUT ( 'ZZEKIIC1'                   )
         RETURN
 
      END IF
 
      RETURN
      END
