C$Procedure   ZZEKRSI ( EK, read scalar, integer )
 
      SUBROUTINE ZZEKRSI (  HANDLE,  SEGDSC,  COLDSC,  RECPTR,
     .                      ELTIDX,  IVAL,    ISNULL,  FOUND  )
 
C$ Abstract
C
C     Read scalar data from an integer column in a specified EK record.
C
C$ Copyright
C
C     Copyright (1995), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     EK
C
C$ Keywords
C
C     EK
C     PRIVATE
C
C$ Declarations
 
      INCLUDE 'ekcnamsz.inc'
      INCLUDE 'ekcoldsc.inc'
      INCLUDE 'eksegdsc.inc'
      INCLUDE 'ektype.inc'
 
      INTEGER               HANDLE
      INTEGER               SEGDSC ( SDSCSZ )
      INTEGER               COLDSC ( CDSCSZ )
      INTEGER               RECPTR
      INTEGER               ELTIDX
      INTEGER               IVAL
      LOGICAL               ISNULL
      LOGICAL               FOUND
 
C$ Brief_I/O
C
C     Variable  I/O  Description
C     --------  ---  --------------------------------------------------
C     HANDLE     I   Handle attached to EK file.
C     SEGDSC     I   Segment descriptor.
C     COLDSC     I   Column descriptor.
C     RECPTR     I   Pointer to record from which data is to be read.
C     ELTIDX     I   Index of column entry element to be read.
C     IVAL       O   Integer value in column entry.
C     ISNULL     O   Flag indicating whether column entry is null.
C     FOUND      O   Flag indicting whether entry element was found.
C
C$ Detailed_Input
C
C     HANDLE         is an EK file handle.
C
C     SEGDSC         is the descriptor of the segment from which data is
C                    to be read.
C
C     COLDSC         is the column descriptor corresponding to the
C                    column from which to read.
C
C     RECPTR         is a pointer to the record from which data is to be
C                    read.
C
C     ELTIDX         is the index of the column entry element to read.
C                    If the column entry is scalar, this argument is
C                    ignored.
C
C$ Detailed_Output
C
C     IVAL           is the specified column entry.  IVAL is valid only
C                    when FOUND is set to .TRUE.
C
C     ISNULL         is a logical flag indicating whether the entry is
C                    null.  ISNULL is valid only when FOUND is set to
C                    .TRUE.
C
C     FOUND          is a logical flag indicating whether the specified
C                    column entry element was found.  For vector-valued
C                    columns, if ELTIDX refers to a non-existent
C                    column entry element, FOUND is set to .FALSE.
C
C$ Parameters
C
C     None.
C
C$ Exceptions
C
C     1)  If HANDLE is invalid, the error will be diagnosed by routines
C         called by this routine.
C
C     2)  If COLDSC is not the descriptor of a declared column, the
C         error will be diagnosed by routines called by this routine.
C
C     3)  If COLDSC specifies a column of whose data type is not
C         integer, the error SPICE(WRONGDATATYPE) will be signalled.
C
C     4)  If COLDSC specifies a column of whose class is not
C         an integer class known to this routine, the error
C         SPICE(NOCLASS) will be signalled.
C
C     5)  If the indicated column is array-valued, and if ELTIDX is
C         non-positive, the error will be diagnosed by routines called
C         by this routine.  However, if ELTIDX is greater than the
C         number of elements in the specified column entry, FOUND is
C         set to .FALSE. and no error is signalled.
C
C     6)  If an I/O error occurs while reading the indicated file,
C         the error will be diagnosed by routines called by this
C         routine.
C
C$ Files
C
C     See the EK Required Reading for a discussion of the EK file
C     format.
C
C$ Particulars
C
C     The ZZEKRSx routines are low-level readers that expect column
C     entries to be defined by descriptors.  Since these routines do not
C     look up descriptors, in cases where many successive accesses to
C     the same segment and column are required, these routines are
C     considerably more efficient than the high-level readers.
C
C     These routines do not participate in tracing.
C
C$ Examples
C
C     See ZZEKECMP.
C
C$ Restrictions
C
C     None.
C
C$ Literature_References
C
C     None.
C
C$ Author_and_Institution
C
C     N.J. Bachman   (JPL)
C
C$ Version
C
C-    Beta Version 1.0.0, 06-NOV-1995 (NJB)
C
C-&
 
C
C     Non-SPICELIB functions
C
      INTEGER               ZZEKRP2N
 
C
C     Local variables
C
      CHARACTER*(CNAMSZ)    COLUMN
 
      INTEGER               CLASS
      INTEGER               DTYPE
      INTEGER               RECNO
      INTEGER               SEGNO
      INTEGER               UNIT
 
C
C     Use discovery check-in.
C
C     Nothing found to begin with.
C
      FOUND  =  .FALSE.
 
C
C     This column had better be of integer type.
C
      DTYPE  =  COLDSC(TYPIDX)
 
      IF ( DTYPE .NE. INT ) THEN
 
         CALL ZZEKCNAM ( HANDLE, COLDSC, COLUMN )
         CALL DASHLU   ( HANDLE, UNIT )
 
         SEGNO  =  SEGDSC   ( SNOIDX )
         RECNO  =  ZZEKRP2N ( HANDLE, SEGDSC(SNOIDX), RECPTR )
 
         CALL CHKIN  ( 'ZZEKRSI'                                       )
         CALL DASHLU ( HANDLE,  UNIT                                   )
         CALL SETMSG ( 'Column # is of type #; ZZEKRSI only works '   //
     .                 'with integer columns.  RECNO = #; SEGNO = '   //
     .                 '#; EK = #.'                                    )
         CALL ERRCH  ( '#',  COLUMN                                    )
         CALL ERRINT ( '#',  DTYPE                                     )
         CALL ERRINT ( '#',  RECNO                                     )
         CALL ERRINT ( '#',  SEGNO                                     )
         CALL ERRFNM ( '#',  UNIT                                      )
         CALL SIGERR ( 'SPICE(WRONGDATATYPE)'                          )
         CALL CHKOUT ( 'ZZEKRSI'                                       )
         RETURN
 
      END IF
 
C
C     Now it's time to read data from the file.  Call the low-level
C     reader appropriate to the column's class.
C
      CLASS  =  COLDSC ( CLSIDX )
 
 
      IF ( CLASS .EQ. 1 ) THEN
C
C        Class 1 columns contain scalar, integer entries.
C
         CALL ZZEKRD01 ( HANDLE, SEGDSC, COLDSC, RECPTR, IVAL, ISNULL )
 
         FOUND  =  .TRUE.
 
 
      ELSE IF ( CLASS .EQ. 4 ) THEN
C
C        Class 4 columns contain integer array entries.
C
         CALL ZZEKRD04 ( HANDLE,  SEGDSC,  COLDSC,  RECPTR,
     .                   ELTIDX,  ELTIDX,  IVAL,    ISNULL,  FOUND )
 
 
      ELSE IF ( CLASS .EQ. 7 ) THEN
C
C        Class 7 columns are fixed-count columns that contain scalar,
C        integer entries.
C
         CALL ZZEKRD07 ( HANDLE, SEGDSC, COLDSC, RECPTR, IVAL, ISNULL )
 
         FOUND  =  .TRUE.
 
 
      ELSE
 
C
C        This is an unsupported integer column class.
C
         CALL ZZEKCNAM ( HANDLE, COLDSC, COLUMN )
         CALL DASHLU   ( HANDLE, UNIT )
 
         SEGNO  =  SEGDSC   ( SNOIDX )
         RECNO  =  ZZEKRP2N ( HANDLE, SEGDSC(SNOIDX), RECPTR )
 
         CALL CHKIN  ( 'ZZEKRSI'                                       )
         CALL DASHLU ( HANDLE,  UNIT                                   )
         CALL SETMSG ( 'Class # from input column descriptor is not ' //
     .                 'a supported integer class.  COLUMN = #; '     //
     .                 'RECNO = #; SEGNO = #; EK = #.'                 )
         CALL ERRINT ( '#',  CLASS                                     )
         CALL ERRCH  ( '#',  COLUMN                                    )
         CALL ERRINT ( '#',  RECNO                                     )
         CALL ERRINT ( '#',  SEGNO                                     )
         CALL ERRFNM ( '#',  UNIT                                      )
         CALL SIGERR ( 'SPICE(NOCLASS)'                                )
         CALL CHKOUT ( 'ZZEKRSI'                                       )
         RETURN
 
      END IF
 
      RETURN
      END
