C$Procedure      ZZEKSRCP ( EK, set record companion pointer )
 
      SUBROUTINE ZZEKSRCP ( HANDLE, RECPTR, RECNO )
 
C$ Abstract
C
C     Set the companion pointer of a specified EK record.
C
C$ Copyright
C
C     Copyright (1995), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     EK
C
C$ Keywords
C
C     EK
C     PRIVATE
C
C$ Declarations
 
      INCLUDE 'ekrecptr.inc'
 
      INTEGER               HANDLE
      INTEGER               RECPTR
      INTEGER               RECNO
 
C$ Brief_I/O
C
C     Variable  I/O  Description
C     --------  ---  --------------------------------------------------
C     HANDLE     I   File handle.
C     RECPTR     I   Record pointer.
C     RECNO      I   Record number of companion of specified EK record.
C
C$ Detailed_Input
C
C     HANDLE         is a file handle of an EK open for write access.
C
C     RECPTR         is a pointer to the record whose companion pointer
C                    is to be set.
C
C     RECNO          is the `companion record pointer' of the record
C                    designated by RECPTR.  This name is a little
C                    misleading:  we identify the companion record
C                    by its record number, not by an address.  So RECNO
C                    is a pointer only in an abstract sense.
C
C                    If the input record belongs to a shadowed EK, the
C                    companion record is the corresponding backup
C                    record.  If the input record is a backup record,
C                    the companion record is the corresponding source
C                    record.
C
C$ Detailed_Output
C
C     None.  See $Particulars for a description of the action of this
C     routine.
C
C$ Parameters
C
C     None.
C
C$ Exceptions
C
C     1)  If HANDLE is invalid, the error will be diagnosed by routines
C         called by this routine.
C
C     2)  If an I/O error occurs while reading or writing the indicated
C         file, the error will be diagnosed by routines called by this
C         routine.
C
C$ Files
C
C     See the EK Required Reading for a discussion of the EK file
C     format.
C
C$ Particulars
C
C     This routine sets the companion record pointer of a specified EK
C     record.  As noted in $Detailed_Input, the `pointer' is simply
C     the number of the companion record.
C
C$ Examples
C
C     See ZZEKRBCK.
C
C$ Restrictions
C
C     None.
C
C$ Literature_References
C
C     None.
C
C$ Author_and_Institution
C
C     N.J. Bachman   (JPL)
C
C$ Version
C
C-    Beta Version 1.0.0, 18-OCT-1995 (NJB)
C
C-&
 
C
C     SPICELIB functions
C
      LOGICAL               FAILED
 
C
C     Local variables
C
      INTEGER               LOC
 
C
C     Use discovery check-in.
C
C
C     Is this file handle valid--is the file open for paged write
C     access?  Signal an error if not.
C
      CALL ZZEKPGCH ( HANDLE, 'WRITE' )
 
      IF ( FAILED() ) THEN
         RETURN
      END IF
 
C
C     Compute the companion pointer and set the pointer.
C
      LOC  =  RECPTR + RCPIDX
 
      CALL DASUDI ( HANDLE, LOC, LOC, RECNO )
 
      RETURN
      END
