C$Procedure      ZZEKUE06 ( EK, update column entry, class 6 )
 
      SUBROUTINE ZZEKUE06 (  HANDLE,  SEGDSC,  COLDSC,
     .                       RECPTR,  NVALS,   CVALS,  ISNULL  )
 
C$ Abstract
C
C     Update a specified class 6 column entry in an EK record.
C
C$ Copyright
C
C     Copyright (1995), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     EK
C
C$ Keywords
C
C     EK
C     PRIVATE
C
C$ Declarations
 
 
      INCLUDE 'ekbool.inc'
      INCLUDE 'ekcoldsc.inc'
      INCLUDE 'ekdatpag.inc'
      INCLUDE 'ekrecptr.inc'
      INCLUDE 'eksegdsc.inc'
      INCLUDE 'ektype.inc'
 
      INTEGER               HANDLE
      INTEGER               SEGDSC ( SDSCSZ )
      INTEGER               COLDSC ( CDSCSZ )
      INTEGER               RECPTR
      INTEGER               NVALS
      CHARACTER*(*)         CVALS
      LOGICAL               ISNULL
 
C$ Brief_I/O
C
C     Variable  I/O  Description
C     --------  ---  --------------------------------------------------
C     HANDLE     I   File handle.
C     SEGDSC     I   Segment descriptor.
C     COLDSC     I   Column descriptor.
C     RECPTR     I   Record pointer.
C     NVALS      I   Number of values.
C     CVALS      I   Character string values.
C     ISNULL     I   Null flag.
C
C$ Detailed_Input
C
C     HANDLE         is a file handle of an EK open for write access.
C
C     SEGDSC         is the descriptor of the segment containing
C                    the specified column entry.
C
C     COLDSC         is the descriptor of the column containing
C                    the specified column entry.
C
C     RECPTR         is a pointer to the record containing the column
C                    entry to update.
C
C     NVALS          is the number of values in the replacement
C                    column entry.
C
C     CVALS          is an array of character string values with which
C                    to update the specified column entry.
C
C     ISNULL         is a logical flag indicating whether the value
C                    of the specified column entry is to be set to NULL.
C                    If so, the input CVALS is ignored.
C
C$ Detailed_Output
C
C     None.  See the $Particulars section for a description of the
C     effect of this routine.
C
C$ Parameters
C
C     None.
C
C$ Exceptions
C
C     1)  If HANDLE is invalid, the error will be diagnosed by routines
C         called by this routine.  The file will not be modified.
C
C     2)  If an I/O error occurs while reading or writing the indicated
C         file, the error will be diagnosed by routines called by this
C         routine.  The file may be corrupted.
C
C$ Files
C
C     See the EK Required Reading for a discussion of the EK file
C     format.
C
C$ Particulars
C
C     This routine operates by side effects:  it updates a column entry
C     in an EK segment.  The status of the record containing the entry
C     is set to `updated'.  If the column containing the entry is
C     indexed, the corresponding index is updated.
C
C     The changes made by this routine to the target EK file become
C     permanent when the file is closed.  Failure to close the file
C     properly will leave it in an indeterminate state.
C
C$ Examples
C
C     See EKUCEC.
C
C$ Restrictions
C
C     None.
C
C$ Literature_References
C
C     None.
C
C$ Author_and_Institution
C
C     N.J. Bachman   (JPL)
C
C$ Version
C
C-    Beta Version 1.0.0, 27-SEP-1995 (NJB)
C
C-&
 
C
C     SPICELIB functions
C
      LOGICAL               FAILED
      LOGICAL               RETURN
 
C
C     Standard SPICE error handling.
C
      IF ( RETURN () ) THEN
         RETURN
      ELSE
         CALL CHKIN ( 'ZZEKUE06' )
      END IF
 
C
C     Get rid of the old column entry first.
C
      CALL ZZEKDE06 ( HANDLE, SEGDSC, COLDSC, RECPTR )
 
      IF ( FAILED() ) THEN
         CALL  CHKOUT ( 'ZZEKUE06' )
         RETURN
      END IF
 
C
C     We've reduced the problem to a solved one:  that of adding
C     a column entry.
C
      CALL ZZEKAD06 (  HANDLE,  SEGDSC,  COLDSC,
     .                 RECPTR,  NVALS,   CVALS,  ISNULL )
 
 
      CALL CHKOUT ( 'ZZEKUE06' )
      RETURN
      END
