C$Procedure ZZIDMAP ( SPICE body ID/name assignments )

      SUBROUTINE  ZZIDMAP( BLTCOD, BLTNAM )
      IMPLICIT NONE

C$ Abstract
C
C   The default SPICE body/ID mapping assignments available
C   to the SPICE library.
C
C$ Copyright
C
C   Copyright (2003), California Institute of Technology.
C   U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C   naif_ids.req
C
C$ Keywords
C
C   Body mappings.
C
C$ Declarations

      INCLUDE              'zzbodtrn.inc'

      INTEGER              BLTCOD(NPERM)
      CHARACTER*(MAXL)     BLTNAM(NPERM)

C$ Brief_I/O
C
C     Variable  I/O  Description
C     --------  ---  --------------------------------------------------
C     BLTCOD     O  List of default integer ID codes
C     BLTNAM     O  List of default names
C     NPERM      P  Number of name/ID mappings
C
C$ Detailed_Input
C
C     None.
C
C$ Detailed_Output
C
C     BLTCOD     The array of NPERM elements listing the body ID codes.
C
C     BLTNAM     The array of NPERM elements listing the body names 
C                corresponding to the ID entry in BLTCOD
C
C$ Parameters
C
C     NPERM      The length of both BLTCOD, BLTNAM
C                (read from zzbodtrn.inc).
C
C$ Exceptions
C
C     None.
C
C$ Files
C
C     None.
C
C$ Particulars
C
C     Each ith entry of BLTCOD maps to the ith entry of BLTNAM.
C
C$ Examples
C
C     Simple to use, a call the ZZIDMAP returns the arrays defining the
C     name/ID mappings.
C
C
C        INCLUDE            'zzbodtrn.inc'
C
C        INTEGER             ID  ( NPERM )
C        CHARACTER*(MAXL)    NAME( NPERM )
C
C        CALL ZZIDMAP( ID, NAME )
C
C$ Restrictions
C
C     None.
C
C$ Literature_References
C
C     None.
C
C$ Author_and_Institution
C
C     E.D. Wright, Mon Dec 20 07:32:37 2004 (JPL)
C
C$ Version
C
C-    SPICELIB 1.0.2 20-DEC-2004 (EDW)
C
C     Added:
C
C           Due to the previous definition of Parkes with DSS-05,
C           the Parkes ID remains 399005.
C
C             -486   HERSCHEL
C             -489   PLANCK
C           399049   DSS-49
C           399055   DSS-55
C             -203   DAWN
C          1000012   67P/CHURYUMOV-GERASIMENKO (1969 R1)
C          1000012   CHURYUMOV-GERASIMENKO
C          398989    NOTO
C             -84    PHOENIX
C            -131    SELENE
C            -238    SMART-1, S1, SM1, SMART1
C            -130    HAYABUSA
C
C-    SPICELIB 1.0.1 19-DEC-2003 (EDW)
C
C     Added:
C              -79   SPITZER
C          2000216   KLEOPATRA
C
C-    SPICELIB 1.0.0 27-JUL-2003 (EDW)
C
C     Added:
C              -47   GNS
C              -74   MRO
C              -74   MARS RECON ORBITER
C             -130   MUSES-C
C             -142   TERRA
C             -154   AQUA
C             -159   EUROPA ORBITER
C             -190   SIM
C             -198   INTEGRAL
C             -227   KEPLER
C             -234   STEREO AHEAD
C             -235   STEREO BEHIND
C             -253   OPPORTUNITY
C             -254   SPIRIT
C              528   AUTONOE      
C              529   THYONE       
C              530   HERMIPPE        
C              531   AITNE
C              532   EURYDOME
C              533   EUANTHE        
C              534   EUPORIE         
C              535   ORTHOSIE          
C              536   SPONDE          
C              537   KALE        
C              538   PASITHEE
C              619   YMIR
C              620   PAALIAQ
C              621   TARVOS
C              622   IJIRAQ
C              623   SUTTUNG
C              624   KIVIUQ
C              625   MUNDILFARI
C              626   ALBIORIX
C              627   SKADI
C              628   ERRIAPO
C              629   SIARNAQ
C              630   THRYM
C              718   PROSPERO
C              719   SETEBOS
C              720   STEPHANO
C              721   TRINCULO
C           398990   NEW NORCIA
C          2431011   DACTYL
C          2000001   CERES
C          2000004   VESTA
C
C     Renamed:
C
C              -25   LPM to
C              -25   LP
C
C             -180   MUSES-C to
C             -130   MUSES-B
C
C             -172   STARLIGHT COMBINER to
C             -172   SPACETECH-3 COMBINER
C
C             -205   STARLIGHT COLLECTOR to
C             -205   SPACETECH-3 COLLECTOR
C
C      Removed:
C             -172   SLCOMB
C
C
C-&

C$ Index_Entries
C
C     body ID mapping
C
C-&

C
C     A script generates this file. Do not edit by hand.
C     Edit the creation script to modify the contents of
C     ZZIDMAP.
C

      BLTCOD(1) =   0
      BLTNAM(1) =  'SSB'

      BLTCOD(2) =   0
      BLTNAM(2) =  'SOLAR SYSTEM BARYCENTER'

      BLTCOD(3) =   1
      BLTNAM(3) =  'MERCURY BARYCENTER'

      BLTCOD(4) =   2
      BLTNAM(4) =  'VENUS BARYCENTER'

      BLTCOD(5) =   3
      BLTNAM(5) =  'EMB'

      BLTCOD(6) =   3
      BLTNAM(6) =  'EARTH MOON BARYCENTER'

      BLTCOD(7) =   3
      BLTNAM(7) =  'EARTH-MOON BARYCENTER'

      BLTCOD(8) =   3
      BLTNAM(8) =  'EARTH BARYCENTER'

      BLTCOD(9) =   4
      BLTNAM(9) =  'MARS BARYCENTER'

      BLTCOD(10) =   5
      BLTNAM(10) =  'JUPITER BARYCENTER'

      BLTCOD(11) =   6
      BLTNAM(11) =  'SATURN BARYCENTER'

      BLTCOD(12) =   7
      BLTNAM(12) =  'URANUS BARYCENTER'

      BLTCOD(13) =   8
      BLTNAM(13) =  'NEPTUNE BARYCENTER'

      BLTCOD(14) =   9
      BLTNAM(14) =  'PLUTO BARYCENTER'

      BLTCOD(15) =   10
      BLTNAM(15) =  'SUN'

      BLTCOD(16) =   199
      BLTNAM(16) =  'MERCURY'

      BLTCOD(17) =   299
      BLTNAM(17) =  'VENUS'

      BLTCOD(18) =   399
      BLTNAM(18) =  'EARTH'

      BLTCOD(19) =   301
      BLTNAM(19) =  'MOON'

      BLTCOD(20) =   499
      BLTNAM(20) =  'MARS'

      BLTCOD(21) =   401
      BLTNAM(21) =  'PHOBOS'

      BLTCOD(22) =   402
      BLTNAM(22) =  'DEIMOS'

      BLTCOD(23) =   599
      BLTNAM(23) =  'JUPITER'

      BLTCOD(24) =   501
      BLTNAM(24) =  'IO'

      BLTCOD(25) =   502
      BLTNAM(25) =  'EUROPA'

      BLTCOD(26) =   503
      BLTNAM(26) =  'GANYMEDE'

      BLTCOD(27) =   504
      BLTNAM(27) =  'CALLISTO'

      BLTCOD(28) =   505
      BLTNAM(28) =  'AMALTHEA'

      BLTCOD(29) =   506
      BLTNAM(29) =  'HIMALIA'

      BLTCOD(30) =   507
      BLTNAM(30) =  'ELARA'

      BLTCOD(31) =   508
      BLTNAM(31) =  'PASIPHAE'

      BLTCOD(32) =   509
      BLTNAM(32) =  'SINOPE'

      BLTCOD(33) =   510
      BLTNAM(33) =  'LYSITHEA'

      BLTCOD(34) =   511
      BLTNAM(34) =  'CARME'

      BLTCOD(35) =   512
      BLTNAM(35) =  'ANANKE'

      BLTCOD(36) =   513
      BLTNAM(36) =  'LEDA'

      BLTCOD(37) =   514
      BLTNAM(37) =  '1979J2'

      BLTCOD(38) =   514
      BLTNAM(38) =  'THEBE'

      BLTCOD(39) =   515
      BLTNAM(39) =  '1979J1'

      BLTCOD(40) =   515
      BLTNAM(40) =  'ADRASTEA'

      BLTCOD(41) =   516
      BLTNAM(41) =  '1979J3'

      BLTCOD(42) =   516
      BLTNAM(42) =  'METIS'

      BLTCOD(43) =   517
      BLTNAM(43) =  'CALLIRRHOE'

      BLTCOD(44) =   518
      BLTNAM(44) =  'THEMISTO'

      BLTCOD(45) =   519
      BLTNAM(45) =  'MAGACLITE'

      BLTCOD(46) =   520
      BLTNAM(46) =  'TAYGETE'

      BLTCOD(47) =   521
      BLTNAM(47) =  'CHALDENE'

      BLTCOD(48) =   522
      BLTNAM(48) =  'HARPALYKE'

      BLTCOD(49) =   523
      BLTNAM(49) =  'KALYKE'

      BLTCOD(50) =   524
      BLTNAM(50) =  'IOCASTE'

      BLTCOD(51) =   525
      BLTNAM(51) =  'ERINOME'

      BLTCOD(52) =   526
      BLTNAM(52) =  'ISONOE'

      BLTCOD(53) =   527
      BLTNAM(53) =  'PRAXIDIKE'

      BLTCOD(54) =   528
      BLTNAM(54) =  'AUTONOE'

      BLTCOD(55) =   529
      BLTNAM(55) =  'THYONE'

      BLTCOD(56) =   530
      BLTNAM(56) =  'HERMIPPE'

      BLTCOD(57) =   531
      BLTNAM(57) =  'AITNE'

      BLTCOD(58) =   532
      BLTNAM(58) =  'EURYDOME'

      BLTCOD(59) =   533
      BLTNAM(59) =  'EUANTHE'

      BLTCOD(60) =   534
      BLTNAM(60) =  'EUPORIE'

      BLTCOD(61) =   535
      BLTNAM(61) =  'ORTHOSIE'

      BLTCOD(62) =   536
      BLTNAM(62) =  'SPONDE'

      BLTCOD(63) =   537
      BLTNAM(63) =  'KALE'

      BLTCOD(64) =   538
      BLTNAM(64) =  'PASITHEE'

      BLTCOD(65) =   699
      BLTNAM(65) =  'SATURN'

      BLTCOD(66) =   601
      BLTNAM(66) =  'MIMAS'

      BLTCOD(67) =   602
      BLTNAM(67) =  'ENCELADUS'

      BLTCOD(68) =   603
      BLTNAM(68) =  'TETHYS'

      BLTCOD(69) =   604
      BLTNAM(69) =  'DIONE'

      BLTCOD(70) =   605
      BLTNAM(70) =  'RHEA'

      BLTCOD(71) =   606
      BLTNAM(71) =  'TITAN'

      BLTCOD(72) =   607
      BLTNAM(72) =  'HYPERION'

      BLTCOD(73) =   608
      BLTNAM(73) =  'IAPETUS'

      BLTCOD(74) =   609
      BLTNAM(74) =  'PHOEBE'

      BLTCOD(75) =   610
      BLTNAM(75) =  '1980S1'

      BLTCOD(76) =   610
      BLTNAM(76) =  'JANUS'

      BLTCOD(77) =   611
      BLTNAM(77) =  '1980S3'

      BLTCOD(78) =   611
      BLTNAM(78) =  'EPIMETHEUS'

      BLTCOD(79) =   612
      BLTNAM(79) =  '1980S6'

      BLTCOD(80) =   612
      BLTNAM(80) =  'HELENE'

      BLTCOD(81) =   613
      BLTNAM(81) =  '1980S13'

      BLTCOD(82) =   613
      BLTNAM(82) =  'TELESTO'

      BLTCOD(83) =   614
      BLTNAM(83) =  '1980S25'

      BLTCOD(84) =   614
      BLTNAM(84) =  'CALYPSO'

      BLTCOD(85) =   615
      BLTNAM(85) =  '1980S28'

      BLTCOD(86) =   615
      BLTNAM(86) =  'ATLAS'

      BLTCOD(87) =   616
      BLTNAM(87) =  '1980S27'

      BLTCOD(88) =   616
      BLTNAM(88) =  'PROMETHEUS'

      BLTCOD(89) =   617
      BLTNAM(89) =  '1980S26'

      BLTCOD(90) =   617
      BLTNAM(90) =  'PANDORA'

      BLTCOD(91) =   618
      BLTNAM(91) =  'PAN'

      BLTCOD(92) =   619
      BLTNAM(92) =  'YMIR'

      BLTCOD(93) =   620
      BLTNAM(93) =  'PAALIAQ'

      BLTCOD(94) =   621
      BLTNAM(94) =  'TARVOS'

      BLTCOD(95) =   622
      BLTNAM(95) =  'IJIRAQ'

      BLTCOD(96) =   623
      BLTNAM(96) =  'SUTTUNG'

      BLTCOD(97) =   624
      BLTNAM(97) =  'KIVIUQ'

      BLTCOD(98) =   625
      BLTNAM(98) =  'MUNDILFARI'

      BLTCOD(99) =   626
      BLTNAM(99) =  'ALBIORIX'

      BLTCOD(100) =   627
      BLTNAM(100) =  'SKADI'

      BLTCOD(101) =   628
      BLTNAM(101) =  'ERRIAPO'

      BLTCOD(102) =   629
      BLTNAM(102) =  'SIARNAQ'

      BLTCOD(103) =   630
      BLTNAM(103) =  'THRYM'

      BLTCOD(104) =   799
      BLTNAM(104) =  'URANUS'

      BLTCOD(105) =   701
      BLTNAM(105) =  'ARIEL'

      BLTCOD(106) =   702
      BLTNAM(106) =  'UMBRIEL'

      BLTCOD(107) =   703
      BLTNAM(107) =  'TITANIA'

      BLTCOD(108) =   704
      BLTNAM(108) =  'OBERON'

      BLTCOD(109) =   705
      BLTNAM(109) =  'MIRANDA'

      BLTCOD(110) =   706
      BLTNAM(110) =  '1986U7'

      BLTCOD(111) =   706
      BLTNAM(111) =  'CORDELIA'

      BLTCOD(112) =   707
      BLTNAM(112) =  '1986U8'

      BLTCOD(113) =   707
      BLTNAM(113) =  'OPHELIA'

      BLTCOD(114) =   708
      BLTNAM(114) =  '1986U9'

      BLTCOD(115) =   708
      BLTNAM(115) =  'BIANCA'

      BLTCOD(116) =   709
      BLTNAM(116) =  '1986U4'

      BLTCOD(117) =   709
      BLTNAM(117) =  'CRESSIDA'

      BLTCOD(118) =   710
      BLTNAM(118) =  '1986U6'

      BLTCOD(119) =   710
      BLTNAM(119) =  'DESDEMONA'

      BLTCOD(120) =   711
      BLTNAM(120) =  '1986U3'

      BLTCOD(121) =   711
      BLTNAM(121) =  'JULIET'

      BLTCOD(122) =   712
      BLTNAM(122) =  '1986U1'

      BLTCOD(123) =   712
      BLTNAM(123) =  'PORTIA'

      BLTCOD(124) =   713
      BLTNAM(124) =  '1986U2'

      BLTCOD(125) =   713
      BLTNAM(125) =  'ROSALIND'

      BLTCOD(126) =   714
      BLTNAM(126) =  '1986U5'

      BLTCOD(127) =   714
      BLTNAM(127) =  'BELINDA'

      BLTCOD(128) =   715
      BLTNAM(128) =  '1985U1'

      BLTCOD(129) =   715
      BLTNAM(129) =  'PUCK'

      BLTCOD(130) =   716
      BLTNAM(130) =  'CALIBAN'

      BLTCOD(131) =   717
      BLTNAM(131) =  'SYCORAX'

      BLTCOD(132) =   718
      BLTNAM(132) =  '1986U10'

      BLTCOD(133) =   718
      BLTNAM(133) =  'PROSPERO'

      BLTCOD(134) =   719
      BLTNAM(134) =  'SETEBOS'

      BLTCOD(135) =   720
      BLTNAM(135) =  'STEPHANO'

      BLTCOD(136) =   721
      BLTNAM(136) =  'TRINCULO'

      BLTCOD(137) =   899
      BLTNAM(137) =  'NEPTUNE'

      BLTCOD(138) =   801
      BLTNAM(138) =  'TRITON'

      BLTCOD(139) =   802
      BLTNAM(139) =  'NEREID'

      BLTCOD(140) =   803
      BLTNAM(140) =  'NAIAD'

      BLTCOD(141) =   804
      BLTNAM(141) =  'THALASSA'

      BLTCOD(142) =   805
      BLTNAM(142) =  'DESPINA'

      BLTCOD(143) =   806
      BLTNAM(143) =  'GALATEA'

      BLTCOD(144) =   807
      BLTNAM(144) =  'LARISSA'

      BLTCOD(145) =   808
      BLTNAM(145) =  'PROTEUS'

      BLTCOD(146) =   999
      BLTNAM(146) =  'PLUTO'

      BLTCOD(147) =   901
      BLTNAM(147) =  '1978P1'

      BLTCOD(148) =   901
      BLTNAM(148) =  'CHARON'

      BLTCOD(149) =   -1
      BLTNAM(149) =  'GEOTAIL'

      BLTCOD(150) =   -6
      BLTNAM(150) =  'P6'

      BLTCOD(151) =   -6
      BLTNAM(151) =  'PIONEER-6'

      BLTCOD(152) =   -7
      BLTNAM(152) =  'P7'

      BLTCOD(153) =   -7
      BLTNAM(153) =  'PIONEER-7'

      BLTCOD(154) =   -8
      BLTNAM(154) =  'WIND'

      BLTCOD(155) =   -12
      BLTNAM(155) =  'VENUS ORBITER'

      BLTCOD(156) =   -12
      BLTNAM(156) =  'P12'

      BLTCOD(157) =   -12
      BLTNAM(157) =  'PIONEER 12'

      BLTCOD(158) =   -13
      BLTNAM(158) =  'POLAR'

      BLTCOD(159) =   -18
      BLTNAM(159) =  'MGN'

      BLTCOD(160) =   -18
      BLTNAM(160) =  'MAGELLAN'

      BLTCOD(161) =   -20
      BLTNAM(161) =  'P8'

      BLTCOD(162) =   -20
      BLTNAM(162) =  'PIONEER-8'

      BLTCOD(163) =   -21
      BLTNAM(163) =  'SOHO'

      BLTCOD(164) =   -23
      BLTNAM(164) =  'P10'

      BLTCOD(165) =   -23
      BLTNAM(165) =  'PIONEER-10'

      BLTCOD(166) =   -24
      BLTNAM(166) =  'P11'

      BLTCOD(167) =   -24
      BLTNAM(167) =  'PIONEER-11'

      BLTCOD(168) =   -25
      BLTNAM(168) =  'LP'

      BLTCOD(169) =   -25
      BLTNAM(169) =  'LUNAR PROSPECTOR'

      BLTCOD(170) =   -27
      BLTNAM(170) =  'VK1'

      BLTCOD(171) =   -27
      BLTNAM(171) =  'VIKING 1 ORBITER'

      BLTCOD(172) =   -29
      BLTNAM(172) =  'STARDUST'

      BLTCOD(173) =   -29
      BLTNAM(173) =  'SDU'

      BLTCOD(174) =   -30
      BLTNAM(174) =  'VK2'

      BLTCOD(175) =   -30
      BLTNAM(175) =  'VIKING 2 ORBITER'

      BLTCOD(176) =   -30
      BLTNAM(176) =  'DS-1'

      BLTCOD(177) =   -31
      BLTNAM(177) =  'VG1'

      BLTCOD(178) =   -31
      BLTNAM(178) =  'VOYAGER 1'

      BLTCOD(179) =   -32
      BLTNAM(179) =  'VG2'

      BLTCOD(180) =   -32
      BLTNAM(180) =  'VOYAGER 2'

      BLTCOD(181) =   -40
      BLTNAM(181) =  'CLEMENTINE'

      BLTCOD(182) =   -41
      BLTNAM(182) =  'MEX'

      BLTCOD(183) =   -41
      BLTNAM(183) =  'MARS EXPRESS'

      BLTCOD(184) =   -44
      BLTNAM(184) =  'BEAGLE2'

      BLTCOD(185) =   -44
      BLTNAM(185) =  'BEAGLE 2'

      BLTCOD(186) =   -46
      BLTNAM(186) =  'MS-T5'

      BLTCOD(187) =   -46
      BLTNAM(187) =  'SAKIGAKE'

      BLTCOD(188) =   -47
      BLTNAM(188) =  'PLANET-A'

      BLTCOD(189) =   -47
      BLTNAM(189) =  'SUISEI'

      BLTCOD(190) =   -47
      BLTNAM(190) =  'GNS'

      BLTCOD(191) =   -47
      BLTNAM(191) =  'GENESIS'

      BLTCOD(192) =   -48
      BLTNAM(192) =  'HUBBLE SPACE TELESCOPE'

      BLTCOD(193) =   -48
      BLTNAM(193) =  'HST'

      BLTCOD(194) =   -53
      BLTNAM(194) =  'MARS PATHFINDER'

      BLTCOD(195) =   -53
      BLTNAM(195) =  'MPF'

      BLTCOD(196) =   -53
      BLTNAM(196) =  'MARS ODYSSEY'

      BLTCOD(197) =   -53
      BLTNAM(197) =  'MARS SURVEYOR 01 ORBITER'

      BLTCOD(198) =   -55
      BLTNAM(198) =  'ULYSSES'

      BLTCOD(199) =   -58
      BLTNAM(199) =  'VSOP'

      BLTCOD(200) =   -58
      BLTNAM(200) =  'HALCA'

      BLTCOD(201) =   -59
      BLTNAM(201) =  'RADIOASTRON'

      BLTCOD(202) =   -66
      BLTNAM(202) =  'VEGA 1'

      BLTCOD(203) =   -67
      BLTNAM(203) =  'VEGA 2'

      BLTCOD(204) =   -70
      BLTNAM(204) =  'DEEP IMPACT IMPACTOR SPACECRAFT'

      BLTCOD(205) =   -74
      BLTNAM(205) =  'MRO'

      BLTCOD(206) =   -74
      BLTNAM(206) =  'MARS RECON ORBITER'

      BLTCOD(207) =   -77
      BLTNAM(207) =  'GLL'

      BLTCOD(208) =   -77
      BLTNAM(208) =  'GALILEO ORBITER'

      BLTCOD(209) =   -78
      BLTNAM(209) =  'GIOTTO'

      BLTCOD(210) =   -79
      BLTNAM(210) =  'SPITZER'

      BLTCOD(211) =   -79
      BLTNAM(211) =  'SPACE INFRARED TELESCOPE FACILITY'

      BLTCOD(212) =   -79
      BLTNAM(212) =  'SIRTF'

      BLTCOD(213) =   -81
      BLTNAM(213) =  'CASSINI ITL'

      BLTCOD(214) =   -82
      BLTNAM(214) =  'CAS'

      BLTCOD(215) =   -82
      BLTNAM(215) =  'CASSINI'

      BLTCOD(216) =   -84
      BLTNAM(216) =  'PHOENIX'

      BLTCOD(217) =   -90
      BLTNAM(217) =  'CASSINI SIMULATION'

      BLTCOD(218) =   -93
      BLTNAM(218) =  'NEAR EARTH ASTEROID RENDEZVOUS'

      BLTCOD(219) =   -93
      BLTNAM(219) =  'NEAR'

      BLTCOD(220) =   -94
      BLTNAM(220) =  'MO'

      BLTCOD(221) =   -94
      BLTNAM(221) =  'MARS OBSERVER'

      BLTCOD(222) =   -94
      BLTNAM(222) =  'MGS'

      BLTCOD(223) =   -94
      BLTNAM(223) =  'MARS GLOBAL SURVEYOR'

      BLTCOD(224) =   -95
      BLTNAM(224) =  'MGS SIMULATION'

      BLTCOD(225) =   -97
      BLTNAM(225) =  'TOPEX/POSEIDON'

      BLTCOD(226) =   -107
      BLTNAM(226) =  'TROPICAL RAINFALL MEASURING MISSION'

      BLTCOD(227) =   -107
      BLTNAM(227) =  'TRMM'

      BLTCOD(228) =   -112
      BLTNAM(228) =  'ICE'

      BLTCOD(229) =   -116
      BLTNAM(229) =  'MARS POLAR LANDER'

      BLTCOD(230) =   -116
      BLTNAM(230) =  'MPL'

      BLTCOD(231) =   -127
      BLTNAM(231) =  'MARS CLIMATE ORBITER'

      BLTCOD(232) =   -127
      BLTNAM(232) =  'MCO'

      BLTCOD(233) =   -130
      BLTNAM(233) =  'MUSES-C'

      BLTCOD(234) =   -130
      BLTNAM(234) =  'HAYABUSA'

      BLTCOD(235) =   -131
      BLTNAM(235) =  'SELENE'

      BLTCOD(236) =   -135
      BLTNAM(236) =  'DRTS-W'

      BLTCOD(237) =   -140
      BLTNAM(237) =  'DEEP IMPACT FLYBY SPACECRAFT'

      BLTCOD(238) =   -142
      BLTNAM(238) =  'TERRA'

      BLTCOD(239) =   -142
      BLTNAM(239) =  'EOS-AM1'

      BLTCOD(240) =   -146
      BLTNAM(240) =  'LUNAR-A'

      BLTCOD(241) =   -150
      BLTNAM(241) =  'CASSINI PROBE'

      BLTCOD(242) =   -150
      BLTNAM(242) =  'HUYGENS PROBE'

      BLTCOD(243) =   -150
      BLTNAM(243) =  'CASP'

      BLTCOD(244) =   -151
      BLTNAM(244) =  'AXAF'

      BLTCOD(245) =   -154
      BLTNAM(245) =  'AQUA'

      BLTCOD(246) =   -159
      BLTNAM(246) =  'EUROPA ORBITER'

      BLTCOD(247) =   -164
      BLTNAM(247) =  'YOHKOH'

      BLTCOD(248) =   -164
      BLTNAM(248) =  'SOLAR-A'

      BLTCOD(249) =   -165
      BLTNAM(249) =  'MAP'

      BLTCOD(250) =   -166
      BLTNAM(250) =  'IMAGE'

      BLTCOD(251) =   -172
      BLTNAM(251) =  'SPACETECH-3 COMBINER'

      BLTCOD(252) =   -174
      BLTNAM(252) =  'PLUTO-KUIPER EXPRESS'

      BLTCOD(253) =   -175
      BLTNAM(253) =  'PLUTO-KUIPER EXPRESS SIMULATION'

      BLTCOD(254) =   -178
      BLTNAM(254) =  'PLANET-B'

      BLTCOD(255) =   -178
      BLTNAM(255) =  'NOZOMI'

      BLTCOD(256) =   -183
      BLTNAM(256) =  'CLUSTER 1'

      BLTCOD(257) =   -185
      BLTNAM(257) =  'CLUSTER 2'

      BLTCOD(258) =   -188
      BLTNAM(258) =  'MUSES-B'

      BLTCOD(259) =   -190
      BLTNAM(259) =  'SIM'

      BLTCOD(260) =   -194
      BLTNAM(260) =  'CLUSTER 3'

      BLTCOD(261) =   -196
      BLTNAM(261) =  'CLUSTER 4'

      BLTCOD(262) =   -198
      BLTNAM(262) =  'INTEGRAL'

      BLTCOD(263) =   -200
      BLTNAM(263) =  'CONTOUR'

      BLTCOD(264) =   -203
      BLTNAM(264) =  'DAWN'

      BLTCOD(265) =   -205
      BLTNAM(265) =  'SPACETECH-3 COLLECTOR'

      BLTCOD(266) =   -226
      BLTNAM(266) =  'ROSETTA'

      BLTCOD(267) =   -227
      BLTNAM(267) =  'KEPLER'

      BLTCOD(268) =   -228
      BLTNAM(268) =  'GLL PROBE'

      BLTCOD(269) =   -228
      BLTNAM(269) =  'GALILEO PROBE'

      BLTCOD(270) =   -234
      BLTNAM(270) =  'STEREO AHEAD'

      BLTCOD(271) =   -235
      BLTNAM(271) =  'STEREO BEHIND'

      BLTCOD(272) =   -236
      BLTNAM(272) =  'MESSENGER'

      BLTCOD(273) =   -238
      BLTNAM(273) =  'SMART1'

      BLTCOD(274) =   -238
      BLTNAM(274) =  'SM1'

      BLTCOD(275) =   -238
      BLTNAM(275) =  'S1'

      BLTCOD(276) =   -238
      BLTNAM(276) =  'SMART-1'

      BLTCOD(277) =   -253
      BLTNAM(277) =  'OPPORTUNITY'

      BLTCOD(278) =   -253
      BLTNAM(278) =  'MER-1'

      BLTCOD(279) =   -254
      BLTNAM(279) =  'SPIRIT'

      BLTCOD(280) =   -254
      BLTNAM(280) =  'MER-2'

      BLTCOD(281) =   -486
      BLTNAM(281) =  'HERSCHEL'

      BLTCOD(282) =   -489
      BLTNAM(282) =  'PLANCK'

      BLTCOD(283) =   -550
      BLTNAM(283) =  'MARS-96'

      BLTCOD(284) =   -550
      BLTNAM(284) =  'M96'

      BLTCOD(285) =   -550
      BLTNAM(285) =  'MARS 96'

      BLTCOD(286) =   -550
      BLTNAM(286) =  'MARS96'

      BLTCOD(287) =   50000001
      BLTNAM(287) =  'SHOEMAKER-LEVY 9-W'

      BLTCOD(288) =   50000002
      BLTNAM(288) =  'SHOEMAKER-LEVY 9-V'

      BLTCOD(289) =   50000003
      BLTNAM(289) =  'SHOEMAKER-LEVY 9-U'

      BLTCOD(290) =   50000004
      BLTNAM(290) =  'SHOEMAKER-LEVY 9-T'

      BLTCOD(291) =   50000005
      BLTNAM(291) =  'SHOEMAKER-LEVY 9-S'

      BLTCOD(292) =   50000006
      BLTNAM(292) =  'SHOEMAKER-LEVY 9-R'

      BLTCOD(293) =   50000007
      BLTNAM(293) =  'SHOEMAKER-LEVY 9-Q'

      BLTCOD(294) =   50000008
      BLTNAM(294) =  'SHOEMAKER-LEVY 9-P'

      BLTCOD(295) =   50000009
      BLTNAM(295) =  'SHOEMAKER-LEVY 9-N'

      BLTCOD(296) =   50000010
      BLTNAM(296) =  'SHOEMAKER-LEVY 9-M'

      BLTCOD(297) =   50000011
      BLTNAM(297) =  'SHOEMAKER-LEVY 9-L'

      BLTCOD(298) =   50000012
      BLTNAM(298) =  'SHOEMAKER-LEVY 9-K'

      BLTCOD(299) =   50000013
      BLTNAM(299) =  'SHOEMAKER-LEVY 9-J'

      BLTCOD(300) =   50000014
      BLTNAM(300) =  'SHOEMAKER-LEVY 9-H'

      BLTCOD(301) =   50000015
      BLTNAM(301) =  'SHOEMAKER-LEVY 9-G'

      BLTCOD(302) =   50000016
      BLTNAM(302) =  'SHOEMAKER-LEVY 9-F'

      BLTCOD(303) =   50000017
      BLTNAM(303) =  'SHOEMAKER-LEVY 9-E'

      BLTCOD(304) =   50000018
      BLTNAM(304) =  'SHOEMAKER-LEVY 9-D'

      BLTCOD(305) =   50000019
      BLTNAM(305) =  'SHOEMAKER-LEVY 9-C'

      BLTCOD(306) =   50000020
      BLTNAM(306) =  'SHOEMAKER-LEVY 9-B'

      BLTCOD(307) =   50000021
      BLTNAM(307) =  'SHOEMAKER-LEVY 9-A'

      BLTCOD(308) =   50000022
      BLTNAM(308) =  'SHOEMAKER-LEVY 9-Q1'

      BLTCOD(309) =   50000023
      BLTNAM(309) =  'SHOEMAKER-LEVY 9-P2'

      BLTCOD(310) =   1000001
      BLTNAM(310) =  'AREND'

      BLTCOD(311) =   1000002
      BLTNAM(311) =  'AREND-RIGAUX'

      BLTCOD(312) =   1000003
      BLTNAM(312) =  'ASHBROOK-JACKSON'

      BLTCOD(313) =   1000004
      BLTNAM(313) =  'BOETHIN'

      BLTCOD(314) =   1000005
      BLTNAM(314) =  'BORRELLY'

      BLTCOD(315) =   1000006
      BLTNAM(315) =  'BOWELL-SKIFF'

      BLTCOD(316) =   1000007
      BLTNAM(316) =  'BRADFIELD'

      BLTCOD(317) =   1000008
      BLTNAM(317) =  'BROOKS 2'

      BLTCOD(318) =   1000009
      BLTNAM(318) =  'BRORSEN-METCALF'

      BLTCOD(319) =   1000010
      BLTNAM(319) =  'BUS'

      BLTCOD(320) =   1000011
      BLTNAM(320) =  'CHERNYKH'

      BLTCOD(321) =   1000012
      BLTNAM(321) =  '67P/CHURYUMOV-GERASIMENKO (1969 R1)'

      BLTCOD(322) =   1000012
      BLTNAM(322) =  'CHURYUMOV-GERASIMENKO'

      BLTCOD(323) =   1000013
      BLTNAM(323) =  'CIFFREO'

      BLTCOD(324) =   1000014
      BLTNAM(324) =  'CLARK'

      BLTCOD(325) =   1000015
      BLTNAM(325) =  'COMAS SOLA'

      BLTCOD(326) =   1000016
      BLTNAM(326) =  'CROMMELIN'

      BLTCOD(327) =   1000017
      BLTNAM(327) =  'D''ARREST'

      BLTCOD(328) =   1000018
      BLTNAM(328) =  'DANIEL'

      BLTCOD(329) =   1000019
      BLTNAM(329) =  'DE VICO-SWIFT'

      BLTCOD(330) =   1000020
      BLTNAM(330) =  'DENNING-FUJIKAWA'

      BLTCOD(331) =   1000021
      BLTNAM(331) =  'DU TOIT 1'

      BLTCOD(332) =   1000022
      BLTNAM(332) =  'DU TOIT-HARTLEY'

      BLTCOD(333) =   1000023
      BLTNAM(333) =  'DUTOIT-NEUJMIN-DELPORTE'

      BLTCOD(334) =   1000024
      BLTNAM(334) =  'DUBIAGO'

      BLTCOD(335) =   1000025
      BLTNAM(335) =  'ENCKE'

      BLTCOD(336) =   1000026
      BLTNAM(336) =  'FAYE'

      BLTCOD(337) =   1000027
      BLTNAM(337) =  'FINLAY'

      BLTCOD(338) =   1000028
      BLTNAM(338) =  'FORBES'

      BLTCOD(339) =   1000029
      BLTNAM(339) =  'GEHRELS 1'

      BLTCOD(340) =   1000030
      BLTNAM(340) =  'GEHRELS 2'

      BLTCOD(341) =   1000031
      BLTNAM(341) =  'GEHRELS 3'

      BLTCOD(342) =   1000032
      BLTNAM(342) =  'GIACOBINI-ZINNER'

      BLTCOD(343) =   1000033
      BLTNAM(343) =  'GICLAS'

      BLTCOD(344) =   1000034
      BLTNAM(344) =  'GRIGG-SKJELLERUP'

      BLTCOD(345) =   1000035
      BLTNAM(345) =  'GUNN'

      BLTCOD(346) =   1000036
      BLTNAM(346) =  'HALLEY'

      BLTCOD(347) =   1000037
      BLTNAM(347) =  'HANEDA-CAMPOS'

      BLTCOD(348) =   1000038
      BLTNAM(348) =  'HARRINGTON'

      BLTCOD(349) =   1000039
      BLTNAM(349) =  'HARRINGTON-ABELL'

      BLTCOD(350) =   1000040
      BLTNAM(350) =  'HARTLEY 1'

      BLTCOD(351) =   1000041
      BLTNAM(351) =  'HARTLEY 2'

      BLTCOD(352) =   1000042
      BLTNAM(352) =  'HARTLEY-IRAS'

      BLTCOD(353) =   1000043
      BLTNAM(353) =  'HERSCHEL-RIGOLLET'

      BLTCOD(354) =   1000044
      BLTNAM(354) =  'HOLMES'

      BLTCOD(355) =   1000045
      BLTNAM(355) =  'HONDA-MRKOS-PAJDUSAKOVA'

      BLTCOD(356) =   1000046
      BLTNAM(356) =  'HOWELL'

      BLTCOD(357) =   1000047
      BLTNAM(357) =  'IRAS'

      BLTCOD(358) =   1000048
      BLTNAM(358) =  'JACKSON-NEUJMIN'

      BLTCOD(359) =   1000049
      BLTNAM(359) =  'JOHNSON'

      BLTCOD(360) =   1000050
      BLTNAM(360) =  'KEARNS-KWEE'

      BLTCOD(361) =   1000051
      BLTNAM(361) =  'KLEMOLA'

      BLTCOD(362) =   1000052
      BLTNAM(362) =  'KOHOUTEK'

      BLTCOD(363) =   1000053
      BLTNAM(363) =  'KOJIMA'

      BLTCOD(364) =   1000054
      BLTNAM(364) =  'KOPFF'

      BLTCOD(365) =   1000055
      BLTNAM(365) =  'KOWAL 1'

      BLTCOD(366) =   1000056
      BLTNAM(366) =  'KOWAL 2'

      BLTCOD(367) =   1000057
      BLTNAM(367) =  'KOWAL-MRKOS'

      BLTCOD(368) =   1000058
      BLTNAM(368) =  'KOWAL-VAVROVA'

      BLTCOD(369) =   1000059
      BLTNAM(369) =  'LONGMORE'

      BLTCOD(370) =   1000060
      BLTNAM(370) =  'LOVAS 1'

      BLTCOD(371) =   1000061
      BLTNAM(371) =  'MACHHOLZ'

      BLTCOD(372) =   1000062
      BLTNAM(372) =  'MAURY'

      BLTCOD(373) =   1000063
      BLTNAM(373) =  'NEUJMIN 1'

      BLTCOD(374) =   1000064
      BLTNAM(374) =  'NEUJMIN 2'

      BLTCOD(375) =   1000065
      BLTNAM(375) =  'NEUJMIN 3'

      BLTCOD(376) =   1000066
      BLTNAM(376) =  'OLBERS'

      BLTCOD(377) =   1000067
      BLTNAM(377) =  'PETERS-HARTLEY'

      BLTCOD(378) =   1000068
      BLTNAM(378) =  'PONS-BROOKS'

      BLTCOD(379) =   1000069
      BLTNAM(379) =  'PONS-WINNECKE'

      BLTCOD(380) =   1000070
      BLTNAM(380) =  'REINMUTH 1'

      BLTCOD(381) =   1000071
      BLTNAM(381) =  'REINMUTH 2'

      BLTCOD(382) =   1000072
      BLTNAM(382) =  'RUSSELL 1'

      BLTCOD(383) =   1000073
      BLTNAM(383) =  'RUSSELL 2'

      BLTCOD(384) =   1000074
      BLTNAM(384) =  'RUSSELL 3'

      BLTCOD(385) =   1000075
      BLTNAM(385) =  'RUSSELL 4'

      BLTCOD(386) =   1000076
      BLTNAM(386) =  'SANGUIN'

      BLTCOD(387) =   1000077
      BLTNAM(387) =  'SCHAUMASSE'

      BLTCOD(388) =   1000078
      BLTNAM(388) =  'SCHUSTER'

      BLTCOD(389) =   1000079
      BLTNAM(389) =  'SCHWASSMANN-WACHMANN 1'

      BLTCOD(390) =   1000080
      BLTNAM(390) =  'SCHWASSMANN-WACHMANN 2'

      BLTCOD(391) =   1000081
      BLTNAM(391) =  'SCHWASSMANN-WACHMANN 3'

      BLTCOD(392) =   1000082
      BLTNAM(392) =  'SHAJN-SCHALDACH'

      BLTCOD(393) =   1000083
      BLTNAM(393) =  'SHOEMAKER 1'

      BLTCOD(394) =   1000084
      BLTNAM(394) =  'SHOEMAKER 2'

      BLTCOD(395) =   1000085
      BLTNAM(395) =  'SHOEMAKER 3'

      BLTCOD(396) =   1000086
      BLTNAM(396) =  'SINGER-BREWSTER'

      BLTCOD(397) =   1000087
      BLTNAM(397) =  'SLAUGHTER-BURNHAM'

      BLTCOD(398) =   1000088
      BLTNAM(398) =  'SMIRNOVA-CHERNYKH'

      BLTCOD(399) =   1000089
      BLTNAM(399) =  'STEPHAN-OTERMA'

      BLTCOD(400) =   1000090
      BLTNAM(400) =  'SWIFT-GEHRELS'

      BLTCOD(401) =   1000091
      BLTNAM(401) =  'TAKAMIZAWA'

      BLTCOD(402) =   1000092
      BLTNAM(402) =  'TAYLOR'

      BLTCOD(403) =   1000093
      BLTNAM(403) =  'TEMPEL 1'

      BLTCOD(404) =   1000094
      BLTNAM(404) =  'TEMPEL 2'

      BLTCOD(405) =   1000095
      BLTNAM(405) =  'TEMPEL-TUTTLE'

      BLTCOD(406) =   1000096
      BLTNAM(406) =  'TRITTON'

      BLTCOD(407) =   1000097
      BLTNAM(407) =  'TSUCHINSHAN 1'

      BLTCOD(408) =   1000098
      BLTNAM(408) =  'TSUCHINSHAN 2'

      BLTCOD(409) =   1000099
      BLTNAM(409) =  'TUTTLE'

      BLTCOD(410) =   1000100
      BLTNAM(410) =  'TUTTLE-GIACOBINI-KRESAK'

      BLTCOD(411) =   1000101
      BLTNAM(411) =  'VAISALA 1'

      BLTCOD(412) =   1000102
      BLTNAM(412) =  'VAN BIESBROECK'

      BLTCOD(413) =   1000103
      BLTNAM(413) =  'VAN HOUTEN'

      BLTCOD(414) =   1000104
      BLTNAM(414) =  'WEST-KOHOUTEK-IKEMURA'

      BLTCOD(415) =   1000105
      BLTNAM(415) =  'WHIPPLE'

      BLTCOD(416) =   1000106
      BLTNAM(416) =  'WILD 1'

      BLTCOD(417) =   1000107
      BLTNAM(417) =  'WILD 2'

      BLTCOD(418) =   1000108
      BLTNAM(418) =  'WILD 3'

      BLTCOD(419) =   1000109
      BLTNAM(419) =  'WIRTANEN'

      BLTCOD(420) =   1000110
      BLTNAM(420) =  'WOLF'

      BLTCOD(421) =   1000111
      BLTNAM(421) =  'WOLF-HARRINGTON'

      BLTCOD(422) =   1000112
      BLTNAM(422) =  'LOVAS 2'

      BLTCOD(423) =   1000113
      BLTNAM(423) =  'URATA-NIIJIMA'

      BLTCOD(424) =   1000114
      BLTNAM(424) =  'WISEMAN-SKIFF'

      BLTCOD(425) =   1000115
      BLTNAM(425) =  'HELIN'

      BLTCOD(426) =   1000116
      BLTNAM(426) =  'MUELLER'

      BLTCOD(427) =   1000117
      BLTNAM(427) =  'SHOEMAKER-HOLT 1'

      BLTCOD(428) =   1000118
      BLTNAM(428) =  'HELIN-ROMAN-CROCKETT'

      BLTCOD(429) =   1000119
      BLTNAM(429) =  'HARTLEY 3'

      BLTCOD(430) =   1000120
      BLTNAM(430) =  'PARKER-HARTLEY'

      BLTCOD(431) =   1000121
      BLTNAM(431) =  'HELIN-ROMAN-ALU 1'

      BLTCOD(432) =   1000122
      BLTNAM(432) =  'WILD 4'

      BLTCOD(433) =   1000123
      BLTNAM(433) =  'MUELLER 2'

      BLTCOD(434) =   1000124
      BLTNAM(434) =  'MUELLER 3'

      BLTCOD(435) =   1000125
      BLTNAM(435) =  'SHOEMAKER-LEVY 1'

      BLTCOD(436) =   1000126
      BLTNAM(436) =  'SHOEMAKER-LEVY 2'

      BLTCOD(437) =   1000127
      BLTNAM(437) =  'HOLT-OLMSTEAD'

      BLTCOD(438) =   1000128
      BLTNAM(438) =  'METCALF-BREWINGTON'

      BLTCOD(439) =   1000129
      BLTNAM(439) =  'LEVY'

      BLTCOD(440) =   1000130
      BLTNAM(440) =  'SHOEMAKER-LEVY 9'

      BLTCOD(441) =   1000131
      BLTNAM(441) =  'HYAKUTAKE'

      BLTCOD(442) =   1000132
      BLTNAM(442) =  'HALE-BOPP'

      BLTCOD(443) =   9511010
      BLTNAM(443) =  'GASPRA'

      BLTCOD(444) =   2431010
      BLTNAM(444) =  'IDA'

      BLTCOD(445) =   2431011
      BLTNAM(445) =  'DACTYL'

      BLTCOD(446) =   2000001
      BLTNAM(446) =  'CERES'

      BLTCOD(447) =   2000004
      BLTNAM(447) =  'VESTA'

      BLTCOD(448) =   2000216
      BLTNAM(448) =  'KLEOPATRA'

      BLTCOD(449) =   2000433
      BLTNAM(449) =  'EROS'

      BLTCOD(450) =   2000253
      BLTNAM(450) =  'MATHILDE'

      BLTCOD(451) =   2009969
      BLTNAM(451) =  '1992KD'

      BLTCOD(452) =   2009969
      BLTNAM(452) =  'BRAILLE'

      BLTCOD(453) =   2004015
      BLTNAM(453) =  'WILSON-HARRINGTON'

      BLTCOD(454) =   398989
      BLTNAM(454) =  'NOTO'

      BLTCOD(455) =   398990
      BLTNAM(455) =  'NEW NORCIA'

      BLTCOD(456) =   399001
      BLTNAM(456) =  'GOLDSTONE'

      BLTCOD(457) =   399002
      BLTNAM(457) =  'CANBERRA'

      BLTCOD(458) =   399003
      BLTNAM(458) =  'MADRID'

      BLTCOD(459) =   399004
      BLTNAM(459) =  'USUDA'

      BLTCOD(460) =   399005
      BLTNAM(460) =  'DSS-05'

      BLTCOD(461) =   399005
      BLTNAM(461) =  'PARKES'

      BLTCOD(462) =   399012
      BLTNAM(462) =  'DSS-12'

      BLTCOD(463) =   399013
      BLTNAM(463) =  'DSS-13'

      BLTCOD(464) =   399014
      BLTNAM(464) =  'DSS-14'

      BLTCOD(465) =   399015
      BLTNAM(465) =  'DSS-15'

      BLTCOD(466) =   399016
      BLTNAM(466) =  'DSS-16'

      BLTCOD(467) =   399017
      BLTNAM(467) =  'DSS-17'

      BLTCOD(468) =   399023
      BLTNAM(468) =  'DSS-23'

      BLTCOD(469) =   399024
      BLTNAM(469) =  'DSS-24'

      BLTCOD(470) =   399025
      BLTNAM(470) =  'DSS-25'

      BLTCOD(471) =   399026
      BLTNAM(471) =  'DSS-26'

      BLTCOD(472) =   399027
      BLTNAM(472) =  'DSS-27'

      BLTCOD(473) =   399028
      BLTNAM(473) =  'DSS-28'

      BLTCOD(474) =   399033
      BLTNAM(474) =  'DSS-33'

      BLTCOD(475) =   399034
      BLTNAM(475) =  'DSS-34'

      BLTCOD(476) =   399042
      BLTNAM(476) =  'DSS-42'

      BLTCOD(477) =   399043
      BLTNAM(477) =  'DSS-43'

      BLTCOD(478) =   399045
      BLTNAM(478) =  'DSS-45'

      BLTCOD(479) =   399046
      BLTNAM(479) =  'DSS-46'

      BLTCOD(480) =   399049
      BLTNAM(480) =  'DSS-49'

      BLTCOD(481) =   399053
      BLTNAM(481) =  'DSS-53'

      BLTCOD(482) =   399054
      BLTNAM(482) =  'DSS-54'

      BLTCOD(483) =   399055
      BLTNAM(483) =  'DSS-55'

      BLTCOD(484) =   399061
      BLTNAM(484) =  'DSS-61'

      BLTCOD(485) =   399063
      BLTNAM(485) =  'DSS-63'

      BLTCOD(486) =   399065
      BLTNAM(486) =  'DSS-65'

      BLTCOD(487) =   399066
      BLTNAM(487) =  'DSS-66'



      RETURN
      END

