C$Procedure      ZZPHSH (Private---kernel pool hash function)
 
      INTEGER FUNCTION ZZPHSH ( WORD, M )
 
C$ Abstract
C
C     SPICE Private routine intended solely for the support of SPICE
C     routines.  Users should not call this routine directly due
C     to the volatile nature of this routine.
C
C     This is an umbrella routine for the kernel pool hash function.
C     It should never be called directly.
C
C$ Copyright
C
C     Copyright (1995), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C      None.
C
C$ Keywords
C
C       PRIVATE UTILITY
C
C$ Declarations
 
      IMPLICIT NONE
      CHARACTER*(*)         WORD
      INTEGER               M
 
C$ Brief_I/O
C
C      VARIABLE  I/O  Entry point
C      --------  ---  --------------------------------------------------
C      WORD       I   ZZHASH
C      M          I   ZZSHSH
C
C      The function returns zero.
C
C$ Detailed_Input
C
C     See individual entry points.
C
C$ Detailed_Output
C
C     The function ZZPHSH should never be called. However, it returns
C     the value zero.
C
C$ Parameters
C
C      None.
C
C$ Files
C
C      None.
C
C$ Exceptions
C
C     Error free.
C
C$ Particulars
C
C     This routine is an umbrella for the kernel pool hash function
C     ZZHASH and the set up routine ZZSHSH.
C
C$ Examples
C
C     To make use of the hash function you must first call ZZSHSH
C     somewhere in your program. The value returned by ZZSHSH has
C     no meaning.  You can assign it to any temporary variable you
C     happen to have lying around.
C
C        I = ZZSHSH ( M )
C
C
C        any other set up code.
C
C
C        LOOKAT = ZZHASH ( WORD )
C
C
C$ Restrictions
C
C     None.
C
C$ Author_and_Institution
C
C      W.L. Taber      (JPL)
C
C$ Literature_References
C
C      None.
C
C$ Version
C
C-    SPICELIB Version 1.0.0, 20-SEP-1995 (WLT)
C
C
C-&
 
C
C     Entry Points
C
      INTEGER               ZZSHSH
      INTEGER               ZZHASH
C
C     Local Variables.
C
      INTEGER               I
      INTEGER               DIVISR
      INTEGER               VAL ( 0:128 )
      INTEGER               F
      INTEGER               BASE
      INTEGER               BLANK
      INTEGER               LENGTH
 
      LOGICAL               FIRST
      SAVE
 
      DATA                  FIRST / .TRUE. /
C
C     We do not diagnose a bogus call since this is a private routine.
C
      ZZPHSH = 0
      RETURN
 
 
 
C$Procedure      ZZSHSH (Private---Set up hash function)
 
      ENTRY ZZSHSH ( M )
 
C$ Abstract
C
C     SPICE Private routine intended solely for the support of SPICE
C     routines.  Users should not call this routine directly due
C     to the volatile nature of this routine.
C
C     This routine sets up the kernel pool hash function.  Call it
C     once per program execution.
C
C$ Copyright
C
C     Copyright (1995), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C      None.
C
C$ Keywords
C
C       PRIVATE UTILITY
C
C$ Declarations
C
C     INTEGER               M
C
C$ Brief_I/O
C
C      VARIABLE  I/O  DESCRIPTION
C      --------  ---  --------------------------------------------------
C      M          I   Modulus used for the hash function
C
C      The function returns 0.
C
C$ Detailed_Input
C
C     M           is the modulus of the hashing function.  It is
C                 recommended that this be a prime number.
C
C$ Detailed_Output
C
C     The function returns the value zero (0).
C
C$ Parameters
C
C      None.
C
C$ Files
C
C      None.
C
C$ Exceptions
C
C     Error free.
C
C$ Particulars
C
C     This entry point sets up the modulus used for hashing input
C     strings.  It should be called once by an initialization
C     branch of the kernel pool.
C
C$ Examples
C
C     None.
C
C$ Restrictions
C
C     None.
C
C$ Author_and_Institution
C
C      W.L. Taber      (JPL)
C
C$ Literature_References
C
C      None.
C
C$ Version
C
C-    SPICELIB Version 1.0.0, 20-SEP-1995 (WLT)
C
C
C-&
 
 
      DIVISR = M
 
      IF ( FIRST ) THEN
 
         FIRST = .FALSE.
 
         BASE  = 40
         BLANK = ICHAR( ' ' )
 
         DO I = 0, 128
            VAL(I) = 0
         END DO
 
         VAL(ICHAR('0')) = 1
         VAL(ICHAR('1')) = 2
         VAL(ICHAR('2')) = 3
         VAL(ICHAR('3')) = 4
         VAL(ICHAR('4')) = 5
         VAL(ICHAR('5')) = 6
         VAL(ICHAR('6')) = 7
         VAL(ICHAR('7')) = 8
         VAL(ICHAR('8')) = 9
         VAL(ICHAR('9')) = 10
         VAL(ICHAR('A')) = 11
         VAL(ICHAR('B')) = 12
         VAL(ICHAR('C')) = 13
         VAL(ICHAR('D')) = 14
         VAL(ICHAR('E')) = 15
         VAL(ICHAR('F')) = 16
         VAL(ICHAR('G')) = 17
         VAL(ICHAR('H')) = 18
         VAL(ICHAR('I')) = 19
         VAL(ICHAR('J')) = 20
         VAL(ICHAR('K')) = 21
         VAL(ICHAR('L')) = 22
         VAL(ICHAR('M')) = 23
         VAL(ICHAR('N')) = 24
         VAL(ICHAR('O')) = 25
         VAL(ICHAR('P')) = 26
         VAL(ICHAR('Q')) = 27
         VAL(ICHAR('R')) = 28
         VAL(ICHAR('S')) = 29
         VAL(ICHAR('T')) = 30
         VAL(ICHAR('U')) = 31
         VAL(ICHAR('V')) = 32
         VAL(ICHAR('W')) = 33
         VAL(ICHAR('X')) = 34
         VAL(ICHAR('Y')) = 35
         VAL(ICHAR('Z')) = 36
         VAL(ICHAR('-')) = 37
         VAL(ICHAR('_')) = 38
         VAL(ICHAR('.')) = 39
         VAL(ICHAR('/')) = 40
 
 
         VAL(ICHAR('a')) = VAL(ICHAR('A'))
         VAL(ICHAR('b')) = VAL(ICHAR('B'))
         VAL(ICHAR('c')) = VAL(ICHAR('C'))
         VAL(ICHAR('d')) = VAL(ICHAR('D'))
         VAL(ICHAR('e')) = VAL(ICHAR('E'))
         VAL(ICHAR('f')) = VAL(ICHAR('F'))
         VAL(ICHAR('g')) = VAL(ICHAR('G'))
         VAL(ICHAR('h')) = VAL(ICHAR('H'))
         VAL(ICHAR('i')) = VAL(ICHAR('I'))
         VAL(ICHAR('j')) = VAL(ICHAR('J'))
         VAL(ICHAR('k')) = VAL(ICHAR('K'))
         VAL(ICHAR('l')) = VAL(ICHAR('L'))
         VAL(ICHAR('m')) = VAL(ICHAR('M'))
         VAL(ICHAR('n')) = VAL(ICHAR('N'))
         VAL(ICHAR('o')) = VAL(ICHAR('O'))
         VAL(ICHAR('p')) = VAL(ICHAR('P'))
         VAL(ICHAR('q')) = VAL(ICHAR('Q'))
         VAL(ICHAR('r')) = VAL(ICHAR('R'))
         VAL(ICHAR('s')) = VAL(ICHAR('S'))
         VAL(ICHAR('t')) = VAL(ICHAR('T'))
         VAL(ICHAR('u')) = VAL(ICHAR('U'))
         VAL(ICHAR('v')) = VAL(ICHAR('V'))
         VAL(ICHAR('w')) = VAL(ICHAR('W'))
         VAL(ICHAR('x')) = VAL(ICHAR('X'))
         VAL(ICHAR('y')) = VAL(ICHAR('Y'))
         VAL(ICHAR('z')) = VAL(ICHAR('Z'))
 
      END IF
 
      ZZSHSH = 0
      RETURN
 
 
 
C$Procedure      ZZHASH (Private --- Hash function)
 
      ENTRY ZZHASH ( WORD )
 
C$ Abstract
C
C     SPICE Private routine intended solely for the support of SPICE
C     routines.  Users should not call this routine directly due
C     to the volatile nature of this routine.
C
C     This routine computes the hash value associated with a kernel
C     pool variable name.
C
C$ Copyright
C
C     Copyright (1995), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C      None.
C
C$ Keywords
C
C       PRIVATE UTILITY
C
C$ Declarations
C
C     CHARACTER*(*)         WORD
C
C$ Brief_I/O
C
C      VARIABLE  I/O  DESCRIPTION
C      --------  ---  --------------------------------------------------
C      WORD       I   A left justified string of characters.
C
C      The function returns the hash value associated with WORD.
C
C$ Detailed_Input
C
C     WORD        is a left justified string of characters.  Nominally
C                 this is the name of some kernel pool variable.
C
C$ Detailed_Output
C
C     The function returns the hash value of WORD
C
C$ Parameters
C
C      None.
C
C$ Files
C
C      None.
C
C$ Exceptions
C
C     Error free.
C
C$ Particulars
C
C     This routine computes the hash value of a left justified
C     string of characters.  It is critical that the string be
C     left justified.  All non-left justified strings map to the
C     same value 0.
C
C$ Examples
C
C     See POOL.
C
C$ Restrictions
C
C     None.
C
C$ Author_and_Institution
C
C      W.L. Taber      (JPL)
C
C$ Literature_References
C
C      None.
C
C$ Version
C
C-    SPICELIB Version 1.0.0, 20-SEP-1995 (WLT)
C
C
C-&
 
 
      F      = 0
      LENGTH = LEN( WORD )
 
      DO I = 1, LENGTH
 
         IF ( ICHAR(WORD(I:I)) .EQ. BLANK ) THEN
            ZZHASH = MOD ( F*BASE, DIVISR ) + 1
            RETURN
         END IF
 
         F = VAL(  MIN( 128, ICHAR(WORD(I:I)) )  ) + F * BASE
         F = MOD( F, DIVISR )
 
      END DO
 
      ZZHASH = MOD( F*BASE, DIVISR ) + 1
 
      RETURN
      END
