C$Procedure      ZZPINI ( Private --- kernel pool initialization )
 
      SUBROUTINE ZZPINI ( FIRST,
     .                    MAXVAR, MAXVAL, MAXLIN,
     .                    BEGDAT, BEGTXT,
     .                    NMPOOL, DPPOOL, CHPOOL,
     .                    NAMLST, DATLST,
     .                    MAXAGT, MXNOTE, WATSYM, WATPTR, WATVAL,
     .                    AGENTS, ACTIVE, NOTIFY  )
 
C$ Abstract
C
C     SPICE Private routine intended solely for the support of SPICE
C     routines.  Users should not call this routine directly due
C     to the volatile nature of this routine.
C
C     This routine initializes the data structures needed for
C     maintaining the kernel pool and initializes the hash function
C     used for the name list in the kernel pool.
C
C$ Copyright
C
C     Copyright (1995), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C      None.
C
C$ Keywords
C
C       PRIVATE UTILITY
C
C$ Declarations
 
      IMPLICIT NONE
 
      INTEGER               LBCELL
      PARAMETER           ( LBCELL = -5 )
 
      INTEGER               LBPOOL
      PARAMETER           ( LBPOOL = -5 )
 
      LOGICAL               FIRST
      INTEGER               MAXVAR
      INTEGER               MAXVAL
      INTEGER               MAXLIN
      CHARACTER*(*)         BEGDAT
      CHARACTER*(*)         BEGTXT
      INTEGER               NMPOOL   ( 2, LBPOOL:MAXVAR )
      INTEGER               DPPOOL   ( 2, LBPOOL:MAXVAL )
      INTEGER               CHPOOL   ( 2, LBPOOL:MAXLIN )
      INTEGER               NAMLST   (           MAXVAR )
      INTEGER               DATLST   (           MAXVAR )
      INTEGER               MAXAGT
      INTEGER               MXNOTE
      CHARACTER*(*)         WATSYM ( LBCELL : * )
      INTEGER               WATPTR ( LBCELL : * )
      CHARACTER*(*)         WATVAL ( LBCELL : * )
      CHARACTER*(*)         AGENTS ( LBCELL : * )
      CHARACTER*(*)         ACTIVE ( LBCELL : * )
      CHARACTER*(*)         NOTIFY ( LBCELL : * )
 
C$ Brief_I/O
C
C      VARIABLE  I/O  DESCRIPTION
C      --------  ---  --------------------------------------------------
C      FIRST     I/O  Used to determine if this is the first pass
C      MAXVAR     I   Maximum number of variables in the pool
C      MAXVAL     I   Maximum number of d.p. values in the pool
C      MAXLIN     I   Maximum number of string values in the pool
C      BEGDAT     O   Marker used to begin data section of a kernel
C      BEGTXT     O   Marker used to begin text section of a kernel
C      NMPOOL     O   Linked list for resolving hash collisions of names
C      DPPOOL     O   Linked list for maintaining d.p. values.
C      CHPOOL     O   Linked list for maintaining string values
C      NAMLST     O   Heads of collision resolution lists
C      DATLST     O   Heads of data values lists
C      MAXAGT     I   Maximum number of agents that can be supported
C      MXNOTE     I   Maximum number of agents that can be notified
C      WATSYM     O   Name array of watcher symbol table
C      WATPTR     O   Pointer array of watcher symbol table
C      WATVAL     O   Values array of watcher symbol table.
C      AGENTS     O   Set of agents
C      ACTIVE     O   Watchers that are active.
C      NOTIFY     O   Agents to notify
C
C$ Detailed_Input
C
C     FIRST       is a logical indicating whether or not this is
C                 the first call to this routine.  If FIRST is .TRUE.
C                 the various items are initialized and FIRST is
C                 set to .FALSE.  If FIRST is .FALSE. no action is
C                 taken by this routine.
C
C     MAXVAR      is the maximum number of variables that the
C                 kernel pool may contain at any one time.
C
C
C     MAXVAL      is the maximum number of distinct values that
C                 may belong to the variables in the kernel pool.
C
C     MAXLIN      is the maximum number of character strings that
C                 can be stored as data for kernel pool variables.
C
C     MXNOTE      is the maximum number of distinct variable-agents
C                 pairs that can be maintained by the kernel pool.
C                 (A variable is "paired" with an agent, if that agent
C                 is to be notified whenever the variable is updated.)
C
C     MAXAGT      is the maximum number of agents that can be kept
C                 on the distribution list for notification of updates
C                 to kernel variables.
C
C$ Detailed_Output
C
C      FIRST      is set to .FALSE. on output.
C
C      BEGDAT     Marker used to begin data section of a kernel
C
C      BEGTXT     Marker used to begin text section of a kernel
C
C      NMPOOL     Linked list pool for resolving hash collisions
C                 of names of kernel pool variables.  Each list
C                 other than the free list, is a sequence of pointers
C                 to names that have the same hash value.  On output
C                 from this routine all nodes of the pool are in the
C                 free list.
C
C      DPPOOL     Linked list pool for maintaining d.p. values.
C                 On output all nodes in the pool are in the free list
C                 of DPPOOL
C
C      CHPOOL     Linked list pool for maintaining string values.
C                 On output all nodes in the pool are in the free list
C                 of CHPOOL
C
C      NAMLST     is an array that contains the heads of lists from
C                 NMPOOL.  NAMLST( ZZHASH( NAME ) ) points to the head
C                 of the first name in the collision resolution list
C                 for NAME.  If there is no head for the collision
C                 resolution list for NAME (i.e. no name with the
C                 same hash value as name has been stored)
C                 NAMLST( ZZHASH(NAME) ) will be zero.  On output from
C                 this routine all values in NAMLST are set to zero.
C
C      DATLST     is an array that contains the "heads" of lists of
C                 pointers to the values associated with a variable.
C                 Suppose that NAME has been located in the list of
C                 variable names at location LOC.  Then DATLST(LOC)
C                 is the head node of the list of pointers to the
C                 values of NAME.  If DATLST(LOC) is positive then
C                 the values are d.p.'s If the value of DATLST(LOC)
C                 is negative, the values are strings.  The absolute
C                 value of DATLST(LOC) is the head node to the list
C                 of values associated with NAME.  If DATLST(LOC) is
C                 zero then no values have been assigned to the variable
C                 NAME.  On output all entries of DATLST are set to
C                 zero.
C
C      WATSYM     is a symbol table of variables to watch for.  WATSYM
C      WATPTR     contains the names of variables to watch. The
C      WATVAL     values associated with a name are the names of agents
C                 that have requested that the variable be watched.
C
C      AGENTS     Agents contains the list of agents that need to be
C                 notified about updates to their variables.
C
C      ACTIVE     A temporary set.
C      NOTIFY     A temporary set.
C
C$ Parameters
C
C      None.
C
C$ Files
C
C      None.
C
C$ Exceptions
C
C     None.
C
C$ Particulars
C
C     This is a utility routine that centralizes the initialization
C     code that is common to all entry points of POOL.
C
C$ Examples
C
C     See POOL.
C
C$ Restrictions
C
C     None.
C
C$ Author_and_Institution
C
C      W.L. Taber      (JPL)
C
C$ Literature_References
C
C      None.
C
C$ Version
C
C-    SPICELIB Version 1.1.0, 13-OCT-1995 (WLT)
C
C        An integer variable was renamed to better indicate
C        its role in the routine and to make maintenance a bit
C        easier
C
C-    SPICELIB Version 1.0.0, 20-SEP-1995 (WLT)
C
C-&
 
C$ Revisions
C
C-    SPICELIB Version 1.1.0, 13-OCT-1995 (WLT)
C
C        An integer variable was renamed to better indicate
C        its role in the routine and to make maintenance a bit
C        easier.  The integer variable was 'DONE' which looks
C        a lot like a logical.  It's been changed to 'DUMMY'.
C
C-&
 
C
C     SPICELIB Functions.
C
      INTEGER               ZZSHSH
      LOGICAL               FAILED
C
C     Local Parameters and Variables
C
 
      INTEGER               SHRTLN
      PARAMETER           ( SHRTLN =  9 )
 
      INTEGER               BSLASH
      PARAMETER           ( BSLASH = 92 )
 
      CHARACTER*(SHRTLN)    DAT
      PARAMETER           ( DAT = 'begindata' )
 
      CHARACTER*(SHRTLN)    TXT
      PARAMETER           ( TXT = 'begintext' )
 
      INTEGER               DUMMY
      INTEGER               I
 
 
      IF ( FIRST ) THEN
 
         CALL CHKIN ( 'ZZPINI' )
 
         DO I = 1, MAXVAR
            NAMLST(I) = 0
            DATLST(I) = 0
         END DO
 
         DUMMY  = ZZSHSH ( MAXVAR )
 
         BEGDAT = CHAR(BSLASH) // DAT
         BEGTXT = CHAR(BSLASH) // TXT
 
         CALL LNKINI ( MAXVAR, NMPOOL )
         CALL LNKINI ( MAXVAL, DPPOOL )
         CALL LNKINI ( MAXLIN, CHPOOL )
 
         CALL SSIZEC ( MAXVAR, WATSYM )
         CALL SSIZEI ( MAXVAR, WATPTR )
         CALL SSIZEC ( MXNOTE, WATVAL )
 
         CALL SSIZEC ( MAXAGT, AGENTS )
         CALL SSIZEC ( MAXAGT, ACTIVE )
         CALL SSIZEC ( MAXAGT, NOTIFY )
 
         IF ( .NOT. FAILED() ) THEN
            FIRST = .FALSE.
         END IF
 
         CALL CHKOUT ( 'ZZPINI' )
         RETURN
 
      END IF
 
      RETURN
      END
