 
C$Procedure CBINIT ( Character buffer, initialize  )
 
      SUBROUTINE CBINIT_1 ( DIM, BUFFER )
      IMPLICIT NONE
 
C$ Abstract
C
C     Initialize a character buffer.
C
C$ Required_Reading
C
C     CB
C
C$ Keywords
C
C     ASCII
C     CHARACTER
C     STRING
C     TEXT
C
C$ Declarations
 
      INTEGER               LBCBUF
      PARAMETER           ( LBCBUF = 0 )
 
      INTEGER               DIM
      CHARACTER*(*)         BUFFER      ( LBCBUF:DIM )
 
C$ Brief_I/O
C
C     Variable  I/O  Description
C     --------  ---  --------------------------------------------------
C     DIM        I   Dimension of the character buffer array.
C     BUFFER    I,O  Character buffer.
C
C$ Detailed_Input
C
C     DIM         is the dimension of the array containing the
C                 character buffer to be initialized.
C
C     BUFFER      is the array.
C
C$ Detailed_Output
C
C     BUFFER      is an initialized character buffer.
C
C$ Files
C
C     None.
C
C$ Exceptions
C
C     1) The error 'SPICE(NOTLEGALCB)' is signalled whenever any of
C        the following conditions is detected.
C
C           -- The length of the individual array elements is less
C              than eight.
C
C           -- DIM is less than one.
C
C$ Particulars
C
C     A character buffer must be initialized to allow subsequent
C     operations on the buffer to detect possible overflows.
C
C$ Examples
C
C     The following code fragment illustrates the initialization
C     of a character buffer.
C
C        INTEGER               LBCBUF
C        PARAMETER           ( LBCBUF =    0 )
C
C        INTEGER               BUFDIM
C        PARAMETER           ( BUFDIM =  256 )
C
C        INTEGER               BUFLEN
C        PARAMETER           ( BUFLEN = 1024 )
C
C        CHARACTER*(BUFLEN)    BUFFER   ( LBCBUF:BUFDIM )
C         .
C         .
C
C        CALL CBINIT ( BUFDIM, BUFFER )
C
C     In this example, the buffer contains 256K characters of available
C     storage (256 array elements of 1024 characters each). Note that
C     it is only necessary to supply the dimension of the array (256),
C     and not the length of the individual elements (1024).
C
C$ Restrictions
C
C     None.
C
C$ Literature_References
C
C     None.
C
C$ Author_and_Institution
C
C     Dagny Taggart, (JPL)
C
C$ Version
C
C-    Beta Version 1.0.0, 19-JAN-1989 (DT)
C
C-&
 
C
C     SPICELIB functions
C
      LOGICAL               RETURN
 
 
C
C     Standard error handling.
C
      IF ( RETURN() ) THEN
         RETURN
      ELSE
         CALL CHKIN ( 'CBINIT_1' )
 
         IF ( LEN ( BUFFER(0) ) .LT. 8 ) THEN
            CALL SETMSG ( 'Length is #.'         )
            CALL ERRINT ( '#', LEN ( BUFFER(0) ) )
 
            CALL SIGERR ( 'SPICE(NOTLEGALCB)' )
            CALL CHKOUT ( 'CBINIT_1'            )
            RETURN
 
         ELSE IF ( DIM .LT. 1 ) THEN
            CALL SETMSG ( 'Dimension is #.' )
            CALL ERRINT ( '#', DIM          )
 
            CALL SIGERR ( 'SPICE(NOTLEGALCB)' )
            CALL CHKOUT ( 'CBINIT_1'            )
            RETURN
         END IF
      END IF
 
C
C     Store only the dimension.
C
      CALL ENCHAR ( DIM, BUFFER(0)(1:8) )
 
      CALL CHKOUT ( 'CBINIT_1' )
      RETURN
      END
