C$Procedure      CMSTUP ( Command Loop Startup )
 
      SUBROUTINE CMSTUP
 
C$ Abstract
C
C     This routine performs command loop start ups associated
C     with information on the command line when the user
C     activated the program.
C
C$ Required_Reading
C
C      None.
C
C$ Keywords
C
C       Command Loop
C
C$ Declarations
 
      IMPLICIT NONE
 
 
C$ Brief_I/O
C
C      VARIABLE  I/O  DESCRIPTION
C      --------  ---  --------------------------------------------------
C      None.
C
C$ Detailed_Input
C
C     None.
C
C$ Detailed_Output
C
C     None.
C
C$ Parameters
C
C      None.
C
C$ Files
C
C      None.
C
C$ Exceptions
C
C     Error free.
C
C$ Particulars
C
C     This routine examines the information supplied on the command
C     line when a program was started and sets the symbols indicating
C     whether or not the program is in batch mode and if appropriate
C     sets up to start a command procedure.
C
C     This routine works entirely by side effect.
C
C     Recognized flags are:
C
C     -b                for batch mode
C     -start filename   for starting a startup file.
C
C     Unrecognized options are ignored.
C
C$ Examples
C
C     See the command loop documentation
C
C$ Restrictions
C
C     None.
C
C$ Author_and_Institution
C
C      W.L. Taber      (JPL)
C
C$ Literature_References
C
C      None.
C
C$ Version
C
C-    SPICELIB Version 1.0.0, 20-NOV-1995 (WLT)
C
C
C-&
 
C$ Index_Entries
C
C     Command loop set up.
C
C-&
 
C
C     Command loop fucntions
C
      LOGICAL               SETBAT
 
C
C     Below are the various sources from which
C     commands might come.
C
C     NONE
C     COMBUF
C     KEYBRD
C     INPFIL
C
      INTEGER               NONE
      PARAMETER           ( NONE   = 0 )
 
      INTEGER               COMBUF
      PARAMETER           ( COMBUF = NONE   + 1 )
 
      INTEGER               KEYBRD
      PARAMETER           ( KEYBRD = COMBUF + 1 )
 
      INTEGER               INPFIL
      PARAMETER           ( INPFIL = KEYBRD + 1 )
 
 
 
      INTEGER               LNSIZE
      PARAMETER           ( LNSIZE = 255 )
 
      CHARACTER*(LNSIZE)    COMMND
      CHARACTER*(LNSIZE)    COMLIN
      CHARACTER*(LNSIZE)    FILE
 
      INTEGER               B
      INTEGER               E
      INTEGER               START
 
      LOGICAL               HAVGO
      LOGICAL               DOBTCH
      LOGICAL               HAVFIL
 
      CALL GETCML ( COMLIN )
 
      START  = 1
      HAVGO  = .FALSE.
      DOBTCH = .FALSE.
      HAVFIL = .FALSE.
 
 
      CALL FNDNWD ( COMLIN, START, B, E )
 
      DO WHILE ( B .GT. 0 )
 
         IF ( COMLIN(B:E) .EQ. '-b' ) THEN
 
            DOBTCH = .TRUE.
 
         ELSE IF ( COMLIN(B:E) .EQ. '-start' ) THEN
 
            HAVGO = .TRUE.
 
         ELSE IF ( HAVGO .AND. .NOT. HAVFIL ) THEN
 
            FILE   = COMLIN(B:E)
            HAVFIL = .TRUE.
 
         END IF
 
         START = E + 1
         CALL FNDNWD ( COMLIN, START, B, E )
      END DO
 
C
C     If we have a batch flag, notify NXTCOM
C
      IF ( DOBTCH ) THEN
 
         DOBTCH = SETBAT()
 
      END IF
 
      IF ( HAVGO .AND. HAVFIL ) THEN
 
         CALL TRNLAT ( 'START',  COMMND )
         CALL SUFFIX (  FILE, 1, COMMND )
         CALL PUTCOM (  COMMND,  COMBUF )
 
      END IF
 
 
      RETURN
      END
