C$Procedure                  CRTPTR (Create pointer)
 
      CHARACTER*(*) FUNCTION CRTPTR (BASE, INDEX, PNTER)
 
C$ Abstract
C
C     Returns the symbol 'BASE~INDEX~PNTER'.
C
C$ Required_Reading
C
C     None.
C
C$ Keywords
C
C     None.
C
C$ Declarations
 
      CHARACTER*(*)         BASE
      INTEGER               INDEX
      CHARACTER*(*)         PNTER
 
      INTEGER               SYMLEN
      PARAMETER           ( SYMLEN = 1024 )
 
C$ Brief_I/O
C
C     Variable  I/O  Description
C     --------  ---  --------------------------------------------------
C      BASE,
C      INDEX,
C      PNTER     I    Components of the symbol 'BASE~INDEX~PNTER'.
C
C      SYMLEN    P    Maximum length of the symbol.
C
C$ Detailed_Input
C
C     BASE,
C     INDEX,
C     PNTER      are components of the symbol 'BASE~INDEX~PNTER'.
C
C$ Detailed_Output
C
C     CRTPTR     is the symbol 'BASE~INDEX~PNTER'.
C
C$ Parameters
C
C     SYMLEN     is the maximum length of the symbol 'BASE~INDEX~PNTER'.
C
C$ Exceptions
C
C     1) If the length of the symbol 'BASE~INDEX~PNTER' exceeds SYMLEN,
C        the error SPICE(BUFFERTOOSMALL) is signalled.
C
C     2) If the length of the symbol 'BASE~INDEX~PNTER' exceeds
C        LEN(CRTPTR), the error SPICE(DIMENSIONTOOSMALL) is signalled.
C
C$ Files
C
C     None.
C
C$ Particulars
C
C     This routine creates a symbol that may be used to look up
C     nodes in the symbol table created by CPARSE.
C
C$ Examples
C
C     None.
C
C$ Restrictions
C
C     None.
C
C$ Literature_References
C
C     None.
C
C$ Author_and_Institution
C
C     M.J. Spencer   (JPL)
C
C$ Version
C
C-    Version 1.1.0, 09-DEC-203, (EDW)
C
C       Set the SYMLEN value to 1024 to match the same
C       value in niospk.
C
C-    Beta Version 1.0.0, 11-AUG-1992 (MJS)
C
C-&
 
C
C     SPICELIB functions
C
      INTEGER               RTRIM
      LOGICAL               RETURN
 
C
C     Local variables
C
      CHARACTER*(10)        CNUM
      CHARACTER*(SYMLEN)    SYM
 
      INTEGER               BLEN
      INTEGER               CLEN
      INTEGER               PLEN
      INTEGER               TOTAL
 
C
C     This routine will use discovery check-in.
C
      IF (RETURN()) THEN
         RETURN
      END IF
 
C
C     Compute the lengths of the strings involved.
C
      CALL INTSTR (INDEX, CNUM)
 
      CLEN  = RTRIM (CNUM)
      BLEN  = RTRIM (BASE)
      PLEN  = RTRIM (PNTER)
      TOTAL = CLEN+BLEN+PLEN+2
 
C
C     TOTAL must be SYMLEN characters, or fewer.
C
      IF (TOTAL .GT. SYMLEN) THEN
         CALL CHKIN  ('CRTPTR'                                     )
         CALL SETMSG ('Symbol exceeds # characters. Increase the '  //
     .                'value of SYMLEN.'                           )
         CALL ERRINT ('#', SYMLEN                                  )
         CALL SIGERR ('SPICE(BUFFERTOOSMALL)'                      )
         CALL CHKOUT ('CRTPTR'                                     )
         RETURN
      END IF
 
C
C     And TOTAL must be LEN(CRTPTR) characters, or fewer.
C
      IF (TOTAL .GT. LEN(CRTPTR)) THEN
         CALL CHKIN  ('CRTPTR'                                 )
         CALL SETMSG ('Symbol exceeds the dimension of CRTPTR.')
         CALL SIGERR ('SPICE(DIMENSIONTOOSMALL)'               )
         CALL CHKOUT ('CRTPTR'                                 )
         RETURN
      END IF
 
C
C     Form the symbol 'BASE~INDEX~PNTER'.
C
      SYM = ' '
      SYM = BASE(1:BLEN) //'~'// CNUM(1:CLEN) //'~'// PNTER(1:PLEN)
 
      CRTPTR = SYM
 
      RETURN
      END
