C$Procedure   EXESYS  ( Execute system command )
 
      SUBROUTINE EXESYS ( CMD )
 
C$ Abstract
C
C     Execute an operating system command.
C
C$ Copyright
C
C     Copyright (1995), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     None.
C
C$ Keywords
C
C     UTILITY
C
C$ Declarations
 
      CHARACTER*(*)         CMD
 
C$ Brief_I/O
C
C     Variable  I/O  Description
C     --------  ---  --------------------------------------------------
C     CMD        I   Command to be executed.
C
C$ Detailed_Input
C
C     CMD            is a character string containing a command
C                    recognized by the command line interpreter of
C                    the operating system.  The significance of case
C                    in CMD is system-dependent.  Trailing white space
C                    is not significant.
C
C$ Detailed_Output
C
C     None.   See $Particulars for a description of the action of this
C     routine.
C
C$ Parameters
C
C     None.
C
C$ Exceptions
C
C     1)  If the input command is not executed successfully, and if
C         this routine is able to detect the failure, the error
C         SPICE(SYSTEMCALLFAILED) is signalled.
C
C$ Files
C
C     None.
C
C$ Particulars
C
C     Most popular operating systems provide a Fortran-callable
C     interface that allows a program to execute an operating system
C     command by passing the command, in the form of a string, to the
C     operating system's command interpreter. This routine encapulates
C     most of the system-dependent code required to execute operating
C     system commands in this manner.  The input commands are of course
C     system-dependent.
C
C     Side effects of this routine vary from system to system.
C     See $Restrictions for more information.
C
C     Error checking capabilities also vary from system to system; this
C     routine does the best it can to diagnose errors resulting from
C     the attempt to execute the input command.
C
C
C     Building programs that use this routine
C     ---------------------------------------
C
C     ALPHA-OSF1
C
C        Computer:         ALPHA
C        Operating System: OSF1 V3.2
C        Fortran:          DEC FORTRAN V3.5-053
C
C        No special actions are required for compiling or linking in
C        this environment.
C
C     VAX:
C
C        Computer:         VAX 11/780
C        Operating System: VAX VMS 5.3
C        Fortran:          VAX FORTRAN 5.5
C
C        No special actions are required for compiling or linking in
C        this environment.
C
C
C     SUN
C
C        Computer:         Sun SPARCstation 2
C        Operating System: Sun OS 4.1.2
C        Fortran:          Sun FORTRAN 1.3.1
C
C        No special actions are required for compiling or linking in
C        this environment.
C
C
C     PC-MS
C
C        Computer:         PC
C        Operating System: Microsoft DOS 5.00
C        Fortran:          Microsoft Powerstation Fortran V1.0
C
C        No special actions are required for compiling or linking in
C        this environment.
C
C
C     HP
C
C        Computer:         HP 715/50
C        Operating System: HP-UX 9.01
C        Fortran:          HP-UX.09.00.24
C                          HP-UX FORTRAN/9000
C                             Series 700 B2408A.09.00
C                             Series 800 B2409B.09.00
C
C        Compile this routine using the +U77 option.
C        Link using the +U77 option.
C
C
C     NEXT
C
C        Computer:         NeXT
C        Operating System: NeXtStep 3.0, 3.2
C        Fortran:          Absoft Fortran V3.2
C        NEXT (NeXT 3.0, Absoft Fortran 3.2):
C
C        Link using -lU77 to include the Unix system library.
C
C
C$ Examples
C
C     1)  Unix:  copy the file spud.dat to the file spam.dat.  Test
C         whether the copy command was executed successfully.
C
C         For safety, we recommend appending a null character to the
C         command.
C
C            CALL EXESYS (  'cp spud.dat spam.dat'//CHAR(O)  )
C
C            IF ( FAILED() ) THEN
C
C               [process error condition]
C
C            END IF
C
C
C     2)  VMS:  same action as in example (1):
C
C            CALL EXESYS ( 'COPY  SPUD.DAT;  SPAM.DAT;' )
C
C            IF ( FAILED() ) THEN
C
C               [process error condition]
C
C            END IF
C
C$ Restrictions
C
C     1)  This routine should be used with caution; executing a system
C         command from within your program may have surprising side
C         effects.  For example, the Sun Fortran Reference Manual [1]
C         gives this warning:
C
C               *System* flushes all open files.  For output files,
C               the buffer is flushed to the actual file.  For input
C               files, the position of the pointer is unpredictable.
C
C     2)  Under Sun Fortran
C
C            -- The shell used to execute the command is determined by
C               the environment variable SHELL.
C
C            -- The command string cannot exceed 1024 characters in
C               length.
C
C$ Literature_References
C
C     None.
C
C$ Author_and_Institution
C
C     N.J. Bachman   (JPL)
C
C$ Version
C
C-    Beta Version 2.3.0, 03-JAN-2005 (BVS)
C
C        Updated for PC-CYGWIN_C.
C
C-    Beta Version 2.2.0, 03-JAN-2005 (BVS)
C
C        Updated for PC-CYGWIN.
C
C-    Beta Version 2.1.5, 17-JUL-2002 (BVS)
C
C        Added MAC-OSX environments.
C
C-    Beta Version 2.1.4, 08-OCT-1999 (WLT)
C
C        The environment lines were expanded so that the supported
C        environments are now explicitely given.  New
C        environments are WIN-NT
C
C-    Beta Version 2.1.3, 22-SEP-1999 (NJB)
C
C        CSPICE and PC-LINUX environment lines were added.  Some
C        typos were corrected.
C
C-    Beta Version 2.1.2, 28-JUL-1999 (WLT)
C
C        The environment lines were expanded so that the supported
C        environments are now explicitly given.  New
C        environments are PC-DIGITAL, SGI-O32 and SGI-N32.
C
C-    Beta Version 2.1.1, 18-MAR-1999 (WLT)
C
C        The environment lines were expanded so that the supported
C        environments are now explicitly given.  Previously,
C        environments such as SUN-SUNOS and SUN-SOLARIS were implied
C        by the environment label SUN.
C
C-    Beta Version 2.1.0, 12-AUG-1996 (WLT)
C
C        Added the DEC-OSF1 environment.
C
C-    Beta Version 2.0.0, 16-JUN-1995 (WLT)(HAN)
C
C        Master version of machine dependent collections.
C        Copyright notice added.
C
C-    Beta Version 1.0.0, 16-AUG-1994 (NJB)
C
C-&
 
 
C$ Index_Entries
C
C     execute an operating system command
C
C-&
 
C
C     SPICELIB functions
C
      INTEGER               RTRIM
      LOGICAL               RETURN
 
C
C        Computer:         VAX 11/780
C        Operating System: VAX VMS 5.3
C        Fortran:          VAX FORTRAN 5.5
C
C
C     System functions
C
      INTEGER               LIB$SPAWN
      EXTERNAL              LIB$SPAWN
 
C
C     Local variables
C
      INTEGER               STATUS
 
 
C
C     Standard SPICE error handling.
C
      IF ( RETURN () ) THEN
         RETURN
      ELSE
         CALL CHKIN ( 'EXESYS' )
      END IF
 
 
C
C        Computer:         VAX 11/780
C        Operating System: VAX VMS 5.3
C        Fortran:          VAX FORTRAN 5.5
C
C
      STATUS = LIB$SPAWN ( CMD(:RTRIM(CMD)) )
 
C
C     The following test looks a little strange, since we're treating
C     STATUS as a logical variable, even though it's declared as an
C     integer.  The DEC Run-Time Library documentation uses this
C     technique in an example, however, and it seems to work....`
C
      IF ( .NOT. STATUS ) THEN
C
C        Uh, we've got a problem.
C
         CALL SETMSG ( 'VAX RTL routine LIB$SPAWN returned status '  //
     .                 'code #.'                                      )
         CALL ERRINT ( '#',  STATUS                                   )
         CALL SIGERR ( 'SPICE(SYSTEMCALLFAILED)'                      )
         CALL CHKOUT ( 'EXESYS'                                       )
         RETURN
 
      END IF
 
 
 
      CALL CHKOUT ( 'EXESYS' )
      RETURN
      END
