C$Procedure      GETCML ( Get the command line )
 
      SUBROUTINE GETCML ( LINE )
 
C$ Abstract
C
C     Return command line arguments in a single string.
C
C$ Copyright
C
C     Copyright (1995), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     None.
C
C$ Keywords
C
C     UTILITY
C
C$ Declarations
 
 
      CHARACTER*(*)         LINE
 
C$ Brief_I/O
C
C     Variable  I/O  Description
C     --------  ---  --------------------------------------------------
C     LINE       O   The command line arguments.
C
C$ Detailed_Input
C
C     None.
C
C$ Detailed_Output
C
C     LINE      is the string containing the command line arguments.
C               The actual command is not contained in the string.
C
C               The line is coverted to lower case for compatibility
C               with other environments.  (Normally the VMS
C               environment convertes it to upper case for you which
C               isn't much better.  If you need uppercase, apply UCASE
C               to the line returned by this routine.
C
C$ Parameters
C
C     None.
C
C$ Exceptions
C
C     Error free.
C     This routine does not participate in the SPICELIB error handling
C     mechanism.
C
C     Any other exceptions are unknown at this time.
C
C$ Files
C
C     None.
C
C$ Particulars
C
C     The source code for platforms for which we have no documentation
C     was created as a result of porting the Sun OS/Sun Fortran version
C     of the routine to detemine if it executed successfully on the
C     target platform. This is how we generated the code for the Sun
C     Solaris/Sun Fortran, Silicon Graphics IRIX/SGI Fortran, and
C     DEC Alpha OSF-1/DEC Fortran platforms.
C
C$ Examples
C
C     If inputs is a Fortran program, and the following command is
C     executed from a command line,
C
C       % inputs this is the command line input
C
C     the following string will be returned by GETCML:
C
C       this is the command line input
C
C     The Mac Classic version creates a window into which the user
C     inputs the command line arguments (if any).
C
C$ Restrictions
C
C     None.
C
C$ Literature_References
C
C     1. "FORTRAN/9000 Reference HP 9000 Series 700 Computers,"
C        First Edition, June 1991, Hewlett Packard Company,
C        pages 9-29, 9-30, 18-2 through 18-5.
C
C     2. "Language Guide," accompaniment to Microsoft FORTRAN
C        PowerStation Compiler, version 1.0, 1993, pages 296-297,
C        401-402.
C
C     3. "Absoft FORTRAN 77 Compatibility Libraries,"
C        Absoft Corporation, 1991-1992, pages 3-10 and 3-14.
C
C     4. "Lahey F77L3-EM/32 FORTRAN Programmer's Reference," Lahey
C        Computer Systems, Inc., Revision C, January 1992, page 35.
C
C$ Author_and_Institution
C
C     K.R. Gehringer (JPL)
C     H.A. Neilan    (JPL)
C     M.J. Spencer   (JPL)
C
C$ Version
C
C-    SPICELIB Version 6.2.0, 03-JAN-2005 (BVS)
C
C        Updated for PC-CYGWIN.
C
C-    SPICELIB Version 6.1.1, 17-JUL-2002 (BVS)
C
C        Added MAC-OSX environments.
C
C-    SPICELIB Version 6.1.0, 14-NOV-2001 (EDW)
C
C        Add code to create an input window for arguments
C        under Mac Absoft (Classic) compiler. The enviroment
C        ID is MACPPC.
C
C-    SPICELIB Version 6.0.0, 14-OCT-1999 (WLT)
C
C        The VMS environment was modified to return the command
C        line after applying LCASE.
C
C-    SPICELIB Version 5.0.3, 08-OCT-1999 (WLT)
C
C        The environment lines were expanded so that the supported
C        environments are now explicitely given.  New
C        environments are WIN-NT
C
C-    SPICELIB Version 5.0.2, 28-JUL-1999 (WLT)
C
C        The environment lines were expanded so that the supported
C        environments are now explicitely given.  New
C        environments are PC-DIGITAL, SGI-O32 and SGI-N32.
C
C-    SPICELIB Version 5.0.1, 18-MAR-1999 (WLT)
C
C        The environment lines were expanded so that the supported
C        environments are now explicitely given.  Previously,
C        environments such as SUN-SUNOS and SUN-SOLARIS were implied
C        by the environment label SUN.
C
C-    SPICELIB Version 5.0.0, 24-NOV-1998 (WLT)
C
C        Added references for the MAC.
C
C-    SPICELIB Version 4.0.0, 05-APR-1998 (NJB)
C
C        Added references for the PC-LINUX environment.  Added SAVE
C        statements for the variable FIRST.
C
C-    SPICELIB Version 3.2.0, 18-AUG-1995 (KRG) (HAN)
C
C        Added code for the PC-Lahey environment. Increased the size
C        of ARGLEN to 512 as a result of truncation problems on some
C        Unix platforms.
C
C-    SPICELIB Version 3.1.0, 5-JAN-1995 (HAN)
C
C        Removed Sun Solaris environment since it is now the same
C        as the Sun OS 4.1.x environment.
C        Removed DEC Alpha/OpenVMS environment since it is now the
C        same as the VAX environment.
C
C-    SPICELIB Version 3.0.0, 8-JUL-1994 (HAN)
C
C        Added code for the NeXT/Absoft Fortran, HP-UX/HP Fortran,
C        Silicon Graphics (SGI) IRIX/SGI Fortran,
C        Sun Solaris/Sun Fortran, and DEC Alpha OSF-1/DEC Fortran
C        environments.
C
C-    SPICELIB Version 2.0.0, 15-MAR-1994 (HAN) (MJS)
C
C        Added code for the HP and the PC/Microsoft Powerstation
C        environments.
C
C-    SPICELIB Version 1.0.0, 19-NOV-1992 (HAN)
C
C-&
 
C$ Index_Entries
C
C   get command line arguments
C
C-&
 
 
 
 
C
C     Call the VAX function LIB$GET_FOREIGN to get the command line
C     arguments. The command itself is not returned in the string.
C
      CALL LIB$GET_FOREIGN ( LINE )
      CALL LCASE ( LINE, LINE )
 
      RETURN
      END
