C$Procedure      M2UNIT ( Determine whether a word is a unit spec )
 
      LOGICAL FUNCTION M2UNIT ( WORD )
      IMPLICIT NONE
 
C$ Abstract
C
C     This function is true if the input string is a number in the
C     sense of META/2.
C
C$ Required_Reading
C
C     META/2 a language specification language.
C
C$ Keywords
C
C     ALPHANUMERIC
C     ASCII
C     PARSING
C     UTILITY
C     WORD
C
C$ Declarations
 
      CHARACTER*(*)         WORD
 
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     WORD       I   A character string word
C
C     The function is returned as .TRUE. if word is an META/2 unit.
C
C$ Detailed_Input
C
C     WORD      is a character string that is assumed to have no
C               spaces between the first and last non-blank characters.
C
C$ Detailed_Output
C
C     M2UNIT    returns as .TRUE. if WORD is a parsable unit.
C               Otherwise it is returned .FALSE.
C
C$ Error_Handling
C
C     None.
CC
C$ Input_Files
C
C     None.
C
C$ Output_Files
C
C     None.
C
C$ Particulars
C
C     This is a utility routine for the subroutine META2.  It
C     determines whether or not a word is a unit spec in the sense
C     of the language META/2.
C
C$ Examples
C
C     WORD                                  M2UNIT
C     -------                               ------
C     SPAM                                  .FALSE.
C     KM                                    .TRUE.
C     KM/SEC                                .TRUE.
C     100*AU/YEAR                           .TRUE.
C     12.E2                                 .FALSE.
C
C$ Restrictions
C
C     None.
C
C$ Literature_References
C
C     None.
C
C$ Author_and_Institution
C
C     W.L. Taber     (JPL)
C     I.M. Underwood (JPL)
C
C$ Version
C
C-     META/2 Version 1.0.0, 23-MAR-2000 (WLT)
C
C
C-&
 
 
 
C
C     SPICELIB functions
C
      LOGICAL               UNITP
      INTEGER               LTRIM
      INTEGER               RTRIM
C
C     Local variables
C
      INTEGER               START
      INTEGER               END
 
      SAVE
 
 
C
C     Make sure the string has the right length.
C
      START  = LTRIM  ( WORD )
      END    = RTRIM  ( WORD )
 
      M2UNIT = UNITP( WORD(START:END) )
 
 
      RETURN
      END
