C$Procedure ZZTXTOPN ( Private Routine -- Text file, open new )
 
      SUBROUTINE ZZTXTOPN ( FNAME, UNIT, SUCCSS )
 
C$ Abstract
C
C     Open a new text file for subsequent write access, without
C     signaling an error on failure.
C
C$ Copyright
C
C     Copyright (2000), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     None.
C
C$ Keywords
C
C     FILES
C     TEXT
C
C$ Declarations
 
      CHARACTER*(*)         FNAME
      INTEGER               UNIT
      LOGICAL               SUCCSS
 
C$ Brief_I/O
C
C     Variable  I/O  Description
C     --------  ---  --------------------------------------------------
C     FNAME      I   Name of file.
C     UNIT       O   Logical unit.
C     SUCCSS     O   Logical that indicates successful open.
C
C$ Detailed_Input
C
C     FNAME          is the name of the new text file to be opened.
C
C$ Detailed_Output
C
C     UNIT           is the logical unit connected to the opened file.
C
C     SUCCSS         is the logical flag that indicates whether the
C                    file was opened successfully or not.
C
C$ Parameters
C
C     None.
C
C$ Exceptions
C
C     1) If the file cannot be opened, SUCCSS is returned .FALSE.
C
C     2) If FNAME is a blank string, the error SPICE(BLANKFILENAME) is
C        signaled.
C
C$ Files
C
C     See FNAME and UNIT above.
C
C$ Particulars
C
C     In SPICELIB, a text file is formatted and sequential and may
C     contain only printable ASCII characters and blanks (ASCII 32-127).
C     When printing a text file, records are single spaced; the first
C     character will not be interpreted as a carriage control character.
C
C     ZZTXTOPN opens a new text file and makes use of the SPICELIB
C     mechanism for coordinating the use of logical units.
C
C     System Dependencies
C     ===================
C
C     The open statement will include the following keyword = value
C     pairs:
C
C            UNIT   =  UNIT
C            FILE   =  FNAME
C            FORM   = 'FORMATTED'
C            ACCESS = 'SEQUENTIAL'
C            STATUS = 'NEW'
C            IOSTAT =  IOSTAT
C
C     In addition, the statement will include
C
C            CARRIAGECONTROL = 'LIST'
C
C     for the Vax and Macintosh.
C
C$ Examples
C
C     The following example reads a line from an input file,
C     'INPUT.TXT', and writes it to an output file, 'OUTPUT.TXT'.
C
C        CALL TXTOPR ( 'INPUT.TXT',  IN  )
C        CALL ZZTXTOPN ( 'OUTPUT.TXT', OUT, OK )
C
C        IF ( OK ) THEN
C
C           READ  ( IN,  FMT='(A)' ) LINE
C           WRITE ( OUT, FMT='(A)' ) LINE
C
C        END IF
C
C        CLOSE ( IN  )
C        CLOSE ( OUT )
C
C$ Restrictions
C
C     None.
C
C$ Literature_References
C
C     1. "Absoft FORTRAN 77 Language Reference Manual", page 7-12 for
C        the NeXT.
C
C$ Author_and_Institution
C
C     J.E. McLean    (JPL)
C     H.A. Neilan    (JPL)
C
C$ Version
C
C-    NSPIO Version 2.2.0, 03-JAN-2005 (BVS)
C
C        Updated for PC-CYGWIN_C.
C
C-    NSPIO Version 2.1.0, 03-JAN-2005 (BVS)
C
C        Updated for PC-CYGWIN.
C
C-    NSPIO Version 2.0.1, 17-JUL-2002 (BVS)
C
C        Added MAC-OSX environments.
C
C-    NSPIO Version 2.0.0, 10-FEB-2000 (FST)
C
C-&
 
C
C     SPICELIB functions
C
      LOGICAL               RETURN
 
C
C     Local variables
C
      INTEGER               IOSTAT
 
C
C     Standard SPICE error handling.
C
      IF ( RETURN () ) THEN
         RETURN
      ELSE
         CALL CHKIN ( 'ZZTXTOPN' )
      END IF
 
      SUCCSS = .TRUE.
 
      IF ( FNAME .EQ. ' ' ) THEN
         SUCCSS = .FALSE.
         CALL SETMSG ( 'A blank string is unacceptable as a file name' )
         CALL SIGERR ( 'SPICE(BLANKFILENAME)'                          )
         CALL CHKOUT ( 'ZZTXTOPN'                                      )
         RETURN
      END IF
 
      CALL GETLUN ( UNIT )
 
      OPEN ( UNIT            =  UNIT,
     .       FILE            =  FNAME,
     .       FORM            = 'FORMATTED',
     .       ACCESS          = 'SEQUENTIAL',
     .       STATUS          = 'NEW',
     .       CARRIAGECONTROL = 'LIST',
     .       IOSTAT          =  IOSTAT      )
 
      IF ( IOSTAT .NE. 0 ) THEN
         SUCCSS = .FALSE.
         CALL CHKOUT ( 'ZZTXTOPN' )
         RETURN
      END IF
 
      CALL CHKOUT ( 'ZZTXTOPN' )
      RETURN
      END
