C$Procedure      FILREG ( File Registry )
 
      SUBROUTINE FILREG ( FILE )
 
C$ Abstract
C
C     This routine is an umbrella for a pair of entry points that
C     maintains/deletes a list of files created within a test family.
C
C$ Copyright
C
C     Copyright (1998), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     None.
C
C$ Keywords
C
C     Testing
C
C$ Declarations
 
      IMPLICIT NONE
      CHARACTER*(*)         FILE
 
      INTEGER               MAXFIL
      PARAMETER           ( MAXFIL = 100 )
 
C$ Brief_I/O
C
C     VARIABLE  I/O  ENTRY POINT
C     --------  ---  --------------------------------------------------
C     FILE       I   TFILES
C     MAXFIL     P   Maximum number of files that can be maintained.
C
C$ Detailed_Input
C
C     FILE       is some file that should be registered as a file
C                created by a Test Utility routine.  This file
C                will be "killed" (through a call to KILFIL)
C                when the entry point KFILES is called.
C
C$ Detailed_Output
C
C     None.
C
C$ Parameters
C
C     MAXFIL     is the maximum number of files that can be maintained
C                by the file registry.
C
C$ Files
C
C     None.
C
C$ Exceptions
C
C     Error free.
C
C     1) All files supplied to TFILES after the MAXFILth file
C        has been supplied without a call to KFILES will be
C        ignored.
C
C$ Particulars
C
C     This is a utility routine that allows test utility routines
C     that create files, to register these files with a central
C     manager.
C
C     This allows TOPEN and TCLOSE to delete all such files so that
C     test families organized into a test program (as in tspice) will
C     automatically clean up after themselves without leaving
C     test files on disk as part of the debris of performing a test.
C
C     ==========================================================
C     ==========================================================
C
C     NOTE: If the user supplied the debugging flag '-D' in the
C     invocation of the test program, or if the user explicitely
C     turns on debugging by calling the function SETON as
C     shown below
C
C        DUMMY = SETON ( 'DEBUGGING' )
C
C     Files supplied to TFILES are ignored and as such will not
C     be deleted.
C
C     By placing function invocations
C
C          SETON/SETOFF ( 'DEBUGGING' )
C
C     in balanced pairs within a test family, programmers can override
C     the normal clean up activities of TOPEN and TCLOSE.
C
C
C$ Examples
C
C     If you create a new test file generator, you should insert
C     the following call somewhere in the file.
C
C        CALL TFILE ( <name of the test file> )
C
C     By so doing, all files generated by the test utilities will
C     be cleaned up by the test program alleviating programmers
C     from the error prone responsibility of cleaning up test files
C     at the end of a test family.
C
C$ Restrictions
C
C     None.
C
C$ Author_and_Institution
C
C     W.L. Taber      (JPL)
C
C$ Literature_References
C
C     None.
C
C$ Version
C
C-    Test Utilities Version 1.0.0, 28-JUL-1999 (WLT)
C
C
C-&
      INTEGER               RTRIM
      LOGICAL               ISON
 
 
      INTEGER               FILSIZ
      PARAMETER           ( FILSIZ = 255 )
 
      CHARACTER*(FILSIZ)    FILES ( MAXFIL )
      SAVE                  FILES
 
      INTEGER               NFILE
      SAVE                  NFILE
 
      INTEGER               I
      INTEGER               R
 
      DATA                  NFILE / 0 /

      RETURN 
C
C     The next entry point registers a file.
C
      ENTRY TFILES ( FILE )
C
C        Don't register files when we are in DEBUGGING mode.
C
         IF ( ISON ( 'DEBUGGING' ) ) THEN
            RETURN
         END IF
 
         IF ( NFILE .LT. MAXFIL ) THEN
            NFILE           = NFILE + 1
            FILES ( NFILE ) = FILE
         END IF
 
         RETURN
 
C
C     This entry point deletes all registered files.
C
      ENTRY KFILES
 
 
         DO I = 1, NFILE
 
            R = RTRIM( FILES(I) )
            CALL KILFIL ( FILES(I)(1:R) )
 
         END DO
 
         NFILE = 0
 
         RETURN
 
      END
