C$Procedure      SHOERR ( Show Errors )
 
      SUBROUTINE SHOERR
 
C$ Abstract
C
C     This routine sets the error handling within a test case so
C     that error messages are sent to the screen.  When the
C     test case ends, messages are once again sent to 'NULL'
C
C$ Copyright
C
C     Copyright (1998), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     None.
C
C$ Keywords
C
C     TESTING
C
C$ Declarations
 
      IMPLICIT NONE
 
 
C$ Brief_I/O
C
C     None.
C
C$ Detailed_Input
C
C     None.
C
C$ Detailed_Output
C
C     None.
C
C$ Parameters
C
C     None.
C
C$ Files
C
C     None.
C
C$ Exceptions
C
C     Error free.
C
C$ Particulars
C
C     This routine allows you to cause error messages issued through
C     the SPICE exception handling system to be sent to the screen
C     instead of being blocked from output by the Test Utilities
C     library.
C
C     However, this effect lasts only for the duration of a single
C     test case.  Once a new test case or family is specified
C     by a call to TCASE or TOPEN, error messages will once again
C     be prohibited from being displayed on the terminal window.
C
C     This routine is primarily useful in the debugging stages of
C     a test case or test family.
C
C$ Examples
C
C     Suppose that you are creating a test case within a family of
C     test cases and wish to have all text associated with an
C     exception that may arise within the scope of a test case
C     to be sent to standard output.  Simply set up your
C     test case in this way.
C
C        CALL TCASE ( 'Name of the test case.' )
C        CALL SHOERR
C
C$ Restrictions
C
C     None.
C
C$ Author_and_Institution
C
C     W.L. Taber      (JPL)
C
C$ Literature_References
C
C     None.
C
C$ Version
C
C-    Test Utilities Version 1.0.0, 27-JUL-1999 (WLT)
C
C
C-&
 
      CALL ERRDEV ( 'SET', 'SCREEN' )
      RETURN
 
      END
