
C$Procedure      T_PCKEQ ( Text PCK equation implementation )

      SUBROUTINE T_PCKEQ ( BODY, ET, RA, DEC, PM )
      IMPLICIT NONE
 
      INTEGER               BODY
      DOUBLE PRECISION      ET
      DOUBLE PRECISION      RA
      DOUBLE PRECISION      DEC
      DOUBLE PRECISION      PM
 
C$ Abstract
C
C     This routine contains direct, in-line implementations of the 2000
C     IAU report's Euler angle equations giving attitude of the sun,
C     planets, natural satellites, and asteroids.
C
C     This routine supports tests of the SPICELIB routines
C     
C        BODEUL
C        BODMAT (indirectly, via call to TIPBOD)
C        TIPBOD
C
C     performed by the test family F_RDPCK.
C
C     Results of computations done by this routine are compared with
C     results of computations implemented in the above SPICELIB
C     routines.  This testing approach attempts to validate orientation
C     computations done using text PCK data by comparing their results
C     to those obtained via an alternate computational approach.
C
C     These tests also serve to mininize the chance of transcription 
C     error when a new PCK version is created.  Entering the PCK
C     constants both in the new PCK file and in T_PCKEQ enables 
C     double-checking of the constants.
C
C$ Version
C
C-    TSPICE Version 1.0.0, 10-FEB-2004 (NJB)
C     
C-&
 
C
C     SPICELIB functions
C
      DOUBLE PRECISION      RPD
      DOUBLE PRECISION      SPD
 
C
C     Local variables
C
      DOUBLE PRECISION      A0
      DOUBLE PRECISION      D0
      DOUBLE PRECISION      D
      DOUBLE PRECISION      E1
      DOUBLE PRECISION      E2
      DOUBLE PRECISION      E3
      DOUBLE PRECISION      E4
      DOUBLE PRECISION      E5
      DOUBLE PRECISION      E6
      DOUBLE PRECISION      E7
      DOUBLE PRECISION      E8
      DOUBLE PRECISION      E9
      DOUBLE PRECISION      E10
      DOUBLE PRECISION      E11
      DOUBLE PRECISION      E12
      DOUBLE PRECISION      E13
      DOUBLE PRECISION      J1
      DOUBLE PRECISION      J2
      DOUBLE PRECISION      J3
      DOUBLE PRECISION      J4
      DOUBLE PRECISION      J5
      DOUBLE PRECISION      J6
      DOUBLE PRECISION      J7
      DOUBLE PRECISION      J8
      DOUBLE PRECISION      M1
      DOUBLE PRECISION      M2
      DOUBLE PRECISION      M3
      DOUBLE PRECISION      N
      DOUBLE PRECISION      N1
      DOUBLE PRECISION      N2
      DOUBLE PRECISION      N3
      DOUBLE PRECISION      N4
      DOUBLE PRECISION      N5
      DOUBLE PRECISION      N6
      DOUBLE PRECISION      N7
      DOUBLE PRECISION      S1
      DOUBLE PRECISION      S2
      DOUBLE PRECISION      S3
      DOUBLE PRECISION      S4
      DOUBLE PRECISION      S5
      DOUBLE PRECISION      S6
      DOUBLE PRECISION      S7
      DOUBLE PRECISION      T
      DOUBLE PRECISION      U1
      DOUBLE PRECISION      U2
      DOUBLE PRECISION      U3
      DOUBLE PRECISION      U4
      DOUBLE PRECISION      U5
      DOUBLE PRECISION      U6
      DOUBLE PRECISION      U7
      DOUBLE PRECISION      U8
      DOUBLE PRECISION      U9
      DOUBLE PRECISION      U10
      DOUBLE PRECISION      U11
      DOUBLE PRECISION      U12
      DOUBLE PRECISION      U13
      DOUBLE PRECISION      U14
      DOUBLE PRECISION      U15
      DOUBLE PRECISION      U16
      DOUBLE PRECISION      W
 
 
      CALL CHKIN ( 'T_PCKEQ' )
 
      D  =  ET /   SPD()
      T  =  D  / ( 365.25D0 * 1.D2 )
 
 
      IF ( BODY .EQ. 10 ) THEN
 
         A0  =  286.13D0
         D0  =   63.87D0
         W   =   84.10D0  +  14.1844D0 * D
 
 
      ELSE IF ( BODY .EQ. 199 ) THEN
 
         A0  =  281.01D0  -  0.033D0     * T
         D0  =   61.45D0  -  0.005D0     * T
         W   =  329.548D0 +  6.1385025D0 * D
 
 
      ELSE IF ( BODY .EQ. 299 ) THEN
 
         A0  =  272.76D0
         D0  =   67.16D0
         W   =  160.20D0 - 1.4813688D0 * D
 
 
      ELSE IF ( BODY .EQ. 399 ) THEN
 
         A0  =    0.D0    -   0.641D0     * T
         D0  =   90.D0    -   0.557D0     * T
         W   =  190.147D0 + 360.9856235D0 * D
 
 
      ELSE IF ( BODY .EQ. 499 ) THEN
 
         A0  =  317.68143D0 -   0.1061D0     * T
         D0  =   52.88650D0 -   0.0609D0     * T
         W   =  176.630D0   + 350.89198226D0 * D
 
 
      ELSE IF ( BODY .EQ. 599 ) THEN
 
         A0  =  268.05D0 -   0.009D0     * T
         D0  =   64.49D0 +   0.003D0     * T
         W   =  284.95D0 + 870.5366420D0 * D
 
 
      ELSE IF ( BODY .EQ. 699 ) THEN
 
         A0  =   40.589D0 -   0.036D0     * T
         D0  =   83.537D0 -   0.004D0     * T
         W   =   38.90D0  + 810.7939024D0 * D
 
 
      ELSE IF ( BODY .EQ. 799 ) THEN
 
         A0  =   257.311D0
         D0  =   -15.175D0
         W   =   203.81D0  - 501.1600928D0 * D
 
 
      ELSE IF ( BODY .EQ. 899 ) THEN
 
         N   =   RPD() * ( 357.85D0  +  52.316D0 * T )

         A0  =   299.36D0                       +  0.70D0 * SIN(N)
         D0  =    43.46D0                       -  0.51D0 * COS(N)
         W   =   253.18D0  + 536.3128492D0 * D  -  0.48D0 * SIN(N)
 
 
      ELSE IF ( BODY .EQ. 999 ) THEN
 
         A0  =  313.02D0
         D0  =    9.09D0
         W   =  236.77D0  -  56.3623195D0 * D
 
 
      ELSE IF (  BODY .EQ. 301 ) THEN

         E1  =  ( 125.045D0  -   0.0529921D0 * D ) * RPD()
         E2  =  ( 250.089D0  -   0.1059842D0 * D ) * RPD()
         E3  =  ( 260.008D0  +  13.0120009D0 * D ) * RPD()
         E4  =  ( 176.625D0  +  13.3407154D0 * D ) * RPD()
         E5  =  ( 357.529D0  +   0.9856003D0 * D ) * RPD()
         E6  =  ( 311.589D0  +  26.4057084D0 * D ) * RPD()
         E7  =  ( 134.963D0  +  13.0649930D0 * D ) * RPD()
         E8  =  ( 276.617D0  +   0.3287146D0 * D ) * RPD()
         E9  =  (  34.226D0  +   1.7484877D0 * D ) * RPD()
         E10 =  (  15.134D0  -   0.1589763D0 * D ) * RPD()
         E11 =  ( 119.743D0  +   0.0036096D0 * D ) * RPD()
         E12 =  ( 239.961D0  +   0.1643573D0 * D ) * RPD()
         E13 =  (  25.053D0  +  12.9590088D0 * D ) * RPD()
 

         A0  =    269.9949D0 +   0.0031D0  * T
     .                       -   3.8787D0  * SIN(E1)
     .                       -   0.1204D0  * SIN(E2)
     .                       +   0.0700D0  * SIN(E3)
     .                       -   0.0172D0  * SIN(E4)
     .                       +   0.0072D0  * SIN(E6)
     .                       -   0.0052D0  * SIN(E10)
     .                       +   0.0043D0  * SIN(E13)


         D0  =    66.5392D0  +   0.0130D0 * T
     .                       +   1.5419D0 * COS(E1)
     .                       +   0.0239D0 * COS(E2)
     .                       -   0.0278D0 * COS(E3)
     .                       +   0.0068D0 * COS(E4)
     .                       -   0.0029D0 * COS(E6)
     .                       +   0.0009D0 * COS(E7)
     .                       +   0.0008D0 * COS(E10)
     .                       -   0.0009D0 * COS(E13)
 
         W   =    38.3213D0  +  13.17635815D0 * D  - 1.4D-12 * D**2
     .                       +   3.5610D0     * SIN(E1)
     .                       +   0.1208D0     * SIN(E2)
     .                       -   0.0642D0     * SIN(E3)
     .                       +   0.0158D0     * SIN(E4)
     .                       +   0.0252D0     * SIN(E5)
     .                       -   0.0066D0     * SIN(E6)
     .                       -   0.0047D0     * SIN(E7)
     .                       -   0.0046D0     * SIN(E8)
     .                       +   0.0028D0     * SIN(E9)
     .                       +   0.0052D0     * SIN(E10)
     .                       +   0.0040D0     * SIN(E11)
     .                       +   0.0019D0     * SIN(E12)
     .                       -   0.0044D0     * SIN(E13)
 
 
      ELSE IF ( BODY/100 .EQ. 4 ) THEN
 
C
C        Two expressions for M2 are shown:  one with the quadradic
C        term, one without.  The kernel pool software cannot handle
C        the quadradic term; trying both of these expressions allows
C        the user to observe the effect of ignoring that term.
C
 
         M1 = ( 169.51D0  -    0.4357640D0 * D                 ) * RPD()
C        M2 = ( 192.93D0  + 1128.4096700D0 * D  +  8.864D0*T*T ) * RPD()
         M2 = ( 192.93D0  + 1128.4096700D0 * D                 ) * RPD()
         M3 = (  53.47D0  -    0.0181510D0 * D                 ) * RPD()
 
 
         IF ( BODY .EQ. 401 ) THEN
 
 
            A0  =  317.68D0  -        0.108D0 * T
     .                       +         1.79D0 * SIN(M1)
 
            D0  =   52.90D0  -        0.061D0 * T
     .                       -         1.08D0 * COS(M1)
 
            W   =   35.06D0  + 1128.8445850D0 * D
     .                       +    8.864D0     * T * T
     .                       -    1.42D0      * SIN(M1)
     .                       -    0.78D0      * SIN(M2)
 
 
         ELSE IF ( BODY .EQ. 402 ) THEN
 
 
            A0  =  316.65D0  -        0.108D0 * T
     .                       +        2.98D0  * SIN(M3)
 
            D0  =   53.52D0  -        0.061D0 * T
     .                       -        1.78D0  * COS(M3)
 
            W   =   79.41D0  +      285.1618970D0 * D
     .                       -        0.520D0     * T * T
     .                       -        2.58D0      * SIN(M3)
     .                       +        0.19D0      * COS(M3)
 
 
         ELSE
 
            CALL SETMSG ( 'Body code # was not recognized.' )
            CALL ERRINT ( '#', BODY                         )
            CALL SIGERR ( 'SPICE(INVALIDBODYCODE)'          )
            CALL CHKOUT ( 'T_PCKEQ'                         )
            RETURN
  
         END IF
 
 
 
 
      ELSE IF ( BODY/100 .EQ. 5 ) THEN
 
 
         J1  =   (  73.32D0  +  91472.9D0 * T )  *  RPD()
         J2  =   (  24.62D0  +  45137.2D0 * T )  *  RPD()
         J3  =   ( 283.90D0  +   4850.7D0 * T )  *  RPD()
         J4  =   ( 355.80D0  +   1191.3D0 * T )  *  RPD()
         J5  =   ( 119.90D0  +    262.1D0 * T )  *  RPD()
         J6  =   ( 229.80D0  +     64.3D0 * T )  *  RPD()
         J7  =   ( 352.35D0  +   2382.6D0 * T )  *  RPD()
         J8  =   ( 113.35D0  +   6070.0D0 * T )  *  RPD()
 
 
         IF ( BODY .EQ. 501 ) THEN
 
            A0  =  268.05D0   -    0.009D0 * T
     .                        +    0.094D0 * SIN(J3)
     .                        +    0.024D0 * SIN(J4)
 
            D0  =   64.50D0   +    0.003D0 * T
     .                        +    0.040D0 * COS(J3)
     .                        +    0.011D0 * COS(J4)
 
            W   =  200.39D0   +  203.4889538D0 * D
     .                        -    0.085D0     * SIN(J3)
     .                        -    0.022D0     * SIN(J4)
 
 
         ELSE IF ( BODY .EQ. 502 ) THEN
 
            A0  =  268.08D0   -    0.009D0 * T
     .                        +    1.086D0 * SIN(J4)
     .                        +    0.060D0 * SIN(J5)
     .                        +    0.015D0 * SIN(J6)
     .                        +    0.009D0 * SIN(J7)
 
            D0  =   64.51D0   +    0.003D0 * T
     .                        +    0.468D0 * COS(J4)
     .                        +    0.026D0 * COS(J5)
     .                        +    0.007D0 * COS(J6)
     .                        +    0.002D0 * COS(J7)
 
            W   =   36.022D0  +  101.3747235D0 * D
     .                        -    0.980D0     * SIN(J4)
     .                        -    0.054D0     * SIN(J5)
     .                        -    0.014D0     * SIN(J6)
     .                        -    0.008D0     * SIN(J7)
 
 
 
         ELSE IF ( BODY .EQ. 503 ) THEN
 
            A0  =  268.20D0   -    0.009D0 * T
     .                        -    0.037D0 * SIN(J4)
     .                        +    0.431D0 * SIN(J5)
     .                        +    0.091D0 * SIN(J6)
 
            D0  =   64.57D0   +    0.003D0 * T
     .                        -    0.016D0 * COS(J4)
     .                        +    0.186D0 * COS(J5)
     .                        +    0.039D0 * COS(J6)
 
 
            W   =   44.064D0  +   50.3176081D0 * D
     .                        +    0.033D0     * SIN(J4)
     .                        -    0.389D0     * SIN(J5)
     .                        -    0.082D0     * SIN(J6)
 
 
 
         ELSE IF ( BODY .EQ. 504 ) THEN
 
            A0  =  268.72D0   -   0.009D0 * T
     .                        -   0.068D0 * SIN(J5)
     .                        +   0.590D0 * SIN(J6)
     .                        +   0.010D0 * SIN(J8)
 
            D0  =   64.83D0   +   0.003D0 * T
     .                        -   0.029D0 * COS(J5)
     .                        +   0.254D0 * COS(J6)
     .                        -   0.004D0 * COS(J8)
 
            W   =  259.51D0   +  21.5710715D0 * D
     .                        +   0.061D0     * SIN(J5)
     .                        -   0.533D0     * SIN(J6)
     .                        -   0.009D0     * SIN(J8)
 
 
 
         ELSE IF ( BODY .EQ. 505 ) THEN
 
 
            A0  =  268.05D0   -   0.009D0 * T
     .                        -   0.84D0  * SIN(J1)
     .                        +   0.01D0  * SIN( 2.D0 * J1 )
 
            D0  =   64.49D0   +   0.003D0 * T
     .                        -   0.36D0  * COS(J1)
 
            W   =  231.67D0   + 722.6314560D0 * D
     .                        +   0.76D0      * SIN(J1)
     .                        -   0.01D0      * SIN( 2.D0 * J1 )
 
 
         ELSE IF ( BODY .EQ. 514 ) THEN
 
            A0  =  268.05D0   -   0.009D0 * T
     .                        -   2.11D0  * SIN(J2)
     .                        +   0.04D0  * SIN( 2.D0 * J2 )
 
 
            D0  =   64.49D0   +   0.003D0 * T
     .                        -   0.91D0  * COS(J2)
     .                        +   0.01D0  * COS( 2.D0 * J2 )
 
            W   =    8.56D0   + 533.7004100D0 * D
     .                        +   1.91D0      * SIN(J2)
     .                        -   0.04D0      * SIN( 2.D0 * J2 )
 
 
 
         ELSE IF ( BODY .EQ. 515 ) THEN
 
 
            A0  =  268.05D0   -    0.009D0     * T
            D0  =   64.49D0   +    0.003       * T
            W   =   33.29D0   + 1206.9986602D0 * D
 
 
 
         ELSE IF ( BODY .EQ. 516 ) THEN
 
            A0  =  268.05D0   -    0.009D0     * T
            D0  =   64.49D0   +    0.003       * T
            W   =  346.09D0   + 1221.2547301D0 * D
 
 
         ELSE
 
            CALL SETMSG ( 'Body code # was not recognized.' )
            CALL ERRINT ( '#', BODY                         )
            CALL SIGERR ( 'SPICE(INVALIDBODYCODE)'          )
            CALL CHKOUT ( 'T_PCKEQ'                          )
            RETURN
 
 
         END IF
 
 
 
      ELSE IF ( BODY/100 .EQ. 6 ) THEN
 
         S1  =  ( 353.32D0  +  75706.7D0 * T  ) * RPD()
         S2  =  (  28.72D0  +  75706.7D0 * T  ) * RPD()
         S3  =  ( 177.40D0  -  36505.5D0 * T  ) * RPD()
         S4  =  ( 300.00D0  -   7225.9D0 * T  ) * RPD()
         S5  =  ( 316.45D0  +    506.2D0 * T  ) * RPD()
         S6  =  ( 345.20D0  -   1016.3D0 * T  ) * RPD()
         S7  =  (  29.80D0  -     52.1D0 * T  ) * RPD()
 
 
         IF ( BODY .EQ. 601 ) THEN
 
            A0  =   40.66D0     -     0.036D0 * T
     .                          +    13.56D0  * SIN(S3)
 
            D0  =   83.52D0     -     0.004D0 * T
     .                          -     1.53D0  * COS(S3)
 
            W   =  337.46D0     +   381.9945550D0 * D
     .                          -    13.48D0      * SIN(S3)
     .                          -    44.85D0      * SIN(S5)
 
 
 
         ELSE IF ( BODY .EQ. 602 ) THEN
 
            A0  =   40.66D0      -     0.036D0     * T
            D0  =   83.52D0      -     0.004D0     * T
            W   =    2.82D0      +   262.7318996D0 * D
 
 
 
         ELSE IF ( BODY .EQ. 603 ) THEN
 
            A0  =   40.66D0       -     0.036D0 * T
     .                            +     9.66D0  * SIN(S4)
 
            D0  =   83.52D0       -     0.004D0 * T
     .                            -     1.09D0  * COS(S4)
 
            W   =   10.45D0       +   190.6979085D0 * D
     .                            -     9.60D0      * SIN(S4)
     .                            +     2.23D0      * SIN(S5)
 
 
 
         ELSE IF ( BODY .EQ. 604 ) THEN
 
            A0  =   40.66D0       -     0.036D0 * T
            D0  =   83.52D0       -     0.004D0 * T
            W   =  357.00D0       +   131.5349316D0 * D
 
 
 
         ELSE IF ( BODY .EQ. 605 ) THEN
 
 
           A0  =    40.38D0       -    0.036D0 * T
     .                            +    3.10D0  * SIN(S6)
 
           D0  =    83.55D0       -    0.004D0 * T
     .                            -    0.35D0  * COS(S6)
 
           W   =   235.16D0       +   79.6900478D0 * D
     .                            -    3.08D0      * SIN(S6)
 
 
 
         ELSE IF ( BODY .EQ. 606 ) THEN
 
 
            A0  =    36.41D0      -    0.036D0 * T
     .                            +    2.66D0  * SIN(S7)
 
            D0  =    83.94D0      -    0.004D0 * T
     .                            -    0.30D0  * COS(S7)
 
            W   =   189.64D0      +   22.5769768D0 * D
     .                            -    2.64D0      * SIN(S7)
 
 
 
         ELSE IF ( BODY .EQ. 608 ) THEN
 
            A0  =   318.16D0    -   3.949D0 * T
            D0  =   75.03D0     -   1.143D0 * T
            W   =  350.20D0     +   4.5379572D0 * D
 
 
         ELSE IF ( BODY .EQ. 609 ) THEN
 
            A0  =  355.00D0
            D0  =   68.70D0
            W   =  304.70D0    +  930.8338720D0 * D
 
 
         ELSE IF ( BODY .EQ. 610 ) THEN
 
            A0  =  40.58D0     -     0.036D0 * T
     .                         -     1.623D0 * SIN(S2)
     .                         +     0.023D0 * SIN( 2.D0 * S2 )
 
            D0  =  83.52D0     -     0.004D0 * T
     .                         -     0.183D0 * COS(S2)
     .                         +     0.001D0 * COS( 2.D0 * S2 )
 
            W   =  58.83D0     +   518.2359876D0 * D
     .                         +     1.613D0     * SIN(S2)
     .                         -     0.023D0     * SIN( 2.D0 * S2 )
 
 
         ELSE IF ( BODY .EQ. 611 ) THEN
 
            A0  =   40.58D0    -     0.036D0 * T
     .                         -     3.153D0 * SIN(S1)
     .                         +     0.086D0 * SIN( 2.D0 * S1 )
 
 
            D0  =   83.52D0    -     0.004D0 * T
     .                         -     0.356D0 * COS(S1)
     .                         +     0.005D0 * COS( 2.D0 * S1 )
 
 
            W   =  293.87D0    +   518.4907239D0 * D
     .                         +     3.133D0     * SIN(S1)
     .                         -     0.086D0     * SIN( 2.D0 * S1 )
 
 
 
         ELSE IF ( BODY .EQ. 612 ) THEN
 
            A0  =   40.85D0    -    0.036D0 * T
            D0  =   83.34D0    -    0.004D0 * T
            W   =  245.12D0    +  131.6174056D0 * D
 
 
         ELSE IF ( BODY .EQ. 613 ) THEN
 
            A0  =   50.51D0    -    0.036D0 * T
            D0  =   84.06D0    -    0.004D0 * T
            W   =   56.88D0    +  190.6979332D0 * D
 
 
         ELSE IF ( BODY .EQ. 614 ) THEN
 
            A0  =   36.41D0    -    0.036D0 * T
            D0  =   85.04D0    -    0.004D0 * T
            W   =  153.51D0    +  190.6742373D0 * D
 
 
         ELSE IF ( BODY .EQ. 615 ) THEN
 
            A0  =   40.58D0    -    0.036D0 * T
            D0  =   83.53D0    -    0.004D0 * T
            W   =  137.88D0    +  598.3060000D0 * D
 
 
         ELSE IF ( BODY .EQ. 616 ) THEN
 
            A0  =   40.58D0    -    0.036D0 * T
            D0  =   83.53D0    -    0.004D0 * T
            W   =  296.14D0    +  587.289000D0 * D
 
 
         ELSE IF ( BODY .EQ. 617 ) THEN
 
            A0  =   40.58D0    -    0.036D0 * T
            D0  =   83.53D0    -    0.004D0 * T
            W   =  162.92D0    +  572.7891000D0 * D
 
 
         ELSE IF ( BODY .EQ. 618 ) THEN
 
            A0  =   40.6D0    -    0.036D0 * T
            D0  =   83.5D0    -    0.004D0 * T
            W   =   48.8D0    +  626.0440000D0 * D
 
         ELSE
 
            CALL SETMSG ( 'Body code # was not recognized.' )
            CALL ERRINT ( '#', BODY                         )
            CALL SIGERR ( 'SPICE(INVALIDBODYCODE)'          )
            CALL CHKOUT ( 'T_PCKEQ'                          )
            RETURN
 
         END IF
 
 
 
      ELSE IF ( BODY/100 .EQ. 7 ) THEN
 
 
         U1   =   (  115.75D0   +   54991.87D0 * T  ) * RPD()
         U2   =   (  141.69D0   +   41887.66D0 * T  ) * RPD()
         U3   =   (  135.03D0   +   29927.35D0 * T  ) * RPD()
         U4   =   (   61.77D0   +   25733.59D0 * T  ) * RPD()
         U5   =   (  249.32D0   +   24471.46D0 * T  ) * RPD()
         U6   =   (   43.86D0   +   22278.41D0 * T  ) * RPD()
         U7   =   (   77.66D0   +   20289.42D0 * T  ) * RPD()
         U8   =   (  157.36D0   +   16652.76D0 * T  ) * RPD()
         U9   =   (  101.81D0   +   12872.63D0 * T  ) * RPD()
         U10  =   (  138.64D0   +    8061.81D0 * T  ) * RPD()
         U11  =   (  102.23D0   -    2024.22D0 * T  ) * RPD()
         U12  =   (  316.41D0   +    2863.96D0 * T  ) * RPD()
         U13  =   (  304.01D0   -      51.94D0 * T  ) * RPD()
         U14  =   (  308.71D0   -      93.17D0 * T  ) * RPD()
         U15  =   (  340.82D0   -      75.32D0 * T  ) * RPD()
         U16  =   (  259.14D0   -     504.81D0 * T  ) * RPD()
 
 
 
 
         IF ( BODY .EQ. 701 ) THEN
 
 
            A0  =   257.43D0    +    0.29D0      * SIN(U13)
 
            D0  =   -15.10D0    +    0.28D0      * COS(U13)
 
            W   =   156.22D0    -  142.8356681D0 * D
     .                          +    0.05D0      * SIN(U12)
     .                          +    0.08D0      * SIN(U13)
 
 
         ELSE IF ( BODY .EQ. 702 ) THEN
 
 
            A0  =   257.43D0    +   0.21D0       * SIN(U14)
 
            D0  =   -15.10D0    +   0.20D0       * COS(U14)
 
            W   =   108.05D0    -  86.8688923D0  * D
     .                          -   0.09D0       * SIN(U12)
     .                          +   0.06D0       * SIN(U14)
 
 
         ELSE IF ( BODY .EQ. 703 ) THEN
 
 
            A0  =   257.43D0    +   0.29D0       * SIN(U15)
 
            D0  =   -15.10D0    +   0.28D0       * COS(U15)
 
            W   =    77.74D0    -  41.3514316D0  * D
     .                          +   0.08D0       * SIN(U15)
 
 
 
         ELSE IF ( BODY .EQ. 704 ) THEN
 
 
            A0  =   257.43D0    +   0.16D0       * SIN(U16)
 
            D0  =   -15.10D0    +   0.16D0       * COS(U16)
 
            W   =     6.77D0    -  26.7394932D0  * D
     .                          +   0.04D0       * SIN(U16)
 
 
         ELSE IF ( BODY .EQ. 705 ) THEN
 
            A0  =  257.43D0    +    4.41D0       * SIN(U11)
     .                         -    0.04D0       * SIN( 2.D0 * U11 )
 
            D0  =  -15.08D0    +    4.25D0       * COS(U11)
     .                         -    0.02D0       * COS( 2.D0 * U11 )
 
            W   =   30.70D0    -  254.6906892D0  * D
     .                         -    1.27D0       * SIN(U12)
     .                         +    0.15D0       * SIN( 2.D0 * U12 )
     .                         +    1.15D0       * SIN(U11)
     .                         -    0.09D0       * SIN( 2.D0 * U11 )
 
 
         ELSE IF ( BODY .EQ. 706 ) THEN
 
            A0  =   257.31D0    -    0.15D0      * SIN(U1)
 
            D0  =   -15.18D0    +    0.14D0      * COS(U1)
 
            W   =   127.69D0    -  1074.5205730D0 * D
     .                          -     0.04D0      * SIN(U1)
 
 
 
         ELSE IF ( BODY .EQ. 707 ) THEN
 
            A0  =   257.31D0    -   0.09D0      * SIN(U2)
 
            D0  =   -15.18D0    +   0.09D0      * COS(U2)
 
            W   =   130.35D0    - 956.4068150D0 * D
     .                          -   0.03D0      * SIN(U2)
 
 
 
         ELSE IF ( BODY .EQ. 708 ) THEN
 
            A0  =   257.31D0    -   0.16D0      * SIN(U3)
 
            D0  =   -15.18D0    +   0.16D0      * COS(U3)
 
            W   =   105.46D0    - 828.3914760D0 * D
     .                          -   0.04D0      * SIN(U3)
 
 
 
         ELSE IF ( BODY .EQ. 709 ) THEN
 
            A0  =   257.31D0    -   0.04D0      * SIN(U4)
 
            D0  =   -15.18D0    +   0.04D0      * COS(U4)
 
            W   =    59.16D0    - 776.5816320D0 * D
     .                          -   0.01D0      * SIN(U4)
 
 
 
         ELSE IF ( BODY .EQ. 710 ) THEN
 
            A0  =   257.31D0    -   0.17D0      * SIN(U5)
 
            D0  =   -15.18D0    +   0.16D0      * COS(U5)
 
            W   =    95.08D0    - 760.0531690D0 * D
     .                          -   0.04D0      * SIN(U5)
 
 
 
         ELSE IF ( BODY .EQ. 711 ) THEN
 
            A0  =   257.31D0    -   0.06D0      * SIN(U6)
 
            D0  =   -15.18D0    +   0.06D0      * COS(U6)
 
            W   =   302.56D0    - 730.1253660D0 * D
     .                          -   0.02D0      * SIN(U6)
 
 
 
         ELSE IF ( BODY .EQ. 712 ) THEN
 
            A0  =   257.31D0    -   0.09D0      * SIN(U7)
 
            D0  =   -15.18D0    +   0.09D0      * COS(U7)
 
            W   =    25.03D0    - 701.4865870D0 * D
     .                          -   0.02D0      * SIN(U7)
 
 
 
         ELSE IF ( BODY .EQ. 713 ) THEN
 
            A0  =   257.31D0    -   0.29D0      * SIN(U8)
 
            D0  =   -15.18D0    +   0.28D0      * COS(U8)
 
            W   =   314.90D0    - 644.6311260D0 * D
     .                          -   0.08D0      * SIN(U8)
 
 
 
         ELSE IF ( BODY .EQ. 714 ) THEN
 
            A0  =   257.31D0    -   0.03D0      * SIN(U9)
 
            D0  =   -15.18D0    +   0.03D0      * COS(U9)
 
            W   =   297.46D0    - 577.3628170D0 * D
     .                          -   0.01D0      * SIN(U9)
 
 
         ELSE IF ( BODY .EQ. 715 ) THEN
 
            A0  =   257.31D0    -   0.33D0      * SIN(U10)
 
            D0  =   -15.18D0    +   0.31D0      * COS(U10)
 
            W   =    91.24D0    - 472.5450690D0 * D
     .                          -   0.09D0      * SIN(U10)
 
 
         ELSE
 
            CALL SETMSG ( 'Body code # was not recognized.' )
            CALL ERRINT ( '#', BODY                         )
            CALL SIGERR ( 'SPICE(INVALIDBODYCODE)'          )
            CALL CHKOUT ( 'T_PCKEQ'                          )
            RETURN
 
         END IF
 
 
 
      ELSE IF ( BODY/100 .EQ. 8 ) THEN
 
 
         N     =   (  357.85D0   +      52.316D0 * T  ) * RPD()
         N1    =   (  323.92D0   +   62606.6D0   * T  ) * RPD()
         N2    =   (  220.51D0   +   55064.2D0   * T  ) * RPD()
         N3    =   (  354.27D0   +   46564.5D0   * T  ) * RPD()
         N4    =   (   75.31D0   +   26109.4D0   * T  ) * RPD()
         N5    =   (   35.36D0   +   14325.4D0   * T  ) * RPD()
         N6    =   (  142.61D0   +    2824.6D0   * T  ) * RPD()
         N7    =   (  177.85D0   +      52.316D0 * T  ) * RPD()
 
 
         IF ( BODY .EQ. 801 ) THEN
 
            A0  =   299.36D0    -    32.35D0 * SIN(N7)
     .                          -     6.28D0 * SIN( 2.D0 * N7 )
     .                          -     2.08D0 * SIN( 3.D0 * N7 )
     .                          -     0.74D0 * SIN( 4.D0 * N7 )
     .                          -     0.28D0 * SIN( 5.D0 * N7 )
     .                          -     0.11D0 * SIN( 6.D0 * N7 )
     .                          -     0.07D0 * SIN( 7.D0 * N7 )
     .                          -     0.02D0 * SIN( 8.D0 * N7 )
     .                          -     0.01D0 * SIN( 9.D0 * N7 )
 
            D0  =    41.17D0    +    22.55D0 * COS(N7)
     .                          +     2.10D0 * COS( 2.D0 * N7 )
     .                          +     0.55D0 * COS( 3.D0 * N7 )
     .                          +     0.16D0 * COS( 4.D0 * N7 )
     .                          +     0.05D0 * COS( 5.D0 * N7 )
     .                          +     0.02D0 * COS( 6.D0 * N7 )
     .                          +     0.01D0 * COS( 7.D0 * N7 )
 
 
            W   =   296.53D0    -    61.2572637D0  * D
     .                          +    22.25D0 * SIN(N7)
     .                          +     6.73D0 * SIN( 2.D0 * N7 )
     .                          +     2.05D0 * SIN( 3.D0 * N7 )
     .                          +     0.74D0 * SIN( 4.D0 * N7 )
     .                          +     0.28D0 * SIN( 5.D0 * N7 )
     .                          +     0.11D0 * SIN( 6.D0 * N7 )
     .                          +     0.05D0 * SIN( 7.D0 * N7 )
     .                          +     0.02D0 * SIN( 8.D0 * N7 )
     .                          +     0.01D0 * SIN( 9.D0 * N7 )
 
 
 
         ELSE IF ( BODY .EQ. 803 ) THEN
 
            A0  =   299.36D0    +     0.70D0 * SIN(N)
     .                          -     6.49D0 * SIN(N1)
     .                          +     0.25D0 * SIN( 2.D0 * N1 )
 
            D0  =    43.36D0    -     0.51D0 * COS(N)
     .                          -     4.75D0 * COS(N1)
     .                          +     0.09D0 * COS( 2.D0 * N1 )
 
            W   =   254.06D0    +  1222.8441209D0 * D
     .                          -     0.48D0 * SIN(N)
     .                          +     4.40D0 * SIN(N1)
     .                          -     0.27D0 * SIN( 2.D0 * N1 )
 
 
 
         ELSE IF ( BODY .EQ. 804 ) THEN
 
            A0  =   299.36D0    +     0.70D0 * SIN(N)
     .                          -     0.28D0 * SIN(N2)
 
            D0  =    43.45D0    -     0.51D0 * COS(N)
     .                          -     0.21D0 * COS(N2)
 
            W   =   102.06D0    +  1155.7555612D0 * D
     .                          -     0.48D0 * SIN(N)
     .                          +     0.19D0 * SIN(N2)
 
 
         ELSE IF ( BODY .EQ. 805 ) THEN
 
            A0  =   299.36D0    +     0.70D0 * SIN(N)
     .                          -     0.09D0 * SIN(N3)
 
            D0  =    43.45D0    -     0.51D0 * COS(N)
     .                          -     0.07D0 * COS(N3)
 
            W   =   306.51D0    +  1075.7341562D0 * D
     .                          -     0.49D0 * SIN(N)
     .                          +     0.06D0 * SIN(N3)
 
 
         ELSE IF ( BODY .EQ. 806 ) THEN
 
            A0  =   299.36D0    +     0.70D0 * SIN(N)
     .                          -     0.07D0 * SIN(N4)
 
            D0  =    43.43D0    -     0.51D0 * COS(N)
     .                          -     0.05D0 * COS(N4)
 
            W   =   258.09D0    +   839.6597686D0 * D
     .                          -     0.48D0 * SIN(N)
     .                          +     0.05D0 * SIN(N4)
 
 
 
         ELSE IF ( BODY .EQ. 807 ) THEN
 
            A0  =   299.36D0    +     0.70D0 * SIN(N)
     .                          -     0.27D0 * SIN(N5)
 
            D0  =    43.41D0    -     0.51D0 * COS(N)
     .                          -     0.20D0 * COS(N5)
 
            W   =   179.41D0    +   649.0534470D0 * D
     .                          -     0.48D0 * SIN(N)
     .                          +     0.19D0 * SIN(N5)
 
 
 
         ELSE IF ( BODY .EQ. 808 ) THEN
 
            A0  =   299.27D0    +     0.70D0 * SIN(N)
     .                          -     0.05D0 * SIN(N6)
 
            D0  =    42.91D0    -     0.51D0 * COS(N)
     .                          -     0.04D0 * COS(N6)
 
            W   =    93.38D0    +   320.7654228D0 * D
     .                          -     0.48D0 * SIN(N)
     .                          +     0.04D0 * SIN(N6)
 
 
 
 
         ELSE
 
            CALL SETMSG ( 'Body code # was not recognized.' )
            CALL ERRINT ( '#', BODY                         )
            CALL SIGERR ( 'SPICE(INVALIDBODYCODE)'          )
            CALL CHKOUT ( 'T_PCKEQ'                          )
            RETURN
 
         END IF
 
 
 
      ELSE IF ( BODY/100 .EQ. 9 ) THEN
 
 
        IF ( BODY .EQ. 901 ) THEN
 
            A0  =   313.02D0
 
            D0  =     9.09D0
 
            W   =    56.77D0    -     56.3623195D0 * D
 
 
 
         ELSE
 
            CALL SETMSG ( 'Body code # was not recognized.' )
            CALL ERRINT ( '#', BODY                         )
            CALL SIGERR ( 'SPICE(INVALIDBODYCODE)'          )
            CALL CHKOUT ( 'T_PCKEQ'                          )
            RETURN
 
         END IF
 
 
      ELSE IF ( BODY .EQ. 2431010 ) THEN
 
         A0  =   348.76D0

         D0  =    87.12D0

         W   =   265.95D0    -   1864.6280070D0 * D


      ELSE IF ( BODY .EQ. 9511010 ) THEN
 
         A0  =     9.47D0

         D0  =    26.70D0

         W   =    83.67D0    +   1226.9114850D0 * D


      ELSE IF ( BODY .EQ. 2000004 ) THEN
C
C        Vesta.
C        
         A0  =     301.D0

         D0  =      41.D0

          W  =     292.D0    +   1617.332776D0 * D


      ELSE IF ( BODY .EQ. 2000433 ) THEN
C
C        Eros.
C        
         A0  =      11.35D0

         D0  =      17.22D0

          W  =     326.07D0  +   1639.38864745D0 * D


      ELSE
 
         CALL SETMSG ( 'Body code # was not recognized.' )
         CALL ERRINT ( '#', BODY                         )
         CALL SIGERR ( 'SPICE(INVALIDBODYCODE)'          )
         CALL CHKOUT ( 'T_PCKEQ'                          )
         RETURN
 
 
      END IF
 
 
 
 
      RA   =  RPD() * A0
      DEC  =  RPD() * D0
      PM   =  RPD() * W
 
 
      CALL CHKOUT ( 'T_PCKEQ' )
      END
 
