C$Procedure TSETUP ( Command line loop )
C
      SUBROUTINE TSETUP (  LOGNAM, VERSN )
      IMPLICIT NONE
C
C$ Abstract
C
C     This routine handles the initializations needed for making use
C     of the SPICE testing utilities.
C
C$ Required_Reading
C
C     None.
C
C$ Keywords
C
C     INTERFACE
C
C$ Declarations

      CHARACTER*(*)         LOGNAM
      CHARACTER*(*)         VERSN

C$ Brief_I/O
C
C     Variable  I/O  Description
C     --------  ---  --------------------------------------------------
C     LOGNAM     I   Name pattern of file where commands will be logged
C     VERSN      I   Program name and version
C
C$ Detailed_Input
C
C     LOGNAM    is a pattern to use when creating the name of
C               a file to which all commands will be written.
C               This can be hard coded in the calling
C               program, or may be determined by a file naming
C               convention such as is provided by Christen
C               and NOMEN.
C
C     VERSN     is a string that may contain anything you would
C               like to appear as descriptive text in the first
C               line of the log file (and possibly in the greeting
C               presented by the program)  Something like
C               '<program name> --- Version X.Y' would be appropriate.
C               For example if your programs name is KINDLE and you
C               are at version 4.2.3 of your program a good value for
C               VERSN would be
C
C               'KINDLE --- Version 4.2.3'
C
C               Your greeting routine can make use of this when
C               displaying your program's greeting.  In this way
C               you can centralize the name and version number of
C               your program at a high level or in a subroutine and
C               simply make the information available to TSETUP so
C               that the automatic aspects of presenting this
C               information can be handled for you.
C
C
C
C$ Detailed_Output
C
C     None.
C
C$ Parameters
C
C     None.
C
C$ Exceptions
C
C     None.  This routine cannot detect any errors in its inputs
C     and all commands are regarded as legal input at this level.
C
C$ Files
C
C     The file specified by LOGFIL will be opened if possible
C     and all test results will then be stored in that file.
C
C     Other files may be used a run time by "STARTing" a command
C     sequence file. Or by some result of the activity of the
C     user supplied routines ACTION, GREET, PREPRC.
C
C$ Particulars
C
C     This routine preforms the initializations needed for using
C     the NAIF test utilities.  It should be called once in your
C     test program.
C
C$ Examples
C
C     None.
C
C$ Restrictions
C
C     None.
C
C$ Literature_References
C
C     None.
C
C$ Author_and_Institution
C
C     W.L. Taber    (JPL)
C
C$ Version
C
C      Test Utilities Version 1.3.0, 9-MAY-2002 (EDW)
C
C         Added capability to read command line options from
C         a text kernel. tspice checks for the existence of
C         the kerel "tspice.ker" if present, and if no arguments
C         supplied on the command line, tspice reads the
C         COMMAND_LINE string variable from the kernel then uses
C         that string as the command line.
C     
C-     Test Utilities Version 1.2.0, 24-APR-2002 (EDW)
C
C         Added the quiet mode, activated from the command line
C         by the '-Q' argument. The mode prevents output to the
C         standard device, i.e. the screen. Modifications made to
C         tstio.f.
C
C         Moved command line parse code to a position so it executes
C         prior to logging functions.
C     
C-     Test Utilities Version 1.1.0, 27-JUL-1999 (WLT)
C
C         Added initialization for automatic checks of SPICE
C         exception handling.  Added "DEBUGGING" mode to Test Utilites.
C
C-     Test Utilities Version 1.0.0,  3-NOV-1994 (WLT)
C
C-&
C
C     Test Utility Functions
C
      LOGICAL               VERBON
      LOGICAL               SETOFF
      LOGICAL               SETON

      LOGICAL               EXISTS

C
C     Local Variables
C
      INTEGER               STYSIZ
      PARAMETER           ( STYSIZ = 128 )


      CHARACTER*(STYSIZ)    SSTYLE
      CHARACTER*(STYSIZ)    LSTYLE
      CHARACTER*(STYSIZ)    VSTYLE
      CHARACTER*(STYSIZ)    HSTYLE

      INTEGER               LNSIZE
      PARAMETER           ( LNSIZE = 80 )

      CHARACTER*(LNSIZE)    CMLINE

      INTEGER               WDSIZE
      PARAMETER           ( WDSIZE = 32 )

      INTEGER                START
      INTEGER                N
      INTEGER                ROOM

      CHARACTER*(WDSIZE)    WORD
      CHARACTER*(LNSIZE)    CVALS(1)
      CHARACTER*(32)        VARNAM

      LOGICAL               ON
      LOGICAL               DUMMY
      LOGICAL               FOUND

      SAVE



C
C     The following styles are for reporting errors to the
C     screen and log file respectively.
C
      SSTYLE = 'HARDSPACE ^ NEWLINE /cr '
     .//       'VTAB /vt FLAG Failure: '

      LSTYLE = 'HARDSPACE ^ NEWLINE /cr '
     .//       'VTAB /vt FLAG Failure: '
     .//       'LEADER -- '
     .//       'LEFT 1 RIGHT 72 '


C
C     Set the exception handling status to OFF and set the debugging
C     status to OFF.
C
      DUMMY = SETOFF ( 'CHCKXC' )
      DUMMY = SETOFF ( 'DEBUGGING' )

C
C     The following styles will be used for logging of
C     commands and for commenting them out.
C
      VSTYLE = 'LEFT 1 RIGHT 78 '
      HSTYLE = 'LEFT 1 RIGHT 78 LEADER -- FLAG -- '

      CALL TSTLGS ( VSTYLE, HSTYLE )

C
C     Check for the existence of the tspice command kernel.
C     If found, use the string for command arguments.
C
      CALL GETCML ( CMLINE )

      IF ( EXISTS( 'tspice.ker' ) .AND. (CMLINE .EQ. ' ') ) THEN

         CALL FURNSH ( 'tspice.ker' )

         VARNAM = 'COMMAND_LINE'
         START  = 1
         ROOM   = 1

         CALL GCPOOL ( VARNAM, START, ROOM, N, CVALS, FOUND )

         IF ( FOUND ) THEN
            CMLINE = CVALS(1)
         END IF

C
C        Unload the tspice command kernel and clear the kernel
C        pool. Failure to do so leaves the kernel pool in a
C        non-pristine state before testing begins. tspice
C        expects an empty pool.         
C
         
         CALL CLPOOL()
         CALL UNLOAD( 'tspice.ker' )

      END IF

      DO WHILE ( CMLINE .NE. ' ' )

         CALL NEXTWD ( CMLINE, WORD, CMLINE )
         CALL UCASE  ( WORD,   WORD         )

         IF ( WORD .EQ. '-V' ) THEN

            ON = VERBON()

         ELSE IF ( WORD .EQ. '-C' ) THEN

            CALL TSTLCY

         ELSE IF ( WORD .EQ. '-D' ) THEN
C
C           We want to run in debugging mode.  This means
C           files are not automatically deleted when a new
C           test family is initiated.
C
            ON = SETON ( 'DEBUGGING' )

         END IF

C
C        Check for quiet mode; supress all output to the
C        standard IO device.
C
         IF ( WORD .EQ. '-Q' ) THEN

            CALL LCKOUT ( 'SCREEN' )

         END IF

      END DO

C
C     Open a log file.
C
      CALL TSTOPL ( LOGNAM, VERSN )

C
C     Now, set up the SPICELIB error handling.
C
      CALL ERRACT ( 'SET', 'RETURN' )
      CALL ERRDEV ( 'SET', 'NULL'   )


      RETURN
      END

