C$Procedure      F_BADKPV (Family of tests for BADKPV )
 
      SUBROUTINE F_BADKPV ( OK )
      IMPLICIT NONE
 
      LOGICAL               OK
 
C$ Abstract
C
C     This routine checks all of the various tests possible
C     in the routine BADKPV.
C
C-&
 
 
C
C     Test Utility Functions
C
      CHARACTER*(32)        BEGDAT
      CHARACTER*(32)        BEGTXT
 
C
C     SPICELIB Functions
C
      LOGICAL               BADKPV
 
C
C     Local Variables
C
      INTEGER               LNSIZE
      PARAMETER           ( LNSIZE = 80 )
 
      INTEGER               NLINES
      PARAMETER           ( NLINES = 6 )
 
      CHARACTER*(LNSIZE)    LINES ( NLINES )
 
      LOGICAL               LNUM
      LOGICAL               LSTR
 
C
C     Begin every test family with an open call.
C
      CALL TOPEN ( 'F_BADKPV' )
 
      LINES(  1 ) = BEGTXT()
      LINES(  2 ) = 'This text kernel is for test purposes on'
     .//            'ly.  It serves no'
      LINES(  3 ) = 'other purpose'
      LINES(  4 ) = BEGDAT()
      LINES(  5 ) = 'NUM = ( 1, 2, 3, 4, 5 )'
      LINES(  6 ) = 'STR = ( ''This'', ''is'', ''a'', ''strin'
     .//            'g'', ''of'', ''words.'' )'
 
      CALL KILFIL ( 'sample.txt' )
      CALL TSTTXT ( 'sample.txt', LINES, 6, .TRUE., .TRUE. )
 
      LNUM = .FALSE.
      LSTR = .FALSE.
 
 
      CALL TCASE ( 'Make sure an error is signalled when a '
     .//           'character variable has integer values. ' )
 
 
         LNUM = BADKPV ( 'TEST', 'NUM', '=', 5, 1, 'C' )
 
         CALL CHCKXC ( .TRUE., 'SPICE(BADVARIABLETYPE)',  OK )
         CALL CHCKSL ( 'LNUM',  LNUM, .TRUE.,             OK )
         LNUM = .FALSE.
         LSTR = .FALSE.
 
      CALL TCASE ( 'Make sure an error is signalled when an '
     .//           'numeric variable has character values ' )
 
         LSTR = BADKPV ( 'TEST', 'STR', '=', 6, 1, 'N' )
 
         CALL CHCKXC ( .TRUE., 'SPICE(BADVARIABLETYPE)',  OK )
         CALL CHCKSL ( 'LSTR',  LSTR, .TRUE.,             OK )
         LNUM = .FALSE.
         LSTR = .FALSE.
 
 
 
      CALL TCASE ( 'Make sure an error is signalled when a '
     .//           'variable has a dimension that is not the '
     .//           'exact expected value ')
 
         LNUM = BADKPV ( 'TEST', 'NUM', '=', 6, 1, 'N' )
 
         CALL CHCKXC ( .TRUE., 'SPICE(BADVARIABLESIZE)',  OK )
         CALL CHCKSL ( 'LNUM',  LNUM,         .TRUE.,     OK )
         LNUM = .FALSE.
         LSTR = .FALSE.
 
 
 
      CALL TCASE ( 'Make sure an error is signalled when a '
     .//           'variable has a dimension that is not more '
     .//           'than an expected value. ' )
 
         LNUM = BADKPV ( 'TEST', 'NUM', '>', 5, 1, 'N' )
 
         CALL CHCKXC ( .TRUE., 'SPICE(BADVARIABLESIZE)',  OK )
         CALL CHCKSL ( 'LNUM', LNUM,          .TRUE.,     OK )
         LNUM = .FALSE.
         LSTR = .FALSE.
 
 
      CALL TCASE ( 'Make sure an error is signalled '
     .//           'when a variable has a dimension that is not '
     .//           'at least an expected value. ' )
 
         LSTR = BADKPV ( 'TEST', 'STR', '=>', 7, 1, 'C' )
 
         CALL CHCKXC ( .TRUE., 'SPICE(BADVARIABLESIZE)',  OK )
         CALL CHCKSL ( 'LSTR',  LSTR, .TRUE.,             OK )
         LNUM = .FALSE.
         LSTR = .FALSE.
 
 
      CALL TCASE ( 'Make sure an error is signalled when a '
     .//           'variable has a dimension that is not at most '
     .//           'an expected value. ' )
 
         LNUM = BADKPV ( 'TEST', 'NUM', '<=', 4, 1, 'N' )
 
         CALL CHCKXC ( .TRUE., 'SPICE(BADVARIABLESIZE)',  OK )
         CALL CHCKSL ( 'LNUM',  LNUM,         .TRUE.,     OK )
         LNUM = .FALSE.
         LSTR = .FALSE.
 
 
      CALL TCASE ( 'Make sure an error is signalled '
     .//           'when a variable has a dimension that is not '
     .//           'less than some expected value. ' )
 
         LSTR = BADKPV ( 'TEST', 'STR', '<', 6, 1, 'C' )
 
         CALL CHCKXC ( .TRUE., 'SPICE(BADVARIABLESIZE)',  OK )
         CALL CHCKSL ( 'LSTR',  LSTR, .TRUE.,             OK )
         LNUM = .FALSE.
         LSTR = .FALSE.
 
 
      CALL TCASE ( 'Make sure an error is signalled '
     .//           'when the dimension of a variable is not '
     .//           'divisible by the prescribed value. ' )
 
         LSTR = BADKPV ( 'TEST', 'STR', '=', 6, 4, 'C' )
 
         CALL CHCKXC ( .TRUE., 'SPICE(BADVARIABLESIZE)',  OK )
         CALL CHCKSL ( 'LSTR',  LSTR,         .TRUE.,     OK )
         LNUM = .FALSE.
         LSTR = .FALSE.
 
 
      CALL TCASE ( 'Make sure an error is signalled '
     .//           'when a variable is not found in the kernel '
     .//           'pool. ' )
 
         LNUM = BADKPV ( 'TEST', 'SPK', '=', 1, 1, 'N' )
 
         CALL CHCKXC ( .TRUE., 'SPICE(VARIABLENOTFOUND)',  OK )
         CALL CHCKSL ( 'LNUM',  LNUM,         .TRUE.,     OK )
 
         LNUM = .FALSE.
         LSTR = .FALSE.
 
      CALL TCASE ( 'Make sure an error is signalled '
     .//           'when the comparison operator is not '
     .//           'recognized. ' )
 
         LNUM = BADKPV ( 'TEST', 'NUM', '?', 5, 1, 'N' )
 
         CALL CHCKXC ( .TRUE., 'SPICE(UNKNOWNCOMPARE)',  OK )
         CALL CHCKSL ( 'LNUM',  LNUM,         .TRUE.,    OK )
         LNUM = .FALSE.
         LSTR = .FALSE.
 
 
 
 
      CALL TCASE ( 'Make sure the ''='' operator behaves as '
     .//           'expected ' )
 
 
 
         LSTR = BADKPV ( 'TEST', 'STR', '=', 6, 2, 'C' )
         LNUM = BADKPV ( 'TEST', 'NUM', '=', 5, 5, 'N' )
 
         CALL CHCKXC ( .FALSE., ' ',  OK )
         CALL CHCKSL ( 'LNUM', LNUM, .FALSE.,  OK )
         CALL CHCKSL ( 'LSTR', LSTR, .FALSE.,  OK )
         LNUM = .TRUE.
         LSTR = .TRUE.
 
      CALL TCASE ( 'Make sure the ''>'' operator behaves as '
     .//           'expected ' )
 
 
         LSTR = BADKPV ( 'TEST', 'STR', '>', 4, 2, 'C' )
         LNUM = BADKPV ( 'TEST', 'NUM', '>', 4, 5, 'N' )
 
         CALL CHCKXC ( .FALSE., ' ',  OK )
         CALL CHCKSL ( 'LNUM', LNUM, .FALSE.,  OK )
         CALL CHCKSL ( 'LSTR', LSTR, .FALSE.,  OK )
         LNUM = .TRUE.
         LSTR = .TRUE.
 
      CALL TCASE ( 'Make sure the ''=>'' operator behaves as '
     .//           'expected ' )
 
 
 
         LSTR = BADKPV ( 'TEST', 'STR', '=>', 6, 2, 'C' )
         LNUM = BADKPV ( 'TEST', 'NUM', '=>', 5, 5, 'N' )
 
         CALL CHCKXC ( .FALSE., ' ',  OK )
         CALL CHCKSL ( 'LNUM', LNUM, .FALSE.,  OK )
         CALL CHCKSL ( 'LSTR', LSTR, .FALSE.,  OK )
         LNUM = .TRUE.
         LSTR = .TRUE.
 
      CALL TCASE ( 'Make sure the ''<'' operator behaves as '
     .//           'expected ' )
 
 
         LSTR = BADKPV ( 'TEST', 'STR', '<', 7, 2, 'C' )
         LNUM = BADKPV ( 'TEST', 'NUM', '<', 6, 5, 'N' )
 
         CALL CHCKXC ( .FALSE., ' ',  OK )
         CALL CHCKSL ( 'LNUM', LNUM, .FALSE.,  OK )
         CALL CHCKSL ( 'LSTR', LSTR, .FALSE.,  OK )
         LNUM = .TRUE.
         LSTR = .TRUE.
 
      CALL TCASE ( 'Make sure the ''<='' operator behaves as '
     .//           'expected ' )
 
 
         LSTR = BADKPV ( 'TEST', 'STR', '<=', 6, 2, 'C' )
         LNUM = BADKPV ( 'TEST', 'NUM', '<=', 5, 5, 'N' )
 
         CALL CHCKXC ( .FALSE., ' ',  OK )
         CALL CHCKSL ( 'LNUM', LNUM, .FALSE.,  OK )
         CALL CHCKSL ( 'LSTR', LSTR, .FALSE.,  OK )
         LNUM = .TRUE.
         LSTR = .TRUE.
 
      CALL KILFIL ( 'sample.txt' )
      CALL T_SUCCESS ( OK )
      RETURN
      END
