C$Procedure      F_CK05 ( CK type 5 tests )
 
      SUBROUTINE F_CK05 ( OK )
      IMPLICIT NONE
 
      LOGICAL               OK

      INCLUDE 'ck05.inc'
 
C$ Abstract
C
C     This routine tests the SPICELIB CK type 5 routines.
C     This is rudimentary set of tests to make sure the routines
C     cycle in every environment; thorough tests are performed
C     in the tspice_c test package.
C
C$ Version
C
C-    SPICELIB Version 1.0.0, 06-SEP-2002 (NJB)
C
C-&
 
 
C
C     Test Utility Functions
C
 
 
C
C     SPICELIB Functions
C     
      LOGICAL               EXISTS
 
C
C     Local Parameters
C
      CHARACTER*(*)         CK05
      PARAMETER           ( CK05   = 'ck05_test.bc' )

      CHARACTER*(*)         REF
      PARAMETER           ( REF    = 'J2000' )


      INTEGER               MAXDEG
      PARAMETER           ( MAXDEG = 15 )

      INTEGER               BIGN
      PARAMETER           ( BIGN   = 200 )

      INTEGER               SIDLEN
      PARAMETER           ( SIDLEN = 40 )


      DOUBLE PRECISION      TIGHT
      PARAMETER           ( TIGHT  = 1.D-14 )

      DOUBLE PRECISION      MEDIUM
      PARAMETER           ( MEDIUM = 1.D-12 )
      
      
C
C     Local Variables
C      
      CHARACTER*(SIDLEN)    SEGID
      
      DOUBLE PRECISION      ANGLE
      DOUBLE PRECISION      AV     ( 3 )
      DOUBLE PRECISION      CLKOUT
      DOUBLE PRECISION      CMAT   ( 3, 3 )
      DOUBLE PRECISION      EPOCHS ( 0 : BIGN-1 )
      DOUBLE PRECISION      Q      ( 0 : 3 )
      DOUBLE PRECISION      RATE
      DOUBLE PRECISION      SCALE
      DOUBLE PRECISION      T1PACK ( C05PS1, 0 : BIGN-1 )
      DOUBLE PRECISION      TOL
      DOUBLE PRECISION      Z      ( 3 )

      INTEGER               DEGREE
      INTEGER               HANDLE
      INTEGER               I
      INTEGER               INST

      LOGICAL               AVFLAG
      LOGICAL               FOUND

C
C     Saved variables
C     
      SAVE                  Z

C
C     Initial values
C
      DATA                  Z / 0.D0, 0.D0, 1.D0 /


C
C     Begin every test family with an open call.
C
      CALL TOPEN ( 'F_CK05' )

C
C     Create and load  leapseconds kernel.
C
      CALL TSTLSK
      CALL CHCKXC ( .FALSE., ' ', OK )

C
C     Define some CK data sets for use in testing.  First set:  a 
C     sequence of rotations about the z-axis.  The C-matrix starts
C     out as the identity.  The ith attitude is obtained by 
C     rotating about the z-axis by i microradians relative to the 
C     (i-1)st attitude.
C
C     The ith epoch is simply i.
C

      ANGLE = 0.D0
      SCALE = 1.D-9

      DO I = 0, BIGN-1

         ANGLE = ANGLE - I * SCALE

         CALL AXISAR ( Z, ANGLE, CMAT )

         CALL M2Q ( CMAT, T1PACK(1,I) )

         EPOCHS(I) =  DBLE(I)

      END DO

      CALL TCASE (  'CKW05 test:  create a new CK containing '//
     .              'segment of subtype 1.'                    )
 

      AVFLAG = .TRUE.
      RATE   = 1000.D0
      SEGID  = 'CK type 05 test segment.'
      INST   = 1
      DEGREE = 11

C
C     Open a new CK file.
C
      IF ( EXISTS(CK05) ) THEN
         CALL DELFIL ( CK05 )
      END IF

      CALL CKOPN ( CK05, ' ', 0, HANDLE )

      CALL CHCKXC ( .FALSE., ' ', OK )


      CALL CKW05 ( HANDLE, C05TP1, DEGREE, EPOCHS(0), EPOCHS(BIGN-1),
     .             INST,   REF,    AVFLAG, SEGID,     BIGN,
     .             EPOCHS, T1PACK, RATE,   1,         EPOCHS        )

      CALL CHCKXC ( .FALSE., ' ', OK )

      CALL CKCLS ( HANDLE )



      CALL TCASE ( 'Recover pointing from segment of subtype 1 in '//
     .             'CK file CK05'                                  )
  
C
C     Now we'll use the CK user-level readers to look up pointing. 
C   
      CALL FURNSH ( CK05 )
      CALL CHCKXC ( .FALSE., ' ', OK )


      TOL = 0.D0

      DO I = 0, BIGN - 1

         CALL CKGPAV ( INST,   EPOCHS(I), TOL, REF, CMAT, AV, 
     .                 CLKOUT, FOUND                          )

         CALL CHCKXC ( .FALSE., ' ', OK )

         CALL CHCKSL ( 'FOUND', FOUND, .TRUE., OK )

         IF ( FOUND ) THEN

            CALL CHCKSD ( 'CLKOUT',   CLKOUT, '~', 
     ,                     EPOCHS(I), TIGHT,   OK )

            CALL M2Q ( CMAT, Q )
            CALL CHCKXC ( .FALSE., ' ', OK )
      
            CALL CHCKAD ( 'Q', Q, '~', T1PACK(1,I), 4, TIGHT, OK )

         END IF


      END DO

      CALL UNLOAD ( CK05 )

      IF ( EXISTS(CK05) ) THEN
         CALL DELFIL ( CK05 )
      END IF


      CALL T_SUCCESS ( OK )
      RETURN
      END
