C$Procedure      F_CKFXFM ( Family Test of  CKFXFM )
 
      SUBROUTINE F_CKFXFM ( OK )
      IMPLICIT NONE
 
      LOGICAL               OK
 
C$ Abstract
C
C     Test the routine CKFXFM.  There are several test cases. The first
C     few make sure that nothing is found if an instrument is not
C     loaded.  Another to make sure the correct frame is located
C     when the instrument is loaded.
C
C$ Version
C
C-    SPICELIB Version 2.0.0, 14-MAR-2000 (WLT)
C
C        Added three test cases to make sure that the case when no
C        C-kernel is loaded is dealt with correctly as well as
C        the case when no SCLK kernel is loaded.
C
C-    SPICELIB Version 1.0.0, 06-OCT-1999 (WLT)
C
C-&
 
 
C-&
 
 
C
C     Test Utility Functions
C
 
 
C
C     SPICELIB Functions
C
 
C
C     Local Variables
C
 
      INTEGER               LNSIZE
      PARAMETER           ( LNSIZE = 80 )
 
      CHARACTER*(LNSIZE)    ERROR
 
      DOUBLE PRECISION      AV    ( 3    )
      DOUBLE PRECISION      ET
      DOUBLE PRECISION      ROT   ( 3, 3 )
      DOUBLE PRECISION      TMPXFM( 6, 6 )
      DOUBLE PRECISION      XFORM ( 6, 6 )
      DOUBLE PRECISION      XFORM2( 6, 6 )
 
 
      INTEGER               EFRAME
      INTEGER               FRAME
      INTEGER               HANDLE
 
      LOGICAL               FOUND
 
C
C     Begin every test family with an open call.
C
      CALL TOPEN ( 'F_CKFXFM' )
 
      CALL KILFIL ( 'TEST.CK'   )
      CALL KILFIL ( 'TEST.SCLK' )
 
      CALL TCASE ( 'Make sure nothing is found if we don''t have '
     .//           'a C-kernel loaded or SLCK kernel loaded. ' )
 
         CALL TPARSE ( '1-JAN-1990',     ET,    ERROR )
         CALL CKFXFM ( -9998, ET, XFORM, FRAME, FOUND )
 
         CALL CHCKXC ( .FALSE., ' ',            OK )
         CALL CHCKSL ( 'FOUND', FOUND, .FALSE., OK )
 
 
      CALL TCASE ( 'Make sure nothing is even if we don''t have '
     .//           'a C-kernel loaded or SLCK kernel loaded. ' )
 
         CALL TSTCK3 ( 'TEST.CK', 'TEST.SCLK', .FALSE., .TRUE.,
     .                                         .TRUE.,   HANDLE  )
 
         CALL TPARSE ( '1-JAN-1990',     ET,    ERROR )
         CALL CKFXFM ( -9998, ET, XFORM, FRAME, FOUND )
 
         CALL CHCKXC ( .FALSE., ' ',            OK )
         CALL CHCKSL ( 'FOUND', FOUND, .FALSE., OK )
 
 
      CALL TCASE ( 'Make sure nothing is found if we don''t have '
     .//           'an instrument in the C-kernel. ' )
 
C
C        Create and load a test C-kernel.
C
         CALL CKLPF  ( 'TEST.CK',  HANDLE )
 
         CALL TPARSE ( '1-JAN-1990',     ET,    ERROR )
         CALL CKFXFM ( -9998, ET, XFORM, FRAME, FOUND )
 
         CALL CHCKXC ( .FALSE., ' ',            OK )
         CALL CHCKSL ( 'FOUND', FOUND, .FALSE., OK )
 
 
      CALL TCASE ( 'Make sure that when data is available, that '
     .//           'a frame transformation if found and that it '
     .//           'has the correct value. ' )
 
 
         CALL CKFXFM ( -9999, ET, XFORM, FRAME, FOUND  )
         CALL TSTATD (        ET, ROT,   AV            )
 
         CALL RAV2XF ( ROT,  AV,  TMPXFM              )
         CALL INVSTM ( TMPXFM,    XFORM2              )
 
         CALL NAMFRM ( 'GALACTIC', EFRAME              )
 
         CALL CHCKXC ( .FALSE.,               ' ',                OK )
         CALL CHCKSL ( 'FOUND', FOUND,        .TRUE.,             OK )
         CALL CHCKSI ( 'FRAME', FRAME, '=',   EFRAME,    0,       OK )
         CALL CHCKAD ( 'XFORM', XFORM, '||',  XFORM2, 9, 1.0D-14, OK )
         CALL CHCKAD ( 'XFORM', XFORM, '~~/', XFORM2, 9, 1.0D-14, OK )
 
 
      CALL TCASE ( 'Check to make sure CKMETA is propery used '
     .//           'and that we get the expected frame '
     .//           'transformation. (Object -10000)' )
 
 
 
         CALL CKFXFM ( -10000, ET, XFORM, FRAME, FOUND  )
         CALL TSTATD (         ET, ROT,   AV            )
         CALL RAV2XF ( ROT,  AV,  TMPXFM              )
         CALL INVSTM ( TMPXFM,    XFORM2              )
 
         CALL NAMFRM ( 'FK4', EFRAME              )
 
         CALL CHCKXC ( .FALSE.,               ' ',                OK )
         CALL CHCKSL ( 'FOUND', FOUND,        .TRUE.,             OK )
         CALL CHCKSI ( 'FRAME', FRAME, '=',   EFRAME,    0,       OK )
         CALL CHCKAD ( 'XFORM', XFORM, '||',  XFORM2, 9, 1.0D-14, OK )
         CALL CHCKAD ( 'XFORM', XFORM, '~~/', XFORM2, 9, 1.0D-14, OK )
 
 
      CALL TCASE ( 'Same test for object -10001' )
 
 
         CALL CKFXFM ( -10001, ET, XFORM, FRAME, FOUND  )
         CALL TSTATD (         ET, ROT,   AV            )
 
         CALL RAV2XF ( ROT,  AV,  TMPXFM              )
         CALL INVSTM ( TMPXFM,    XFORM2              )
 
         CALL NAMFRM ( 'J2000', EFRAME              )
 
         CALL CHCKXC ( .FALSE.,               ' ',                OK )
         CALL CHCKSL ( 'FOUND', FOUND,        .TRUE.,             OK )
         CALL CHCKSI ( 'FRAME', FRAME, '=',   EFRAME,    0,       OK )
         CALL CHCKAD ( 'XFORM', XFORM, '||',  XFORM2, 9, 1.0D-14, OK )
         CALL CHCKAD ( 'XFORM', XFORM, '~~/', XFORM2, 9, 1.0D-14, OK )
 
 
      CALL TCASE ( 'Perform the same test as before, but clear '
     .//           'the kernel pool first. We should not find a '
     .//           'transformation now, because there is no SCLK '
     .//           'data available. ' )
 
 
         CALL CLPOOL ( )
 
         CALL TPARSE ( '1-JAN-1990',     ET,    ERROR )
         CALL CKFXFM ( -10001, ET, XFORM, FRAME, FOUND  )
 
         CALL CHCKXC ( .FALSE., ' ',            OK )
         CALL CHCKSL ( 'FOUND', FOUND, .FALSE., OK )
 
 
 
      CALL CKUPF  (  HANDLE     )
      CALL KILFIL ( 'TEST.CK'   )
      CALL KILFIL ( 'TEST.SCLK' )
 
      CALL T_SUCCESS ( OK )
      RETURN
      END
