C$Procedure      F_CKMETA (Family of CKMETA tests)
 
      SUBROUTINE F_CKMETA ( OK )
      IMPLICIT NONE
 
      LOGICAL               OK
 
C$ Abstract
C
C     This routine tests the routine CKMETA.
C
C     It first checks out all listed exceptions.  It then
C     loads
C
C-&
 
 
C
C     Test Utility Functions
C
      CHARACTER*(16)        BEGDAT
 
C
C     SPICELIB Functions
C
 
 
C
C     Local Variables
C
      INTEGER               IDCODE
      INTEGER               SCLKID
      INTEGER               SPKID
      INTEGER               SUNIT
 
 
 
C
C     Begin every test family with an open call.
C
      CALL TOPEN ( 'F_CKMETA' )
 
 
      CALL TCASE ( 'Check to make sure that a META item other '
     .//           'than  SPK or SCLK cause an error to be '
     .//           'signalled. ' )
C
C        Give IDCODE and initial value other than 0.
C
         IDCODE = 1
 
         CALL CKMETA ( -10000, 'IK', IDCODE )
 
         CALL CHCKXC ( .TRUE., 'SPICE(UNKNOWNCKMETA)',  OK )
         CALL CHCKSI ( 'IDCODE', IDCODE, '=', 0, 0,     OK )
 
      CALL TCASE ( 'Check that values of CKID greater than -1000 '
     .//           'cause an idcode of 0 to be returned for both '
     .//           'SCLK and SPK. ' )
 
         SPKID  = 1
         SCLKID = 1
         CALL CKMETA ( -900, 'SPK',  SPKID  )
         CALL CKMETA ( -900, 'SCLK', SCLKID )
 
         CALL CHCKXC ( .FALSE., ' ',  OK )
         CALL CHCKSI ( 'SPKID',  SPKID,  '=', 0, 0, OK )
         CALL CHCKSI ( 'SCLKID', SCLKID, '=', 0, 0, OK )
 
      CALL TCASE ( 'No kernel pool values are stored yet.  Make '
     .//           'sure that CKID''s less than -1000 return the '
     .//           'correct values. ' )
 
 
         CALL CKMETA ( -10100, 'SPK',  SPKID  )
         CALL CKMETA ( -10101, 'SCLK', SCLKID )
 
         CALL CHCKXC ( .FALSE., ' ',  OK )
         CALL CHCKSI ( 'SPKID',  SPKID,  '=', -10, 0, OK )
         CALL CHCKSI ( 'SCLKID', SCLKID, '=', -10, 0, OK )
 
         CALL CKMETA ( -900000, 'SPK',  SPKID  )
         CALL CKMETA ( -990000, 'SCLK', SCLKID )
 
         CALL CHCKXC ( .FALSE., ' ',  OK )
         CALL CHCKSI ( 'SPKID',  SPKID,  '=', -900, 0, OK )
         CALL CHCKSI ( 'SCLKID', SCLKID, '=', -990, 0, OK )
 
      CALL TCASE ( 'Load the kernel pool with associated SPK and '
     .//           'SCLK values. Make sure that we can retrieve '
     .//           'them. ' )
 
         CALL KILFIL ( 'myconns.ker' )
         CALL TXTOPN ( 'myconns.ker', SUNIT )
 
         WRITE (SUNIT,*) BEGDAT()
 
         WRITE (SUNIT,*) 'CK_-1001_SPK   = -12 '
         WRITE (SUNIT,*) 'CK_-1001_SCLK  = 13 '
         WRITE (SUNIT,*) 'CK_-10000_SPK  = -20 '
         WRITE (SUNIT,*) 'CK_-10000_SCLK = 20 '
         WRITE (SUNIT,*) 'CK_-900_SPK    = -9 '
         WRITE (SUNIT,*) 'CK_-900_SCLK   = 11 '
         WRITE (SUNIT,*) ' '
         CLOSE (SUNIT  )
 
         CALL LDPOOL ( 'myconns.ker' )
         CALL KILFIL ( 'myconns.ker' )
 
         CALL CKMETA ( -1001, 'SPK',  SPKID  )
         CALL CKMETA ( -1001, 'SCLK', SCLKID )
 
         CALL CHCKXC ( .FALSE., ' ',  OK )
         CALL CHCKSI ( 'SPKID',  SPKID,  '=', -12, 0, OK )
         CALL CHCKSI ( 'SCLKID', SCLKID, '=',  13, 0, OK )
 
         CALL CKMETA ( -10000, 'SPK',  SPKID  )
         CALL CKMETA ( -10000, 'SCLK', SCLKID )
 
         CALL CHCKXC ( .FALSE., ' ',  OK )
         CALL CHCKSI ( 'SPKID',  SPKID,  '=', -20, 0, OK )
         CALL CHCKSI ( 'SCLKID', SCLKID, '=',  20, 0, OK )
 
         CALL CKMETA ( -900, 'SPK',  SPKID  )
         CALL CKMETA ( -900, 'SCLK', SCLKID )
 
         CALL CHCKXC ( .FALSE., ' ',  OK )
         CALL CHCKSI ( 'SPKID',  SPKID,  '=',  -9, 0, OK )
         CALL CHCKSI ( 'SCLKID', SCLKID, '=',  11, 0, OK )
 
 
      CALL TCASE ( 'Kernel pool values are stored.  Make '
     .//           'sure that CKID''s less than -1000 return the '
     .//           'correct values if they aren''t in the pool.' )
 
 
         CALL CKMETA ( -10100, 'SPK',  SPKID  )
         CALL CKMETA ( -10101, 'SCLK', SCLKID )
 
         CALL CHCKXC ( .FALSE., ' ',  OK )
         CALL CHCKSI ( 'SPKID',  SPKID,  '=', -10, 0, OK )
         CALL CHCKSI ( 'SCLKID', SCLKID, '=', -10, 0, OK )
 
         CALL CKMETA ( -900000, 'SPK',  SPKID  )
         CALL CKMETA ( -990000, 'SCLK', SCLKID )
 
         CALL CHCKXC ( .FALSE., ' ',  OK )
         CALL CHCKSI ( 'SPKID',  SPKID,  '=', -900, 0, OK )
         CALL CHCKSI ( 'SCLKID', SCLKID, '=', -990, 0, OK )
 
 
 
      CALL T_SUCCESS ( OK )
      RETURN
      END
