C$Procedure      F_CKW03 (Family of checks for CKW03)
 
      SUBROUTINE F_CKW03 ( OK )
      IMPLICIT NONE
 
      LOGICAL               OK
 
C$ Abstract
C
C     This family of tests checks that the exceptions for non-unit
C     quaternions work and that unit quaternions do indeed get written
C     to a file.
C
C$ Version
C
C-    SPICELIB Version 1.1.0, 15-FEB-2001 (EDW)
C
C     Altered Test Case 2 to use an error tolerance of 1.D-14 instead of
C     an exact equality. That test failed due to roundoff error (on the
C     order of 1.D-16) when compiled under the Macintosh Absoft FORTRAN
C     compiler.
C
C-&
 
 
C
C     Test Utility Functions
C
 
 
C
C     SPICELIB Functions
C
 
 
C
C     Local Variables
C
      INTEGER               COUNT
      PARAMETER           ( COUNT = 4 )
 
      INTEGER               HANDLE
      DOUBLE PRECISION      BEGTIM
      DOUBLE PRECISION      ENDTIM
      INTEGER               INST
      CHARACTER*(8)         REF
      LOGICAL               AVFLAG
      CHARACTER*(32)        SEGID
      INTEGER               NREC
      DOUBLE PRECISION      SCLKDP (      COUNT )
      DOUBLE PRECISION      QUATS  ( 0:3, COUNT )
      DOUBLE PRECISION      AVVS   (   3, COUNT )
      INTEGER               NINTS
      DOUBLE PRECISION      STARTS (      COUNT )
 
      DOUBLE PRECISION      EMAT ( 3, 3 )
      DOUBLE PRECISION      AV   ( 3 )
      DOUBLE PRECISION      CMAT ( 3, 3 )
      DOUBLE PRECISION      CLKOUT
      LOGICAL               FOUND
 
 
C
C     Begin every test family with an open call.
C
      CALL TOPEN ( 'F_CKW03' )
 
      CALL KILFIL( 'ckw03.bc' )
      CALL CKOPN ( 'ckw03.bc', 'TestCK03', 1000, HANDLE )
 
      BEGTIM    =  2.0
      ENDTIM    = 10.0
 
      SCLKDP(1) =  2.0D0
      SCLKDP(2) =  4.0D0
      SCLKDP(3) =  8.0D0
      SCLKDP(4) = 10.0D0
 
      INST      = -1003
      REF       = 'J2000'
      SEGID     = 'TEST CKTYPE 03'
      AVFLAG    = .TRUE.
      NINTS     =  1
      STARTS(1) =  BEGTIM
 
      QUATS( 0, 1 ) = 1.0D0
      QUATS( 1, 1 ) = 0.0D0
      QUATS( 2, 1 ) = 0.0D0
      QUATS( 3, 1 ) = 0.0D0
 
      QUATS( 0, 2 ) = DCOS ( 0.1D0 )
      QUATS( 1, 2 ) = DSIN ( 0.1D0 )
      QUATS( 2, 2 ) = 0.0D0
      QUATS( 3, 2 ) = 0.0D0
 
 
      QUATS( 0, 3 ) = DCOS ( 0.15D0 )
      QUATS( 1, 3 ) = DSIN ( 0.15D0 )
      QUATS( 2, 3 ) = 0.0D0
      QUATS( 3, 3 ) = 0.0D0
 
      QUATS( 0, 4 ) = DCOS ( 0.25D0 )
      QUATS( 1, 4 ) = DSIN ( 0.25D0 )
      QUATS( 2, 4 ) = 0.0D0
      QUATS( 3, 4 ) = 0.0D0
 
      AVVS ( 1, 1 ) = 1.0D0
      AVVS ( 2, 1 ) = 0.0D0
      AVVS ( 3, 1 ) = 0.0D0
 
      AVVS ( 1, 2 ) = 0.5D0
      AVVS ( 2, 2 ) = 0.0D0
      AVVS ( 3, 2 ) = 0.0D0
 
      AVVS ( 1, 3 ) = 0.3D0
      AVVS ( 2, 3 ) = 0.0D0
      AVVS ( 3, 3 ) = 0.0D0
 
      AVVS ( 1, 4 ) = 0.2D0
      AVVS ( 2, 4 ) = 0.0D0
      AVVS ( 3, 4 ) = 0.0D0
 
      NREC = 4
 
 
 
      CALL TCASE ( 'Case with a non-unit quaternion.' )
 
 
         QUATS( 0, 4 ) = 0.0D0
         CALL CKW03 ( HANDLE, BEGTIM, ENDTIM, INST,  REF,  AVFLAG,
     .                SEGID,  NREC,   SCLKDP, QUATS, AVVS, NINTS,
     .                STARTS                                      )
 
         CALL CHCKXC ( .TRUE., 'SPICE(NONUNITQUATERNION)',  OK )
 
      CALL TCASE ( 'All quaternions unit length.' )
 
         QUATS( 0, 4 ) = DCOS ( 0.25D0 )
 
         CALL CKW03 ( HANDLE, BEGTIM, ENDTIM, INST,  REF,  AVFLAG,
     .                SEGID,  NREC,   SCLKDP, QUATS, AVVS, NINTS,
     .                STARTS                                      )
 
 
 
         CALL CKCLS ( HANDLE )
 
         CALL CKLPF ( 'ckw03.bc', HANDLE )
 
         CALL CKGPAV ( INST, 4.0D0, 1.0D0, 'J2000',
     .                 CMAT, AV,    CLKOUT, FOUND )
 
         CALL CHCKXC ( .FALSE., ' ',  OK )
         CALL CHCKSD ( 'CLKOUT', CLKOUT, '=', 4.0D0, 0.0D0, OK )
 
         CALL Q2M    ( QUATS(0,2), EMAT )
         CALL CHCKAD ( 'CMAT', CMAT, '~', EMAT,      9, 1.0D-14, OK)
         CALL CHCKAD ( 'AV',   AV,   '~', AVVS(1,2), 3, 1.0D-14, OK)
         CALL CHCKSL ( 'FOUND', FOUND, .TRUE.,  OK )
 
 
      CALL CKUPF ( HANDLE )
      CALL KILFIL( 'ckw03.bc' )
 
      CALL T_SUCCESS ( OK )
      RETURN
      END
 
