C$Procedure F_DAFANA ( DAFANA Test Family )
 
      SUBROUTINE F_DAFANA ( OK )
 
C$ Abstract
C
C     Test family to exercise the logic and code in the DAFANA
C     umbrella.
C
C$ Copyright
C
C     Copyright (2001), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     None.
C
C$ Keywords
C
C     TEST FAMILY
C
C$ Declarations
 
      IMPLICIT NONE
 
      INCLUDE              'zzddhman.inc'
 
      LOGICAL               OK
 
 
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     OK         O   logical indicating test status.
C
C$ Detailed_Input
C
C     None.
C
C$ Detailed_Output
C
C     OK         is a logical that indicates the test status to the
C                caller.
C
C$ Parameters
C
C     None.
C
C$ Files
C
C     None.
C
C$ Exceptions
C
C     This routine does not generate any errors. Routines in its
C     call tree may generate errors that are either intentional and
C     trapped or unintentional and need reporting.  The test family
C     utilities manage this.
C
C$ Particulars
C
C     This routine exercises a subset of DAFANA's logic that concerns
C     the handle manager implementation.
C
C$ Examples
C
C     None.
C
C$ Restrictions
C
C     None.
C
C$ Author_and_Institution
C
C     F.S. Turner     (JPL)
C
C$ Literature_References
C
C     None.
C
C$ Version
C
C-    TSPICE Version 1.0.0, 15-NOV-2001 (FST)
C
C
C-&
 
C
C     Local Parameters
C
      INTEGER               NUMDAF
      PARAMETER           ( NUMDAF = 21 )
 
      INTEGER               SUMLEN
      PARAMETER           ( SUMLEN = 125 )
 
C
C     Local Variables
C
      CHARACTER*(FILEN)     FNAME
      CHARACTER*(FILEN)     FNMTMP
 
      DOUBLE PRECISION      SUM    ( SUMLEN )
      DOUBLE PRECISION      ONES   ( SUMLEN )
      DOUBLE PRECISION      VALS   ( SUMLEN )
 
      INTEGER               I
      INTEGER               HANLST ( NUMDAF )
 
C
C     Start the test family with an open call.
C
      CALL TOPEN ( 'F_DAFANA' )
 
C
C --- Case: ------------------------------------------------------
C
      CALL TCASE ( 'F_DAFANA Initialization' )
 
C
C     Set the file name template.
C
      FNMTMP = 'test#.daf'
 
C
C     Initialize the summary record for testing purposes.
C
      DO I = 1, SUMLEN
         SUM(I) = 0.0D0
      END DO
 
C
C --- Case: ------------------------------------------------------
C
      CALL TCASE ( 'DAFBNA SPICE(STFULL) Exception' )
 
C
C     Create and load some test DAFs to use.
C
      DO I = 1, NUMDAF
         CALL REPMI  ( FNMTMP, '#', I, FNAME )
         CALL KILFIL ( FNAME )
         CALL DAFONW ( FNAME, 'SPK ', 2, 6, 'TEST DAF', 0, HANLST(I) )
      END DO
 
C
C     Since NUMDAF is 1 more than the number of DAFs DAFANA's
C     state table can track, attempt to initiate a search on
C     all NUMDAF DAFs and check for the error.
C
      DO I = 1, NUMDAF
         CALL DAFBNA ( HANLST(I), SUM, 'TEST SEGMENT' )
      END DO
 
C
C     Check for the exception.
C
      CALL CHCKXC ( .TRUE., 'SPICE(STFULL)', OK )
 
C
C     Clean up.
C
      DO I = 1, NUMDAF
         CALL DAFCLS ( HANLST(I) )
         CALL REPMI  ( FNMTMP, '#', I, FNAME )
         CALL KILFIL ( FNAME )
      END DO
 
C
C --- Case: ------------------------------------------------------
C
      CALL TCASE ( 'DAFBNA Remove Inactive Entries in State Table' )
 
C
C     Create and load some test DAFs to use.
C
      DO I = 1, NUMDAF
         CALL REPMI  ( FNMTMP, '#', I, FNAME )
         CALL KILFIL ( FNAME )
         CALL DAFONW ( FNAME, 'SPK ', 2, 6, 'TEST DAF', 0, HANLST(I) )
      END DO
 
C
C     Now start appends on the first NUMDAF-1 DAFs.
C
      DO I = 1, NUMDAF-1
         CALL DAFBNA ( HANLST(I), SUM, 'TEST SEGMENT' )
         CALL DAFADA ( SUM, SUMLEN )
      END DO
 
C
C     Conclude writing to the first DAF.
C
      CALL DAFCAD ( HANLST(1) )
      CALL DAFENA (           )
 
C
C     Now attempt to write to the NUMDAF DAF.
C
      CALL DAFBNA ( HANLST(NUMDAF), SUM, 'TEST SEGMENT' )
 
      DO I = 1, SUMLEN
         ONES(I) = 1.0D0
      END DO
 
      CALL DAFADA ( ONES, SUMLEN )
      CALL DAFENA (              )
 
C
C     Check to see that no exception was signaled.
C
      CALL CHCKXC ( .FALSE., ' ', OK )
 
C
C     And that the data was added appropriately.
C
      CALL CLEARD ( SUMLEN, VALS )
      CALL DAFRDA ( HANLST(NUMDAF), 385, 509, VALS )
 
      CALL CHCKAD ( 'VALS', VALS, '=', ONES, SUMLEN, 0.0D0, OK )
 
C
C     Lastly, begin appending a new array to the file we originally
C     bumped.
C
      CALL DAFBNA ( HANLST(1), SUM, 'TEST SEGMENT 2' )
      CALL DAFADA ( ONES, SUMLEN )
      CALL DAFENA (              )
 
C
C     Check for the absence of an exception.
C
      CALL CHCKXC ( .FALSE., ' ', OK )
 
C
C     Check the values of the data we just added.
C
      CALL CLEARD ( SUMLEN, VALS )
      CALL DAFRDA ( HANLST(1), 510, 634, VALS )
 
      CALL CHCKAD ( 'VALS', VALS, '=', ONES, SUMLEN, 0.0D0, OK )
 
C
C     Clean up.
C
      DO I = 1, NUMDAF
         CALL DAFCLS ( HANLST(I) )
         CALL REPMI  ( FNMTMP, '#', I, FNAME )
         CALL KILFIL ( FNAME )
      END DO
 
C
C     Close out the test family.
C
      CALL T_SUCCESS ( OK )
      RETURN
 
      END
