C$Procedure      F_DASCUD ( DASCUD routine tests )
 
      SUBROUTINE F_DASCUD ( OK )
      IMPLICIT NONE
 
      LOGICAL               OK
 
C$ Abstract
C
C     This routine tests the SPICELIB routine
C     
C        DASCUD
C
C$ Particulars
C
C     This routine tests some of the more complex aspects of the SPICE
C     DAS subsystem.  The DAS Required Reading and thorough 
C     knowledge of the DAS routines are prerequisites for understanding
C     this test family.
C
C     This file contains source code for the following utility
C     routines:
C
C        PACKFS
C        CHKFS
C        CHKCDR
C
C
C$ Version
C
C-    SPICELIB Version 1.0.0, 22-FEB-2003 (NJB)
C
C-&
 
 
C
C     Test Utility Functions
C
 
 
C
C     SPICELIB Functions
C     

C
C     Local Parameters
C
C
C     Words per data record, for each data type:
C
      INTEGER               NWC
      PARAMETER           ( NWC    = 1024 )
 
      INTEGER               NWD
      PARAMETER           ( NWD    =  128 )
 
      INTEGER               NWI
      PARAMETER           ( NWI    =  256 )
 
C
C     DAS type codes:
C
      INTEGER               CHAR
      PARAMETER           ( CHAR   =  1  )
      
      INTEGER               DP
      PARAMETER           ( DP     =  2  )
 
      INTEGER               INT
      PARAMETER           ( INT    =  3  )

C
C     Directory pointer locations (backward and forward):
C
      INTEGER               BWDLOC
      PARAMETER           ( BWDLOC = 1 )
 
      INTEGER               FWDLOC
      PARAMETER           ( FWDLOC = 2 )
 
C
C     Directory address range locations
C
      INTEGER               CHRRNG
      PARAMETER           ( CHRRNG =          3 )
 
      INTEGER               DPRNG
      PARAMETER           ( DPRNG  = CHRRNG + 2 )
 
      INTEGER               INTRNG
      PARAMETER           ( INTRNG = DPRNG  + 2 )

      INTEGER               CRNGMX
      PARAMETER           ( CRNGMX = CHRRNG + 1 )
 
      INTEGER               DRNGMX
      PARAMETER           ( DRNGMX = DPRNG  + 1 )

      INTEGER               IRNGMX
      PARAMETER           ( IRNGMX = INTRNG + 1 )

C
C     Location of first type descriptor
C
      INTEGER               BEGDSC
      PARAMETER           ( BEGDSC = 9 )

C
C     DAS file summary size:
C
      INTEGER               FSDIM
      PARAMETER           ( FSDIM  = 14 )

C
C     Local Variables
C      
      INTEGER               CLREC  ( NWI )
      INTEGER               DSCLOC
      INTEGER               DTYPE
      INTEGER               FREE
      INTEGER               FSUM   ( FSDIM )
      INTEGER               LASTLA ( 3 )
      INTEGER               LASTRC ( 3 )
      INTEGER               LASTWD ( 3 )
      INTEGER               NADD
      INTEGER               NRESVR
      INTEGER               NCOMR
      INTEGER               NRESVC
      INTEGER               NCOMC
      INTEGER               PRVCLR
      INTEGER               PRVTYP
      INTEGER               RECNO
      INTEGER               RNGMAX ( 3 )
      INTEGER               RNGMIN ( 3 )
      INTEGER               SCRHAN
      INTEGER               SIZES  ( 3 )
      INTEGER               XCLREC ( NWI )
      INTEGER               XFSUM  ( FSDIM )

C
C     Saved variables
C     
      SAVE                  RNGMAX
      SAVE                  RNGMIN
      SAVE                  SIZES

C
C     Initial values
C
      DATA                  RNGMAX / CRNGMX, DRNGMX, IRNGMX /
      DATA                  RNGMIN / CHRRNG, DPRNG,  INTRNG /
      DATA                  SIZES  / NWC,    NWD,    NWI    /


C
C     Begin every test family with an open call.
C
      CALL TOPEN ( 'F_DASCUD' )      

C
C     Our approach to testing will be to create a scratch DAS 
C     file by successive additions, such that the set of states
C     of the scratch DAS' file summary and directory contents span the
C     range of possibilities handled by DASCUD.  For each data addition
C     case, we'll verify that the addition results in the expected
C     update of the cluster directory structure and the file summary.
C
C     We don't actually write data to the files in these tests; we
C     simply update metadata to indicate where the data would be if
C     they were there.  Below, when we say we're "adding data" to
C     the file, we're lying to DASCUD.  But as long as the free
C     record pointer FREE is updated correctly, the DAS system is
C     none the wiser.
C

      
      CALL TCASE ( 'Tell DASCUD we''re adding one integer datum.' //
     .             'to an empty file.'                            )

      CALL DASOPS ( SCRHAN )
      CALL CHCKXC ( .FALSE., ' ', OK )

C
C     Update the file.  Note that the file update is generally made
C     to buffered records; these records might not be written to
C     the physical file.
C
      CALL DASCUD ( SCRHAN, INT, 1 )
      CALL CHCKXC ( .FALSE., ' ', OK )

C
C     Set up the expected file summary.  Note that the first cluster
C     record should follow the file record, reserved records, and 
C     comment records.  The last integer logical address is 1.  
C     The cluster record containing a descriptor for the last 
C     integer cluster is the only cluster record.  The first
C     data record follows the cluster directory.  The first free
C     record follows the data record.
C
      NRESVR        = 0
      NCOMR         = 0
      NRESVC        = 0
      NCOMC         = 0
      FREE          = 1 + NRESVR + NCOMR + 1 + 1 + 1
      LASTLA (CHAR) = 0
      LASTLA (DP)   = 0
      LASTLA (INT)  = 1
      LASTRC (CHAR) = 0
      LASTRC (DP)   = 0
      LASTRC (INT)  = 1 + NRESVR + NCOMR + 1
      LASTWD (CHAR) = 0
      LASTWD (DP)   = 0
      LASTWD (INT)  = BEGDSC + 1
 
      CALL PACKFS ( NRESVR, NRESVC, NCOMR,  NCOMC, FREE,  
     .              LASTLA, LASTRC, LASTWD, XFSUM       )

C
C     Look up the file summary, pack into a summary array, and compare.
C
      CALL DASHFS ( SCRHAN, NRESVR, NRESVC, NCOMR,    
     .              NCOMC,  FREE,   LASTLA, LASTRC, LASTWD )

      CALL CHCKXC ( .FALSE., ' ', OK )


      CALL PACKFS ( NRESVR, NRESVC, NCOMR,  NCOMC,  FREE,  
     .              LASTLA, LASTRC, LASTWD, FSUM           )

      CALL CHKFS  ( FSUM, XFSUM, OK )



C
C     Set up the expected first cluster record.
C
      CALL CLEARI ( NWI, XCLREC )

      XCLREC(BWDLOC  ) = 0 
      XCLREC(FWDLOC  ) = 0 
      XCLREC(CHRRNG  ) = 0 
      XCLREC(CHRRNG+1) = 0 
      XCLREC(DPRNG   ) = 0 
      XCLREC(DPRNG+1 ) = 0 
      XCLREC(INTRNG  ) = 1
      XCLREC(INTRNG+1) = 1
      XCLREC(BEGDSC  ) = INT 
      XCLREC(BEGDSC+1) = 1 

C
C     Read the cluster record and compare.
C
      RECNO = 1 + NRESVR + NCOMR + 1
      CALL DASRRI ( SCRHAN, RECNO, 1, NWI, CLREC )
      CALL CHCKXC ( .FALSE., ' ', OK )

      CALL CHKCDS ( CLREC, XCLREC, OK )



      CALL TCASE ( 'Add one d.p. datum to the file.' )

C
C     Update the file. 
C
      CALL DASCUD ( SCRHAN, DP, 1 )
      CALL CHCKXC ( .FALSE., ' ', OK )

C
C     Set up the expected file summary.
C
      FREE        = FREE + 1
      LASTLA (DP) = 1
      LASTRC (DP) = 1 + NRESVR + NCOMR + 1
      LASTWD (DP) = BEGDSC + 2
 
      CALL PACKFS ( NRESVR, NRESVC, NCOMR,  NCOMC, FREE,  
     .              LASTLA, LASTRC, LASTWD, XFSUM       )

C
C     Look up the file summary, pack into a summary array, and compare.
C
      CALL DASHFS ( SCRHAN, NRESVR, NRESVC, NCOMR,    
     .              NCOMC,  FREE,   LASTLA, LASTRC, LASTWD )

      CALL CHCKXC ( .FALSE., ' ', OK )


      CALL PACKFS ( NRESVR, NRESVC, NCOMR,  NCOMC,  FREE,  
     .              LASTLA, LASTRC, LASTWD, FSUM           )

      CALL CHKFS  ( FSUM, XFSUM, OK )



C
C     Set up the expected first cluster record.
C
      XCLREC(DPRNG   ) =  1 
      XCLREC(DPRNG+1 ) =  1 
      XCLREC(BEGDSC+2) = -1 

C
C     Read the cluster record and compare.
C
      RECNO = 1 + NRESVR + NCOMR + 1
      CALL DASRRI ( SCRHAN, RECNO, 1, NWI, CLREC )
      CALL CHCKXC ( .FALSE., ' ', OK )

      CALL CHKCDS ( CLREC, XCLREC, OK )




      CALL TCASE ( 'Add one character datum to the file.' )

C
C     Update the file. 
C
      CALL DASCUD ( SCRHAN, CHAR, 1 )
      CALL CHCKXC ( .FALSE., ' ', OK )

C
C     Set up the expected file summary.
C
      FREE          = FREE + 1
      LASTLA (CHAR) = 1
      LASTRC (CHAR) = 1 + NRESVR + NCOMR + 1
      LASTWD (CHAR) = BEGDSC + 3
 
      CALL PACKFS ( NRESVR, NRESVC, NCOMR,  NCOMC, FREE,  
     .              LASTLA, LASTRC, LASTWD, XFSUM       )

C
C     Look up the file summary, pack into a summary array, and compare.
C
      CALL DASHFS ( SCRHAN, NRESVR, NRESVC, NCOMR,    
     .              NCOMC,  FREE,   LASTLA, LASTRC, LASTWD )

      CALL CHCKXC ( .FALSE., ' ', OK )


      CALL PACKFS ( NRESVR, NRESVC, NCOMR,  NCOMC,  FREE,  
     .              LASTLA, LASTRC, LASTWD, FSUM           )

      CALL CHKFS  ( FSUM, XFSUM, OK )



C
C     Set up the expected first cluster record.
C
      XCLREC(CHRRNG  ) =  1 
      XCLREC(CHRRNG+1) =  1 
      XCLREC(BEGDSC+3) = -1 

C
C     Read the cluster record and compare.
C
      RECNO = 1 + NRESVR + NCOMR + 1
      CALL DASRRI ( SCRHAN, RECNO, 1, NWI, CLREC )
      CALL CHCKXC ( .FALSE., ' ', OK )

      CALL CHKCDS ( CLREC, XCLREC, OK )




      CALL TCASE ( 'Add data to fill up the first integer data ' //
     .             'record.'                                      )

C
C     Update the file. 
C
      CALL DASCUD ( SCRHAN, INT, NWI-1 )
      CALL CHCKXC ( .FALSE., ' ', OK )

C
C     Set up the expected file summary.
C
C
C     Note:  FREE is unchanged.
C
      LASTLA (INT) = NWI
 
      CALL PACKFS ( NRESVR, NRESVC, NCOMR,  NCOMC, FREE,  
     .              LASTLA, LASTRC, LASTWD, XFSUM       )

C
C     Look up the file summary, pack into a summary array, and compare.
C
      CALL DASHFS ( SCRHAN, NRESVR, NRESVC, NCOMR,    
     .              NCOMC,  FREE,   LASTLA, LASTRC, LASTWD )

      CALL CHCKXC ( .FALSE., ' ', OK )


      CALL PACKFS ( NRESVR, NRESVC, NCOMR,  NCOMC,  FREE,  
     .              LASTLA, LASTRC, LASTWD, FSUM           )

      CALL CHKFS  ( FSUM, XFSUM, OK )



C
C     Set up the expected first cluster record.
C
      XCLREC(INTRNG+1) =  NWI

C
C     Read the cluster record and compare.
C
      RECNO = 1 + NRESVR + NCOMR + 1
      CALL DASRRI ( SCRHAN, RECNO, 1, NWI, CLREC )
      CALL CHCKXC ( .FALSE., ' ', OK )

      CALL CHKCDS ( CLREC, XCLREC, OK )






      CALL TCASE ( 'Add data to fill up 3 1/2 new integer data '     //
     .             'records.  This creates a second integer cluster.' )

C
C     Update the file. 
C
      CALL DASCUD ( SCRHAN, INT, 7*NWI/2 )
      CALL CHCKXC ( .FALSE., ' ', OK )

C
C     Set up the expected file summary.
C
      FREE       = FREE + 4
      LASTLA (INT) = LASTLA (INT)  +  7*NWI/2
      LASTWD (INT) = BEGDSC + 4
 
      CALL PACKFS ( NRESVR, NRESVC, NCOMR,  NCOMC, FREE,  
     .              LASTLA, LASTRC, LASTWD, XFSUM       )

C
C     Look up the file summary, pack into a summary array, and compare.
C
      CALL DASHFS ( SCRHAN, NRESVR, NRESVC, NCOMR,    
     .              NCOMC,  FREE,   LASTLA, LASTRC, LASTWD )

      CALL CHCKXC ( .FALSE., ' ', OK )


      CALL PACKFS ( NRESVR, NRESVC, NCOMR,  NCOMC,  FREE,  
     .              LASTLA, LASTRC, LASTWD, FSUM           )

      CALL CHKFS  ( FSUM, XFSUM, OK )



C
C     Set up the expected first cluster record.
C
      XCLREC(INTRNG+1) =  XCLREC(INTRNG+1) + 7*NWI/2
      XCLREC(BEGDSC+4) = -4

C
C     Read the cluster record and compare.
C
      RECNO = 1 + NRESVR + NCOMR + 1
      CALL DASRRI ( SCRHAN, RECNO, 1, NWI, CLREC )
      CALL CHCKXC ( .FALSE., ' ', OK )

      CALL CHKCDS ( CLREC, XCLREC, OK )



      CALL TCASE ( 'Add data to fill up 3 new integer data records. ' //
     .             'This extends the second integer cluster.' )

C
C     Update the file. 
C
      CALL DASCUD ( SCRHAN, INT, 3*NWI )
      CALL CHCKXC ( .FALSE., ' ', OK )

C
C     Set up the expected file summary.
C
      FREE       = FREE + 3
      LASTLA (INT) = LASTLA(3) + 3*NWI
 
      CALL PACKFS ( NRESVR, NRESVC, NCOMR,  NCOMC, FREE,  
     .              LASTLA, LASTRC, LASTWD, XFSUM       )

C
C     Look up the file summary, pack into a summary array, and compare.
C
      CALL DASHFS ( SCRHAN, NRESVR, NRESVC, NCOMR,    
     .              NCOMC,  FREE,   LASTLA, LASTRC, LASTWD )

      CALL CHCKXC ( .FALSE., ' ', OK )


      CALL PACKFS ( NRESVR, NRESVC, NCOMR,  NCOMC,  FREE,  
     .              LASTLA, LASTRC, LASTWD, FSUM           )

      CALL CHKFS  ( FSUM, XFSUM, OK )



C
C     Set up the expected first cluster record.
C
      XCLREC(INTRNG+1) =  XCLREC(INTRNG+1) + 3*NWI
      XCLREC(BEGDSC+4) = -7

C
C     Read the cluster record and compare.
C
      RECNO = 1 + NRESVR + NCOMR + 1
      CALL DASRRI ( SCRHAN, RECNO, 1, NWI, CLREC )
      CALL CHCKXC ( .FALSE., ' ', OK )

      CALL CHKCDS ( CLREC, XCLREC, OK )





      CALL TCASE ( 'Add data to fill up 1 1/2 new integer data ' //
     .             'records. This extends the second integer cluster.' )

C
C     Update the file. 
C
      CALL DASCUD ( SCRHAN, INT, 3*NWI/2 )
      CALL CHCKXC ( .FALSE., ' ', OK )

C
C     Set up the expected file summary.
C
C
C     Recall the last integer data record is half full.  We only need
C     one new integer data record.
C
      FREE         = FREE + 1
      LASTLA (INT) = LASTLA(INT) + 3*NWI/2
 
      CALL PACKFS ( NRESVR, NRESVC, NCOMR,  NCOMC, FREE,  
     .              LASTLA, LASTRC, LASTWD, XFSUM       )

C
C     Look up the file summary, pack into a summary array, and compare.
C
      CALL DASHFS ( SCRHAN, NRESVR, NRESVC, NCOMR,    
     .              NCOMC,  FREE,   LASTLA, LASTRC, LASTWD )

      CALL CHCKXC ( .FALSE., ' ', OK )


      CALL PACKFS ( NRESVR, NRESVC, NCOMR,  NCOMC,  FREE,  
     .              LASTLA, LASTRC, LASTWD, FSUM           )

      CALL CHKFS  ( FSUM, XFSUM, OK )



C
C     Set up the expected first cluster record.
C
      XCLREC(INTRNG+1) =  XCLREC(INTRNG+1) + 3*NWI/2
      XCLREC(BEGDSC+4) = -8

C
C     Read the cluster record and compare.
C
      RECNO = 1 + NRESVR + NCOMR + 1
      CALL DASRRI ( SCRHAN, RECNO, 1, NWI, CLREC )
      CALL CHCKXC ( .FALSE., ' ', OK )

      CALL CHKCDS ( CLREC, XCLREC, OK )

C
C     We're now going to repeat the integer data additions for
C     the double precision and character cases.
C



      CALL TCASE ( 'Add data to fill up the first d.p. data ' //
     .             'record.'                                      )

C
C     Update the file. 
C
      CALL DASCUD ( SCRHAN, DP, NWD-1 )
      CALL CHCKXC ( .FALSE., ' ', OK )

C
C     Set up the expected file summary.
C
C
C     Note:  FREE is unchanged.
C
      LASTLA (DP) = NWD
 
      CALL PACKFS ( NRESVR, NRESVC, NCOMR,  NCOMC, FREE,  
     .              LASTLA, LASTRC, LASTWD, XFSUM       )

C
C     Look up the file summary, pack into a summary array, and compare.
C
      CALL DASHFS ( SCRHAN, NRESVR, NRESVC, NCOMR,    
     .              NCOMC,  FREE,   LASTLA, LASTRC, LASTWD )

      CALL CHCKXC ( .FALSE., ' ', OK )


      CALL PACKFS ( NRESVR, NRESVC, NCOMR,  NCOMC,  FREE,  
     .              LASTLA, LASTRC, LASTWD, FSUM           )

      CALL CHKFS  ( FSUM, XFSUM, OK )



C
C     Set up the expected first cluster record.  
C
      XCLREC(DPRNG+1 ) =  NWD


C
C     Read the cluster record and compare.
C
      RECNO = 1 + NRESVR + NCOMR + 1
      CALL DASRRI ( SCRHAN, RECNO, 1, NWI, CLREC )
      CALL CHCKXC ( .FALSE., ' ', OK )

      CALL CHKCDS ( CLREC, XCLREC, OK )






      CALL TCASE ( 'Add data to fill up 3 1/2 new d.p. data '     //
     .             'records.  This creates a second d.p. cluster.' )

C
C     Update the file. 
C
      CALL DASCUD ( SCRHAN, DP, 7*NWD/2 )
      CALL CHCKXC ( .FALSE., ' ', OK )

C
C     Set up the expected file summary.
C
      FREE        = FREE + 4
      LASTLA (DP) = LASTLA(DP) + 7*NWD/2
      LASTWD (DP) = BEGDSC + 5
 
      CALL PACKFS ( NRESVR, NRESVC, NCOMR,  NCOMC, FREE,  
     .              LASTLA, LASTRC, LASTWD, XFSUM       )

C
C     Look up the file summary, pack into a summary array, and compare.
C
      CALL DASHFS ( SCRHAN, NRESVR, NRESVC, NCOMR,    
     .              NCOMC,  FREE,   LASTLA, LASTRC, LASTWD )

      CALL CHCKXC ( .FALSE., ' ', OK )


      CALL PACKFS ( NRESVR, NRESVC, NCOMR,  NCOMC,  FREE,  
     .              LASTLA, LASTRC, LASTWD, FSUM           )

      CALL CHKFS  ( FSUM, XFSUM, OK )



C
C     Set up the expected first cluster record.
C
      XCLREC(DPRNG+1 ) =  XCLREC(DPRNG+1)  + 7*NWD/2
      XCLREC(INTRNG  ) =  1
      XCLREC(BEGDSC+5) = -4

C
C     Read the cluster record and compare.
C
      RECNO = 1 + NRESVR + NCOMR + 1
      CALL DASRRI ( SCRHAN, RECNO, 1, NWI, CLREC )
      CALL CHCKXC ( .FALSE., ' ', OK )

      CALL CHKCDS ( CLREC, XCLREC, OK )



      CALL TCASE ( 'Add data to fill up 3 new d.p. data records. ' //
     .             'This extends the second d.p. cluster.' )

C
C     Update the file. 
C
      CALL DASCUD ( SCRHAN, DP, 3*NWD )
      CALL CHCKXC ( .FALSE., ' ', OK )

C
C     Set up the expected file summary.
C
      FREE        = FREE + 3
      LASTLA (DP) = LASTLA(DP) + 3*NWD
 
      CALL PACKFS ( NRESVR, NRESVC, NCOMR,  NCOMC, FREE,  
     .              LASTLA, LASTRC, LASTWD, XFSUM       )

C
C     Look up the file summary, pack into a summary array, and compare.
C
      CALL DASHFS ( SCRHAN, NRESVR, NRESVC, NCOMR,    
     .              NCOMC,  FREE,   LASTLA, LASTRC, LASTWD )

      CALL CHCKXC ( .FALSE., ' ', OK )


      CALL PACKFS ( NRESVR, NRESVC, NCOMR,  NCOMC,  FREE,  
     .              LASTLA, LASTRC, LASTWD, FSUM           )

      CALL CHKFS  ( FSUM, XFSUM, OK )



C
C     Set up the expected first cluster record.
C
      XCLREC(DPRNG+1 ) = XCLREC(DPRNG+1) + 3*NWD 
      XCLREC(BEGDSC+5) = -7

C
C     Read the cluster record and compare.
C
      RECNO = 1 + NRESVR + NCOMR + 1
      CALL DASRRI ( SCRHAN, RECNO, 1, NWI, CLREC )
      CALL CHCKXC ( .FALSE., ' ', OK )

      CALL CHKCDS ( CLREC, XCLREC, OK )



      CALL TCASE ( 'Add data to fill up 1 1/2 new d.p. data ' //
     .             'records. This extends the second d.p. cluster.' )

C
C     Update the file. 
C
      CALL DASCUD ( SCRHAN, DP, 3*NWD/2 )
      CALL CHCKXC ( .FALSE., ' ', OK )

C
C     Set up the expected file summary.
C
C
C     Recall the last d.p. data record is half full.  We only need
C     one new d.p. data record.
C
      FREE        = FREE + 1
      LASTLA (DP) = LASTLA(DP) + 3*NWD/2
 
      CALL PACKFS ( NRESVR, NRESVC, NCOMR,  NCOMC, FREE,  
     .              LASTLA, LASTRC, LASTWD, XFSUM       )

C
C     Look up the file summary, pack into a summary array, and compare.
C
      CALL DASHFS ( SCRHAN, NRESVR, NRESVC, NCOMR,    
     .              NCOMC,  FREE,   LASTLA, LASTRC, LASTWD )

      CALL CHCKXC ( .FALSE., ' ', OK )


      CALL PACKFS ( NRESVR, NRESVC, NCOMR,  NCOMC,  FREE,  
     .              LASTLA, LASTRC, LASTWD, FSUM           )

      CALL CHKFS  ( FSUM, XFSUM, OK )



C
C     Set up the expected first cluster record.
C
      XCLREC(DPRNG+1 ) =  XCLREC(DPRNG+1 ) + 3*NWD/2
      XCLREC(BEGDSC+5) = -8

C
C     Read the cluster record and compare.
C
      RECNO = 1 + NRESVR + NCOMR + 1
      CALL DASRRI ( SCRHAN, RECNO, 1, NWI, CLREC )
      CALL CHCKXC ( .FALSE., ' ', OK )

      CALL CHKCDS ( CLREC, XCLREC, OK )





      CALL TCASE ( 'Add data to fill up the first char data ' //
     .             'record.'                                      )

C
C     Update the file. 
C
      CALL DASCUD ( SCRHAN, CHAR, NWC-1 )
      CALL CHCKXC ( .FALSE., ' ', OK )

C
C     Set up the expected file summary.
C
C
C     Note:  FREE is unchanged.
C
      LASTLA (CHAR) = NWC
 
      CALL PACKFS ( NRESVR, NRESVC, NCOMR,  NCOMC, FREE,  
     .              LASTLA, LASTRC, LASTWD, XFSUM       )

C
C     Look up the file summary, pack into a summary array, and compare.
C
      CALL DASHFS ( SCRHAN, NRESVR, NRESVC, NCOMR,    
     .              NCOMC,  FREE,   LASTLA, LASTRC, LASTWD )

      CALL CHCKXC ( .FALSE., ' ', OK )


      CALL PACKFS ( NRESVR, NRESVC, NCOMR,  NCOMC,  FREE,  
     .              LASTLA, LASTRC, LASTWD, FSUM           )

      CALL CHKFS  ( FSUM, XFSUM, OK )



C
C     Set up the expected first cluster record.  
C
      XCLREC(CHRRNG+1) =  NWC


C
C     Read the cluster record and compare.
C
      RECNO = 1 + NRESVR + NCOMR + 1
      CALL DASRRI ( SCRHAN, RECNO, 1, NWI, CLREC )
      CALL CHCKXC ( .FALSE., ' ', OK )

      CALL CHKCDS ( CLREC, XCLREC, OK )






      CALL TCASE ( 'Add data to fill up 3 1/2 new char data '     //
     .             'records.  This creates a second char cluster.' )

C
C     Update the file. 
C
      CALL DASCUD ( SCRHAN, CHAR, 7*NWC/2 )
      CALL CHCKXC ( .FALSE., ' ', OK )

C
C     Set up the expected file summary.
C
      FREE          = FREE + 4
      LASTLA (CHAR) = LASTLA(CHAR) + 7*NWC/2
      LASTWD (CHAR) = BEGDSC + 6
 
      CALL PACKFS ( NRESVR, NRESVC, NCOMR,  NCOMC, FREE,  
     .              LASTLA, LASTRC, LASTWD, XFSUM       )

C
C     Look up the file summary, pack into a summary array, and compare.
C
      CALL DASHFS ( SCRHAN, NRESVR, NRESVC, NCOMR,    
     .              NCOMC,  FREE,   LASTLA, LASTRC, LASTWD )

      CALL CHCKXC ( .FALSE., ' ', OK )


      CALL PACKFS ( NRESVR, NRESVC, NCOMR,  NCOMC,  FREE,  
     .              LASTLA, LASTRC, LASTWD, FSUM           )

      CALL CHKFS  ( FSUM, XFSUM, OK )



C
C     Set up the expected first cluster record.
C
      XCLREC(CHRRNG+1 ) =  XCLREC(CHRRNG+1)  + 7*NWC/2
      XCLREC(BEGDSC+6)  = -4

C
C     Read the cluster record and compare.
C
      RECNO = 1 + NRESVR + NCOMR + 1
      CALL DASRRI ( SCRHAN, RECNO, 1, NWI, CLREC )
      CALL CHCKXC ( .FALSE., ' ', OK )

      CALL CHKCDS ( CLREC, XCLREC, OK )



      CALL TCASE ( 'Add data to fill up 3 new char data records. ' //
     .             'This extends the second char cluster.' )

C
C     Update the file. 
C
      CALL DASCUD ( SCRHAN, CHAR, 3*NWC )
      CALL CHCKXC ( .FALSE., ' ', OK )

C
C     Set up the expected file summary.
C
      FREE          = FREE + 3
      LASTLA (CHAR) = LASTLA(CHAR) + 3*NWC
 
      CALL PACKFS ( NRESVR, NRESVC, NCOMR,  NCOMC, FREE,  
     .              LASTLA, LASTRC, LASTWD, XFSUM       )

C
C     Look up the file summary, pack into a summary array, and compare.
C
      CALL DASHFS ( SCRHAN, NRESVR, NRESVC, NCOMR,    
     .              NCOMC,  FREE,   LASTLA, LASTRC, LASTWD )

      CALL CHCKXC ( .FALSE., ' ', OK )


      CALL PACKFS ( NRESVR, NRESVC, NCOMR,  NCOMC,  FREE,  
     .              LASTLA, LASTRC, LASTWD, FSUM           )

      CALL CHKFS  ( FSUM, XFSUM, OK )



C
C     Set up the expected first cluster record.
C
      XCLREC(CHRRNG+1 ) = XCLREC(CHRRNG+1) + 3*NWC 
      XCLREC(BEGDSC+6) = -7

C
C     Read the cluster record and compare.
C
      RECNO = 1 + NRESVR + NCOMR + 1
      CALL DASRRI ( SCRHAN, RECNO, 1, NWI, CLREC )
      CALL CHCKXC ( .FALSE., ' ', OK )

      CALL CHKCDS ( CLREC, XCLREC, OK )



      CALL TCASE ( 'Add data to fill up 1 1/2 new char data ' //
     .             'records. This extends the second char cluster.' )

C
C     Update the file. 
C
      CALL DASCUD ( SCRHAN, CHAR, 3*NWC/2 )
      CALL CHCKXC ( .FALSE., ' ', OK )

C
C     Set up the expected file summary.
C
C
C     Recall the last char data record is half full.  We only need
C     one new char data record.
C
      FREE          = FREE + 1
      LASTLA (CHAR) = LASTLA(CHAR) + 3*NWC/2
 
      CALL PACKFS ( NRESVR, NRESVC, NCOMR,  NCOMC, FREE,  
     .              LASTLA, LASTRC, LASTWD, XFSUM       )

C
C     Look up the file summary, pack into a summary array, and compare.
C
      CALL DASHFS ( SCRHAN, NRESVR, NRESVC, NCOMR,    
     .              NCOMC,  FREE,   LASTLA, LASTRC, LASTWD )

      CALL CHCKXC ( .FALSE., ' ', OK )


      CALL PACKFS ( NRESVR, NRESVC, NCOMR,  NCOMC,  FREE,  
     .              LASTLA, LASTRC, LASTWD, FSUM           )

      CALL CHKFS  ( FSUM, XFSUM, OK )



C
C     Set up the expected first cluster record.
C
      XCLREC(CHRRNG+1 ) =  XCLREC(CHRRNG+1 ) + 3*NWC/2
      XCLREC(BEGDSC+6)  = -8

C
C     Read the cluster record and compare.
C
      RECNO = 1 + NRESVR + NCOMR + 1
      CALL DASRRI ( SCRHAN, RECNO, 1, NWI, CLREC )
      CALL CHCKXC ( .FALSE., ' ', OK )

      CALL CHKCDS ( CLREC, XCLREC, OK )




      CALL TCASE ( 'Now add data, cycling types as we go, so as to ' //
     .             'fill in the first cluster directory.  We''ll '   //
     .             'add one record of d.p. data, then one of '       //
     .             'int data, and so on.'                            )

C
C     Update the file. 
C
      DSCLOC = BEGDSC + 7
      PRVTYP = CHAR

      DO WHILE ( DSCLOC .LE. NWI )
C
C        Find the successor of PRVTYP using the cycling ordering
C
C           1 -> 2 -> 3 -> 1
C
         DTYPE = MOD( PRVTYP, 3 ) + 1

         CALL DASCUD ( SCRHAN, DTYPE, SIZES(DTYPE) )
         CALL CHCKXC ( .FALSE., ' ', OK )

C
C        Set up the expected file summary.
C
C        Recall the last DTYPE data record is full.  We need one new,
C        non-contiguous data record of this type.
C
         FREE           = FREE + 1
         LASTLA (DTYPE) = LASTLA(DTYPE)  + SIZES(DTYPE)
         LASTWD (DTYPE) = LASTWD(PRVTYP) + 1
 

C
C        Set up the expected first cluster record.
C
         XCLREC( RNGMAX(DTYPE) ) =  XCLREC( RNGMAX(DTYPE) ) +
     .                              SIZES(DTYPE)
         XCLREC( DSCLOC )        =  1


         PRVTYP = DTYPE
         DSCLOC = DSCLOC + 1


         IF ( MOD(DSCLOC,10) .EQ. 0 ) THEN
C
C           Read the cluster record and compare.
C   
            CALL DASRRI ( SCRHAN, RECNO, 1, NWI, CLREC )
            CALL CHCKXC ( .FALSE., ' ', OK )

            CALL CHKCDS ( CLREC, XCLREC, OK )

         END IF

      END DO

C
C     We will have allocated a new, empty record for the next cluster
C     directory, so increment FREE.
C
      FREE = FREE + 1

C
C     Now check the file summary.
C
      CALL PACKFS ( NRESVR, NRESVC, NCOMR,  NCOMC, FREE,  
     .              LASTLA, LASTRC, LASTWD, XFSUM       )

C
C     Look up the file summary, pack into a summary array, and 
C     compare.
C
      CALL DASHFS ( SCRHAN, NRESVR, NRESVC, NCOMR,    
     .              NCOMC,  FREE,   LASTLA, LASTRC, LASTWD )

      CALL CHCKXC ( .FALSE., ' ', OK )


      CALL PACKFS ( NRESVR, NRESVC, NCOMR,  NCOMC,  FREE,  
     .              LASTLA, LASTRC, LASTWD, FSUM           )

      CALL CHKFS  ( FSUM, XFSUM, OK )

C
C     The forward pointer of the cluster directory record will point to
C     the newly allocated cluster directory record.
C
      XCLREC(FWDLOC) = FREE - 1
C
C     Read the cluster record and compare.
C
      RECNO  = 1 + NRESVR + NCOMR + 1
      CALL DASRRI ( SCRHAN, RECNO, 1, NWI, CLREC )
      CALL CHCKXC ( .FALSE., ' ', OK )

      CALL CHKCDS ( CLREC, XCLREC, OK )

      PRVCLR = RECNO



      CALL TCASE ( 'Add another set of data that fills in an entire ' //
     .             'cluster directory.  This time we''ll alternate '  //
     .             'between integer and d.p. data.  We''ll '          //
     .             'leave the last (INT) cluster half full.'           )

      RECNO  = FREE   - 1
      DSCLOC = BEGDSC + 1
      PRVTYP = DP

C
C     Check the empty cluster directory.
C
      CALL CLEARI ( NWI, XCLREC )

      XCLREC( BWDLOC ) = PRVCLR
      XCLREC( FWDLOC ) = 0
C
C     Read the cluster record and compare.
C
      CALL DASRRI ( SCRHAN, RECNO, 1, NWI, CLREC )
      CALL CHCKXC ( .FALSE., ' ', OK )

      CALL CHKCDS ( CLREC, XCLREC, OK )

C
C     Initialize the the rest of the expected cluster directory. 
C 
      XCLREC( RNGMIN(CHAR) ) =  0
      XCLREC( RNGMIN(DP)   ) =  0
      XCLREC( RNGMIN(INT)  ) =  0

      XCLREC( RNGMAX(CHAR) ) =  0
      XCLREC( RNGMAX(DP)   ) =  0   
      XCLREC( RNGMAX(INT)  ) =  0  

      XCLREC( BEGDSC )       =  INT




      DO WHILE ( DSCLOC .LE. NWI )
C
C        Find the successor of PRVTYP using the cycling ordering
C
C           1 -> 2 -> 3 -> 1
C
         DTYPE = MOD( PRVTYP, 3 ) + 1

C
C        Skip over the character type.
C
         IF ( DTYPE .EQ. CHAR ) THEN
            DTYPE = MOD( DTYPE, 3 ) + 1
         END IF

         IF ( DSCLOC .LT. NWI ) THEN
            NADD = SIZES(DTYPE)
         ELSE
            NADD = SIZES(DTYPE)/2
         END IF

         CALL DASCUD ( SCRHAN, DTYPE, NADD )
         CALL CHCKXC ( .FALSE., ' ', OK )

C
C        Set up the expected file summary.
C
C        Recall the last DTYPE data record is full.  We need one new,
C        non-contiguous data record of this type.
C
         IF ( DSCLOC .LT. NWI ) THEN

            FREE = FREE + 1

         ELSE
C
C           When we fill in the last cluster directory entry, we'll
C           allocate another empty directory.
C
            FREE   = FREE + 2
            PRVCLR = FREE - 1

         END IF


         LASTLA (DTYPE) = LASTLA(DTYPE)  +  NADD
         LASTRC (DTYPE) = RECNO
         LASTWD (DTYPE) = DSCLOC
 
C
C        Now check the file summary.
C
         CALL PACKFS ( NRESVR, NRESVC, NCOMR,  NCOMC, FREE,  
     .                 LASTLA, LASTRC, LASTWD, XFSUM       )

C
C        Look up the file summary, pack into a summary array, and 
C        compare.
C
         CALL DASHFS ( SCRHAN, NRESVR, NRESVC, NCOMR,    
     .                 NCOMC,  FREE,   LASTLA, LASTRC, LASTWD )

         CALL CHCKXC ( .FALSE., ' ', OK )


         CALL PACKFS ( NRESVR, NRESVC, NCOMR,  NCOMC,  FREE,  
     .                 LASTLA, LASTRC, LASTWD, FSUM           )

         CALL CHKFS  ( FSUM, XFSUM, OK )

C
C        Set up the expected  cluster record.
C
         IF ( XCLREC( RNGMAX(DTYPE) ) .EQ. 0 ) THEN
C
C           The range for this data type is initially set at 0:0.
C           We've already updated LASTLA(DTYPE).
C
            XCLREC( RNGMAX(DTYPE) ) =  LASTLA(DTYPE)

            XCLREC( RNGMIN(DTYPE) ) =  LASTLA(DTYPE) - NADD + 1

         ELSE
            XCLREC( RNGMAX(DTYPE) ) =  XCLREC( RNGMAX(DTYPE) ) + NADD
         END IF

         IF ( DTYPE .EQ. XCLREC(BEGDSC) ) THEN
            XCLREC( DSCLOC ) =   1
         ELSE
            XCLREC( DSCLOC ) =  -1
         END IF


         PRVTYP = DTYPE
         DSCLOC = DSCLOC + 1

         IF ( MOD(DSCLOC,10) .EQ. 0 ) THEN
C
C           Read the cluster record and compare.
C   
            CALL DASRRI ( SCRHAN, RECNO, 1, NWI, CLREC )
            CALL CHCKXC ( .FALSE., ' ', OK )

            CALL CHKCDS ( CLREC, XCLREC, OK )

         END IF

      END DO


C
C     Now check the file summary.
C
      CALL PACKFS ( NRESVR, NRESVC, NCOMR,  NCOMC, FREE,  
     .              LASTLA, LASTRC, LASTWD, XFSUM       )

C
C     Look up the file summary, pack into a summary array, and 
C     compare.
C
      CALL DASHFS ( SCRHAN, NRESVR, NRESVC, NCOMR,    
     .              NCOMC,  FREE,   LASTLA, LASTRC, LASTWD )

      CALL CHCKXC ( .FALSE., ' ', OK )


      CALL PACKFS ( NRESVR, NRESVC, NCOMR,  NCOMC,  FREE,  
     .              LASTLA, LASTRC, LASTWD, FSUM           )

      CALL CHKFS  ( FSUM, XFSUM, OK )

C
C     The forward pointer of the cluster directory record will point to
C     the newly allocated cluster directory record.
C
      XCLREC(FWDLOC) = FREE-1


C     Read the cluster record and compare.
C
      CALL DASRRI ( SCRHAN, RECNO, 1, NWI, CLREC )
      CALL CHCKXC ( .FALSE., ' ', OK )

      CALL CHKCDS ( CLREC, XCLREC, OK )

      PRVCLR = RECNO



      CALL TCASE ( 'Add another set of data that fills in an entire ' //
     .             'cluster directory.  This time we''ll alternate '  //
     .             'between integer and character data.  We''ll '     //
     .             'leave the last (CHAR) cluster half full.'          )

      RECNO  = FREE   - 1
      DSCLOC = BEGDSC + 1
      PRVTYP = INT

C
C     Check the empty cluster directory.
C
      CALL CLEARI ( NWI, XCLREC )

      XCLREC( BWDLOC ) = PRVCLR
      XCLREC( FWDLOC ) = 0
C
C     Read the cluster record and compare.
C
      CALL DASRRI ( SCRHAN, RECNO, 1, NWI, CLREC )
      CALL CHCKXC ( .FALSE., ' ', OK )

      CALL CHKCDS ( CLREC, XCLREC, OK )


C
C     Initialize the expected cluster directory. 
C
      CALL CLEARI ( NWI, XCLREC )

      XCLREC( BWDLOC ) = PRVCLR
      XCLREC( FWDLOC ) = 0

      XCLREC( RNGMIN(CHAR) ) =  0
      XCLREC( RNGMIN(DP)   ) =  0
      XCLREC( RNGMIN(INT)  ) =  0

      XCLREC( RNGMAX(CHAR) ) =  0
      XCLREC( RNGMAX(DP)   ) =  0   
      XCLREC( RNGMAX(INT)  ) =  0  

      XCLREC( BEGDSC )       =  CHAR




      DO WHILE ( DSCLOC .LE. NWI )
C
C        Find the successor of PRVTYP using the cycling ordering
C
C           1 -> 2 -> 3 -> 1
C
         DTYPE = MOD( PRVTYP, 3 ) + 1

C
C        Skip over the d.p. type.
C
         IF ( DTYPE .EQ. DP ) THEN
            DTYPE = MOD( DTYPE, 3 ) + 1
         END IF

         IF ( DSCLOC .LT. NWI ) THEN
            NADD = SIZES(DTYPE)
         ELSE
            NADD = SIZES(DTYPE)/2
         END IF

         CALL DASCUD ( SCRHAN, DTYPE, NADD )
         CALL CHCKXC ( .FALSE., ' ', OK )

C
C        Set up the expected file summary.
C
C        Recall the last DTYPE data record is full.  We need one new,
C        non-contiguous data record of this type.
C
         IF ( DSCLOC .LT. NWI ) THEN

            FREE = FREE + 1

         ELSE
C
C           When we fill in the last cluster directory entry, we'll
C           allocate another empty directory.
C
            FREE   = FREE + 2
            PRVCLR = FREE - 1

         END IF


         LASTLA (DTYPE) = LASTLA(DTYPE)  +  NADD
         LASTRC (DTYPE) = RECNO
         LASTWD (DTYPE) = DSCLOC
 
C
C        Now check the file summary.
C
         CALL PACKFS ( NRESVR, NRESVC, NCOMR,  NCOMC, FREE,  
     .                 LASTLA, LASTRC, LASTWD, XFSUM       )

C
C        Look up the file summary, pack into a summary array, and 
C        compare.
C
         CALL DASHFS ( SCRHAN, NRESVR, NRESVC, NCOMR,    
     .                 NCOMC,  FREE,   LASTLA, LASTRC, LASTWD )

         CALL CHCKXC ( .FALSE., ' ', OK )


         CALL PACKFS ( NRESVR, NRESVC, NCOMR,  NCOMC,  FREE,  
     .                 LASTLA, LASTRC, LASTWD, FSUM           )

         CALL CHKFS  ( FSUM, XFSUM, OK )

C
C        Set up the expected  cluster record.
C
         IF ( XCLREC( RNGMAX(DTYPE) ) .EQ. 0 ) THEN
C
C           The range for this data type is initially set at 0:0.
C           We've already updated LASTLA(DTYPE).
C
            XCLREC( RNGMAX(DTYPE) ) =  LASTLA(DTYPE)

            IF ( DTYPE .EQ. CHAR ) THEN
               XCLREC( RNGMIN(DTYPE) ) =  LASTLA(DTYPE) - NADD + 1
            ELSE
C
C              In the integer case, we'll start by filling in the 
C              last half of that empty data record which is in the
C              last integer cluster belonging to the previous cluster
C              directory.  So the minimum integer logical address 
C              belonging to this cluster directory will be NWI/2
C              larger than it would be if the previous integer
C              record were full.
C              
               XCLREC( RNGMIN(DTYPE) ) = LASTLA(DTYPE) - NADD + 1 
     .                                   + NWI/2
            END IF                                 

         ELSE
            XCLREC( RNGMAX(DTYPE) ) =  XCLREC( RNGMAX(DTYPE) ) + NADD
         END IF

         IF ( DTYPE .EQ. XCLREC(BEGDSC) ) THEN
            XCLREC( DSCLOC ) =   1
         ELSE
            XCLREC( DSCLOC ) =  -1
         END IF


         PRVTYP = DTYPE
         DSCLOC = DSCLOC + 1

         IF ( MOD(DSCLOC,10) .EQ. 0 ) THEN
C
C           Read the cluster record and compare.
C   
            CALL DASRRI ( SCRHAN, RECNO, 1, NWI, CLREC )
            CALL CHCKXC ( .FALSE., ' ', OK )

            CALL CHKCDS ( CLREC, XCLREC, OK )

         END IF

      END DO


C
C     Now check the file summary.
C
      CALL PACKFS ( NRESVR, NRESVC, NCOMR,  NCOMC, FREE,  
     .              LASTLA, LASTRC, LASTWD, XFSUM       )

C
C     Look up the file summary, pack into a summary array, and 
C     compare.
C
      CALL DASHFS ( SCRHAN, NRESVR, NRESVC, NCOMR,    
     .              NCOMC,  FREE,   LASTLA, LASTRC, LASTWD )

      CALL CHCKXC ( .FALSE., ' ', OK )


      CALL PACKFS ( NRESVR, NRESVC, NCOMR,  NCOMC,  FREE,  
     .              LASTLA, LASTRC, LASTWD, FSUM           )

      CALL CHKFS  ( FSUM, XFSUM, OK )

C
C     The forward pointer of the cluster directory record will point to
C     the newly allocated cluster directory record.
C
      XCLREC(FWDLOC) = PRVCLR


C     Read the cluster record and compare.
C
      CALL DASRRI ( SCRHAN, RECNO, 1, NWI, CLREC )
      CALL CHCKXC ( .FALSE., ' ', OK )

      CALL CHKCDS ( CLREC, XCLREC, OK )

      PRVCLR = RECNO



      CALL TCASE ( 'Add another set of data that fills in an entire ' //
     .             'cluster directory.  This time we''ll alternate '  //
     .             'between d.p. and character data.  We''ll '        //
     .             'leave the last(DP) cluster half full.'            )

      RECNO  = FREE   - 1
      DSCLOC = BEGDSC + 1
      PRVTYP = CHAR

C
C     Check the empty cluster directory.
C
      CALL CLEARI ( NWI, XCLREC )

      XCLREC( BWDLOC ) = PRVCLR
      XCLREC( FWDLOC ) = 0
C
C     Read the cluster record and compare.
C
      CALL DASRRI ( SCRHAN, RECNO, 1, NWI, CLREC )
      CALL CHCKXC ( .FALSE., ' ', OK )

      CALL CHKCDS ( CLREC, XCLREC, OK )


C
C     Initialize the expected cluster directory. 
C
      CALL CLEARI ( NWI, XCLREC )

      XCLREC( BWDLOC ) = PRVCLR
      XCLREC( FWDLOC ) = 0

      XCLREC( RNGMIN(CHAR) ) =  0
      XCLREC( RNGMIN(DP)   ) =  0
      XCLREC( RNGMIN(INT)  ) =  0

      XCLREC( RNGMAX(CHAR) ) =  0
      XCLREC( RNGMAX(DP)   ) =  0   
      XCLREC( RNGMAX(INT)  ) =  0  

      XCLREC( BEGDSC )       =  DP




      DO WHILE ( DSCLOC .LE. NWI )
C
C        Find the successor of PRVTYP using the cycling ordering
C
C           1 -> 2 -> 3 -> 1
C
         DTYPE = MOD( PRVTYP, 3 ) + 1

C
C        Skip over the integer type.
C
         IF ( DTYPE .EQ. INT ) THEN
            DTYPE = MOD( DTYPE, 3 ) + 1
         END IF

         IF ( DSCLOC .LT. NWI ) THEN
            NADD = SIZES(DTYPE)
         ELSE
            NADD = SIZES(DTYPE)/2
         END IF

         CALL DASCUD ( SCRHAN, DTYPE, NADD )
         CALL CHCKXC ( .FALSE., ' ', OK )

C
C        Set up the expected file summary.
C
C        Recall the last DTYPE data record is full.  We need one new,
C        non-contiguous data record of this type.
C
         IF ( DSCLOC .LT. NWI ) THEN

            FREE = FREE + 1

         ELSE
C
C           When we fill in the last cluster directory entry, we'll
C           allocate another empty directory.
C
            FREE   = FREE + 2
            PRVCLR = FREE - 1

         END IF


         LASTLA (DTYPE) = LASTLA(DTYPE)  +  NADD
         LASTRC (DTYPE) = RECNO
         LASTWD (DTYPE) = DSCLOC
 
C
C        Now check the file summary.
C
         CALL PACKFS ( NRESVR, NRESVC, NCOMR,  NCOMC, FREE,  
     .                 LASTLA, LASTRC, LASTWD, XFSUM       )

C
C        Look up the file summary, pack into a summary array, and 
C        compare.
C
         CALL DASHFS ( SCRHAN, NRESVR, NRESVC, NCOMR,    
     .                 NCOMC,  FREE,   LASTLA, LASTRC, LASTWD )

         CALL CHCKXC ( .FALSE., ' ', OK )


         CALL PACKFS ( NRESVR, NRESVC, NCOMR,  NCOMC,  FREE,  
     .                 LASTLA, LASTRC, LASTWD, FSUM           )

         CALL CHKFS  ( FSUM, XFSUM, OK )

C
C        Set up the expected  cluster record.
C
         IF ( XCLREC( RNGMAX(DTYPE) ) .EQ. 0 ) THEN
C
C           The range for this data type is initially set at 0:0.
C           We've already updated LASTLA(DTYPE).
C
            XCLREC( RNGMAX(DTYPE) ) =  LASTLA(DTYPE)

            IF ( DTYPE .EQ. DP ) THEN
               XCLREC( RNGMIN(DTYPE) ) =  LASTLA(DTYPE) - NADD + 1
            ELSE
C
C              In the character case, we'll start by filling in the 
C              last half of that empty data record which is in the
C              last character cluster belonging to the previous cluster
C              directory.  So the minimum character logical address 
C              belonging to this cluster directory will be NWC/2
C              larger than it would be if the previous character
C              record were full.
C              
               XCLREC( RNGMIN(DTYPE) ) = LASTLA(DTYPE) - NADD + 1 
     .                                   + NWC/2
            END IF                                 

         ELSE
            XCLREC( RNGMAX(DTYPE) ) =  XCLREC( RNGMAX(DTYPE) ) + NADD
         END IF

         IF ( DTYPE .EQ. XCLREC(BEGDSC) ) THEN
            XCLREC( DSCLOC ) =   1
         ELSE
            XCLREC( DSCLOC ) =  -1
         END IF


         PRVTYP = DTYPE
         DSCLOC = DSCLOC + 1

         IF ( MOD(DSCLOC,10) .EQ. 0 ) THEN
C
C           Read the cluster record and compare.
C   
            CALL DASRRI ( SCRHAN, RECNO, 1, NWI, CLREC )
            CALL CHCKXC ( .FALSE., ' ', OK )

            CALL CHKCDS ( CLREC, XCLREC, OK )

         END IF

      END DO


C
C     Now check the file summary.
C
      CALL PACKFS ( NRESVR, NRESVC, NCOMR,  NCOMC, FREE,  
     .              LASTLA, LASTRC, LASTWD, XFSUM       )

C
C     Look up the file summary, pack into a summary array, and 
C     compare.
C
      CALL DASHFS ( SCRHAN, NRESVR, NRESVC, NCOMR,    
     .              NCOMC,  FREE,   LASTLA, LASTRC, LASTWD )

      CALL CHCKXC ( .FALSE., ' ', OK )


      CALL PACKFS ( NRESVR, NRESVC, NCOMR,  NCOMC,  FREE,  
     .              LASTLA, LASTRC, LASTWD, FSUM           )

      CALL CHKFS  ( FSUM, XFSUM, OK )

C
C     The forward pointer of the cluster directory record will point to
C     the newly allocated cluster directory record.
C
      XCLREC(FWDLOC) = PRVCLR


C     Read the cluster record and compare.
C
      CALL DASRRI ( SCRHAN, RECNO, 1, NWI, CLREC )
      CALL CHCKXC ( .FALSE., ' ', OK )

      CALL CHKCDS ( CLREC, XCLREC, OK )

      PRVCLR = RECNO


      CALL T_SUCCESS ( OK )
      RETURN
      END




C
C     PACKFS is a utility subroutine which packs DAS file summary
C     information into an integer array.
C
      SUBROUTINE PACKFS ( NRESVR,
     .                    NRESVC,
     .                    NCOMR,
     .                    NCOMC,
     .                    FREE,
     .                    LASTLA,
     .                    LASTRC,
     .                    LASTWD,
     .                    FSUM     )
      IMPLICIT NONE

      INTEGER               NRESVR
      INTEGER               NRESVC
      INTEGER               NCOMR
      INTEGER               NCOMC
      INTEGER               FREE
      INTEGER               LASTLA
      INTEGER               LASTRC
      INTEGER               LASTWD
      INTEGER               FSUM   ( * )


      FSUM(1) =  NRESVR
      FSUM(2) =  NRESVC
      FSUM(3) =  NCOMR
      FSUM(4) =  NCOMC
      FSUM(5) =  FREE

      CALL MOVEI ( LASTLA, 3, FSUM(6)  )
      CALL MOVEI ( LASTRC, 3, FSUM(9)  )
      CALL MOVEI ( LASTWD, 3, FSUM(12) )

      RETURN
      END


C
C     CHKFS is a utility subroutine which compares a DAS file summary
C     to an expected summary.  Both summaries are packed into integer
C     arrays.
C

      SUBROUTINE CHKFS ( FSUM, XFSUM, OK )
      IMPLICIT NONE

      INTEGER               FSUM   ( * )
      INTEGER               XFSUM  ( * )
      LOGICAL               OK


      CALL CHCKSI( 'NRESVR',           FSUM(1),  '=', XFSUM(1),  0, OK )
      CALL CHCKSI( 'NRESVC',           FSUM(2),  '=', XFSUM(2),  0, OK )
      CALL CHCKSI( 'NCOMR',            FSUM(3),  '=', XFSUM(3),  0, OK )
      CALL CHCKSI( 'NCOMC',            FSUM(4),  '=', XFSUM(4),  0, OK )
      CALL CHCKSI( 'FREE',             FSUM(5),  '=', XFSUM(5),  0, OK )
      CALL CHCKSI( 'LASTLA(1) (CHAR)', FSUM(6),  '=', XFSUM(6),  0, OK )
      CALL CHCKSI( 'LASTLA(2) (DP)',   FSUM(7),  '=', XFSUM(7),  0, OK )
      CALL CHCKSI( 'LASTLA(3) (INT)',  FSUM(8),  '=', XFSUM(8),  0, OK )
      CALL CHCKSI( 'LASTRC(1) (CHAR)', FSUM(9),  '=', XFSUM(9),  0, OK )
      CALL CHCKSI( 'LASTRC(2) (DP)',   FSUM(10), '=', XFSUM(10), 0, OK )
      CALL CHCKSI( 'LASTRC(3) (INT)',  FSUM(11), '=', XFSUM(11), 0, OK )
      CALL CHCKSI( 'LASTWD(1) (CHAR)', FSUM(12), '=', XFSUM(12), 0, OK )
      CALL CHCKSI( 'LASTWD(2) (DP)',   FSUM(13), '=', XFSUM(13), 0, OK )
      CALL CHCKSI( 'LASTWD(3) (INT)',  FSUM(14), '=', XFSUM(14), 0, OK )

      RETURN
      END



C
C     CHKCDS is a utility subroutine which compares a DAS cluster
C     directory record to an expected cluster directory record.
C

      SUBROUTINE CHKCDS ( CDREC, XCDREC, OK )
      IMPLICIT NONE

      INTEGER               CDREC  ( * )
      INTEGER               XCDREC ( * )
      LOGICAL               OK

C
C     Local parameters
C
      INTEGER               NWI
      PARAMETER           ( NWI    =  256 )

      INTEGER               LNSIZE
      PARAMETER           ( LNSIZE =   80 )

C
C     Local variables
C
      CHARACTER*(LNSIZE)    TITLE
      INTEGER               I


      CALL CHCKSI( 'BWD ptr',       CDREC(1),  '=', XCDREC(1),  0, OK )
      CALL CHCKSI( 'FWD ptr',       CDREC(2),  '=', XCDREC(2),  0, OK )
      CALL CHCKSI( 'Min CHAR addr', CDREC(3),  '=', XCDREC(3),  0, OK )
      CALL CHCKSI( 'Max CHAR addr', CDREC(4),  '=', XCDREC(4),  0, OK )
      CALL CHCKSI( 'Min DP addr',   CDREC(5),  '=', XCDREC(5),  0, OK )
      CALL CHCKSI( 'Max DP addr',   CDREC(6),  '=', XCDREC(6),  0, OK )
      CALL CHCKSI( 'Min INT addr',  CDREC(7),  '=', XCDREC(7),  0, OK )
      CALL CHCKSI( 'Max INT addr',  CDREC(8),  '=', XCDREC(8),  0, OK )
      CALL CHCKSI( '1st type',      CDREC(9),  '=', XCDREC(9),  0, OK )
      CALL CHCKSI( '1st count',     CDREC(10), '=', XCDREC(10), 0, OK )

      DO I = 11, NWI

         TITLE = 'the # cluster count'
         CALL REPMOT ( TITLE, '#', I-9, 'L', TITLE )

         CALL CHCKSI( TITLE,  CDREC(I), '=', XCDREC(I), 0, OK )

      END DO

      RETURN
      END


