C$Procedure      F_DNEARP ( Family of DNEARP tests )
 
      SUBROUTINE F_DNEARP ( OK )
      IMPLICIT NONE
 
      LOGICAL               OK
 
C$ Abstract
C
C     This routine performs a set of rudimentary checks on the
C     routine DNEARP
C
C$ Version
C
C-    Version 2.2.1 17-JUL-2002 (BVS)
C
C        Added MAC-OSX environments (only FORTRAN ones because
C        MAC-OSX C environment has the same problem with the
C        focal point test as the Linux and classic Mac C.)
C
C-    Version 2.2.0 02-JAN-2002 (NJB) (EDW)
C
C        Added PC-LINUX_C and MACPPC_C to the set of environments
C        for which the focal point test is omitted.
C
C-    Version 2.1.0 20-Oct-1999 (WLT)
C
C         Made the test environment specific because we can't get
C         a point on the focal set of the ellipsoid on our edition
C         of PC-LINUX or the MAC
C
C-&
C
C     Spicelib Functions
C
      DOUBLE PRECISION      VNORM
      DOUBLE PRECISION      VDOT
 
 
C
C     Local Variables
C
 
      DOUBLE PRECISION      A
      DOUBLE PRECISION      ALT
      DOUBLE PRECISION      B
      DOUBLE PRECISION      C
      DOUBLE PRECISION      DALT   ( 2 )
      DOUBLE PRECISION      DNEAR  ( 6 )
      DOUBLE PRECISION      EALT   ( 2 )
      DOUBLE PRECISION      EDNEAR ( 6 )
      DOUBLE PRECISION      NPOINT1( 3 )
      DOUBLE PRECISION      NPOINT2( 3 )
      DOUBLE PRECISION      STATE  ( 6 )
 
      LOGICAL               FOUND
 
 
C
C     Begin every test family with an open call.
C
      CALL TOPEN ( 'F_DNEARP' )
 
 
      CALL TCASE ( 'Make sure that the found flag is set to '
     .//           'FALSE for a point on the focal set of the '
     .//           'ellipsoid. ' )
 
 
 
         A          = 10.0D0
         B          = 20.0D0
         C          = 20.0D0
 
         STATE( 1 ) = 0.0D0
         STATE( 2 ) = 0.0D0
         STATE( 3 ) = 0.0D0
         STATE( 4 ) = 1.0D0
         STATE( 5 ) = 2.0D0
         STATE( 6 ) = 3.0D0
 
         CALL DNEARP ( STATE, A, B, C, DNEAR, DALT, FOUND )
 
         CALL CHCKXC ( .FALSE., ' ',  OK )
         CALL CHCKSL ( 'FOUND', FOUND, .FALSE.,  OK )
 
 
      CALL TCASE ( 'Check the results of DNEARP when the body in '
     .//           'question is the unit sphere. ' )
 
         A           = 1.0D0
         B           = 1.0D0
         C           = 1.0D0
 
         STATE ( 1 ) = 10.0D0
         STATE ( 2 ) = 11.0D0
         STATE ( 3 ) = 12.0D0
         STATE ( 4 ) =  2.0D0
         STATE ( 5 ) =  3.0D0
         STATE ( 6 ) = -1.0D0
C
C        When the body is the unit sphere, the near point is just
C        the unit vector that is parallel to the position component
C        of the state vector.  The velocity of the near point
C        is the derivative of this unit vector  DVHAT handles the
C        whole problem.
C
         CALL DVHAT ( STATE, EDNEAR )
 
C
C        The latitude will be the distance from the origin minus 1.
C        The rate of change of
C
         EALT(1) = VNORM(STATE) - 1.0D0
         EALT(2) = VDOT (EDNEAR, STATE(4) )
 
         CALL DNEARP ( STATE, A, B, C, DNEAR, DALT, FOUND )
 
 
         CALL CHCKXC ( .FALSE., ' ',            OK )
         CALL CHCKSL ( 'FOUND', FOUND, .TRUE.,  OK )
         CALL CHCKAD ( 'DNEAR', DNEAR, '~/', EDNEAR, 6, 1.0D-13, OK )
         CALL CHCKAD ( 'DALT',  DALT,  '~/', EALT,   2, 1.0D-13, OK )
 
 
      CALL TCASE ( 'Check state of near point over a vertex of '
     .//           'an ellipsoid. ' )
 
         A           = 4.0D0
         B           = 4.0D0
         C           = 9.0D0
 
 
         STATE ( 1 ) =  0.0D0
         STATE ( 2 ) =  0.0D0
         STATE ( 3 ) = 12.0D0
         STATE ( 4 ) =  1.0D0
         STATE ( 5 ) =  2.0D0
         STATE ( 6 ) =  5.0D0
 
 
         EDNEAR( 1 ) =  0.0D0
         EDNEAR( 2 ) =  0.0D0
         EDNEAR( 3 ) =  9.0D0
         EDNEAR( 4 ) =  0.75D0
         EDNEAR( 5 ) =  1.50D0
         EDNEAR( 6 ) =  0.0D0
 
         EALT  ( 1 ) =  3.0D0
         EALT  ( 2 ) =  5.0D0
 
         CALL NEARPT ( STATE, A, B, C, NPOINT1, ALT )
         CALL VLCOM  ( 1.0D0, STATE, 0.00001D0, STATE(4), STATE )
         CALL NEARPT ( STATE, A, B, C, NPOINT2, ALT )
 
         CALL VLCOM  ( 100000.0D0, NPOINT2,
     .                -100000.0D0, NPOINT1, EDNEAR(4) )
 
         STATE ( 1 ) =  0.0D0
         STATE ( 2 ) =  0.0D0
         STATE ( 3 ) = 12.0D0
         STATE ( 4 ) =  1.0D0
         STATE ( 5 ) =  2.0D0
         STATE ( 6 ) =  5.0D0
 
         CALL DNEARP ( STATE, A, B, C, DNEAR, DALT, FOUND )
 
         CALL CHCKXC ( .FALSE., ' ',            OK )
         CALL CHCKSL ( 'FOUND', FOUND, .TRUE.,  OK )
         CALL CHCKAD ( 'DNEAR', DNEAR, '~',  EDNEAR, 6, 1.0D-5,  OK )
         CALL CHCKAD ( 'DALT',  DALT,  '~/', EALT,   2, 1.0D-13, OK )
 
 
      CALL T_SUCCESS ( OK )
      RETURN
      END
