C$Procedure      F_DVOPS (Family of vector operations derivative tests)
 
      SUBROUTINE F_DVOPS ( OK )
      IMPLICIT NONE
 
      LOGICAL               OK
 
C$ Abstract
C
C     This routine performs rudimentary tests on a collection
C     of derivative of vector operation
C
C-&
 
 
C
C     Test Utility Functions
C
 
 
C
C     SPICELIB Functions
C
      DOUBLE PRECISION      DVDOT
 
C
C     Local Variables
C
      DOUBLE PRECISION      S1   ( 6 )
      DOUBLE PRECISION      S2   ( 6 )
      DOUBLE PRECISION      SOUT ( 6 )
      DOUBLE PRECISION      PRT1 ( 3 )
      DOUBLE PRECISION      PRT2 ( 3 )
 
      DOUBLE PRECISION      EXP
      DOUBLE PRECISION      EXPV ( 6 )
      DOUBLE PRECISION      CMP
      DOUBLE PRECISION      LENGTH
 
 
 
 
 
C
C     Begin every test family with an open call.
C
      CALL TOPEN ( 'F_DVOPS' )
 
      S1( 1 ) =  1.0D0
      S1( 2 ) =  2.0D0
      S1( 3 ) =  1.0D0
      S1( 4 ) =  1.0D0
      S1( 5 ) = -1.0D0
      S1( 6 ) =  3.0D0
 
      S2( 1 ) = 2.0D0
      S2( 2 ) = 3.0D0
      S2( 3 ) = 4.0D0
      S2( 4 ) = 1.0D0
      S2( 5 ) = 2.0D0
      S2( 6 ) = 3.0D0
 
      CALL TCASE ( 'Test DVDOT.' )
 
 
         EXP =  S1(1) * S2(4)   +  S1(4)*S2(1)
     .       +  S1(2) * S2(5)   +  S1(5)*S2(2)
     .       +  S1(3) * S2(6)   +  S1(6)*S2(3)
 
         CMP = DVDOT( S1, S2 )
 
         CALL CHCKXC ( .FALSE.,      ' ',             OK )
         CALL CHCKSD ( 'DVDOT', CMP, '=', EXP, 0.0D0, OK )
 
 
      CALL TCASE ( 'Test DVCRSS.' )
 
 
         CALL VCRSS ( S1(1),   S2  (1), EXPV(1) )
         CALL VCRSS ( S1(1),   S2  (4), PRT1(1) )
         CALL VCRSS ( S1(4),   S2  (1), PRT2(1) )
         CALL VADD  ( PRT1(1), PRT2(1), EXPV(4) )
 
         CALL CHCKXC ( .FALSE., ' ',  OK   )
         CALL DVCRSS (  S1,      S2,  SOUT )
 
         CALL CHCKXC ( .FALSE., ' ',  OK )
         CALL CHCKAD ( 'SOUT', SOUT, '=', EXPV, 6, 0.0D0, OK )
 
 
      CALL TCASE ( 'Test DVHAT with a state having non-zero position.' )
 
         CALL UNORM ( S1,           EXPV,    LENGTH  )
         CALL VPERP ( S1(4),        EXPV,    EXPV(4) )
         CALL VSCL  ( 1.0D0/LENGTH, EXPV(4), EXPV(4) )
 
         CALL DVHAT ( S1,                    SOUT    )
 
         CALL CHCKXC ( .FALSE., ' ',  OK )
         CALL CHCKAD ( 'SOUT', SOUT, '=', EXPV, 6, 0.0D0, OK )
 
      CALL TCASE ( 'Test DVHAT with a state having zero position.' )
 
 
         S1(1)   = 0.0D0
         S1(2)   = 0.0D0
         S1(3)   = 0.0D0
 
         EXPV(1) = 0.0D0
         EXPV(2) = 0.0D0
         EXPV(3) = 0.0D0
         EXPV(4) = S1(4)
         EXPV(5) = S1(5)
         EXPV(6) = S1(6)
 
         CALL DVHAT  ( S1,            SOUT )
 
         CALL CHCKXC ( .FALSE., ' ',  OK   )
         CALL CHCKAD ( 'SOUT', SOUT, '=', EXPV, 6, 0.0D0, OK )
 
      CALL TCASE ( 'Test DUCRSS' )
 
         S1( 1 ) =  1.0D0
         S1( 2 ) =  2.0D0
         S1( 3 ) =  1.0D0
 
         CALL VCRSS ( S1(1),   S2(1),        EXPV(1) )
         CALL VCRSS ( S1(1),   S2(4),        PRT1(1) )
         CALL VCRSS ( S1(4),   S2(1),        PRT2(1) )
         CALL VADD  ( PRT1(1), PRT2(1),      EXPV(4) )
         CALL UNORM ( EXPV,    EXPV,         LENGTH  )
         CALL VPERP ( EXPV(4), EXPV(1),      EXPV(4) )
         CALL VSCL  ( 1.0D0/LENGTH, EXPV(4), EXPV(4) )
 
         CALL DUCRSS ( S1, S2,  SOUT )
 
         CALL CHCKXC ( .FALSE., ' ',                      OK )
         CALL CHCKAD ( 'SOUT', SOUT, '=', EXPV, 6, 0.0D0, OK )
 
 
      CALL T_SUCCESS ( OK )
      RETURN
      END
