C$Procedure F_DYN05 ( Dynamic Frame Test Family 05 )
 
      SUBROUTINE F_DYN05 ( OK )
 
C$ Abstract
C
C     Test family to exercise SPICELIB interfaces that indirectly
C     exercise dynamic frame code.
C
C$ Copyright
C
C     Copyright (2004), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     None.
C
C$ Keywords
C
C     TEST FAMILY
C
C$ Declarations
 
      IMPLICIT NONE
 
      INCLUDE 'zzdyn.inc'
      INCLUDE 'frmtyp.inc'
 
      LOGICAL               OK
 
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     OK         O   logical indicating test status.
C
C$ Detailed_Input
C
C     None.
C
C$ Detailed_Output
C
C     OK         is a logical that indicates the test status to the
C                caller.
C
C$ Parameters
C
C     None.
C
C$ Files
C
C     This test family uses the following kernels:
C
C        CKs generated by tstck3:  one default, one modified
C        by changing descriptor via DAFRS.
C
C        LSK generated by tstlsk
C
C        PCK generated by t_pck08
C
C        SPKs generated by tstspk: one default, one modified
C        by changing descriptor via DAFRS.
C
C$ Exceptions
C
C     This routine does not generate any errors. Routines in its
C     call tree may generate errors that are either intentional and
C     trapped or unintentional and need reporting.  The test family
C     utilities manage this.
C
C$ Particulars
C
C     Test family F_DYN05 exercises SPICELIB interfaces that use
C     dynamic frames.
C
C     Most tests done here check interfaces by means of consistency
C     checks:  computations are done in alternate ways and the results
C     are compared.  The test rely heavily on the routines SXFORM
C     and PXFORM; the other test families are expected to prove these
C     two routines correct.
C
C     This routine attempts to exercise the main computational paths of
C     the underlying frame transformation code; for this reason,
C     examples of each frame family are used in at least one test. The
C     tests of the frame transformation code are meant first of all to
C     simply verify that the integrated dynamic frame capability works,
C     but also to probe for possible recursion violations.  However
C     these tests are not exhaustive; the frame-family-specific test
C     families are expected to cover all logic paths in the low-level
C     frame transformation code.
C
C     In some cases, the tests simply verify that improper uses
C     of dynamic frames are diagnosed.
C
C     Here kernel readers are considered to be part of the API:  this
C     test family checks the ability of the SPK and CK readers,
C     respectively, to properly handle SPK and CK segments having
C     dynamic base frames.  Note that PCKs are not allowed to have
C     non-inertial base frames.
C
C
C     Covered API routines are:
C
C        Frame subsystem
C        ===============
C
C           Transformation routines
C           -----------------------
C           PXFORM
C           SXFORM
C
C
C           FRAMEX ("frame expert") routines
C           --------------------------------
C           CIDFRM
C           CNMFRM
C           FRINFO
C           FRMNAM
C           NAMFRM
C
C        SPK subsystem
C        ===============
C
C           Principal readers
C           -----------------
C           SPKEZR
C           SPKPOS
C           SPKEZ
C           SPKEZP
C
C           Geometric state API
C           -------------------
C           SPKGEO
C           SPKGPS
C
C           Apparent state routines
C           -----------------------
C           SPKAPO
C           SPKAPP
C
C           Barycentric state API
C           ---------------------
C           SPKSSB
C
C           Miscellaneous (deprecated)
C           --------------------------
C           SPKPV
C
C
C        CK subsystem
C        ===============
C        CKGP
C        CPGPAV
C
C        PCK subsystem
C        ===============
C        TIPBOD
C        TISBOD
C
C
C$ Examples
C
C     None.
C
C$ Restrictions
C
C     None.
C
C$ Author_and_Institution
C
C     N.J. Bachman     (JPL)
C
C$ Literature_References
C
C     None.
C
C$ Version
C
C-    TSPICE Version 1.0.0, 22-DEC-2004 (NJB)
C
C
C-&
 
C
C     SPICELIB functions
C
 
 
C
C     Local Parameters
C
      CHARACTER*(*)         IAU76
      PARAMETER           ( IAU76  = 'EARTH_IAU_1976' )
 
      CHARACTER*(*)         IAU80
      PARAMETER           ( IAU80  = 'EARTH_IAU_1980' )
 
      CHARACTER*(*)         TXTPCK
      PARAMETER           ( TXTPCK = 'test_dyn.tpc' )
 
      CHARACTER*(*)         SPK
      PARAMETER           ( SPK    = 'test_dyn.bsp' )
 
      CHARACTER*(*)         SPK2
      PARAMETER           ( SPK2   = 'tst_dyn2.bsp' )
 
C
C     Note:  the name CKNM was picked because the more consistent
C     name "CK" is taken---it's the name of a frame class.
C
      CHARACTER*(*)         CKNM
      PARAMETER           ( CKNM   = 'test_ck3.bc'  )
 
      CHARACTER*(*)         CK2
      PARAMETER           ( CK2    = 'tst_dyn2.bc'  )
 
      CHARACTER*(*)         SCLK
      PARAMETER           ( SCLK   = 'test_ck3.tsc' )
 
 
C
C     Tolerance levels for various tests.
C
      DOUBLE PRECISION      EX13
      PARAMETER           ( EX13   = 1.D-13 )
 
 
      INTEGER               SIDLEN
      PARAMETER           ( SIDLEN = 40 )
 
      INTEGER               NAMLEN
      PARAMETER           ( NAMLEN = 32 )
 
      INTEGER               LNSIZE
      PARAMETER           ( LNSIZE = 80 )
 
      INTEGER               MAXDEF
      PARAMETER           ( MAXDEF = 50 )
 
      INTEGER               MAXTOK
      PARAMETER           ( MAXTOK = 7 )
 
      INTEGER               DSCSIZ
      PARAMETER           ( DSCSIZ = 5 )
 
      INTEGER               ND
      PARAMETER           ( ND     = 2 )
 
      INTEGER               NI
      PARAMETER           ( NI     = 6 )
 
C
C     Local Variables
C
      CHARACTER*(LNSIZE)    DEFTXT ( MAXDEF )
      CHARACTER*(NAMLEN)    FRNAME
      CHARACTER*(SIDLEN)    IDENT
 
      DOUBLE PRECISION      AV0    ( 3 )
      DOUBLE PRECISION      AV1    ( 3 )
      DOUBLE PRECISION      AV2    ( 3 )
      DOUBLE PRECISION      CLKOUT
      DOUBLE PRECISION      CMAT0  ( 3, 3 )
      DOUBLE PRECISION      CMAT1  ( 3, 3 )
      DOUBLE PRECISION      CMAT2  ( 3, 3 )
      DOUBLE PRECISION      DC     ( ND )
      DOUBLE PRECISION      ET
      DOUBLE PRECISION      ETCORR
      DOUBLE PRECISION      LT
      DOUBLE PRECISION      POS0   ( 3 )
      DOUBLE PRECISION      POS1   ( 3 )
      DOUBLE PRECISION      POS2   ( 3 )
      DOUBLE PRECISION      R      ( 3, 3 )
      DOUBLE PRECISION      SCLKDP
      DOUBLE PRECISION      STATE0 ( 6 )
      DOUBLE PRECISION      STATE1 ( 6 )
      DOUBLE PRECISION      STATE2 ( 6 )
      DOUBLE PRECISION      SUM    ( DSCSIZ )
      DOUBLE PRECISION      XF2    ( 6, 6 )
      DOUBLE PRECISION      XF3    ( 6, 6 )
      DOUBLE PRECISION      XF4    ( 6, 6 )
      DOUBLE PRECISION      XFORM  ( 6, 6 )
 
      INTEGER               CENTER
      INTEGER               CLASS
      INTEGER               CLKID
      INTEGER               CLSSID
      INTEGER               FRCODE
      INTEGER               HAN
      INTEGER               HANDLE ( 4  )
      INTEGER               IC     ( NI )
      INTEGER               INSTID
      INTEGER               RC2CDE
 
      LOGICAL               FOUND
 
C
C     Saved variables
C
 
C
C     Initial values
C
 
 
 
 
C
C     Open the test family.
C
      CALL TOPEN ( 'F_DYN05' )
 
 
C
C --- Case: ------------------------------------------------------
C
      CALL TCASE ( 'Create test inputs for comprehensive mean-of' //
     .             '-date test.'                                  )
 
C
C     Create and load kernels.
C
      CALL TSTLSK
      CALL CHCKXC  ( .FALSE., ' ', OK )
 
      CALL TSTSPK  ( SPK, .TRUE., HANDLE(1) )
      CALL CHCKXC  ( .FALSE., ' ', OK )
 
      CALL T_PCK08 ( TXTPCK, .TRUE., .FALSE. )
      CALL CHCKXC  ( .FALSE., ' ', OK )
 
      CALL TSTCK3  ( CKNM, SCLK, .TRUE., .TRUE., .FALSE., HANDLE(2) )
 
 
C
C     Define a CK frame associated with instrument -10001; the pointing
C     for this instrument is given by the CK created by the test
C     utility TSTCK3.
C
      DEFTXT(1) =
     .'FRAME_CK_-10001                  =  -10001'
      DEFTXT(2) =
     .'FRAME_-10001_NAME                = ''CK_-10001'''
      DEFTXT(3) =
     .'FRAME_-10001_CLASS               =  3'
      DEFTXT(4) =
     .'FRAME_-10001_CLASS_ID            =  -10001'
      DEFTXT(5) =
     .'FRAME_-10001_CENTER              =  -9'
      DEFTXT(6) =
     .'FRAME_-10001_RELATIVE            = ''J2000'''
 
C
C     Load the CK_-10001 frame definition.
C
      CALL LMPOOL ( DEFTXT, 6 )
      CALL CHCKXC ( .FALSE., ' ', OK )
 
 
C
C     Define a CK frame associated with instrument -9901; the pointing
C     for this instrument is given by the CK created by the test
C     utility TSTCK3.
C
      DEFTXT(1) =
     .'FRAME_CK_-9901                   =  -9901'
      DEFTXT(2) =
     .'FRAME_-9901_NAME                 = ''CK_-9901'''
      DEFTXT(3) =
     .'FRAME_-9901_CLASS                =  3'
      DEFTXT(4) =
     .'FRAME_-9901_CLASS_ID             =  -9901'
      DEFTXT(5) =
     .'FRAME_-9901_CENTER               =  -9'
      DEFTXT(6) =
     .'FRAME_-9901_RELATIVE             = ''GALACTIC'''
 
C
C     Load the CK_-9901 frame definition.
C
      CALL LMPOOL ( DEFTXT, 6 )
      CALL CHCKXC ( .FALSE., ' ', OK )
 
C
C     We'll need to several dynamic frames. Since the purpose of the
C     frames is to test the ability of the frame subsystem to handle
C     varying levels of recursive calls, we'll name the frames based on
C     the required recursion levels associated with transformations
C     between the frames and the J2000 frame.
C
      DEFTXT(1) =
     .'FRAME_RECUR_1                    =  2399001'
      DEFTXT(2) =
     .'FRAME_2399001_NAME               = ''RECUR_1'''
      DEFTXT(3) =
     .'FRAME_2399001_CLASS              =  5'
      DEFTXT(4) =
     .'FRAME_2399001_CLASS_ID           =  2399001'
      DEFTXT(5) =
     .'FRAME_2399001_CENTER             =  399'
      DEFTXT(6) =
     .'FRAME_2399001_RELATIVE           = ''J2000'''
      DEFTXT(7) =
     .'FRAME_2399001_'//KWSTYL//'       = '''// KVPARM //''''
      DEFTXT(8) =
     .'FRAME_2399001_'//KWFFAM//'             = '''// KV2VEC //''''
      DEFTXT(9) =
     .'FRAME_2399001_'//KWPRI//KWVAXI//'       = '''//KWX//''''
      DEFTXT(10) =
     .'FRAME_2399001_'//KWPRI//KWVCDF//'       = '''//KVNEAR//''''
      DEFTXT(11) =
     .'FRAME_2399001_'//KWPRI//KWVOBS//'       = ''EARTH'''
      DEFTXT(12) =
     .'FRAME_2399001_'//KWPRI//KWVTRG//'         = ''SUN'''
      DEFTXT(13) =
     .'FRAME_2399001_'//KWPRI//KWVABC//'         = ''NONE'''
      DEFTXT(14) =
     .'FRAME_2399001_'//KWSEC//KWVAXI//'       = ''-'//KWY//''''
      DEFTXT(15) =
     .'FRAME_2399001_'//KWSEC//KWVCDF//'       =  '''// KVVELV //''''
      DEFTXT(16) =
     .'FRAME_2399001_'//KWSEC//KWVOBS//'       = ''SUN'''
      DEFTXT(17) =
     .'FRAME_2399001_'//KWSEC//KWVTRG//'       = ''EARTH'''
      DEFTXT(18) =
     .'FRAME_2399001_'//KWSEC//KWVABC//'         = ''NONE'''
      DEFTXT(19) =
     .'FRAME_2399001_'//KWSEC//KWVFRM//'          = ''J2000'''
      DEFTXT(20) =
     .'FRAME_2399001_'//KWRSTA//'       =  '''// KVROTG //''''
 
 
C
C     Load the RECUR_1 frame definition.
C
      CALL LMPOOL ( DEFTXT, 20 )
      CALL CHCKXC ( .FALSE., ' ', OK )
 
C
C     Define a two-vector frame using a constant vector and
C     requiring one level of recursion for evaluation.
C
      DEFTXT(1) =
     .'FRAME_RECUR_1B                    =  2399002'
      DEFTXT(2) =
     .'FRAME_2399002_NAME               = ''RECUR_1B'''
      DEFTXT(3) =
     .'FRAME_2399002_CLASS              =  5'
      DEFTXT(4) =
     .'FRAME_2399002_CLASS_ID           =  2399002'
      DEFTXT(5) =
     .'FRAME_2399002_CENTER             =  399'
      DEFTXT(6) =
     .'FRAME_2399002_RELATIVE           = ''J2000'''
      DEFTXT(7) =
     .'FRAME_2399002_'//KWSTYL//'       = '''// KVPARM //''''
      DEFTXT(8) =
     .'FRAME_2399002_'//KWFFAM//'             = '''// KV2VEC //''''
      DEFTXT(9) =
     .'FRAME_2399002_'//KWPRI//KWVAXI//'       = '''//KWX//''''
      DEFTXT(10) =
     .'FRAME_2399002_'//KWPRI//KWVCDF//'       = '''//KVCONS//''''
      DEFTXT(11) =
     .'FRAME_2399002_'//KWPRI//KWVFRM//'          = ''IAU_SUN'''
      DEFTXT(12) =
     .'FRAME_2399002_'//KWPRI//KWVOBS//'       = ''EARTH'''
      DEFTXT(13) =
     .'FRAME_2399002_'//KWPRI//KWVABC//'         = ''LT'''
      DEFTXT(14) =
     .'FRAME_2399002_'//KWPRI//KWVSPC//'         = '''//KVLATC//''''
      DEFTXT(15) =
     .'FRAME_2399002_'//KWPRI//KWUNIT//'         = '''//KVDEGR//''''
      DEFTXT(16) =
     .'FRAME_2399002_'//KWPRI//KWLON//'          =  60.0'
      DEFTXT(17) =
     .'FRAME_2399002_'//KWPRI//KWLAT//'          = -30.0'
      DEFTXT(18) =
     .'FRAME_2399002_'//KWSEC//KWVAXI//'       = ''-'//KWY//''''
      DEFTXT(19) =
     .'FRAME_2399002_'//KWSEC//KWVCDF//'       =  '''// KVVELV //''''
      DEFTXT(20) =
     .'FRAME_2399002_'//KWSEC//KWVOBS//'       = ''SUN'''
      DEFTXT(21) =
     .'FRAME_2399002_'//KWSEC//KWVTRG//'       = ''EARTH'''
      DEFTXT(22) =
     .'FRAME_2399002_'//KWSEC//KWVABC//'         = ''NONE'''
      DEFTXT(23) =
     .'FRAME_2399002_'//KWSEC//KWVFRM//'          = ''J2000'''
      DEFTXT(24) =
     .'FRAME_2399002_'//KWRSTA//'       =  '''// KVROTG //''''
 
 
 
C
C     Load the RECUR_1B frame definition.
C
      CALL LMPOOL ( DEFTXT, 24 )
      CALL CHCKXC ( .FALSE., ' ', OK )
 
 
C
C     Define the RECUR_2 frame.
C
      DEFTXT(1) =
     .'FRAME_RECUR_2                    =  2401000'
      DEFTXT(2) =
     .'FRAME_2401000_NAME               = ''RECUR_2'''
      DEFTXT(3) =
     .'FRAME_2401000_CLASS              =  5'
      DEFTXT(4) =
     .'FRAME_2401000_CLASS_ID           =  2401000'
      DEFTXT(5) =
     .'FRAME_2401000_CENTER             =  401'
      DEFTXT(6) =
     .'FRAME_2401000_RELATIVE           = ''IAU_MARS'''
      DEFTXT(7) =
     .'FRAME_2401000_'//KWSTYL//'       = '''// KVPARM //''''
      DEFTXT(8) =
     .'FRAME_2401000_'//KWFFAM//'             = '''// KV2VEC //''''
      DEFTXT(9) =
     .'FRAME_2401000_'//KWPRI//KWVAXI//'       = '''//KWZ//''''
      DEFTXT(10) =
     .'FRAME_2401000_'//KWPRI//KWVCDF//'       = '''//KVPOSV//''''
      DEFTXT(11) =
     .'FRAME_2401000_'//KWPRI//KWVOBS//'       = ''PHOBOS'''
      DEFTXT(12) =
     .'FRAME_2401000_'//KWPRI//KWVTRG//'         = ''MARS'''
      DEFTXT(13) =
     .'FRAME_2401000_'//KWPRI//KWVABC//'         = ''NONE'''
      DEFTXT(14) =
     .'FRAME_2401000_'//KWSEC//KWVAXI//'       = ''-'//KWX//''''
      DEFTXT(15) =
     .'FRAME_2401000_'//KWSEC//KWVCDF//'       =  '''// KVVELV //''''
      DEFTXT(16) =
     .'FRAME_2401000_'//KWSEC//KWVOBS//'       = ''PHOBOS'''
      DEFTXT(17) =
     .'FRAME_2401000_'//KWSEC//KWVTRG//'       = ''MARS'''
      DEFTXT(18) =
     .'FRAME_2401000_'//KWSEC//KWVABC//'         = ''NONE'''
      DEFTXT(19) =
     .'FRAME_2401000_'//KWSEC//KWVFRM//'          = ''RECUR_1'''
      DEFTXT(20) =
     .'FRAME_2401000_'//KWRSTA//'       =  '''// KVROTG //''''
 
C
C     Load the RECUR_2 frame definition.
C
      CALL LMPOOL ( DEFTXT, 20 )
      CALL CHCKXC ( .FALSE., ' ', OK )
 
 
C
C     Define a two-vector frame using a constant vector and
C     requiring two levels of recursion for evaluation.
C
C
      DEFTXT(1) =
     .'FRAME_RECUR_2B                    =  2399003'
      DEFTXT(2) =
     .'FRAME_2399003_NAME               = ''RECUR_2B'''
      DEFTXT(3) =
     .'FRAME_2399003_CLASS              =  5'
      DEFTXT(4) =
     .'FRAME_2399003_CLASS_ID           =  2399003'
      DEFTXT(5) =
     .'FRAME_2399003_CENTER             =  399'
      DEFTXT(6) =
     .'FRAME_2399003_RELATIVE           = ''J2000'''
      DEFTXT(7) =
     .'FRAME_2399003_'//KWSTYL//'       = '''// KVPARM //''''
      DEFTXT(8) =
     .'FRAME_2399003_'//KWFFAM//'             = '''// KV2VEC //''''
      DEFTXT(9) =
     .'FRAME_2399003_'//KWPRI//KWVAXI//'       = '''//KWX//''''
      DEFTXT(10) =
     .'FRAME_2399003_'//KWPRI//KWVCDF//'       = '''//KVCONS//''''
      DEFTXT(11) =
     .'FRAME_2399003_'//KWPRI//KWVFRM//'          = ''RECUR_1B'''
      DEFTXT(12) =
     .'FRAME_2399003_'//KWPRI//KWVOBS//'       = ''SUN'''
      DEFTXT(13) =
     .'FRAME_2399003_'//KWPRI//KWVABC//'         = ''XS'''
      DEFTXT(14) =
     .'FRAME_2399003_'//KWPRI//KWVSPC//'         = '''//KVLATC//''''
      DEFTXT(15) =
     .'FRAME_2399003_'//KWPRI//KWUNIT//'         = '''//KVDEGR//''''
      DEFTXT(16) =
     .'FRAME_2399003_'//KWPRI//KWLON//'          =  60.0'
      DEFTXT(17) =
     .'FRAME_2399003_'//KWPRI//KWLAT//'          = -30.0'
      DEFTXT(18) =
     .'FRAME_2399003_'//KWSEC//KWVAXI//'       = ''-'//KWY//''''
      DEFTXT(19) =
     .'FRAME_2399003_'//KWSEC//KWVCDF//'       =  '''// KVVELV //''''
      DEFTXT(20) =
     .'FRAME_2399003_'//KWSEC//KWVOBS//'       = ''SUN'''
      DEFTXT(21) =
     .'FRAME_2399003_'//KWSEC//KWVTRG//'       = ''EARTH'''
      DEFTXT(22) =
     .'FRAME_2399003_'//KWSEC//KWVABC//'         = ''NONE'''
      DEFTXT(23) =
     .'FRAME_2399003_'//KWSEC//KWVFRM//'          = ''J2000'''
      DEFTXT(24) =
     .'FRAME_2399003_'//KWRSTA//'       =  '''// KVROTG //''''
 
C
C     Load the RECUR_2B frame definition.
C
      CALL LMPOOL ( DEFTXT, 24 )
      CALL CHCKXC ( .FALSE., ' ', OK )
 
 
C
C     Define the RECUR_3 frame.  This frame is used to test
C     error detection when excessive recursion depth is required
C     to evaluate a dynamic frame.
C
      DEFTXT(1) =
     .'FRAME_RECUR_3                    =  2499000'
      DEFTXT(2) =
     .'FRAME_2499000_NAME               = ''RECUR_3'''
      DEFTXT(3) =
     .'FRAME_2499000_CLASS              =  5'
      DEFTXT(4) =
     .'FRAME_2499000_CLASS_ID           =  2499000'
      DEFTXT(5) =
     .'FRAME_2499000_CENTER             =  401'
      DEFTXT(6) =
     .'FRAME_2499000_RELATIVE           = ''IAU_MARS'''
      DEFTXT(7) =
     .'FRAME_2499000_'//KWSTYL//'       = '''// KVPARM //''''
      DEFTXT(8) =
     .'FRAME_2499000_'//KWFFAM//'             = '''// KV2VEC //''''
      DEFTXT(9) =
     .'FRAME_2499000_'//KWPRI//KWVAXI//'       = '''//KWZ//''''
      DEFTXT(10) =
     .'FRAME_2499000_'//KWPRI//KWVCDF//'       = '''//KVPOSV//''''
      DEFTXT(11) =
     .'FRAME_2499000_'//KWPRI//KWVOBS//'       = ''MARS'''
      DEFTXT(12) =
     .'FRAME_2499000_'//KWPRI//KWVTRG//'         = ''SUN'''
      DEFTXT(13) =
     .'FRAME_2499000_'//KWPRI//KWVABC//'         = ''NONE'''
      DEFTXT(14) =
     .'FRAME_2499000_'//KWSEC//KWVAXI//'       = ''-'//KWX//''''
      DEFTXT(15) =
     .'FRAME_2499000_'//KWSEC//KWVCDF//'       =  '''// KVVELV //''''
      DEFTXT(16) =
     .'FRAME_2499000_'//KWSEC//KWVOBS//'       = ''MARS'''
      DEFTXT(17) =
     .'FRAME_2499000_'//KWSEC//KWVTRG//'       = ''SUN'''
      DEFTXT(18) =
     .'FRAME_2499000_'//KWSEC//KWVABC//'         = ''NONE'''
      DEFTXT(19) =
     .'FRAME_2499000_'//KWSEC//KWVFRM//'          = ''RECUR_2'''
      DEFTXT(20) =
     .'FRAME_2499000_'//KWRSTA//'       =  '''// KVROTG //''''
 
C
C     Load the RECUR_3 frame definition.
C
      CALL LMPOOL ( DEFTXT, 20 )
      CALL CHCKXC ( .FALSE., ' ', OK )
 
 
C
C     Define the RECUR_3B frame.  This frame is used to test
C     error detection when excessive recursion depth is required
C     to evaluate a dynamic frame.
C
      DEFTXT(1) =
     .'FRAME_RECUR_3B                   =  2499001'
      DEFTXT(2) =
     .'FRAME_2499001_NAME               = ''RECUR_3B'''
      DEFTXT(3) =
     .'FRAME_2499001_CLASS              =  5'
      DEFTXT(4) =
     .'FRAME_2499001_CLASS_ID           =  2499001'
      DEFTXT(5) =
     .'FRAME_2499001_CENTER             =  401'
      DEFTXT(6) =
     .'FRAME_2499001_RELATIVE           = ''IAU_MARS'''
      DEFTXT(7) =
     .'FRAME_2499001_'//KWSTYL//'       = '''// KVPARM //''''
      DEFTXT(8) =
     .'FRAME_2499001_'//KWFFAM//'             = '''// KV2VEC //''''
      DEFTXT(9) =
     .'FRAME_2499001_'//KWPRI//KWVAXI//'       = '''//KWZ//''''
      DEFTXT(10) =
     .'FRAME_2499001_'//KWPRI//KWVCDF//'       = '''//KVPOSV//''''
      DEFTXT(11) =
     .'FRAME_2499001_'//KWPRI//KWVOBS//'       = ''MARS'''
      DEFTXT(12) =
     .'FRAME_2499001_'//KWPRI//KWVTRG//'         = ''SUN'''
      DEFTXT(13) =
     .'FRAME_2499001_'//KWPRI//KWVABC//'         = ''NONE'''
      DEFTXT(14) =
     .'FRAME_2499001_'//KWSEC//KWVAXI//'       = ''-'//KWX//''''
      DEFTXT(15) =
     .'FRAME_2499001_'//KWSEC//KWVCDF//'       =  '''// KVVELV //''''
      DEFTXT(16) =
     .'FRAME_2499001_'//KWSEC//KWVOBS//'       = ''MARS'''
      DEFTXT(17) =
     .'FRAME_2499001_'//KWSEC//KWVTRG//'       = ''SUN'''
      DEFTXT(18) =
     .'FRAME_2499001_'//KWSEC//KWVABC//'         = ''NONE'''
      DEFTXT(19) =
     .'FRAME_2499001_'//KWSEC//KWVFRM//'          = ''RECUR_2B'''
      DEFTXT(20) =
     .'FRAME_2499001_'//KWRSTA//'       =  '''// KVROTG //''''
 
 
C
C     Load the RECUR_3B frame definition.
C
      CALL LMPOOL ( DEFTXT, 20 )
      CALL CHCKXC ( .FALSE., ' ', OK )
 
 
C
C     Define the EARTH_MEAN_OF_DATE frame.
C
      DEFTXT(1) =
     .'FRAME_EARTH_MEAN_OF_DATE         =  2399004'
      DEFTXT(2) =
     .'FRAME_2399004_NAME               = ''EARTH_MEAN_OF_DATE'''
      DEFTXT(3) =
     .'FRAME_2399004_CLASS              =  5'
      DEFTXT(4) =
     .'FRAME_2399004_CLASS_ID           =  2399004'
      DEFTXT(5) =
     .'FRAME_2399004_CENTER             =  399'
      DEFTXT(6) =
     .'FRAME_2399004_RELATIVE           = ''J2000'''
      DEFTXT(7) =
     .'FRAME_2399004_' // KWSTYL // '   = ''' // KVPARM // ''''
      DEFTXT(8) =
     .'FRAME_2399004_' // KWFFAM // '             = '''// KVMEQT //''''
      DEFTXT(9) =
     .'FRAME_2399004_' // KWPRCM // '   = ''' // KVM001 // ''''
      DEFTXT(10) =
     .'FRAME_2399004_' // KWRSTA // '    = ''' // KVROTG //''''
 
C
C     Load the EARTH_MEAN_OF_DATE frame definition.
C
      CALL LMPOOL ( DEFTXT, 10 )
      CALL CHCKXC ( .FALSE., ' ', OK )
 
 
C
C     Define the EARTH_TRUE_OF_DATE frame.
C
      DEFTXT(1) =
     .'FRAME_EARTH_TRUE_OF_DATE         =  2399005'
      DEFTXT(2) =
     .'FRAME_2399005_NAME               = ''EARTH_TRUE_OF_DATE'''
      DEFTXT(3) =
     .'FRAME_2399005_CLASS              =  5'
      DEFTXT(4) =
     .'FRAME_2399005_CLASS_ID           =  2399005'
      DEFTXT(5) =
     .'FRAME_2399005_CENTER             =  399'
      DEFTXT(6) =
     .'FRAME_2399005_RELATIVE           = ''J2000'''
      DEFTXT(7) =
     .'FRAME_2399005_' // KWSTYL // '   = ''' // KVPARM // ''''
      DEFTXT(8) =
     .'FRAME_2399005_' // KWFFAM // '             = '''// KVTEQT //''''
      DEFTXT(9) =
     .'FRAME_2399005_' // KWPRCM // '   = ''' // KVM001 // ''''
      DEFTXT(10) =
     .'FRAME_2399005_' // KWNUTM // '   = ''' // KVM002 // ''''
      DEFTXT(11) =
     .'FRAME_2399005_' // KWRSTA // '    = ''' // KVROTG //''''
 
C
C     Load the EARTH_TRUE_OF_DATE frame definition.
C
      CALL LMPOOL ( DEFTXT, 11 )
      CALL CHCKXC ( .FALSE., ' ', OK )
 
 
C
C     Define the MARS_EULER frame.
C
      DEFTXT(1) =
     .'FRAME_MARS_EULER                 =  2499002'
      DEFTXT(2) =
     .'FRAME_2499002_NAME               = ''MARS_EULER'''
      DEFTXT(3) =
     .'FRAME_2499002_CLASS              =  5'
      DEFTXT(4) =
     .'FRAME_2499002_CLASS_ID           =  2499002'
      DEFTXT(5) =
     .'FRAME_2499002_CENTER             =  499'
      DEFTXT(6) =
     .'FRAME_2499002_RELATIVE           = ''J2000'''
      DEFTXT(7) =
     .'FRAME_2499002_' // KWSTYL // '   = ''' // KVPARM // ''''
      DEFTXT(8) =
     .'FRAME_2499002_' // KWFFAM // '             = '''// KVEULR //''''
      DEFTXT(9) =
     .'FRAME_2499002_' // KWEPOC // '              =  ' //
     .                   '@2000-NOV-23/04:25:00'
      DEFTXT(10) =
     .'FRAME_2499002_' // KWUNIT // '              =  '''//KVDEGR//''''
      DEFTXT(11) =
     .'FRAME_2499002_' // KWEUAX // '               = ( 1  3  2 )'
      DEFTXT(12) =
     .'FRAME_2499002_' // KWEAC1 // '     = (  1      2.D-10 )'
      DEFTXT(13) =
     .'FRAME_2499002_' // KWEAC2 // '     = (  3      4.D-10 )'
      DEFTXT(14) =
     .'FRAME_2499002_' // KWEAC3 // '     = (  5      6.D-10 )'
      DEFTXT(15) =
     .'FRAME_2499002_' // KWRSTA // '    = ''' // KVROTG //''''
 
 
C
C     Load the MARS_EULER frame definition.
C
      CALL LMPOOL ( DEFTXT, 15 )
      CALL CHCKXC ( .FALSE., ' ', OK )
 
 
C
C     Start out by checking the FRAMEX interfaces.  These
C     tests are of a trivial nature; their purpose is to verify
C     that class 5 (dynamic) frames are handled properly.
C
C--- Case: ------------------------------------------------------
C
      CALL TCASE  ( 'Map name RECUR_2 to an ID code, and back.' )
 
      RC2CDE = 2401000
      CALL NAMFRM ( 'RECUR_2', FRCODE )
      CALL CHCKXC ( .FALSE., ' ', OK  )
      CALL CHCKSI ( 'FRCODE', FRCODE, '=',  RC2CDE,   0,  OK )
 
      CALL FRMNAM ( RC2CDE,   FRNAME )
      CALL CHCKXC ( .FALSE., ' ', OK  )
      CALL CHCKSC ( 'FRNAME', FRNAME, '=', 'RECUR_2',     OK )
 
 
C
C--- Case: ------------------------------------------------------
C
      CALL TCASE  ( 'Look up frame info for RECUR_2' )
 
      CALL FRINFO ( RC2CDE, CENTER, CLASS, CLSSID, FOUND )
      CALL CHCKXC ( .FALSE., ' ', OK  )
 
      CALL CHCKSL ( 'FOUND', FOUND, .TRUE., OK )
 
C
C     The frame class is "dynamic."  The parameter DYN is defined
C     in frmtyp.inc.
C
      CALL CHCKSI ( 'CLASS', CLASS, '=', DYN, 0, OK )
 
C
C     The class ID is just the frame ID in this case.
C
      CALL CHCKSI ( 'CLASS ID', CLSSID, '=', RC2CDE, 0, OK )
 
 
C
C--- Case: ------------------------------------------------------
C
      CALL TCASE  ( 'Get the center of frame RECUR_2' )
 
C
C     This case is quite obscure:  we're making RECUR_2 the
C     default frame associated with Phobos, and we want to
C     make sure the FRAMEX API handles this.  Note that changing
C     the default frame associated with a planet or satellite
C     is a bad idea, unless the new frame is an improved body-fixed
C     frame for the object in question.
C
      CALL PCPOOL ( 'OBJECT_401_FRAME', 1, 'RECUR_2' )
      CALL CHCKXC ( .FALSE., ' ', OK  )
 
C
C     Get the center using CIDFRM first, then CNMFRM.
C
      CALL CIDFRM ( 401,      FRCODE, FRNAME, FOUND )
      CALL CHCKXC ( .FALSE.,  ' ',    OK  )
 
      CALL CHCKSL ( 'FOUND',  FOUND,  .TRUE.,             OK )
      CALL CHCKSI ( 'FRCODE', FRCODE, '=',  RC2CDE,   0,  OK )
      CALL CHCKSC ( 'FRNAME', FRNAME, '=', 'RECUR_2',     OK )
 
 
      CALL CNMFRM ( 'PHOBOS', FRCODE, FRNAME, FOUND )
      CALL CHCKXC ( .FALSE.,  ' ',    OK  )
 
      CALL CHCKSL ( 'FOUND',  FOUND,  .TRUE.,             OK )
      CALL CHCKSI ( 'FRCODE', FRCODE, '=',  RC2CDE,   0,  OK )
      CALL CHCKSC ( 'FRNAME', FRNAME, '=', 'RECUR_2',     OK )
 
C
C     Delete the OBJECT_401_FRAME kernel variable.
C
      CALL DVPOOL ( 'OBJECT_401_FRAME' )
      CALL CHCKXC ( .FALSE.,  ' ', OK  )
 
C
C     Now we want to perform an SXFORM test:  transform between
C     two frames which both require two levels of recursion
C     for evaluation.
C
C
C--- Case: ------------------------------------------------------
C
      CALL TCASE ( 'SXFORM test:  create and test transformation ' //
     .             'between RECUR_2 and RECUR_2B.'                 )
 
 
      CALL STR2ET ( '2005 JAN 1', ET )
      CALL CHCKXC ( .FALSE., ' ', OK )
 
C
C     Create the transformation matrix.
C
      CALL SXFORM ( 'RECUR_2', 'RECUR_2B', ET, XFORM )
      CALL CHCKXC ( .FALSE.,    ' ',   OK )
 
C
C     Create transformations from RECUR_2 to J2000 and from
C     J2000 to RECUR_2B.  Compose and compare to XFORM.
C
      CALL SXFORM ( 'RECUR_2', 'J2000',    ET, XF2 )
      CALL CHCKXC ( .FALSE.,    ' ',   OK )
 
      CALL SXFORM ( 'J2000',   'RECUR_2B', ET, XF3 )
      CALL CHCKXC ( .FALSE.,    ' ',   OK )
 
      CALL MXMG   ( XF3, XF2, 6, 6, 6, XF4 )
      CALL CHCKXC ( .FALSE.,    ' ',   OK  )
 
C
C     Compare results.
C
      CALL CHCKAD ( 'XFORM', XFORM, '~/', XF4, 36, EX13, OK )
 
 
C
C     Now test the SPK interfaces.
C
C     We'll test the state and corresponding position-only routines
C     together, to the extent possible.
C
C--- Case: ------------------------------------------------------
C
      CALL TCASE ( 'Check SPKEZR/SPKPOS using the frame RECUR_2.' )
C
C     For each SPK API routine, we'll verify that the SPK routine
C     can do the same transformation that we can do explicitly
C     by looking up the state relative to the J2000 frame and
C     then using SXFORM or PXFORM to convert the state to the
C     dynamic frame.
C
      CALL STR2ET ( '2005 JAN 1', ET )
      CALL CHCKXC ( .FALSE., ' ', OK )
 
C
C     Compute the light time from the center of the frame RECUR_2
C     to the observer.  Determine the "aberration corrected epoch"
C     ETCORR.  The inertial to dynamic frame transformation XFORM will
C     be computed at this epoch.
C
      CALL SPKEZR ( 'PHOBOS', ET, 'J2000', 'LT+S', 'MARS', STATE0, LT )
 
C
C     Compute the transformation from J2000 to the dynamic frame at
C     the aberration corrected epoch.
C
      CALL ZZCOREPC ( 'LT+S', ET, LT, ETCORR )
      CALL CHCKXC   ( .FALSE., ' ', OK )
 
      CALL SXFORM ( 'J2000', 'RECUR_2', ETCORR, XFORM )
      CALL CHCKXC ( .FALSE., ' ', OK )
 
      CALL PXFORM ( 'J2000', 'RECUR_2', ETCORR, R )
      CALL CHCKXC ( .FALSE., ' ', OK )
 
C
C     Look up the state and position in the dynamic frame.
C
      CALL SPKEZR ( 'EARTH', ET, 'RECUR_2', 'LT+S', 'MARS', STATE0, LT )
      CALL CHCKXC ( .FALSE., ' ', OK )
 
      CALL SPKPOS ( 'EARTH', ET, 'RECUR_2', 'LT+S', 'MARS', POS0,   LT )
      CALL CHCKXC ( .FALSE., ' ', OK )
 
C
C     Look up the state and position in the inertial frame, then
C     transform to the dynamic frame.
C
      CALL SPKEZR ( 'EARTH', ET, 'J2000',   'LT+S', 'MARS', STATE1, LT )
      CALL CHCKXC ( .FALSE., ' ', OK )
 
      CALL SPKPOS ( 'EARTH', ET, 'J2000',   'LT+S', 'MARS', POS1,   LT )
      CALL CHCKXC ( .FALSE., ' ', OK )
 
      CALL MXVG   ( XFORM, STATE1, 6, 6, STATE2 )
      CALL MXV    ( R,     POS1,         POS2   )
 
C
C     Check position and velocity separately.  Measure error in
C     relative terms.
C
      CALL CHCKAD ( 'STATE0 position',
     .               STATE0,    '~/', STATE2,    3, EX13, OK )
 
      CALL CHCKAD ( 'STATE0 velocity',
     .               STATE0(4), '~/', STATE2(4), 3, EX13, OK )
 
C
C     Check position from SPKPOS.
C
      CALL CHCKAD ( 'POS0', POS0, '~/', POS2,    3, EX13, OK )
 
 
C
C--- Case: ------------------------------------------------------
C
      CALL TCASE ( 'Check SPKEZR/SPKPOS using the frame RECUR_2B.' )
C
C     This test is a repeat of the previous one, but we use a
C     frame whose constant vector is defined relative to a
C     dynamic frame.
C
      CALL STR2ET ( '2005 JAN 1', ET )
      CALL CHCKXC ( .FALSE., ' ', OK )
 
C
C     Compute the light time from the center of the frame RECUR_2
C     to the observer.  Determine the "aberration corrected epoch"
C     ETCORR.  The inertial to dynamic frame transformation XFORM will
C     be computed at this epoch.
C
C     RECUR_2B is centered at the earth.
C
      CALL SPKEZR ( 'EARTH', ET, 'J2000', 'XLT+S', 'MARS', STATE0, LT )
 
C
C     Compute the transformation from J2000 to the dynamic frame at
C     the aberration corrected epoch.
C
      CALL ZZCOREPC ( 'XLT+S', ET, LT, ETCORR )
      CALL CHCKXC   ( .FALSE., ' ', OK )
 
      CALL SXFORM ( 'J2000', 'RECUR_2B', ETCORR, XFORM )
      CALL CHCKXC ( .FALSE., ' ', OK )
 
      CALL PXFORM ( 'J2000', 'RECUR_2B', ETCORR, R )
      CALL CHCKXC ( .FALSE., ' ', OK )
 
C
C     Look up the state and position in the dynamic frame.
C
      CALL SPKEZR( 'EARTH', ET, 'RECUR_2B', 'XLT+S', 'MARS', STATE0, LT)
      CALL CHCKXC( .FALSE., ' ', OK )
 
      CALL SPKPOS( 'EARTH', ET, 'RECUR_2B', 'XLT+S', 'MARS', POS0,   LT)
      CALL CHCKXC( .FALSE., ' ', OK )
 
C
C     Look up the state and position in the inertial frame, then
C     transform to the dynamic frame.
C
      CALL SPKEZR( 'EARTH', ET, 'J2000',   'XLT+S', 'MARS', STATE1, LT )
      CALL CHCKXC( .FALSE., ' ', OK )
 
      CALL SPKPOS( 'EARTH', ET, 'J2000',   'XLT+S', 'MARS', POS1,   LT )
      CALL CHCKXC( .FALSE., ' ', OK )
 
      CALL MXVG  ( XFORM, STATE1, 6, 6, STATE2 )
      CALL MXV   ( R,     POS1,         POS2   )
 
C
C     Check position and velocity separately.  Measure error in
C     relative terms.
C
      CALL CHCKAD ( 'STATE0 position',
     .               STATE0,    '~/', STATE2,    3, EX13, OK )
 
      CALL CHCKAD ( 'STATE0 velocity',
     .               STATE0(4), '~/', STATE2(4), 3, EX13, OK )
 
C
C     Check position from SPKPOS.
C
      CALL CHCKAD ( 'POS0', POS0, '~/', POS2,    3, EX13, OK )
 
 
C
C     Exercise the code for evaluting frames of the remaining
C     families.
C
C
C--- Case: ------------------------------------------------------
C
      CALL TCASE ( 'Check SPKEZR/SPKPOS using the frame ' //
     .             'EARTH_MEAN_OF_DATE.'                  )
 
C
C     Compute the light time from the center of the frame
C     EARTH_MEAN_OF_DATE (namely the earth) to the observer.  Determine
C     the "aberration corrected epoch" ETCORR.  The inertial to dynamic
C     frame transformation XFORM will be computed at this epoch.
C
      CALL SPKEZR ( 'EARTH', ET, 'J2000', 'LT', 'MARS', STATE0, LT )
 
C
C     Compute the transformation from J2000 to the dynamic frame at
C     the aberration corrected epoch.
C
      CALL ZZCOREPC ( 'LT', ET, LT, ETCORR )
      CALL CHCKXC   ( .FALSE., ' ', OK )
 
      CALL SXFORM ( 'J2000', 'EARTH_MEAN_OF_DATE', ETCORR, XFORM )
      CALL CHCKXC ( .FALSE., ' ', OK )
 
      CALL PXFORM ( 'J2000', 'EARTH_MEAN_OF_DATE', ETCORR, R     )
      CALL CHCKXC ( .FALSE., ' ', OK )
 
C
C     Look up the state and position in the dynamic frame.
C
      CALL SPKEZR ( 'EARTH', ET,     'EARTH_MEAN_OF_DATE',
     .              'LT',    'MARS', STATE0,                LT )
      CALL CHCKXC ( .FALSE., ' ', OK )
 
      CALL SPKPOS ( 'EARTH', ET,     'EARTH_MEAN_OF_DATE',
     .              'LT',    'MARS', POS0,                  LT )
      CALL CHCKXC ( .FALSE., ' ', OK )
 
C
C     Look up the state and position in the inertial frame, then
C     transform to the dynamic frame.
C
      CALL SPKEZR ( 'EARTH', ET, 'J2000', 'LT', 'MARS', STATE1, LT )
      CALL CHCKXC ( .FALSE., ' ', OK )
 
      CALL SPKPOS ( 'EARTH', ET, 'J2000', 'LT', 'MARS', POS1,   LT )
      CALL CHCKXC ( .FALSE., ' ', OK )
 
      CALL MXVG   ( XFORM, STATE1, 6, 6, STATE2 )
      CALL MXV    ( R,     POS1,         POS2   )
 
C
C     Check position and velocity separately.  Measure error in
C     relative terms.
C
      CALL CHCKAD ( 'STATE0 position',
     .               STATE0,    '~/', STATE2,    3, EX13, OK )
 
      CALL CHCKAD ( 'STATE0 velocity',
     .               STATE0(4), '~/', STATE2(4), 3, EX13, OK )
 
C
C     Check position from SPKPOS.
C
      CALL CHCKAD ( 'POS0', POS0, '~/', POS2,    3, EX13, OK )
 
 
 
C
C--- Case: ------------------------------------------------------
C
      CALL TCASE ( 'Check SPKEZR/SPKPOS using the frame ' //
     .             'EARTH_TRUE_OF_DATE.'                  )
 
C
C     Compute the light time from the center of the frame
C     EARTH_TRUE_OF_DATE (namely the earth) to the observer.  Determine
C     the "aberration corrected epoch" ETCORR.  The inertial to dynamic
C     frame transformation XFORM will be computed at this epoch.
C
      CALL SPKEZR ( 'EARTH', ET, 'J2000', 'LT+S', 'MARS', STATE0, LT )
 
C
C     Compute the transformation from J2000 to the dynamic frame at
C     the aberration corrected epoch.
C
      CALL ZZCOREPC ( 'LT', ET, LT, ETCORR )
      CALL CHCKXC   ( .FALSE., ' ', OK )
 
      CALL SXFORM ( 'J2000', 'EARTH_TRUE_OF_DATE', ETCORR, XFORM )
      CALL CHCKXC ( .FALSE., ' ', OK )
 
      CALL PXFORM ( 'J2000', 'EARTH_TRUE_OF_DATE', ETCORR, R     )
      CALL CHCKXC ( .FALSE., ' ', OK )
 
C
C     Look up the state and position in the dynamic frame.
C
      CALL SPKEZR ( 'EARTH', ET,     'EARTH_TRUE_OF_DATE',
     .              'LT',    'MARS', STATE0,                LT )
      CALL CHCKXC ( .FALSE., ' ', OK )
 
      CALL SPKPOS ( 'EARTH', ET,     'EARTH_TRUE_OF_DATE',
     .              'LT',    'MARS', POS0,                  LT )
      CALL CHCKXC ( .FALSE., ' ', OK )
 
C
C     Look up the state and position in the inertial frame, then
C     transform to the dynamic frame.
C
      CALL SPKEZR ( 'EARTH', ET, 'J2000', 'LT', 'MARS', STATE1, LT )
      CALL CHCKXC ( .FALSE., ' ', OK )
 
      CALL SPKPOS ( 'EARTH', ET, 'J2000', 'LT', 'MARS', POS1,   LT )
      CALL CHCKXC ( .FALSE., ' ', OK )
 
      CALL MXVG   ( XFORM, STATE1, 6, 6, STATE2 )
      CALL MXV    ( R,     POS1,         POS2   )
 
C
C     Check position and velocity separately.  Measure error in
C     relative terms.
C
      CALL CHCKAD ( 'STATE0 position',
     .               STATE0,    '~/', STATE2,    3, EX13, OK )
 
      CALL CHCKAD ( 'STATE0 velocity',
     .               STATE0(4), '~/', STATE2(4), 3, EX13, OK )
 
C
C     Check position from SPKPOS.
C
      CALL CHCKAD ( 'POS0', POS0, '~/', POS2,    3, EX13, OK )
 
 
C
C--- Case: ------------------------------------------------------
C
      CALL TCASE ( 'Check SPKEZR/SPKPOS using the frame ' //
     .             'MARS_EULER.'                          )
 
C
C     Compute the light time from the center of the frame MARS_EULER to
C     the observer.  Determine the "aberration corrected epoch" ETCORR.
C     The inertial to dynamic frame transformation XFORM will be
C     computed at this epoch.
C
      CALL SPKEZR ( 'MARS', ET, 'J2000', 'CN+S', 'EARTH', STATE0, LT )
 
C
C     Compute the transformation from J2000 to the dynamic frame at
C     the aberration corrected epoch.
C
      CALL ZZCOREPC ( 'CN+S', ET, LT, ETCORR )
      CALL CHCKXC   ( .FALSE., ' ', OK )
 
      CALL SXFORM ( 'J2000', 'MARS_EULER', ETCORR, XFORM )
      CALL CHCKXC ( .FALSE., ' ', OK )
 
      CALL PXFORM ( 'J2000', 'MARS_EULER', ETCORR, R     )
      CALL CHCKXC ( .FALSE., ' ', OK )
 
C
C     Look up the state and position in the inertial frame, then
C     transform to the dynamic frame.
C
      CALL SPKEZR ( 'MARS', ET,      'MARS_EULER',
     .              'CN+S', 'EARTH', STATE0,       LT )
      CALL CHCKXC ( .FALSE., ' ', OK )
 
      CALL SPKPOS ( 'MARS', ET,      'MARS_EULER',
     .              'CN+S', 'EARTH', POS0,         LT )
      CALL CHCKXC ( .FALSE., ' ', OK )
 
C
C     Look up the state in the inertial frame, then transform to
C     the dynamic frame.
C
      CALL SPKEZR ( 'MARS', ET, 'J2000', 'CN+S', 'EARTH', STATE1, LT )
      CALL CHCKXC ( .FALSE., ' ', OK )
 
      CALL SPKPOS ( 'MARS', ET, 'J2000', 'CN+S', 'EARTH', POS1,   LT )
      CALL CHCKXC ( .FALSE., ' ', OK )
 
      CALL MXVG   ( XFORM, STATE1, 6, 6, STATE2 )
      CALL MXV    ( R,     POS1,         POS2   )
 
C
C     Check position and velocity separately.  Measure error in
C     relative terms.
C
      CALL CHCKAD ( 'STATE0 position',
     .               STATE0,    '~/', STATE2,    3, EX13, OK )
 
      CALL CHCKAD ( 'STATE0 velocity',
     .               STATE0(4), '~/', STATE2(4), 3, EX13, OK )
 
C
C     Check position from SPKPOS.
C
      CALL CHCKAD ( 'POS0', POS0, '~/', POS2,    3, EX13, OK )
 
 
C
C     Suppose we do a lookup requiring three levels of recursion?
C
C--- Case: ------------------------------------------------------
C
C
C     SPKEZR:  catch error when evaluating two-vector frame
C     defined using velocity vector.
C
      CALL TCASE ( 'Check SPKEZR using the frame RECUR_3. '    //
     .             'In this test, the error should be caught ' //
     .             'in routine ZZSPKEZ1.'                      )
 
      CALL STR2ET ( '2005 JAN 1', ET )
      CALL CHCKXC ( .FALSE., ' ', OK )
 
      CALL SPKEZR ( 'PHOBOS', ET,     'RECUR_3', 'LT+S',
     .              'MARS',   STATE0, LT                  )
 
      CALL CHCKXC ( .TRUE., 'SPICE(RECURSIONTOODEEP)', OK )
 
 
C
C--- Case: ------------------------------------------------------
C
C
C     SPKPOS:  catch error when evaluating two-vector frame defined
C     using velocity vector. Because the error will occur when
C     obtaining a state vector, the error will be trapped in ZZSPKEZ1
C     rather than the position-only analog ZZSPKZP1.
C
      CALL TCASE ( 'Check SPKEZR using the frame RECUR_3. '    //
     .             'In this test, the error should be caught ' //
     .             'in routine ZZSPKEZ1.'                      )
 
      CALL STR2ET ( '2005 JAN 1', ET )
      CALL CHCKXC ( .FALSE., ' ', OK )
 
      CALL SPKPOS ( 'PHOBOS', ET,  'RECUR_3', 'LT+S',
     .              'MARS',   POS0, LT                  )
 
      CALL CHCKXC ( .TRUE., 'SPICE(RECURSIONTOODEEP)', OK )
 
C
C     Make sure ZZSPKZP1 can trap the recursion error.  Note:
C     this case should be excluded in Icy testing.
C
      CALL ZZSPKZP1 ( 401, ET, 'RECUR_1', 'LT+S', 499, POS0, LT )
 
      CALL CHCKXC ( .TRUE., 'SPICE(RECURSIONTOODEEP)', OK )
 
 
C
C--- Case: ------------------------------------------------------
C
C
C     SPKEZR:  catch error when evaluating two-vector frame
C     defined using constant vector.
C
      CALL TCASE ( 'Check SPKEZR using the frame RECUR_3B. '    //
     .             'In this test, the error should be caught ' //
     .             'in routine ZZFRMCH1.'                      )
 
      CALL STR2ET ( '2005 JAN 1', ET )
      CALL CHCKXC ( .FALSE., ' ', OK )
 
      CALL SPKEZR ( 'PHOBOS', ET,     'RECUR_3B', 'LT+S',
     .              'MARS',   STATE0, LT                  )
 
      CALL CHCKXC ( .TRUE., 'SPICE(RECURSIONTOODEEP)', OK )
 
 
 
C
C--- Case: ------------------------------------------------------
C
C     SPKPOS:  catch error when evaluating two-vector frame
C     defined using constant vector.
C
      CALL TCASE ( 'Check SPKPOS using the frame RECUR_3B. '    //
     .             'In this test, the error should be caught ' //
     .             'in routine ZZFRMCH1.'                      )
 
      CALL STR2ET ( '2005 JAN 1', ET )
      CALL CHCKXC ( .FALSE., ' ', OK )
 
      CALL SPKPOS ( 'PHOBOS', ET,     'RECUR_3B', 'LT+S',
     .              'MARS',   POS0,   LT                  )
 
      CALL CHCKXC ( .TRUE., 'SPICE(RECURSIONTOODEEP)', OK )
 
 
C
C     Now test the rest of the SPK API routines.  We'll use just
C     one dynamic frame for each case, since we've already exercised
C     the low-level code needed to evaluate each family of dynamic
C     frames.  (Note, however, that we haven't covered every
C     possible logic branch in the low-level code---the other
C     dynamic frame test families are responsible for that.)
C
C
C--- Case: ------------------------------------------------------
C
 
      CALL TCASE ( 'Check SPKEZ/SPKEZP using the frame RECUR_1.' )
C
C     Compute the light time from the center of the frame RECUR_2
C     to the observer.  Determine the "aberration corrected epoch"
C     ETCORR.  The inertial to dynamic frame transformation XFORM will
C     be computed at this epoch.
C
      CALL SPKEZR ( 'EARTH', ET, 'J2000', 'XLT+S', 'MARS', STATE0, LT )
 
C
C     Compute the transformation from J2000 to the dynamic frame at
C     the aberration corrected epoch.
C
      CALL ZZCOREPC ( 'XLT+S', ET, LT, ETCORR )
      CALL CHCKXC   ( .FALSE., ' ', OK )
 
      CALL SXFORM ( 'J2000', 'RECUR_1', ETCORR, XFORM )
      CALL CHCKXC ( .FALSE., ' ', OK )
 
      CALL PXFORM ( 'J2000', 'RECUR_1', ETCORR, R     )
      CALL CHCKXC ( .FALSE., ' ', OK )
 
C
C     Look up the state and position in the dynamic frame.
C
      CALL SPKEZ  (  399, ET, 'RECUR_1', 'XLT+S', 499, STATE0, LT )
      CALL CHCKXC ( .FALSE., ' ', OK )
 
      CALL SPKEZP (  399, ET, 'RECUR_1', 'XLT+S', 499, POS0,   LT )
      CALL CHCKXC ( .FALSE., ' ', OK )
 
C
C     Look up the state and position in the inertial frame, then
C     transform to the dynamic frame.
C
      CALL SPKEZ  ( 399, ET, 'J2000',    'XLT+S', 499, STATE1, LT )
      CALL CHCKXC ( .FALSE., ' ', OK )
 
      CALL SPKEZP ( 399, ET, 'J2000',    'XLT+S', 499, POS1,   LT )
      CALL CHCKXC ( .FALSE., ' ', OK )
 
      CALL MXVG   ( XFORM, STATE1, 6, 6, STATE2 )
      CALL MXV    ( R,     POS1,         POS2   )
 
C
C     Check position and velocity separately.  Measure error in
C     relative terms.
C
      CALL CHCKAD ( 'STATE0 position',
     .               STATE0,    '~/', STATE2,    3, EX13, OK )
 
      CALL CHCKAD ( 'STATE0 velocity',
     .               STATE0(4), '~/', STATE2(4), 3, EX13, OK )
 
C
C     Check position from SPKEZP.
C
      CALL CHCKAD ( 'POS0', POS0, '~/', POS2,    3, EX13, OK )
 
 
 
 
C
C--- Case: ------------------------------------------------------
C
      CALL TCASE ( 'Check SPKGEO/SPKGPS using the frame RECUR_1.' )
 
 
 
      CALL SXFORM ( 'J2000', 'RECUR_1', ET, XFORM )
      CALL CHCKXC ( .FALSE., ' ', OK )
 
      CALL PXFORM ( 'J2000', 'RECUR_1', ET, R     )
      CALL CHCKXC ( .FALSE., ' ', OK )
 
C
C     Look up the state and position in the dynamic frame.
C
      CALL SPKGEO (  399, ET, 'RECUR_1', 499, STATE0, LT )
      CALL CHCKXC ( .FALSE., ' ', OK )
 
      CALL SPKGPS (  399, ET, 'RECUR_1', 499, POS0,   LT )
      CALL CHCKXC ( .FALSE., ' ', OK )
 
C
C     Look up the state and position in the inertial frame, then
C     transform to the dynamic frame.
C
      CALL SPKGEO ( 399, ET, 'J2000',    499, STATE1, LT )
      CALL CHCKXC ( .FALSE., ' ', OK )
 
      CALL SPKGPS ( 399, ET, 'J2000',    499, POS1,   LT )
      CALL CHCKXC ( .FALSE., ' ', OK )
 
      CALL MXVG   ( XFORM, STATE1, 6, 6, STATE2 )
      CALL MXV    ( R,     POS1,         POS2   )
 
C
C     Check position and velocity separately.  Measure error in
C     relative terms.
C
      CALL CHCKAD ( 'STATE0 position',
     .               STATE0,    '~/', STATE2,    3, EX13, OK )
 
      CALL CHCKAD ( 'STATE0 velocity',
     .               STATE0(4), '~/', STATE2(4), 3, EX13, OK )
 
 
C
C     Check position and velocity separately.  Measure error in
C     relative terms.
C
      CALL CHCKAD ( 'STATE0 position',
     .               STATE0,    '~/', STATE2,    3, EX13, OK )
 
      CALL CHCKAD ( 'STATE0 velocity',
     .               STATE0(4), '~/', STATE2(4), 3, EX13, OK )
 
C
C     Check position from SPKGPS. Measure error in relative terms. We
C     have a slightly larger relative error here (presumably due to
C     implementation differences between the two computation paths), so
C     use a slightly larger tolerance.
C
      CALL CHCKAD ( 'POS0', POS0, '~/', POS2,    3, EX13, OK )
 
 
 
C
C     Check SPKSSB.  Note:  there's no position-only analog of SPKSSB.
C
C
C--- Case: ------------------------------------------------------
C
      CALL TCASE ( 'Check SPKSSB using the frame RECUR_2.' )
 
C
C     SPKSSB computes only geometric states, so the dynamic frame
C     is evaluated at ET.
C
      CALL SXFORM ( 'J2000', 'RECUR_2', ET, XFORM )
      CALL CHCKXC ( .FALSE., ' ', OK )
 
C
C     Look up the state in the dynamic frame.
C
      CALL SPKSSB ( 399, ET, 'RECUR_2', STATE0 )
      CALL CHCKXC ( .FALSE., ' ', OK )
 
C
C     Look up the state in the inertial frame, then transform to
C     the dynamic frame.
C
      CALL SPKSSB ( 399, ET, 'J2000',   STATE1 )
      CALL CHCKXC ( .FALSE., ' ', OK )
 
      CALL MXVG   ( XFORM, STATE1, 6, 6, STATE2 )
 
C
C     Check position and velocity separately.  Measure error in
C     relative terms.
C
      CALL CHCKAD ( 'STATE0 position',
     .               STATE0,    '~/', STATE2,    3, EX13, OK )
 
      CALL CHCKAD ( 'STATE0 velocity',
     .               STATE0(4), '~/', STATE2(4), 3, EX13, OK )
 
 
C
C--- Case: ------------------------------------------------------
C
      CALL TCASE ( 'Check SPKAPP/SPKAPO using the frame RECUR_2.' )
 
C
C     SPKAPP supports only inertial frames.  However, we want to make
C     sure this routine rejects dynamic frames if they're provided as
C     inputs.
C
      CALL SPKAPP ( 499, ET, 'RECUR_2', STATE0, 'LT+S', STATE1, LT )
      CALL CHCKXC ( .TRUE., 'SPICE(BADFRAME)', OK )
 
C
C     Ditto for SPKAPO.
C
      CALL SPKAPO ( 499, ET, 'RECUR_2', STATE0, 'LT+S', POS1, LT )
      CALL CHCKXC ( .TRUE., 'SPICE(BADFRAME)', OK )
 
 
C
C     Check SPKPV.  Note:  this test need not be done for Icy.
C
C
C--- Case: ------------------------------------------------------
C
      CALL TCASE ( 'Check SPKPV using the frame RECUR_2.' )
 
C
C     SPKPV computes only geometric states, so the dynamic frame
C     is evaluated at ET.
C
      CALL SXFORM ( 'J2000', 'RECUR_2', ET, XFORM )
      CALL CHCKXC ( .FALSE., ' ', OK )
 
C
C     Look up the state in the dynamic frame.
C
      CALL SPKSFS ( 399, ET, HAN, SUM, IDENT, FOUND )
      CALL CHCKXC ( .FALSE., ' ', OK )
 
      CALL CHCKSL ( 'FOUND',  FOUND, .TRUE., OK )
 
      CALL SPKPV  ( HAN, SUM, ET, 'RECUR_2', STATE0, CENTER )
      CALL CHCKXC ( .FALSE., ' ', OK )
 
C
C     Look up the state in the inertial frame, then transform to
C     the dynamic frame.
C
      CALL SPKPV  ( HAN, SUM, ET, 'J2000',   STATE1, CENTER )
      CALL CHCKXC ( .FALSE., ' ', OK )
 
      CALL MXVG   ( XFORM, STATE1, 6, 6, STATE2 )
 
C
C     Check position and velocity separately.  Measure error in
C     relative terms.
C
      CALL CHCKAD ( 'STATE0 position',
     .               STATE0,    '~/', STATE2,    3, EX13, OK )
 
      CALL CHCKAD ( 'STATE0 velocity',
     .               STATE0(4), '~/', STATE2(4), 3, EX13, OK )
 
 
 
C
C     Check the CK interfaces.
C
C
C--- Case: ------------------------------------------------------
C
      CALL TCASE ( 'Look up attitude of object -10001 relative ' //
     .             'to frame RECUR_2 using CKGP.'                )
 
      INSTID = -10001
      CLKID  = -9
 
      CALL STR2ET ( '2005 JAN 1 12:00 TDB', ET )
      CALL CHCKXC ( .FALSE., ' ', OK )
 
      CALL SCE2C  ( CLKID,   ET,     SCLKDP )
      CALL CHCKXC ( .FALSE., ' ',    OK     )
 
C
C     Look up pointing relative to frame RECUR_2.
C
      CALL CKGP   ( INSTID,  SCLKDP, 0.D0, 'RECUR_2',
     .              CMAT0,    CLKOUT, FOUND            )
      CALL CHCKXC ( .FALSE., ' ',    OK                )
      CALL CHCKSL ( 'FOUND',  FOUND, .TRUE., OK        )
 
C
C     Look up pointing relative to frame J2000; convert to
C     pointing relative to RECUR_2.
C
      CALL CKGP   ( INSTID,  SCLKDP, 0.D0, 'J2000',
     .              CMAT1,   CLKOUT, FOUND            )
      CALL CHCKXC ( .FALSE., ' ',    OK               )
      CALL CHCKSL ( 'FOUND',  FOUND, .TRUE., OK       )
 
      CALL PXFORM ( 'J2000', 'RECUR_2', ET, R  )
      CALL CHCKXC ( .FALSE., ' ', OK )
 
      CALL MXMT   ( CMAT1,   R,   CMAT2 )
 
C
C     Compare C-matrices.
C
      CALL CHCKAD ( 'CMAT0', CMAT0, '~', CMAT2, 9, EX13, OK )
 
 
C
C--- Case: ------------------------------------------------------
C
      CALL TCASE ( 'Look up attitude of object -10001 relative ' //
     .             'to frame RECUR_2 using CKGPAV.'              )
 
 
C
C     Look up pointing relative to frame RECUR_2.
C
      CALL CKGPAV ( INSTID,  SCLKDP, 0.D0,   'RECUR_2',
     .              CMAT0,   AV0,    CLKOUT, FOUND      )
      CALL CHCKXC ( .FALSE., ' ',    OK                 )
 
C
C     Look up pointing relative to frame J2000; convert to
C     pointing relative to RECUR_2.
C
      CALL CKGPAV  ( INSTID,  SCLKDP, 0.D0,   'J2000',
     .               CMAT1,   AV1,    CLKOUT, FOUND   )
      CALL CHCKXC ( .FALSE., ' ',    OK               )
 
      CALL PXFORM ( 'J2000', 'RECUR_2', ET, R  )
      CALL CHCKXC ( .FALSE., ' ', OK )
 
      CALL MXMT   ( CMAT1,   R,   CMAT2 )
      CALL CHCKXC ( .FALSE., ' ', OK )
 
C
C     Compare C-matrices.
C
      CALL CHCKAD ( 'CMAT0', CMAT0, '~', CMAT2, 9, EX13, OK )
 
C
C     Compare angular velocity vectors.  To do this, we first
C     must find the the angular velocity of frame CK_-10001 relative
C     to RECUR_2, given the angular velocity of frame CK_-10001 relative
C     to J2000.  We start by looking up the state transformation
C     from RECUR_2 to J2000.
C
      CALL SXFORM ( 'RECUR_2',  'J2000',  ET,  XFORM )
      CALL CHCKXC ( .FALSE.,    ' ',      OK         )
 
C
C     Get the state transformation from J2000 to CK_-10001.
C
      CALL RAV2XF ( CMAT1,    AV1,  XF2 )
      CALL CHCKXC ( .FALSE.,  ' ',  OK  )
 
C
C     Get the state transformation from RECUR_2 to CK_-10001.
C     Extract the angular velocity from this transformation.
C
      CALL MXMG   ( XF2,  XFORM,  6,  6, 6, XF3 )
      CALL CHCKXC ( .FALSE.,      ' ',      OK  )
 
      CALL XF2RAV ( XF3,      CMAT2,  AV2 )
      CALL CHCKXC ( .FALSE.,  ' ',    OK  )
 
C
C     Check AV0.
C
      CALL CHCKAD ( 'AV0', AV0, '~', AV2, 3, EX13, OK )
 
 
 
 
 
C
C     Check the PCK interfaces.
C
C
C--- Case: ------------------------------------------------------
C
C
C     TISBOD is supposed to support only inertial base frames.
C     Make sure that a dynamic base frame is rejected.
C
      CALL TCASE ( 'Look up attitude of Mars relative ' //
     .             'to frame RECUR_1 using TISBOD.'     )
 
 
      CALL TISBOD ( 'RECUR_1', 499, ET, XFORM )
      CALL CHCKXC ( .TRUE.,  'SPICE(IRFNOTREC)',    OK  )
 
 
C
C     Same deal for TIPBOD.
C
      CALL TCASE ( 'Look up attitude of Mars relative ' //
     .             'to frame RECUR_1 using TIPBOD.'     )
 
 
      CALL TIPBOD ( 'RECUR_1', 499, ET, R )
      CALL CHCKXC ( .TRUE.,  'SPICE(IRFNOTREC)',    OK  )
 
 
 
C
C     Now we're going to perform tests using SPK and CK files that use
C     dynamic frames as base frames.  First we'll create these kernels.
C     We'll use the existing test utilities to do most of our work,
C     then we'll change some segment descriptors to make selected
C     segments refer to new bodies and dynamic frames.
C
C
C--- Case: ------------------------------------------------------
C
      CALL TCASE ( 'Create an SPK for tests using dynamic ' //
     .             'base frames.'                            )
 
C
C     Start with the SPK file.  Create but don't load the file.
C
      CALL TSTSPK  ( SPK2, .FALSE., HANDLE(3) )
      CALL CHCKXC  ( .FALSE., ' ', OK )
 
C
C     Locate the segment for the Jupiter barycenter; change the
C     descriptor to make the base frame RECUR_2.  Make the base frame
C     for the Saturn barycenter RECUR_2B.  Change the ID codes of the
C     objects at the same time, so we can compare states from the new
C     segments with those from the old.
C
C     Change the frame for the Uranus barycenter to RECUR_3.  This
C     segment should become unusable; we'll check this later.
C
      CALL DAFOPW ( SPK2, HANDLE(3) )
      CALL CHCKXC ( .FALSE., ' ', OK )
 
      CALL DAFBFS ( HANDLE(3) )
      CALL CHCKXC ( .FALSE., ' ', OK )
 
      CALL DAFFNA  ( FOUND )
      CALL CHCKXC  ( .FALSE., ' ', OK )
 
      DO WHILE ( FOUND )
 
         CALL DAFGS ( SUM )
         CALL CHCKXC  ( .FALSE., ' ', OK )
 
         CALL DAFUS ( SUM, ND, NI, DC, IC )
         CALL CHCKXC  ( .FALSE., ' ', OK )
 
         IF ( IC(1) .EQ. 5 ) THEN
C
C           Update the descriptor.
C
            CALL NAMFRM ( 'RECUR_2', IC(3) )
            CALL CHCKXC ( .FALSE., ' ', OK )
            IC(1) = IC(1) * 100
 
            CALL DAFPS  ( ND, NI, DC, IC, SUM )
            CALL CHCKXC ( .FALSE., ' ', OK )
C
C           Write the new descriptor.
C
            CALL DAFRS  ( SUM )
            CALL CHCKXC ( .FALSE., ' ', OK )
 
         ELSE IF ( IC(1) .EQ. 6 ) THEN
C
C           Update the descriptor.
C
            CALL NAMFRM ( 'RECUR_2B',  IC(3) )
            CALL CHCKXC ( .FALSE., ' ', OK   )
            IC(1) = IC(1) * 100
 
            CALL DAFPS  ( ND, NI, DC, IC, SUM )
            CALL CHCKXC ( .FALSE., ' ', OK )
C
C           Write the new descriptor.
C
            CALL DAFRS  ( SUM )
            CALL CHCKXC ( .FALSE., ' ', OK )
 
 
         ELSE IF ( IC(1) .EQ. 7 ) THEN
C
C           Update the descriptor.
C
            CALL NAMFRM ( 'RECUR_3', IC(3) )
            IC(1) = IC(1) * 100
 
            CALL DAFPS  ( ND, NI, DC, IC, SUM )
            CALL CHCKXC ( .FALSE., ' ', OK )
C
C           Write the new descriptor.
C
            CALL DAFRS  ( SUM )
            CALL CHCKXC ( .FALSE., ' ', OK )
 
         END IF
 
         CALL DAFFNA ( FOUND )
         CALL CHCKXC ( .FALSE., ' ', OK )
 
      END DO
 
C
C     Close the modified SPK file.
C
      CALL DAFCLS ( HANDLE(3) )
      CALL CHCKXC ( .FALSE., ' ', OK )
 
C
C--- Case: ------------------------------------------------------
C
      CALL TCASE ( 'Look up state of body 500 relative to '   //
     .             'the sun, in frame RECUR_2. Compare to '   //
     .             'state of Jupiter barycenter in frame '    //
     .             'DE-96'                                    )
C
C     Load our modified SPK file.
C
      CALL SPKLEF ( SPK2, HANDLE(3) )
      CALL CHCKXC ( .FALSE., ' ', OK )
 
 
      CALL STR2ET ( '2005 JAN 1', ET )
      CALL CHCKXC ( .FALSE., ' ', OK )
 
C
C     Look up the state of body 500 relative to the solar system
C     barycenter in the dynamic frame RECUR_2. The state should match
C     that of the Jupiter barycenter relative to the solar system
C     barycenter in frame DE-96.
C
      CALL SPKEZ  (  500,       ET,    'RECUR_2',
     .              'NONE',     10,    STATE0,     LT )
      CALL CHCKXC ( .FALSE.,    ' ',   OK )
 
C
C     The frame DE-96 is what's used for this segment by TSTSPK.
C
      CALL SPKEZ  (  5,         ET,    'DE-96',
     .              'NONE',     10,    STATE1,     LT )
      CALL CHCKXC ( .FALSE.,    ' ',   OK )
 
C
C     Check position and velocity separately.  Measure error in
C     relative terms.
C
      CALL CHCKAD ( 'STATE0 position',
     .               STATE0,    '~/', STATE1,    3, EX13, OK )
 
      CALL CHCKAD ( 'STATE0 velocity',
     .               STATE0(4), '~/', STATE1(4), 3, EX13, OK )
 
 
 
C
C--- Case: ------------------------------------------------------
C
      CALL TCASE ( 'Look up state of body 500 relative to  '  //
     .             'body 600 in frame RECUR_1. '              )
 
C
C     Look up the state of body 600 relative to the solar system
C     barycenter in the dynamic frame RECUR_1. The state should match
C     that of the Jupiter barycenter relative to the solar system
C     barycenter in frame DE-102.
C
      CALL SPKEZ  (  600,       ET,    'RECUR_1',
     .              'NONE',     500,   STATE0,     LT )
      CALL CHCKXC ( .FALSE.,    ' ',   OK )
 
C
C     Look up the same state using the J2000 frame.  Map to
C     RECUR_1 and compare.
C
      CALL SPKEZ  (  600,       ET,    'J2000',
     .              'NONE',     500,   STATE1,     LT )
      CALL CHCKXC ( .FALSE.,    ' ',   OK )
 
 
      CALL SXFORM ( 'J2000', 'RECUR_1', ET, XFORM )
      CALL CHCKXC ( .FALSE.,    ' ',    OK )
 
      CALL MXVG   ( XFORM, STATE1, 6, 6, STATE2 )
 
C
C     Check position and velocity separately.  Measure error in
C     relative terms.
C
      CALL CHCKAD ( 'STATE0 position',
     .               STATE0,    '~/', STATE2,    3, EX13, OK )
 
      CALL CHCKAD ( 'STATE0 velocity',
     .               STATE0(4), '~/', STATE2(4), 3, EX13, OK )
 
 
C
C--- Case: ------------------------------------------------------
C
      CALL TCASE ( 'Look up state of the Uranus barycenter '  //
     .             'relative to the sun, in frame J2000. '    //
     .             'Our Uranus barycenter segment has a '     //
     .             'dynamic base frame requiring three '      //
     .             'levels of recursion for evaluation.'   )
 
C
C     Look up the state of body 700 relative to the solar system
C     barycenter in the dynamic frame RECUR_3.  We expect an error
C     to be signaled.
C
      CALL SPKEZ  (  700,       ET,    'J2000',
     .              'NONE',     10,    STATE0,     LT )
 
      CALL CHCKXC ( .TRUE.,    'SPICE(RECURSIONTOODEEP)',   OK )
 
 
C
C     Now create a CK containing a segment with dynamic base
C     frame.
C
C
C--- Case: ------------------------------------------------------
C
      CALL TCASE ( 'Create a CK for tests using dynamic ' //
     .             'base frames.'                            )
 
C
C     Start with the CK file.  Create but don't load the file.
C
      CALL TSTCK3 ( CK2, SCLK, .FALSE., .FALSE., .FALSE., HANDLE(4) )
      CALL CHCKXC ( .FALSE., ' ', OK )
 
C
C     Locate the segment for the instrument -9901; change the descriptor
C     to make the base frame RECUR_2. Change the ID code of the
C     instrument at the same time, so we can compare pointing from the
C     new segments with those from the old.
C
C     Change the frame for the instrument -10000 to RECUR_3.  This
C     segment should become unusable; we'll check this later.
C
      CALL DAFOPW ( CK2, HANDLE(4)   )
      CALL CHCKXC ( .FALSE., ' ', OK )
 
      CALL DAFBFS ( HANDLE(4) )
      CALL CHCKXC ( .FALSE., ' ', OK )
 
      CALL DAFFNA  ( FOUND )
      CALL CHCKXC  ( .FALSE., ' ', OK )
 
      DO WHILE ( FOUND )
 
         CALL DAFGS  ( SUM )
         CALL CHCKXC ( .FALSE., ' ', OK )
 
         CALL DAFUS ( SUM, ND, NI, DC, IC )
         CALL CHCKXC  ( .FALSE., ' ', OK )
 
         IF ( IC(1) .EQ. -10001 ) THEN
C
C           Update the descriptor.  For CK descriptors, the frame
C           ID is in the second element of the integer component.
C
            CALL NAMFRM ( 'RECUR_2', IC(2) )
            CALL CHCKXC ( .FALSE., ' ', OK )
            IC(1) = IC(1) + 100
 
            CALL DAFPS  ( ND, NI, DC, IC, SUM )
            CALL CHCKXC ( .FALSE., ' ', OK )
C
C           Write the new descriptor.
C
            CALL DAFRS  ( SUM )
            CALL CHCKXC ( .FALSE., ' ', OK )
 
         ELSE IF ( IC(1) .EQ. -10000 ) THEN
C
C           Update the descriptor.
C
            CALL NAMFRM ( 'RECUR_3', IC(2) )
            IC(1) = IC(1) + 100
 
            CALL DAFPS  ( ND, NI, DC, IC, SUM )
            CALL CHCKXC ( .FALSE., ' ', OK )
C
C           Write the new descriptor.
C
            CALL DAFRS  ( SUM )
            CALL CHCKXC ( .FALSE., ' ', OK )
 
         END IF
 
         CALL DAFFNA ( FOUND )
         CALL CHCKXC ( .FALSE., ' ', OK )
 
      END DO
 
C
C     Close the modified CK file.
C
      CALL DAFCLS ( HANDLE(4) )
      CALL CHCKXC ( .FALSE., ' ', OK )
 
C
C--- Case: ------------------------------------------------------
C
      CALL TCASE ( 'Look up pointing of instrument -9901 ' //
     .             'in frame RECUR_2.'                      )
 
C
C     Load the CK containing data of interest.
C
      CALL CKLPF  ( CK2, HANDLE(4)   )
      CALL CHCKXC ( .FALSE., ' ', OK )
 
C
C     Look up the pointing and angular velocity of instrument -9901 in
C     the dynamic frame RECUR_2. The data should match those of the
C     instrument -10001 in frame J2000.
C
      INSTID = -9901
      CLKID  = -9
 
      CALL STR2ET ( '2005 JAN 1 12:00 TDB', ET )
      CALL CHCKXC ( .FALSE., ' ', OK )
 
      CALL SCE2C  ( CLKID,   ET,     SCLKDP )
      CALL CHCKXC ( .FALSE., ' ',    OK     )
 
C
C     Look up pointing relative to frame RECUR_2.
C
      CALL CKGPAV ( INSTID,  SCLKDP, 0.D0,   'RECUR_2',
     .              CMAT0,   AV0,    CLKOUT, FOUND     )
      CALL CHCKXC ( .FALSE., ' ',    OK                )
      CALL CHCKSL ( '-9901 FOUND',  FOUND, .TRUE., OK  )
 
C
C     Look up the same data for instrument -10001 using the
C     J2000 frame (base frame for instrument -10001).
C     Compare.
C
      CALL CKGPAV ( -10001,   SCLKDP, 0.D0,   'J2000',
     .              CMAT1,    AV1,    CLKOUT, FOUND      )
      CALL CHCKXC ( .FALSE., ' ',    OK                 )
      CALL CHCKSL ( '-10001 FOUND',  FOUND, .TRUE., OK  )
 
C
C     Compare C-matrices.
C
      CALL CHCKAD ( 'CMAT0', CMAT0, '~', CMAT1, 9, EX13, OK )
 
C
C     Compare angular velocity vectors.
C
      CALL CHCKAD ( 'AV0', AV0, '~', AV1, 3, EX13, OK )
 
C
C--- Case: ------------------------------------------------------
C
      CALL TCASE ( 'Look up pointing of instrument -9901 ' //
     .             'in frame J2000.  This forces the CK '  //
     .             'subsystem to do a dynamic frame '      //
     .             'transformation.'                       )
 
C
C     Load the CK containing data of interest.
C
      CALL CKLPF  ( CK2, HANDLE(4)   )
      CALL CHCKXC ( .FALSE., ' ', OK )
 
C
C     Look up the pointing and angular velocity of instrument -9901 in
C     the dynamic frame J2000.  The data should match those of the
C     instrument -10001 after the RECUR_2 to J2000 state transformation
C     is applied.
C
      INSTID = -9901
      CLKID  = -9
 
      CALL STR2ET ( '2005 JAN 1 12:00 TDB', ET )
      CALL CHCKXC ( .FALSE., ' ', OK )
 
      CALL SCE2C  ( CLKID,   ET,     SCLKDP )
      CALL CHCKXC ( .FALSE., ' ',    OK     )
 
C
C     Look up pointing relative to frame J2000.
C
      CALL CKGPAV ( INSTID,  SCLKDP, 0.D0,   'J2000',
     .              CMAT0,   AV0,    CLKOUT, FOUND     )
      CALL CHCKXC ( .FALSE., ' ',    OK                )
      CALL CHCKSL ( '-9901 FOUND',  FOUND, .TRUE., OK  )
 
C
C     Look up the same data for instrument -10001 using the
C     J2000 frame (base frame for instrument -10001).
C     Compare.
C
      CALL CKGPAV ( -10001,   SCLKDP, 0.D0,   'J2000',
     .              CMAT1,    AV1,    CLKOUT, FOUND     )
      CALL CHCKXC ( .FALSE., ' ',    OK                 )
      CALL CHCKSL ( '-10001 FOUND',  FOUND, .TRUE., OK  )
 
C
C     Get the  J2000 to RECUR_2 position transformation matrix.
C     Right-multiply CMAT1 by this.
C
      CALL PXFORM ( 'J2000', 'RECUR_2', ET, R )
      CALL CHCKXC ( .FALSE., ' ',    OK       )
 
      CALL MXM    ( CMAT1,    R,        CMAT2 )
 
C
C     Compare C-matrices.
C
      CALL CHCKAD ( 'CMAT0', CMAT0, '~', CMAT2, 9, EX13, OK )
 
C
C     Compare angular velocity vectors. To simplify the computations,
C     we'll work with state transformations. Construct the J2000 to
C     CK_-10001 state transformation XF2 from the corresponding
C     C-matrix and angular velocity vector. Right-multiply this by the
C     J2000 to RECUR_2 state transformation XF3. This should yield a
C     transformation XF4 equivalent to XFORM, since XFORM was
C     effectively created by the same right-multiplication of the state
C     transformation matrix mapping RECUR_2 to CK_-9901.  The angular
C     velocity vector AV2 extracted from XF4 can then be compared to
C     the original angular velocity vector AV0.
C
      CALL RAV2XF ( CMAT1, AV1, XF2 )
 
      CALL SXFORM ( 'J2000', 'RECUR_2', ET, XF3 )
      CALL CHCKXC ( .FALSE., ' ',    OK         )
 
      CALL MXMG   ( XF2, XF3, 6, 6, 6, XF4 )
 
C
C     Extract angular velocity from XF4.
C
      CALL XF2RAV ( XF4, CMAT2, AV2 )
 
C
C     Check AV0.
C
      CALL CHCKAD ( 'AV0', AV0, '~', AV2, 3, EX13, OK )
 
C
C--- Case: ------------------------------------------------------
C
      CALL TCASE ( 'Look up pointing of instrument -9900 '     //
     .             'in frame J2000.  The segment for -9900 '   //
     .             'has a dynamic base frame requiring three ' //
     .             'levels of recursion for evaluation.'       )
 
C
C     Look up the state of body 700 relative to the solar system
C     barycenter in the dynamic frame RECUR_3.  We expect an error
C     to be signaled.
C
      CALL CKGPAV ( -9900,   SCLKDP, 0.D0,   'J2000',
     .              CMAT0,   AV0,    CLKOUT, FOUND           )
      CALL CHCKXC ( .TRUE.,  'SPICE(RECURSIONTOODEEP)',   OK )
 
C
C     End of test cases.
C
 
 
C
C     Clean up the SPK and CK files.
C
      CALL SPKUEF ( HANDLE(1) )
      CALL CHCKXC ( .FALSE., ' ', OK )
      CALL DELFIL ( SPK       )
      CALL CHCKXC ( .FALSE., ' ', OK )
 
      CALL CKUPF  ( HANDLE(2) )
      CALL CHCKXC ( .FALSE., ' ', OK )
      CALL DELFIL ( CKNM      )
      CALL CHCKXC ( .FALSE., ' ', OK )
 
      CALL SPKUEF ( HANDLE(3) )
      CALL CHCKXC ( .FALSE., ' ', OK )
      CALL DELFIL ( SPK2      )
      CALL CHCKXC ( .FALSE., ' ', OK )
 
      CALL CKUPF  ( HANDLE(4) )
      CALL CHCKXC ( .FALSE., ' ', OK )
      CALL DELFIL ( CK2       )
      CALL CHCKXC ( .FALSE., ' ', OK )
 
C
C     Close out the test family.
C
      CALL T_SUCCESS ( OK )
      RETURN
 
      END
