C$Procedure F_DYN07 ( Dynamic Frame Test Family 07 )
 
      SUBROUTINE F_DYN07 ( OK )
 
C$ Abstract
C
C     Test family to exercise the logic and code used to handle
C     frame kernel errors.
C
C$ Copyright
C
C     Copyright (2004), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     None.
C
C$ Keywords
C
C     TEST FAMILY
C
C$ Declarations
 
      IMPLICIT NONE
 
      INCLUDE 'zzdyn.inc'
      INCLUDE 'errhnd.inc'
 
      LOGICAL               OK
 
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     OK         O   logical indicating test status.
C
C$ Detailed_Input
C
C     None.
C
C$ Detailed_Output
C
C     OK         is a logical that indicates the test status to the
C                caller.
C
C$ Parameters
C
C     None.
C
C$ Files
C
C     This test family uses the following kernels:
C
C        LSK generated by tstlsk
C        PCK generated by t_pck08
C        SPK generated by tstspk
C
C$ Exceptions
C
C     This routine does not generate any errors. Routines in its
C     call tree may generate errors that are either intentional and
C     trapped or unintentional and need reporting.  The test family
C     utilities manage this.
C
C$ Particulars
C
C     None.
C
C$ Examples
C
C     None.
C
C$ Restrictions
C
C     None.
C
C$ Author_and_Institution
C
C     N.J. Bachman     (JPL)
C
C$ Literature_References
C
C     None.
C
C$ Version
C
C-    TSPICE Version 1.0.0, 22-DEC-2004 (NJB)
C
C
C-&
 
C
C     SPICELIB functions
C
      LOGICAL               EQSTR
C
C     Local Parameters
C
      CHARACTER*(*)         PCK
      PARAMETER           ( PCK    = 'test_dyn.tpc' )
 
      CHARACTER*(*)         SPK
      PARAMETER           ( SPK    = 'test_dyn.bsp' )
 
 
      INTEGER               LNSIZE
      PARAMETER           ( LNSIZE = 80 )
 
      INTEGER               MAXDEF
      PARAMETER           ( MAXDEF = 50 )
 
      INTEGER               TIMLEN
      PARAMETER           ( TIMLEN = 50 )
 
 
C
C     Parameters controlling frame definitions:
C
 
C
C     Local Variables
C
      CHARACTER*(LNSIZE)    DEFTX2 ( MAXDEF )
      CHARACTER*(LMSGLN)    ERRMSG
      CHARACTER*(LNSIZE)    GSETXT ( MAXDEF )
      CHARACTER*(LNSIZE)    GSMTXT ( MAXDEF )
      CHARACTER*(LNSIZE)    KEYWRD
      CHARACTER*(LNSIZE)    MARTXT ( MAXDEF )
      CHARACTER*(LNSIZE)    MCQTXT ( MAXDEF )
      CHARACTER*(LNSIZE)    MQQTXT ( MAXDEF )
      CHARACTER*(LNSIZE)    TQQTXT ( MAXDEF )
 
      DOUBLE PRECISION      R      ( 3, 3 )
      DOUBLE PRECISION      XFORM  ( 6, 6 )
 
      INTEGER               DX
      INTEGER               HANDLE
      INTEGER               I
      INTEGER               J
 
C
C     Saved variables
C
 
C
C     Initial values
C
 
C
C     Open the test family.
C
      CALL TOPEN ( 'F_DYN07' )
 
 
C **************************************************************
C **************************************************************
C **************************************************************
C     TWO-VECTOR CASES
C **************************************************************
C **************************************************************
C **************************************************************
 
C
C --- Case: ------------------------------------------------------
C
      CALL TCASE ( 'Create and load kernels.' )
 
 
C
C     Create and load kernels.
C
      CALL TSTLSK
      CALL CHCKXC  ( .FALSE., ' ', OK )
 
      CALL TSTSPK  ( SPK, .TRUE., HANDLE  )
      CALL CHCKXC  ( .FALSE., ' ', OK )
 
      CALL T_PCK08 ( PCK, .TRUE., .FALSE. )
      CALL CHCKXC  ( .FALSE., ' ', OK )
 
C
C     Define the GSE frame.
C
      GSETXT(1) =
     .'FRAME_GSE                        =  2399001'
      GSETXT(2) =
     .'FRAME_2399001_NAME               = ''GSE'''
      GSETXT(3) =
     .'FRAME_2399001_CLASS              =  5'
      GSETXT(4) =
     .'FRAME_2399001_CLASS_ID           =  2399001'
      GSETXT(5) =
     .'FRAME_2399001_CENTER             =  399'
      GSETXT(6) =
     .'FRAME_2399001_RELATIVE           = ''J2000'''
      GSETXT(7) =
     .'FRAME_2399001_'//KWSTYL//'       = '''// KVPARM //''''
      GSETXT(8) =
     .'FRAME_2399001_'//KWFFAM//'             = '''// KV2VEC //''''
      GSETXT(9) =
     .'FRAME_2399001_'//KWPRI//KWVAXI//'       = '''//KWX//''''
      GSETXT(10) =
     .'FRAME_2399001_'//KWPRI//KWVCDF//'       = '''//KVPOSV//''''
      GSETXT(11) =
     .'FRAME_2399001_'//KWPRI//KWVOBS//'       = ''EARTH'''
      GSETXT(12) =
     .'FRAME_2399001_'//KWPRI//KWVTRG//'         = ''SUN'''
      GSETXT(13) =
     .'FRAME_2399001_'//KWPRI//KWVABC//'         = ''NONE'''
      GSETXT(14) =
     .'FRAME_2399001_'//KWSEC//KWVAXI//'       = ''-'//KWY//''''
      GSETXT(15) =
     .'FRAME_2399001_'//KWSEC//KWVCDF//'       =  '''// KVVELV //''''
      GSETXT(16) =
     .'FRAME_2399001_'//KWSEC//KWVOBS//'       = ''SUN'''
      GSETXT(17) =
     .'FRAME_2399001_'//KWSEC//KWVTRG//'       = ''EARTH'''
      GSETXT(18) =
     .'FRAME_2399001_'//KWSEC//KWVABC//'         = ''NONE'''
      GSETXT(19) =
     .'FRAME_2399001_'//KWSEC//KWVFRM//'          = ''J2000'''
      GSETXT(20) =
     .'FRAME_2399001_'//KWATOL//'       =  1.E-04'
      GSETXT(21) =
     .'FRAME_2399001_'//KWRSTA//'       =  '''// KVROTG //''''
 
      DX = 21
 
 
 
C
C --- Case: ------------------------------------------------------
C
      CALL TCASE ( 'Check handling of missing keywords in ' //
     .             'GSE (two-vector) frame definition.' )
C
C     First set of tests:  delete required variables from the GSE
C     definition.  Make sure we get the expected error messages
C     when we refer to the GSE frame in an SXFORM or PXFORM call.
C     We currently restrict the testing to the keywords applicable
C     to dynamic frames.  These are keywords 7 through DX.
C
      DO I = 7, DX
C
C        Make a copy of the GSE definition.
C
         CALL MOVEC ( GSETXT, DX, DEFTX2 )
C
C        Lose the Ith element of the definition.
C
         J      = INDEX ( DEFTX2(I), '=' )
         KEYWRD = DEFTX2(I)(:J-1)
C
C
C        Load the modified GSE frame definition.
C
         CALL LMPOOL ( DEFTX2, DX )
         CALL CHCKXC  ( .FALSE., ' ', OK )
 
C
C        Delete the Ith element of the frame definition from
C        the kernel pool.
C
         CALL DVPOOL ( KEYWRD )
         CALL CHCKXC  ( .FALSE., ' ', OK )
 
C
C --- Case: ------------------------------------------------------
C
         CALL TCASE ( 'GSE SXFORM case: deleting keyword '//KEYWRD  )
C
C        Try an SXFORM call.
C
         CALL SXFORM ( 'GSE', 'J2000', 1.D6, XFORM )
 
         IF ( ( I .LT. DX ) .AND. ( I .NE. 20 ) )  THEN
C
C           We've deleted a required keyword.
C
            CALL CHCKXC ( .TRUE., 'SPICE(KERNELVARNOTFOUND)', OK )
 
         ELSE
C
C           The ROTATION STATE keyword is optional.
C
            CALL CHCKXC  ( .FALSE., ' ', OK )
 
         END IF
 
C
C --- Case: ------------------------------------------------------
C
         CALL TCASE ( 'GSE PXFORM case: deleting keyword '//KEYWRD  )
C
C        Try a PXFORM call.
C
         CALL PXFORM ( 'GSE', 'J2000', 1.D6, R )
 
         IF ( ( I .LT. DX ) .AND. ( I .NE. 20 ) )  THEN
C
C           We've deleted a required keyword.
C
            CALL CHCKXC ( .TRUE., 'SPICE(KERNELVARNOTFOUND)', OK )
 
         ELSE
C
C           The ROTATION STATE keyword is optional.
C
            CALL CHCKXC  ( .FALSE., ' ', OK )
 
         END IF
 
      END DO
 
C
C     Second set of tests:  assign bogus values to variables from the
C     GSE definition.  Make sure we get the expected error messages
C     when we refer to the GSE frame in an SXFORM or PXFORM call. We
C     currently restrict the testing to the keywords applicable to
C     dynamic frames. These are keywords 7 through DX.
C
      DO I = 7, DX
C
C        Make a copy of the GSE definition.
C
         CALL MOVEC ( GSETXT, DX, DEFTX2 )
 
         J       = INDEX ( DEFTX2(I), '=' )
 
         KEYWRD  =  DEFTX2(I)(:J-1)
 
C
C --- Case: ------------------------------------------------------
C
         CALL TCASE ( 'GSE SXFORM case: Changing RHS value ' //
     .                'for keyword ' //  KEYWRD )
 
 
         DEFTX2(I)(J+1:) = '''ABC'''
 
C
C        Load the modified GSE frame definition.
C
         CALL LMPOOL ( DEFTX2, DX )
         CALL CHCKXC  ( .FALSE., ' ', OK )
 
C
C        Set the expected error message resulting from an SXFORM
C        call relying on this frame definition.
C
C        Start with the most common error message.
C
         ERRMSG = 'SPICE(NOTSUPPORTED)'
 
C
C        Handle body name errors.
C
         IF (      ( INDEX ( KEYWRD, KWVTRG ) .GT. 0  )
     .        .OR. ( INDEX ( KEYWRD, KWVOBS ) .GT. 0  )  ) THEN
 
            ERRMSG = 'SPICE(NOTRANSLATION)'
 
         END IF
 
C
C        Handle aberration correction errors.
C
         IF (  INDEX ( KEYWRD, KWVABC ) .GT. 0  ) THEN
 
            ERRMSG = 'SPICE(SPKINVALIDOPTION)'
 
         END IF
 
C
C        Handle axis name errors.
C
         IF (  INDEX ( KEYWRD, KWVAXI ) .GT. 0  ) THEN
 
            ERRMSG = 'SPICE(INVALIDAXIS)'
 
         END IF
 
C
C        Handle velocity frame name errors.  (Careful, the
C        substring 'FRAME' is at the start of each keyword.)
C
         IF (  INDEX ( KEYWRD, '_'//KWVFRM ) .GT. 0  ) THEN
 
            ERRMSG = 'SPICE(NOTRANSLATION)'
 
         END IF
 
C
C        Handle minimum anglular separation errors.
C
         IF (  INDEX ( KEYWRD, KWATOL ) .GT. 0  ) THEN
            ERRMSG = 'SPICE(BADVARIABLETYPE)'
         END IF
 
C
C        Try an SXFORM call.
C
         CALL SXFORM ( 'GSE', 'J2000', 1.D6, XFORM )
         CALL CHCKXC ( .TRUE., ERRMSG, OK )
 
 
C
C --- Case: ------------------------------------------------------
C
         CALL TCASE ( 'GSE PXFORM case: changing value for ' //
     .                'keyword '//KEYWRD  )
C
C        Try a PXFORM call.
C
         CALL PXFORM ( 'GSE', 'J2000', 1.D6, R )
         CALL CHCKXC  ( .TRUE., ERRMSG, OK )
 
 
      END DO
 
 
 
C **************************************************************
C **************************************************************
C **************************************************************
C     TWO-VECTOR CASE:  GSM
C **************************************************************
C **************************************************************
C **************************************************************
 
 
C
C     Define the GSM frame.
C
      GSMTXT(1) =
     .'FRAME_GSM                        =  2399002'
      GSMTXT(2) =
     .'FRAME_2399002_NAME               = ''GSM'''
      GSMTXT(3) =
     .'FRAME_2399002_CLASS              =  5'
      GSMTXT(4) =
     .'FRAME_2399002_CLASS_ID           =  2399002'
      GSMTXT(5) =
     .'FRAME_2399002_CENTER             =  399'
      GSMTXT(6) =
     .'FRAME_2399002_RELATIVE           = ''J2000'''
      GSMTXT(7) =
     .'FRAME_2399002_'//KWSTYL//'       = '''// KVPARM //''''
      GSMTXT(8) =
     .'FRAME_2399002_'//KWFFAM//'             = '''// KV2VEC //''''
      GSMTXT(9) =
     .'FRAME_2399002_'//KWPRI//KWVAXI//'       = '''//KWX//''''
      GSMTXT(10) =
     .'FRAME_2399002_'//KWPRI//KWVCDF//'       =  '''// KVPOSV //''''
      GSMTXT(11) =
     .'FRAME_2399002_'//KWPRI//KWVOBS//'       = ''EARTH'''
      GSMTXT(12) =
     .'FRAME_2399002_'//KWPRI//KWVTRG//'       = ''SUN'''
      GSMTXT(13) =
     .'FRAME_2399002_'//KWPRI//KWVABC//'         = ''NONE'''
      GSMTXT(14) =
     .'FRAME_2399002_'//KWSEC//KWVAXI//'       = '''//KWZ//''''
      GSMTXT(15) =
     .'FRAME_2399002_'//KWSEC//KWVCDF//'       = '''//KVCONS//''''
      GSMTXT(16) =
     .'FRAME_2399002_'//KWSEC//KWVSPC//'         = '''//KVLATC//''''
      GSMTXT(17) =
     .'FRAME_2399002_'//KWSEC//KWUNIT//'         = '''//KVDEGR//''''
      GSMTXT(18) =
     .'FRAME_2399002_'//KWSEC//KWLON//'          =   288.43'
      GSMTXT(19) =
     .'FRAME_2399002_'//KWSEC//KWLAT//'          =    79.54'
      GSMTXT(20) =
     .'FRAME_2399002_'//KWSEC//KWVFRM//'          = ''J2000'''
      GSMTXT(21) =
     .'FRAME_2399002_'//KWATOL//'       =  1.E-4'
 
      DX = 21
 
 
C
C --- Case: ------------------------------------------------------
C
      CALL TCASE ( 'Check handling of missing keywords in ' //
     .             'GSM (two-vector) frame definition.' )
C
C     First set of tests:  delete required variables from the GSM
C     definition.  Make sure we get the expected error messages
C     when we refer to the GSM frame in an SXFORM or PXFORM call.
C     We currently restrict the testing to the keywords applicable
C     to dynamic frames.  These are keywords 7 through DX.
C
      DO I = 7, DX
C
C        Make a copy of the GSM definition.
C
         CALL MOVEC ( GSMTXT, DX, DEFTX2 )
C
C        Lose the Ith element of the definition.
C
         J      = INDEX ( DEFTX2(I), '=' )
         KEYWRD = DEFTX2(I)(:J-1)
C
C
C        Load the modified GSM frame definition.  We don't
C        want to clear the kernel pool here because we'd have
C        to keep re-loading the PCK.
C
         CALL LMPOOL ( DEFTX2, DX )
         CALL CHCKXC  ( .FALSE., ' ', OK )
 
C
C        Delete the Ith element of the frame definition from
C        the kernel pool.
C
         CALL DVPOOL ( KEYWRD )
         CALL CHCKXC  ( .FALSE., ' ', OK )
 
C
C --- Case: ------------------------------------------------------
C
         CALL TCASE ( 'GSM SXFORM case: deleting keyword '//KEYWRD  )
C
C        Try an SXFORM call.
C
         CALL SXFORM ( 'GSM', 'J2000', 1.D6, XFORM )
 
         IF ( ( I .LT. DX ) .AND. ( I .NE. 21 ) )  THEN
C
C           We've deleted a required keyword.
C
            CALL CHCKXC ( .TRUE., 'SPICE(KERNELVARNOTFOUND)', OK )
 
         ELSE
C
C           The MIN_ANG_SEP keyword is optional.
C
            CALL CHCKXC  ( .FALSE., ' ', OK )
 
         END IF
 
C
C --- Case: ------------------------------------------------------
C
         CALL TCASE ( 'GSM PXFORM case: deleting keyword '//KEYWRD  )
C
C        Try a PXFORM call.
C
         CALL PXFORM ( 'GSM', 'J2000', 1.D6, R )
 
         IF ( ( I .LT. DX ) .AND. ( I .NE. 21 ) )  THEN
C
C           We've deleted a required keyword.
C
            CALL CHCKXC ( .TRUE., 'SPICE(KERNELVARNOTFOUND)', OK )
 
         ELSE
C
C           The MIN_ANG_SEP keyword is optional.
C
            CALL CHCKXC  ( .FALSE., ' ', OK )
 
         END IF
 
      END DO
 
C
C     Second set of tests:  assign bogus values to variables from the
C     GSM definition.  Make sure we get the expected error messages
C     when we refer to the GSM frame in an SXFORM or PXFORM call. We
C     currently restrict the testing to the keywords applicable to
C     dynamic frames. These are keywords 7 through DX.
C
      DO I = 7, DX
 
C
C        Make a copy of the GSM definition.
C
         CALL MOVEC ( GSMTXT, DX, DEFTX2 )
 
         J       = INDEX ( DEFTX2(I), '=' )
 
         KEYWRD  =  DEFTX2(I)(:J-1)
C
C --- Case: ------------------------------------------------------
C
         CALL TCASE ( 'GSM SXFORM case: Changing RHS value ' //
     .                'for keyword ' //  KEYWRD )
 
         DEFTX2(I)(J+1:) = '''ABC'''
 
C
C        Load the modified GSM frame definition.
C
         CALL LMPOOL ( DEFTX2, DX )
         CALL CHCKXC  ( .FALSE., ' ', OK )
 
C
C        Set the expected error message resulting from an SXFORM
C        call relying on this frame definition.
C
C        Start with the most common error message.
C
         ERRMSG = 'SPICE(NOTSUPPORTED)'
 
C
C        Handle body name errors.
C
         IF (      ( INDEX ( KEYWRD, KWVTRG ) .GT. 0  )
     .        .OR. ( INDEX ( KEYWRD, KWVOBS ) .GT. 0  )  ) THEN
 
            ERRMSG = 'SPICE(NOTRANSLATION)'
 
         END IF
 
C
C        Handle aberration correction errors.
C
         IF (  INDEX ( KEYWRD, KWVABC ) .GT. 0  ) THEN
 
            ERRMSG = 'SPICE(SPKINVALIDOPTION)'
 
         END IF
 
C
C        Handle axis name errors.
C
         IF (  INDEX ( KEYWRD, KWVAXI ) .GT. 0  ) THEN
 
            ERRMSG = 'SPICE(INVALIDAXIS)'
 
         END IF
 
C
C        Handle constant frame name errors.
C
         IF (  INDEX ( KEYWRD, '_'//KWVFRM ) .GT. 0  ) THEN
 
            ERRMSG = 'SPICE(NOTRANSLATION)'
 
         END IF
 
C
C        Handle minimum anglular separation errors.
C
         IF (  INDEX ( KEYWRD, KWATOL ) .GT. 0  ) THEN
            ERRMSG = 'SPICE(BADVARIABLETYPE)'
         END IF
 
C
C        Handle latitude and longitude errors.
C
         IF (  INDEX ( KEYWRD, 'LATITUDE' ) .GT. 0  ) THEN
            ERRMSG = 'SPICE(BADVARIABLETYPE)'
         END IF
 
         IF (  INDEX ( KEYWRD, 'LONGITUDE' ) .GT. 0  ) THEN
            ERRMSG = 'SPICE(BADVARIABLETYPE)'
         END IF
 
C
C        Handle unit errors.
C
         IF (  INDEX ( KEYWRD, KWUNIT ) .GT. 0  ) THEN
 
            ERRMSG = 'SPICE(UNITSNOTREC)'
 
         END IF
 
 
C
C        Try an SXFORM call.
C
         CALL SXFORM ( 'GSM', 'J2000', 1.D6, XFORM )
         CALL CHCKXC ( .TRUE., ERRMSG, OK )
 
 
C
C --- Case: ------------------------------------------------------
C
         CALL TCASE ( 'GSM PXFORM case: changing value for ' //
     .                'keyword '//KEYWRD  )
C
C        Try a PXFORM call.
C
         CALL PXFORM ( 'GSM', 'J2000', 1.D6, R )
         CALL CHCKXC  ( .TRUE., ERRMSG, OK )
 
 
      END DO
 
 
 
C **************************************************************
C **************************************************************
C **************************************************************
C     MEAN EQUATOR AND EQUINOX OF DATE CASES
C **************************************************************
C **************************************************************
C **************************************************************
 
C
C     First set of tests:  delete required variables from the MQQ
C     definition.  Make sure we get the expected error messages
C     when we refer to the MQQ frame in an SXFORM or PXFORM call.
C     We currently restrict the testing to the keywords applicable
C     to dynamic frames.  These are keywords 7 through DX.
C
      MQQTXT(1) =
     .'FRAME_MQQ                        =  2399003'
      MQQTXT(2) =
     .'FRAME_2399003_NAME               = ''MQQ'''
      MQQTXT(3) =
     .'FRAME_2399003_CLASS              =  5'
      MQQTXT(4) =
     .'FRAME_2399003_CLASS_ID           =  2399003'
      MQQTXT(5) =
     .'FRAME_2399003_CENTER             =  399'
      MQQTXT(6) =
     .'FRAME_2399003_RELATIVE           = ''J2000'''
      MQQTXT(7) =
     .'FRAME_2399003_' // KWSTYL // '   = ''' // KVPARM // ''''
      MQQTXT(8) =
     .'FRAME_2399003_' // KWFFAM // '             = '''// KVMEQT //''''
      MQQTXT(9) =
     .'FRAME_2399003_' // KWPRCM // '   = ''' // KVM001 // ''''
      MQQTXT(10) =
     .'FRAME_2399003_' // KWRSTA // '    = ''' // KVROTG //''''
 
      DX = 10
 
 
      DO I = 7, DX
C
C        Make a copy of the MQQ definition.
C
         CALL MOVEC ( MQQTXT, DX, DEFTX2 )
C
C        Lose the Ith element of the definition.
C
         J      = INDEX ( DEFTX2(I), '=' )
         KEYWRD = DEFTX2(I)(:J-1)
C
C
C        Load the modified MQQ frame definition.  We don't
C        want to clear the kernel pool here because we'd have
C        to keep re-loading the PCK.
C
         CALL LMPOOL ( DEFTX2, DX )
         CALL CHCKXC  ( .FALSE., ' ', OK )
 
C
C        Delete the Ith element of the frame definition from
C        the kernel pool.
C
         CALL DVPOOL ( KEYWRD )
         CALL CHCKXC  ( .FALSE., ' ', OK )
 
C
C --- Case: ------------------------------------------------------
C
         CALL TCASE ( 'MQQ SXFORM case: deleting keyword '//KEYWRD  )
C
C        Try an SXFORM call.
C
         CALL SXFORM ( 'MQQ', 'J2000', 1.D6, XFORM )
 
         IF ( I .LT. DX ) THEN
C
C           We've deleted a required keyword.
C
            CALL CHCKXC ( .TRUE., 'SPICE(KERNELVARNOTFOUND)', OK )
 
         ELSE
C
C           The ROTATION_STATE keyword or the FREEZE_EPOCH keyword
C           must be present.
C
            CALL CHCKXC ( .TRUE., 'SPICE(FRAMEDEFERROR)', OK )
 
         END IF
 
C
C --- Case: ------------------------------------------------------
C
         CALL TCASE ( 'MQQ PXFORM case: deleting keyword '//KEYWRD  )
C
C        Try a PXFORM call.
C
         CALL PXFORM ( 'MQQ', 'J2000', 1.D6, R )
 
         IF ( I .LT. DX ) THEN
C
C           We've deleted a required keyword.
C
            CALL CHCKXC ( .TRUE., 'SPICE(KERNELVARNOTFOUND)', OK )
 
         ELSE
C
C           The ROTATION_STATE keyword or the FREEZE_EPOCH keyword
C           must be present.
C
            CALL CHCKXC ( .TRUE., 'SPICE(FRAMEDEFERROR)', OK )
 
         END IF
 
      END DO
 
C
C     Second set of tests:  assign bogus values to variables from the
C     MQQ definition.  Make sure we get the expected error messages
C     when we refer to the MQQ frame in an SXFORM or PXFORM call. We
C     currently restrict the testing to the keywords applicable to
C     dynamic frames. These are keywords 7 through DX.
C
      DO I = 7, DX
 
C
C        Make a copy of the MQQ definition.
C
         CALL MOVEC ( MQQTXT, DX, DEFTX2 )
 
         J       = INDEX ( DEFTX2(I), '=' )
 
         KEYWRD  =  DEFTX2(I)(:J-1)
C
C --- Case: ------------------------------------------------------
C
         CALL TCASE ( 'MQQ SXFORM case: Changing RHS value ' //
     .                'for keyword ' //  KEYWRD )
 
         DEFTX2(I)(J+1:) = '''ABC'''
 
C
C        Load the modified MQQ frame definition.
C
         CALL LMPOOL ( DEFTX2, DX )
         CALL CHCKXC  ( .FALSE., ' ', OK )
 
C
C        Set the expected error message resulting from an SXFORM
C        call relying on this frame definition.
C
C        Start with the most common error message.
C
         ERRMSG = 'SPICE(NOTSUPPORTED)'
 
 
C
C        Try an SXFORM call.
C
         CALL SXFORM ( 'MQQ', 'J2000', 1.D6, XFORM )
         CALL CHCKXC ( .TRUE., ERRMSG, OK )
 
 
C
C --- Case: ------------------------------------------------------
C
         CALL TCASE ( 'MQQ PXFORM case: changing value for ' //
     .                'keyword '//KEYWRD  )
C
C        Try a PXFORM call.
C
         CALL PXFORM ( 'MQQ', 'J2000', 1.D6, R )
         CALL CHCKXC  ( .TRUE., ERRMSG, OK )
 
 
      END DO
 
 
 
 
C **************************************************************
C **************************************************************
C **************************************************************
C     TRUE EQUATOR AND EQUINOX OF DATE CASES
C **************************************************************
C **************************************************************
C **************************************************************
C
C     First set of tests:  delete required variables from the TQQ
C     definition.  Make sure we get the expected error messages
C     when we refer to the TQQ frame in an SXFORM or PXFORM call.
C     We currently restrict the testing to the keywords applicable
C     to dynamic frames.  These are keywords 7 through DX.
C
 
      TQQTXT(1) =
     .'FRAME_TQQ                        =  2399004'
      TQQTXT(2) =
     .'FRAME_2399004_NAME               = ''TQQ'''
      TQQTXT(3) =
     .'FRAME_2399004_CLASS              =  5'
      TQQTXT(4) =
     .'FRAME_2399004_CLASS_ID           =  2399004'
      TQQTXT(5) =
     .'FRAME_2399004_CENTER             =  399'
      TQQTXT(6) =
     .'FRAME_2399004_RELATIVE           = ''J2000'''
      TQQTXT(7) =
     .'FRAME_2399004_' // KWSTYL // '   = ''' // KVPARM // ''''
      TQQTXT(8) =
     .'FRAME_2399004_' // KWFFAM // '             = '''// KVTEQT //''''
      TQQTXT(9) =
     .'FRAME_2399004_' // KWPRCM // '   = ''' // KVM001 // ''''
      TQQTXT(10) =
     .'FRAME_2399004_' // KWNUTM // '   = ''' // KVM002 // ''''
      TQQTXT(11) =
     .'FRAME_2399004_' // KWRSTA // '    = ''' // KVINRT //''''
 
 
      DX = 11
 
 
      DO I = 7, DX
C
C        Make a copy of the TQQ definition.
C
         CALL MOVEC ( TQQTXT, DX, DEFTX2 )
C
C        Lose the Ith element of the definition.
C
         J      = INDEX ( DEFTX2(I), '=' )
         KEYWRD = DEFTX2(I)(:J-1)
C
C
C        Load the modified TQQ frame definition.  We don't
C        want to clear the kernel pool here because we'd have
C        to keep re-loading the PCK.
C
         CALL LMPOOL ( DEFTX2, DX )
         CALL CHCKXC  ( .FALSE., ' ', OK )
 
C
C        Delete the Ith element of the frame definition from
C        the kernel pool.
C
         CALL DVPOOL ( KEYWRD )
         CALL CHCKXC  ( .FALSE., ' ', OK )
 
C
C --- Case: ------------------------------------------------------
C
         CALL TCASE ( 'TQQ SXFORM case: deleting keyword '//KEYWRD  )
C
C        Try an SXFORM call.
C
         CALL SXFORM ( 'TQQ', 'J2000', 1.D6, XFORM )
 
         IF ( I .LT. DX )  THEN
C
C           We've deleted a required keyword.
C
            CALL CHCKXC ( .TRUE., 'SPICE(KERNELVARNOTFOUND)', OK )
 
         ELSE
C
C           The ROTATION STATE keyword or the FREEZE EPOCH keyword
C           must be present.
C
            CALL CHCKXC ( .TRUE., 'SPICE(FRAMEDEFERROR)', OK )
 
         END IF
 
C
C --- Case: ------------------------------------------------------
C
         CALL TCASE ( 'TQQ PXFORM case: deleting keyword '//KEYWRD  )
C
C        Try a PXFORM call.
C
         CALL PXFORM ( 'TQQ', 'J2000', 1.D6, R )
 
         IF ( I .LT. DX )  THEN
C
C           We've deleted a required keyword.
C
            CALL CHCKXC ( .TRUE., 'SPICE(KERNELVARNOTFOUND)', OK )
 
         ELSE
C
C           The ROTATION_STATE keyword or the FREEZE_EPOCH keyword
C           must be present.
C
            CALL CHCKXC ( .TRUE., 'SPICE(FRAMEDEFERROR)', OK )
 
         END IF
 
      END DO
 
C
C     Second set of tests:  assign bogus values to variables from the
C     TQQ definition.  Make sure we get the expected error messages
C     when we refer to the TQQ frame in an SXFORM or PXFORM call. We
C     currently restrict the testing to the keywords applicable to
C     dynamic frames. These are keywords 7 through DX.
C
      DO I = 7, DX
 
C
C        Make a copy of the TQQ definition.
C
         CALL MOVEC ( TQQTXT, DX, DEFTX2 )
 
         J       = INDEX ( DEFTX2(I), '=' )
 
         KEYWRD  =  DEFTX2(I)(:J-1)
C
C --- Case: ------------------------------------------------------
C
         CALL TCASE ( 'TQQ SXFORM case: Changing RHS value ' //
     .                'for keyword ' //  KEYWRD )
 
         DEFTX2(I)(J+1:) = '''ABC'''
 
C
C        Load the modified TQQ frame definition.
C
         CALL LMPOOL ( DEFTX2, DX )
         CALL CHCKXC  ( .FALSE., ' ', OK )
 
C
C        Set the expected error message resulting from an SXFORM
C        call relying on this frame definition.
C
C        Start with the most common error message.
C
         ERRMSG = 'SPICE(NOTSUPPORTED)'
 
 
C
C        Try an SXFORM call.
C
         CALL SXFORM ( 'TQQ', 'J2000', 1.D6, XFORM )
         CALL CHCKXC ( .TRUE., ERRMSG, OK )
 
 
C
C --- Case: ------------------------------------------------------
C
         CALL TCASE ( 'TQQ PXFORM case: changing value for ' //
     .                'keyword '//KEYWRD  )
C
C        Try a PXFORM call.
C
         CALL PXFORM ( 'TQQ', 'J2000', 1.D6, R )
         CALL CHCKXC  ( .TRUE., ERRMSG, OK )
 
 
      END DO
 
 
C **************************************************************
C **************************************************************
C **************************************************************
C     MEAN ECLIPTIC AND EQUINOX OF DATE CASES
C **************************************************************
C **************************************************************
C **************************************************************
C
C     First set of tests:  delete required variables from the MCQ
C     definition.  Make sure we get the expected error messages
C     when we refer to the MCQ frame in an SXFORM or PXFORM call.
C     We currently restrict the testing to the keywords applicable
C     to dynamic frames.  These are keywords 7 through DX.
C
 
 
      MCQTXT(1) =
     .'FRAME_MCQ                        =  2399005'
      MCQTXT(2) =
     .'FRAME_2399005_NAME               = ''MCQ'''
      MCQTXT(3) =
     .'FRAME_2399005_CLASS              =  5'
      MCQTXT(4) =
     .'FRAME_2399005_CLASS_ID           =  2399005'
      MCQTXT(5) =
     .'FRAME_2399005_CENTER             =  399'
      MCQTXT(6) =
     .'FRAME_2399005_RELATIVE           = ''J2000'''
      MCQTXT(7) =
     .'FRAME_2399005_' // KWSTYL // '   = ''' // KVPARM // ''''
      MCQTXT(8) =
     .'FRAME_2399005_' // KWFFAM // '             = '''// KVMECL //''''
      MCQTXT(9) =
     .'FRAME_2399005_' // KWPRCM // '  = ''' // KVM001 // ''''
      MCQTXT(10) =
     .'FRAME_2399005_' // KWOBQM // '    = ''' // KVM002 // ''''
      MCQTXT(11) =
     .'FRAME_2399005_' // KWFREZ // '       = @2005-JAN-1/00:00:00'
 
      DX = 11
 
 
      DO I = 7, DX
C
C        Make a copy of the MCQ definition.
C
         CALL MOVEC ( MCQTXT, DX, DEFTX2 )
C
C        Lose the Ith element of the definition.
C
         J      = INDEX ( DEFTX2(I), '=' )
         KEYWRD = DEFTX2(I)(:J-1)
C
C
C        Load the modified MCQ frame definition.  We don't
C        want to clear the kernel pool here because we'd have
C        to keep re-loading the PCK.
C
         CALL LMPOOL ( DEFTX2, DX )
         CALL CHCKXC  ( .FALSE., ' ', OK )
 
C
C        Delete the Ith element of the frame definition from
C        the kernel pool.
C
         CALL DVPOOL ( KEYWRD )
         CALL CHCKXC  ( .FALSE., ' ', OK )
 
C
C --- Case: ------------------------------------------------------
C
         CALL TCASE ( 'MCQ SXFORM case: deleting keyword '//KEYWRD  )
C
C        Try an SXFORM call.
C
         CALL SXFORM ( 'MCQ', 'J2000', 1.D6, XFORM )
 
         IF ( I .LT. DX )  THEN
C
C           We've deleted a required keyword.
C
            CALL CHCKXC ( .TRUE., 'SPICE(KERNELVARNOTFOUND)', OK )
 
         ELSE
C
C           The ROTATION_STATE keyword or the FREEZE_EPOCH keyword
C           must be present.
C
            CALL CHCKXC ( .TRUE., 'SPICE(FRAMEDEFERROR)', OK )
 
         END IF
 
C
C --- Case: ------------------------------------------------------
C
         CALL TCASE ( 'MCQ PXFORM case: deleting keyword '//KEYWRD  )
C
C        Try a PXFORM call.
C
         CALL PXFORM ( 'MCQ', 'J2000', 1.D6, R )
 
         IF ( I .LT. DX )  THEN
C
C           We've deleted a required keyword.
C
            CALL CHCKXC ( .TRUE., 'SPICE(KERNELVARNOTFOUND)', OK )
 
         ELSE
C
C           The ROTATION STATE keyword or the FREEZE EPOCH keyword
C           must be present.
C
            CALL CHCKXC ( .TRUE., 'SPICE(FRAMEDEFERROR)', OK )
 
         END IF
 
      END DO
 
C
C     Second set of tests:  assign bogus values to variables from the
C     MCQ definition.  Make sure we get the expected error messages
C     when we refer to the MCQ frame in an SXFORM or PXFORM call. We
C     currently restrict the testing to the keywords applicable to
C     dynamic frames. These are keywords 7 through DX.
C
      DO I = 7, DX
 
C
C        Make a copy of the MCQ definition.
C
         CALL MOVEC ( MCQTXT, DX, DEFTX2 )
 
         J       = INDEX ( DEFTX2(I), '=' )
 
         KEYWRD  =  DEFTX2(I)(:J-1)
C
C --- Case: ------------------------------------------------------
C
         CALL TCASE ( 'MCQ SXFORM case: Changing RHS value ' //
     .                'for keyword ' //  KEYWRD )
 
         DEFTX2(I)(J+1:) = '''ABC'''
 
C
C        Load the modified MCQ frame definition.
C
         CALL LMPOOL ( DEFTX2, DX )
         CALL CHCKXC  ( .FALSE., ' ', OK )
 
C
C        Set the expected error message resulting from an SXFORM
C        call relying on this frame definition.
C
C        Start with the most common error message.
C
         ERRMSG = 'SPICE(NOTSUPPORTED)'
 
C
C        Handle freeze epoch errors.
C
         IF (  INDEX ( KEYWRD, KWFREZ ) .GT. 0  ) THEN
            ERRMSG = 'SPICE(BADVARIABLETYPE)'
         END IF
 
C
C        Try an SXFORM call.
C
         CALL SXFORM ( 'MCQ', 'J2000', 1.D6, XFORM )
         CALL CHCKXC ( .TRUE., ERRMSG, OK )
 
 
C
C --- Case: ------------------------------------------------------
C
         CALL TCASE ( 'MCQ PXFORM case: changing value for ' //
     .                'keyword '//KEYWRD  )
C
C        Try a PXFORM call.
C
         CALL PXFORM ( 'MCQ', 'J2000', 1.D6, R )
         CALL CHCKXC  ( .TRUE., ERRMSG, OK )
 
 
      END DO
 
 
C **************************************************************
C **************************************************************
C **************************************************************
C     EULER FRAME CASES
C **************************************************************
C **************************************************************
C **************************************************************
C
C     Define the pseudo IAU_MARS frame.
C
      MARTXT(1) =
     .'FRAME_IAU_MARS2                  =  2499000'
      MARTXT(2) =
     .'FRAME_2499000_NAME               = ''IAU_MARS2'''
      MARTXT(3) =
     .'FRAME_2499000_CLASS              =  5'
      MARTXT(4) =
     .'FRAME_2499000_CLASS_ID           =  2499000'
      MARTXT(5) =
     .'FRAME_2499000_CENTER             =  499'
      MARTXT(6) =
     .'FRAME_2499000_RELATIVE           = ''J2000'''
      MARTXT(7) =
     .'FRAME_2499000_' // KWSTYL // '   = ''' // KVPARM // ''''
      MARTXT(8) =
     .'FRAME_2499000_' // KWFFAM // '             = '''// KVEULR //''''
      MARTXT(9) =
     .'FRAME_2499000_' // KWEPOC // '              =  ' //
     .                   '@2000-JAN-1/12:00'
      MARTXT(10) =
     .'FRAME_2499000_' // KWEUAX // '               = ( 3  1  3 )'
      MARTXT(11) =
     .'FRAME_2499000_' // KWEAC1 // '     = ( -47.68143 '             //
     .                                    '0.33621061170684714E-10 )'
      MARTXT(12) =
     .'FRAME_2499000_' // KWEAC2 // '     = ( -37.1135 '              //
     .                                   '-0.19298045478743630E-10 )'
      MARTXT(13) =
     .'FRAME_2499000_' // KWEAC3 // '     = (-176.630  '              //
     .                                   '-0.40612497946759260E-02 )'
      MARTXT(14) =
     .'FRAME_2499000_' // KWUNIT // '              =  '''//KVDEGR//''''
 
      MARTXT(15) =
     .'FRAME_2499000_' // KWRSTA // '    = ''' // KVROTG //''''
 
 
      DX = 15
 
C
C --- Case: ------------------------------------------------------
C
      CALL TCASE ( 'Check handling of missing keywords in ' //
     .             'IAU_MARS2 (Euler) frame definition.' )
C
C     First set of tests:  delete required variables from the GSE
C     definition.  Make sure we get the expected error messages
C     when we refer to the GSE frame in an SXFORM or PXFORM call.
C     We currently restrict the testing to the keywords applicable
C     to dynamic frames.  These are keywords 7 through DX.
C
      DO I = 7, DX
C
C        Make a copy of the IAU_MARS2 definition.
C
         CALL MOVEC ( MARTXT, DX, DEFTX2 )
C
C        Lose the Ith element of the definition.
C
         J      = INDEX ( DEFTX2(I), '=' )
         KEYWRD = DEFTX2(I)(:J-1)
C
C
C        Load the modified IAU_MARS2 frame definition.
C
         CALL LMPOOL ( DEFTX2, DX )
         CALL CHCKXC  ( .FALSE., ' ', OK )
 
C
C        Delete the Ith element of the frame definition from
C        the kernel pool.
C
         CALL DVPOOL ( KEYWRD )
         CALL CHCKXC  ( .FALSE., ' ', OK )
 
C
C --- Case: ------------------------------------------------------
C
         CALL TCASE ( 'IAU_MARS2 SXFORM case: deleting ' //
     .                'keyword '//KEYWRD  )
C
C        Try an SXFORM call.
C
         CALL SXFORM ( 'IAU_MARS2', 'J2000', 1.D6, XFORM )
 
         IF ( I .LT. DX ) THEN
C
C           We've deleted a required keyword.
C
            CALL CHCKXC ( .TRUE., 'SPICE(KERNELVARNOTFOUND)', OK )
 
         ELSE
C
C           The ROTATION_STATE keyword is optional.
C
            CALL CHCKXC  ( .FALSE., ' ', OK )
 
         END IF
 
C
C --- Case: ------------------------------------------------------
C
         CALL TCASE ( 'IAU_MARS2 PXFORM case: deleting ' //
     .                'keyword '//KEYWRD  )
C
C        Try a PXFORM call.
C
         CALL PXFORM ( 'IAU_MARS2', 'J2000', 1.D6, R )
 
         IF ( I .LT. DX ) THEN
C
C           We've deleted a required keyword.
C
            CALL CHCKXC ( .TRUE., 'SPICE(KERNELVARNOTFOUND)', OK )
 
         ELSE
C
C           The ROTATION_STATE keyword is optional.
C
            CALL CHCKXC  ( .FALSE., ' ', OK )
 
         END IF
 
      END DO
 
C
C     Second set of tests:  assign bogus values to variables from the
C     IAU_MARS2 definition. Make sure we get the expected error
C     messages when we refer to the IAU_MARS2 frame in an SXFORM or
C     PXFORM call. We currently restrict the testing to the keywords
C     applicable to dynamic frames. These are keywords 7 through DX.
C
      DO I = 7, DX
C
C --- Case: ------------------------------------------------------
C
         CALL TCASE ( 'IAU_MARS2 SXFORM case: Changing RHS ' //
     .                'value for keyword '// KEYWRD )
 
C
C        Make a copy of the IAU_MARS2 definition.
C
         CALL MOVEC ( MARTXT, DX, DEFTX2 )
 
         J       = INDEX ( DEFTX2(I), '=' )
 
         KEYWRD  =  DEFTX2(I)(:J-1)
 
         IF ( EQSTR( KEYWRD, 'FRAME_2499000_'//KWEUAX )  ) THEN
 
            DEFTX2(I)(J+1:) = '( 1, 0, 1 )'
 
         ELSE IF ( EQSTR( KEYWRD, 'FRAME_2499000_'//KWEPOC )  ) THEN
 
            DEFTX2(I)(J+1:) = '@2004-ABC/12:00:00'
 
         ELSE
            DEFTX2(I)(J+1:) = '''ABC'''
         END IF
 
C
C        Load the modified IAU_MARS2 frame definition.
C
         CALL LMPOOL ( DEFTX2, DX )
 
         IF ( EQSTR( KEYWRD, 'FRAME_2499000_'//KWEPOC )  ) THEN
C
C           LMPOOL catches malformed time tokens of the form @*.
C
            ERRMSG = 'SPICE(BADTIMESPEC)'
 
            CALL CHCKXC ( .TRUE., ERRMSG, OK )
 
C
C           Re-set the time token to a string not recognized
C           as a time token.
C
            DEFTX2(I)(J+1:) = '''ABC'''
 
            CALL LMPOOL ( DEFTX2, DX )
            CALL CHCKXC  ( .FALSE., ' ', OK )
 
         ELSE
            CALL CHCKXC  ( .FALSE., ' ', OK )
         END IF
 
C
C        Set the expected error message resulting from an SXFORM
C        call relying on this frame definition.
C
C        Start with the most common error message.
C
         ERRMSG = 'SPICE(NOTSUPPORTED)'
 
C
C        Handle epoch errors.
C
         IF (  INDEX ( KEYWRD, KWEPOC ) .GT. 0  ) THEN
 
            ERRMSG = 'SPICE(BADVARIABLETYPE)'
 
         END IF
 
C
C        Handle units errors.
C
         IF (  INDEX ( KEYWRD, KWUNIT ) .GT. 0  ) THEN
 
            ERRMSG = 'SPICE(UNITSNOTREC)'
 
         END IF
 
C
C        Handle axis sequence errors.
C
         IF (  INDEX ( KEYWRD, KWEUAX ) .GT. 0  ) THEN
 
            ERRMSG = 'SPICE(BADAXISNUMBERS)'
 
         END IF
 
C
C        Handle angle 1 coefficient errors.
C
         IF (  INDEX ( KEYWRD, KWEAC1 ) .GT. 0  ) THEN
            ERRMSG = 'SPICE(BADVARIABLETYPE)'
         END IF
 
C
C        Handle angle 2 coefficient errors.
C
         IF (  INDEX ( KEYWRD, KWEAC2 ) .GT. 0  ) THEN
            ERRMSG = 'SPICE(BADVARIABLETYPE)'
         END IF
C
C        Handle angle 3 coefficient errors.
C
         IF (  INDEX ( KEYWRD, KWEAC3 ) .GT. 0  ) THEN
            ERRMSG = 'SPICE(BADVARIABLETYPE)'
         END IF
 
 
C
C        Try an SXFORM call.
C
         CALL SXFORM ( 'IAU_MARS2', 'J2000', 1.D6, XFORM )
         CALL CHCKXC ( .TRUE., ERRMSG, OK )
 
 
C
C --- Case: ------------------------------------------------------
C
         CALL TCASE ( 'IAU_MARS2 PXFORM case: changing value for ' //
     .                'keyword '//KEYWRD  )
C
C        Try a PXFORM call.
C
         CALL PXFORM ( 'IAU_MARS2', 'J2000', 1.D6, R )
         CALL CHCKXC  ( .TRUE., ERRMSG, OK )
 
 
      END DO
 
 
 
 
 
 
 
C
C     Clean up the SPK file.
C
      CALL TCASE  ( 'File clean-up.' )
      CALL SPKUEF ( HANDLE )
      CALL CHCKXC ( .FALSE., ' ', OK )
 
      CALL DELFIL ( SPK    )
      CALL CHCKXC ( .FALSE., ' ', OK )
 
C
C     Close out the test family.
C
      CALL T_SUCCESS ( OK )
      RETURN
 
      END
