C$Procedure      F_GETFOV (Family of tests for GETFOV )
 
      SUBROUTINE F_GETFOV ( OK )
      IMPLICIT NONE
 
      LOGICAL               OK
 
C$ Abstract
C
C     This routine tests the exceptions for the routine GETFOV
C     as well as determining whether or not all data specified
C     in an I-kernel can be retrieved.
C
C-&
 
 
C
C     Test Utility Functions
C
 
 
C
C     SPICELIB Functions
C
 
 
C
C     Local Variables
C
      INTEGER               WDSIZE
      PARAMETER           ( WDSIZE = 32 )
 
      CHARACTER*(WDSIZE)    SHAPE
      CHARACTER*(WDSIZE)    FRAME
      DOUBLE PRECISION      BSIGHT( 3 )
      INTEGER               N
      DOUBLE PRECISION      BOUNDS( 3, 5 )
 
      CHARACTER*(WDSIZE)    FOVFRM
      CHARACTER*(WDSIZE)    FOVSHP
      DOUBLE PRECISION      FOVBS ( 3 )
      DOUBLE PRECISION      FOVBND( 3, 5 )
 
      INTEGER               INSTID
      INTEGER               ROOM
 
      CHARACTER*(WDSIZE)    KWBORE
      CHARACTER*(WDSIZE)    KWSHAP
      CHARACTER*(WDSIZE)    KWFRAM
      CHARACTER*(WDSIZE)    KWBOUN
 
 
C
C     Begin every test family with an open call.
C
      CALL TOPEN ( 'F_GETFOV' )
 
      KWBOUN = 'INS-1000_FOV_BOUNDARY'
      KWBORE = 'INS-1000_BORESIGHT'
      KWSHAP = 'INS-1000_FOV_SHAPE'
      KWFRAM = 'INS-1000_FOV_FRAME'
 
      ROOM   = 3
      INSTID = -1000
 
      SHAPE = 'POLYGON'
      FRAME = 'CKERNEL'
      BOUNDS(1,1) =  1.0D0
      BOUNDS(2,1) =  1.0D0
      BOUNDS(3,1) =  1.0D0
 
      BOUNDS(1,2) = -1.0D0
      BOUNDS(2,2) =  1.0D0
      BOUNDS(3,2) =  1.0D0
 
      BOUNDS(1,3) = -1.0D0
      BOUNDS(2,3) = -1.0D0
      BOUNDS(3,3) =  1.0D0
 
      BOUNDS(1,4) =  1.0D0
      BOUNDS(2,4) = -1.0D0
      BOUNDS(3,4) =  1.0D0
 
      BOUNDS(1,5) = 0.0D0
      BOUNDS(2,5) = 0.0D0
      BOUNDS(3,5) = 0.0D0
 
      BSIGHT(1)   = 0.0D0
      BSIGHT(2)   = 0.0D0
      BSIGHT(3)   = 1.0D0
 
      CALL TCASE ( 'Check that a an exception is signalled if '
     .//           'the frame of the instrument has not been '
     .//           'stored in the kernel pool. ' )
 
 
         CALL CLPOOL
         CALL PCPOOL ( KWSHAP,               1, SHAPE )
         CALL PDPOOL ( KWBORE,               3, BSIGHT)
         CALL PDPOOL ( KWBOUN,              12, BOUNDS)
         CALL PCPOOL ( 'INS-1001_FOV_FRAME', 1, FRAME )
 
         CALL GETFOV ( INSTID, ROOM, FOVSHP, FOVFRM, FOVBS, N, FOVBND )
         CALL CHCKXC ( .TRUE., 'SPICE(FRAMEMISSING)',  OK )
 
      CALL TCASE ( 'Check that a an exception is signalled if '
     .//           'the shape of the instrument field of view is '
     .//           'not in the kernel pool. ' )
 
 
         CALL CLPOOL
         CALL PCPOOL ( KWFRAM,               1, FRAME )
         CALL PCPOOL ( 'INS-1001_FOV_SHAPE', 1, SHAPE )
         CALL PDPOOL ( KWBORE,               3, BSIGHT)
         CALL PDPOOL ( KWBOUN,              12, BOUNDS)
 
         CALL GETFOV ( INSTID, ROOM, FOVSHP, FOVFRM, FOVBS, N, FOVBND )
         CALL CHCKXC ( .TRUE., 'SPICE(SHAPEMISSING)',  OK )
 
      CALL TCASE ( 'Check that a an exception is signalled if '
     .//           'the shape specified is not one of the known '
     .//           'shapes. ' )
 
 
         SHAPE = 'SQUARE'
 
         CALL CLPOOL
         CALL PCPOOL ( KWFRAM,               1, FRAME )
         CALL PCPOOL ( KWSHAP,               1, SHAPE )
         CALL PDPOOL ( KWBORE,               3, BSIGHT)
         CALL PDPOOL ( KWBOUN,              12, BOUNDS)
 
         CALL GETFOV ( INSTID, ROOM, FOVSHP, FOVFRM, FOVBS, N, FOVBND )
         CALL CHCKXC ( .TRUE., 'SPICE(SHAPENOTSUPPORTED)',  OK )
 
      CALL TCASE ( 'Check that a an exception is signalled if '
     .//           'the boresight information has not been '
     .//           'stored in the kernel pool. ' )
 
         SHAPE = 'POLYGON'
         KWBORE = 'INS-1001_BORESIGHT'
 
         CALL CLPOOL
         CALL PCPOOL ( KWFRAM,               1, FRAME )
         CALL PCPOOL ( KWSHAP,               1, SHAPE )
         CALL PDPOOL ( KWBORE,               3, BSIGHT)
         CALL PDPOOL ( KWBOUN,              12, BOUNDS)
 
         CALL GETFOV ( INSTID, ROOM, FOVSHP, FOVFRM, FOVBS, N, FOVBND )
         CALL CHCKXC ( .TRUE., 'SPICE(BORESIGHTMISSING)',  OK )
 
      CALL TCASE ( 'Check that a an exception is signalled if if '
     .//           'the boresight is not a 3-vector. ' )
 
         KWBORE = 'INS-1000_BORESIGHT'
 
         CALL CLPOOL
         CALL PCPOOL ( KWFRAM,               1, FRAME )
         CALL PCPOOL ( KWSHAP,               1, SHAPE )
         CALL PDPOOL ( KWBORE,               2, BSIGHT)
         CALL PDPOOL ( KWBOUN,              12, BOUNDS)
 
         CALL GETFOV ( INSTID, ROOM, FOVSHP, FOVFRM, FOVBS, N, FOVBND )
         CALL CHCKXC ( .TRUE., 'SPICE(BADBORESIGHTSPEC)',  OK )
 
      CALL TCASE ( 'Check that a an exception is signalled if '
     .//           'the boundary vectors of the field of view '
     .//           'have not been stored in the kernel pool ' )
 
 
         KWBOUN = 'INS-1001_FOV_BOUNDARY'
 
         CALL CLPOOL
         CALL PCPOOL ( KWFRAM,               1, FRAME )
         CALL PCPOOL ( KWSHAP,               1, SHAPE )
         CALL PDPOOL ( KWBORE,               3, BSIGHT)
         CALL PDPOOL ( KWBOUN,              12, BOUNDS)
 
         CALL GETFOV ( INSTID, ROOM, FOVSHP, FOVFRM, FOVBS, N, FOVBND )
         CALL CHCKXC ( .TRUE., 'SPICE(BOUNDARYMISSING)',  OK )
 
      CALL TCASE ( 'Check that a an exception is signalled if '
     .//           'there are too many vectors in the array of '
     .//           'corner vectors. ' )
 
         KWBOUN = 'INS-1000_FOV_BOUNDARY'
         ROOM   =  2
         CALL CLPOOL
         CALL PCPOOL ( KWFRAM,               1, FRAME )
         CALL PCPOOL ( KWSHAP,               1, SHAPE )
         CALL PDPOOL ( KWBORE,               3, BSIGHT)
         CALL PDPOOL ( KWBOUN,              12, BOUNDS)
 
         CALL GETFOV ( INSTID, ROOM, FOVSHP, FOVFRM, FOVBS, N, FOVBND )
         CALL CHCKXC ( .TRUE., 'SPICE(BOUNDARYTOOBIG)',  OK )
 
      CALL TCASE ( 'Check that a an exception is signalled if '
     .//           'the size of the array of boundary numbers is '
     .//           'not a multiple of 3. ' )
 
 
         ROOM   =  4
         CALL CLPOOL
         CALL PCPOOL ( KWFRAM,               1, FRAME )
         CALL PCPOOL ( KWSHAP,               1, SHAPE )
         CALL PDPOOL ( KWBORE,               3, BSIGHT)
         CALL PDPOOL ( KWBOUN,              11, BOUNDS)
 
         CALL GETFOV ( INSTID, ROOM, FOVSHP, FOVFRM, FOVBS, N, FOVBND )
         CALL CHCKXC ( .TRUE., 'SPICE(BADBOUNDARY)',  OK )
 
 
      CALL TCASE ( 'Check that an exception is signalled if the '
     .//           'number of boundary vectors for a circular '
     .//           'field of view is not 1. ' )
 
         SHAPE = 'CIRCLE'
 
         CALL CLPOOL
         CALL PCPOOL ( KWFRAM,               1, FRAME )
         CALL PCPOOL ( KWSHAP,               1, SHAPE )
         CALL PDPOOL ( KWBORE,               3, BSIGHT)
         CALL PDPOOL ( KWBOUN,               9, BOUNDS)
 
         CALL GETFOV ( INSTID, ROOM, FOVSHP, FOVFRM, FOVBS, N, FOVBND )
         CALL CHCKXC ( .TRUE., 'SPICE(BADBOUNDARY)',  OK )
 
      CALL TCASE ( 'Check that an exception is signalled if the '
     .//           'number of boundary vectors for a elliptical '
     .//           'field of view is not 2. ' )
 
         SHAPE = 'ELLIPSE'
 
         CALL CLPOOL
         CALL PCPOOL ( KWFRAM,               1, FRAME )
         CALL PCPOOL ( KWSHAP,               1, SHAPE )
         CALL PDPOOL ( KWBORE,               3, BSIGHT)
         CALL PDPOOL ( KWBOUN,               9, BOUNDS)
 
         CALL GETFOV ( INSTID, ROOM, FOVSHP, FOVFRM, FOVBS, N, FOVBND )
         CALL CHCKXC ( .TRUE., 'SPICE(BADBOUNDARY)',  OK )
 
      CALL TCASE ( 'Check that an exception is signalled if the '
     .//           'number of boundary vectors for a rectangular '
     .//           'field of view is not 4. ' )
 
         SHAPE = 'RECTANGLE'
 
         CALL CLPOOL
         CALL PCPOOL ( KWFRAM,               1, FRAME )
         CALL PCPOOL ( KWSHAP,               1, SHAPE )
         CALL PDPOOL ( KWBORE,               3, BSIGHT)
         CALL PDPOOL ( KWBOUN,               9, BOUNDS)
 
         CALL GETFOV ( INSTID, ROOM, FOVSHP, FOVFRM, FOVBS, N, FOVBND )
         CALL CHCKXC ( .TRUE., 'SPICE(BADBOUNDARY)',  OK )
 
      CALL TCASE ( 'Check that an exception is signalled if the '
     .//           'number of boundary vectors for a polygonal '
     .//           'field of view is not at least 3. ' )
 
         SHAPE = 'POLYGON'
 
         CALL CLPOOL
         CALL PCPOOL ( KWFRAM,               1, FRAME )
         CALL PCPOOL ( KWSHAP,               1, SHAPE )
         CALL PDPOOL ( KWBORE,               3, BSIGHT)
         CALL PDPOOL ( KWBOUN,               6, BOUNDS)
 
         CALL GETFOV ( INSTID, ROOM, FOVSHP, FOVFRM, FOVBS, N, FOVBND )
         CALL CHCKXC ( .TRUE., 'SPICE(BADBOUNDARY)',  OK )
 
 
      CALL TCASE ( 'Check that we can get back a polygonal field '
     .//           'of view. ' )
 
         ROOM  = 15
         SHAPE = 'POLYGON'
 
         CALL CLPOOL
         CALL PCPOOL ( KWFRAM,               1, FRAME )
         CALL PCPOOL ( KWSHAP,               1, SHAPE )
         CALL PDPOOL ( KWBORE,               3, BSIGHT)
         CALL PDPOOL ( KWBOUN,               9, BOUNDS)
 
         CALL GETFOV ( INSTID, ROOM, FOVSHP, FOVFRM, FOVBS, N, FOVBND )
         CALL CHCKXC ( .FALSE., ' ',  OK )
         CALL CHCKSC ( 'SHAPE', FOVSHP, '=', SHAPE, OK )
         CALL CHCKSC ( 'FRAME', FOVFRM, '=', FRAME, OK )
         CALL CHCKSI ( 'N', N, '=', 3, 0, OK )
         CALL CHCKAD ( 'FOVBS',  FOVBS,  '=', BSIGHT, 3, 0.0D0, OK )
         CALL CHCKAD ( 'FOVBND', FOVBND, '=', BOUNDS, 9, 0.0D0, OK )
 
 
      CALL TCASE ( 'Check that we can get back a rectangular '
     .//           'field of view. ' )
 
         SHAPE = 'RECTANGLE'
 
         CALL CLPOOL
         CALL PCPOOL ( KWFRAM,               1, FRAME )
         CALL PCPOOL ( KWSHAP,               1, SHAPE )
         CALL PDPOOL ( KWBORE,               3, BSIGHT)
         CALL PDPOOL ( KWBOUN,              12, BOUNDS)
 
         CALL GETFOV ( INSTID, ROOM, FOVSHP, FOVFRM, FOVBS, N, FOVBND )
         CALL CHCKXC ( .FALSE., ' ',  OK )
         CALL CHCKSC ( 'SHAPE', FOVSHP, '=', SHAPE, OK )
         CALL CHCKSC ( 'FRAME', FOVFRM, '=', FRAME, OK )
         CALL CHCKSI ( 'N', N, '=', 4, 0, OK )
         CALL CHCKAD ( 'FOVBS',  FOVBS,  '=', BSIGHT, 3, 0.0D0, OK )
         CALL CHCKAD ( 'FOVBND', FOVBND, '=', BOUNDS, 12, 0.0D0, OK )
 
 
      CALL TCASE ( 'Check that we can get back a circular field '
     .//           'of view. ' )
 
         SHAPE = 'CIRCLE'
         CALL CLPOOL
         CALL PCPOOL ( KWFRAM,               1, FRAME )
         CALL PCPOOL ( KWSHAP,               1, SHAPE )
         CALL PDPOOL ( KWBORE,               3, BSIGHT)
         CALL PDPOOL ( KWBOUN,               3, BOUNDS)
 
         CALL GETFOV ( INSTID, ROOM, FOVSHP, FOVFRM, FOVBS, N, FOVBND )
         CALL CHCKXC ( .FALSE., ' ',  OK )
         CALL CHCKSC ( 'SHAPE', FOVSHP, '=', SHAPE, OK )
         CALL CHCKSC ( 'FRAME', FOVFRM, '=', FRAME, OK )
         CALL CHCKSI ( 'N', N, '=', 1, 0, OK )
         CALL CHCKAD ( 'FOVBS',  FOVBS,  '=', BSIGHT, 3, 0.0D0, OK )
         CALL CHCKAD ( 'FOVBND', FOVBND, '=', BOUNDS, 3, 0.0D0, OK )
 
 
      CALL TCASE ( 'Check that we can get back a elliptical field '
     .//           'of view. ' )
 
         SHAPE = 'ELLIPSE'
         CALL CLPOOL
         CALL PCPOOL ( KWFRAM,               1, FRAME )
         CALL PCPOOL ( KWSHAP,               1, SHAPE )
         CALL PDPOOL ( KWBORE,               3, BSIGHT)
         CALL PDPOOL ( KWBOUN,               6, BOUNDS)
 
         CALL GETFOV ( INSTID, ROOM, FOVSHP, FOVFRM, FOVBS, N, FOVBND )
         CALL CHCKXC ( .FALSE., ' ',  OK )
         CALL CHCKSC ( 'SHAPE', FOVSHP, '=', SHAPE, OK )
         CALL CHCKSC ( 'FRAME', FOVFRM, '=', FRAME, OK )
         CALL CHCKSI ( 'N', N, '=', 2, 0, OK )
         CALL CHCKAD ( 'FOVBS',  FOVBS,  '=', BSIGHT, 3, 0.0D0, OK )
         CALL CHCKAD ( 'FOVBND', FOVBND, '=', BOUNDS, 6, 0.0D0, OK )
 
 
      CALL T_SUCCESS ( OK )
      RETURN
      END
