C$Procedure      F_LAGRNG ( Lagrange interpolation )
 
      SUBROUTINE F_LAGRNG ( OK )
      IMPLICIT NONE
 
      LOGICAL               OK
 
C$ Abstract
C
C     This routine tests the routine LGRIND.
C     The tests performed check
C
C     1)  That the routines correctly interpolate data sets plucked
C         from known polynomials.
C
C     2)  That both interpolators perform error handling as specified.
C
C$ Version
C
C-    SPICELIB Version 1.0.0, 28-AUG-2002 (NJB)
C
C-&
 
 
C
C     Test Utility Functions
C
 
 
C
C     SPICELIB Functions
C
 
C
C     Local Parameters
C
      INTEGER               MAXDEG
      PARAMETER           ( MAXDEG = 15 )

      DOUBLE PRECISION      TIGHT
      PARAMETER           ( TIGHT  = 1.D-14 )

      DOUBLE PRECISION      MEDIUM
      PARAMETER           ( MEDIUM = 1.D-12 )
      
C
C     Local Variables
C
      DOUBLE PRECISION      P
      DOUBLE PRECISION      DP
      DOUBLE PRECISION      WORK    ( MAXDEG, 2 )
      DOUBLE PRECISION      X
      DOUBLE PRECISION      XVALS   ( MAXDEG )
      DOUBLE PRECISION      YVALS   ( MAXDEG )
      
      INTEGER               I
      INTEGER               N

C
C     Statement function for (a particular) polynomial derivative:
C
      DOUBLE PRECISION      DF
      DF ( X ) = 3.D0*X**2 + 4.D0*X - 4.D0
 
C
C     Begin every test family with an open call.
C
      CALL TOPEN ( 'F_LAGRNG' )
 
 
 
      N         =   4 

      XVALS(1)  =  -1
      XVALS(2)  =   0
      XVALS(3)  =   1
      XVALS(4)  =   3

      YVALS(1)  =  -2
      YVALS(2)  =  -7
      YVALS(3)  =  -8
      YVALS(4)  =  26

C
C        The unique cubic polynomial that fits these points is
C
C                       3       2
C           f(x)   =   x   +  2x  - 4x  - 7
C
C
C        The derivative of f(x) is
C
C             '         2
C           f (x)  =  3x   +  4x  - 4
C

      CALL TCASE ( 'LGRIND normal case #1: f(x) = x**3 + 2*x**2 '//
     .             '-4*x - 7.  Evaluate at input x values.'          )
 
      
      DO I = 1, N

         X = XVALS(I)

         CALL LGRIND ( N, XVALS, YVALS, WORK, X, P, DP )
         CALL CHCKXC ( .FALSE., ' ',  OK )

         CALL CHCKSD ( 'y(xvals(i))',   P,  '~/', YVALS(I), TIGHT, OK )
         CALL CHCKSD ( 'y''(xvals(i))', DP, '~',  DF(X),    TIGHT, OK )

      END DO



      CALL TCASE ( 'LGRIND normal case #2: f(x) = x**3 + 2*x**2 '//
     .             '-4*x - 7.  Evaluate at x = 2.'                   )


      CALL LGRIND ( N, XVALS, YVALS, WORK, 2.D0, P, DP )
      CALL CHCKXC ( .FALSE., ' ',  OK )

C
C        The returned value of P should be 1.D0.
C
C        The returned value of DP should be 1.6D1.
C

      CALL CHCKSD ( 'y(2)',   P,  '~/', 1.0D0, TIGHT, OK )
      CALL CHCKSD ( 'y''(2)', DP, '~',  1.6D1, TIGHT, OK )


      CALL TCASE ( 'LGRIND normal case #3: linear polynomial.'  )
 
 
      N         =   2

      XVALS(1)  =  -1
      XVALS(2)  =   0

      YVALS(1)  =  -2
      YVALS(2)  =  -7

      CALL LGRIND ( N, XVALS, YVALS, WORK, 2.D0, P, DP )
      CALL CHCKXC ( .FALSE., ' ',  OK )

      CALL CHCKSD ( 'y(2)',   P,  '~/', -1.7D1, TIGHT, OK )
      CALL CHCKSD ( 'y''(2)', DP, '~',   -5.D0, TIGHT, OK )


      CALL TCASE ( 'LGRIND normal case #4: constant polynomial.'  )
 
 
      N         =   1

      XVALS(1)  =  -1

      YVALS(1)  =  -2

      CALL LGRIND ( N, XVALS, YVALS, WORK, 2.D0, P, DP )
      CALL CHCKXC ( .FALSE., ' ',  OK )

      CALL CHCKSD ( 'y(2)',   P,  '~/', -2.D0, TIGHT, OK )
      CALL CHCKSD ( 'y''(2)', DP, '~',   0.D0, TIGHT, OK )


C
C     Now for the LGRIND error cases.
C

      CALL TCASE ( 'LGRIND error case:  equal abscissa values.'  )

      XVALS(2)  =      -1.D0

      CALL LGRIND ( 4, XVALS, YVALS, WORK, 3.D0, P, DP )
      CALL CHCKXC ( .TRUE., 'SPICE(DIVIDEBYZERO)',  OK )


      CALL T_SUCCESS ( OK )
      RETURN
      END
