C$Procedure      F_LS ( Test solar longitude routines )

      SUBROUTINE F_LS ( OK )
      IMPLICIT NONE

      LOGICAL               OK

C$ Abstract
C
C     This routine tests the SPICELIB routine
C     
C        LSPCN
C
C$ Version
C
C-    TSPICE Version 1.0.0, 07-JAN-2005 (NJB)
C
C-&
 
C
C     SPICELIB functions
C
      DOUBLE PRECISION      JYEAR
      DOUBLE PRECISION      LSPCN

C
C     Local parameters
C
      CHARACTER*(*)         PCK
      PARAMETER           ( PCK = 'f_ls.tpc' )

      CHARACTER*(*)         SPK
      PARAMETER           ( SPK = 'f_ls.bsp' )


      DOUBLE PRECISION      LOOSE
      PARAMETER           ( LOOSE  = 5.D-3 )


      INTEGER               LNSIZE
      PARAMETER           ( LNSIZE = 80 )

      INTEGER               NCASE
      PARAMETER           ( NCASE  = 100 )

      INTEGER               NCORR
      PARAMETER           ( NCORR  = 3 )

      INTEGER               CORLEN
      PARAMETER           ( CORLEN = 15 )
     
      INTEGER               TIMLEN
      PARAMETER           ( TIMLEN = 40 )

C
C     Local variables
C
      CHARACTER*(CORLEN)    ABCORR ( NCORR )
      CHARACTER*(TIMLEN)    TIMSTR
      CHARACTER*(LNSIZE)    TITLE

      DOUBLE PRECISION      DEC
      DOUBLE PRECISION      ET
      DOUBLE PRECISION      LS
      DOUBLE PRECISION      LT
      DOUBLE PRECISION      RA
      DOUBLE PRECISION      RANGE
      DOUBLE PRECISION      SSTATE ( 6 )

      INTEGER               HANDLE
      INTEGER               I
      INTEGER               J

C
C     Saved variables
C
      SAVE                  ABCORR

C
C     Initial values
C
      DATA                  ABCORR / 'NONE', 'LT', 'LT+S' /


C
C     Begin every test family with an open call.
C
      CALL TOPEN ( 'F_LS' )

C
C --- Case: ------------------------------------------------------
C
      CALL TCASE ( 'Setup:  create and load kernels.' )
C
C     Create, load, and delete a PCK, an SPK and an LSK.
C
      CALL TSTPCK ( PCK, .TRUE., .FALSE. )
      CALL CHCKXC ( .FALSE., ' ', OK )

      CALL TSTSPK ( SPK, .TRUE.,  HANDLE )
      CALL CHCKXC ( .FALSE., ' ', OK )

      CALL TSTLSK 
      CALL CHCKXC ( .FALSE., ' ', OK )

C
C     Test for all aberration corrections.     
C
      DO I = 1, NCORR
C
C        For a variety of times of year, find the RA of
C        the earth-sun vector in the ECLIPJ2000 frame.  
C
         DO J = 1, NCASE

C
C --- Case: ------------------------------------------------------
C
            ET    = (J-1) * JYEAR() / NCASE

            TITLE = 'ET = #; ABCORR = #'

            CALL ETCAL  ( ET, TIMSTR )
            CALL REPMC  ( TITLE, '#', TIMSTR,    TITLE )
            CALL REPMC  ( TITLE, '#', ABCORR(I), TITLE )
            CALL CHCKXC ( .FALSE., ' ', OK )
            CALL TCASE  ( TITLE )

            CALL SPKEZR ( 'SUN',     ET,      'ECLIPJ2000', 
     .                    ABCORR(I), 'EARTH', SSTATE,        LT )
            CALL CHCKXC ( .FALSE., ' ', OK )

            CALL RECRAD ( SSTATE, RANGE, RA, DEC )
            
C
C           Find Ls.
C
            LS = LSPCN  ( 'EARTH', ET, ABCORR(I) )
            CALL CHCKXC ( .FALSE., ' ', OK )

            CALL CHCKSD ( 'LS',  LS, '~', RA, LOOSE, OK )

         END DO


      END DO



C
C --- Case: ------------------------------------------------------
C
      CALL TCASE ( 'Clean up: delete SPK file.' )
C
C     Get rid of the SPK file.  First unload using the routine
C     corresponding to the loader called by TSTSPK.
C
      CALL SPKUEF ( HANDLE )
      CALL CHCKXC ( .FALSE., ' ', OK )
      
      CALL DELFIL ( SPK )

      CALL T_SUCCESS ( OK )
      RETURN
      END
