C$Procedure  F_MOVED ( Family of tests for MOVED )
 
      SUBROUTINE F_MOVED ( OK )
      IMPLICIT NONE
 
      LOGICAL               OK
 
C$ Abstract
C
C     This routine tests MOVED.
C
C
C$ Particulars
C
C     This routine has already been used to detect a bug (NDIM = -1
C     resulted in a segmentation fault for the PC-LINUX and NeXT
C     platforms, on which memmove is used to effect the copy).
C
C     So don't laugh.
C
C$ Version
C
C-     Version 1.2.0, 03-JAN-2005 (BVS)
C
C        Updated for PC-CYGWIN_C.
C
C-     Version 1.1.0, 03-JAN-2005 (BVS)
C
C        Updated for PC-CYGWIN.
C
C-    Version 1.0.1 17-JUL-2002 (BVS)
C
C        Added MAC-OSX environments.
C
C-    Version 1.0.0 12-NOV-2001 (NJB)
C
C-&
 
 
 
C
C     SPICELIB functions
C
      DOUBLE PRECISION      DPMAX
      DOUBLE PRECISION      DPMIN
 
      INTEGER               INTMAX
 
C
C     Local parameters
C
      INTEGER               NITEMS
      PARAMETER           ( NITEMS = 17 )
 
      INTEGER               E1
      PARAMETER           ( E1     = 10 )
 
      INTEGER               E2
      PARAMETER           ( E2     = 20 )
 
      INTEGER               E3
      PARAMETER           ( E3     = 35 )
 
C
C     Local variables
C
      DOUBLE PRECISION      BUFF   ( NITEMS )
      DOUBLE PRECISION      BUFF2  ( NITEMS )
      DOUBLE PRECISION      XBUFF  ( NITEMS )
 
      INTEGER               H
      INTEGER               I
      INTEGER               IC     ( 2 )
      INTEGER               IC2    ( 2 )
      INTEGER               J
      INTEGER               K
      INTEGER               MAXP
      INTEGER               XIC    ( 2 )
 
C
C     EQUIVALENCE statements
C
      EQUIVALENCE           ( BUFF (1), IC  )
      EQUIVALENCE           ( BUFF2(1), IC2 )
 
C
C     Initial values
C
 
 
C
C     Begin every test family with an open call.
C
      CALL TOPEN ( 'F_MOVED' )
 
C
C     Case 1.
C
      CALL TCASE ( 'Test MOVED for a selection of standard d.p. '//
     .             'numbers.' )
 
 
      BUFF(1)   =    1.D0
      BUFF(2)   =   -1.D0
      BUFF(3)   =    0.D0
      BUFF(4)   =    10.D0**( E1)
      BUFF(5)   =    10.D0**(-E1)
      BUFF(6)   = -( 10.D0**( E1) )
      BUFF(7)   = -( 10.D0**(-E1) )
      BUFF(8)   =    10.D0**( E2)
      BUFF(9)   =    10.D0**(-E2)
      BUFF(10)  = -( 10.D0**( E2) )
      BUFF(11)  = -( 10.D0**( E2) )
      BUFF(12)  =    10.D0**( E3)
      BUFF(13)  =    10.D0**(-E3)
      BUFF(14)  = -( 10.D0**( E3) )
      BUFF(15)  = -( 10.D0**(-E3) )
      BUFF(16)  =    DPMAX()
      BUFF(17)  =    DPMIN()
 
      XBUFF(1)  =    1.D0
      XBUFF(2)  =   -1.D0
      XBUFF(3)  =    0.D0
      XBUFF(4)  =    10.D0**( E1)
      XBUFF(5)  =    10.D0**(-E1)
      XBUFF(6)  = -( 10.D0**( E1) )
      XBUFF(7)  = -( 10.D0**(-E1) )
      XBUFF(8)  =    10.D0**( E2)
      XBUFF(9)  =    10.D0**(-E2)
      XBUFF(10) = -( 10.D0**( E2) )
      XBUFF(11) = -( 10.D0**( E2) )
      XBUFF(12) =    10.D0**( E3)
      XBUFF(13) =    10.D0**(-E3)
      XBUFF(14) = -( 10.D0**( E3) )
      XBUFF(15) = -( 10.D0**(-E3) )
      XBUFF(16) =    DPMAX()
      XBUFF(17) =    DPMIN()
 
 
      CALL MOVED  ( BUFF, NITEMS, BUFF2 )
      CALL CHCKXC ( .FALSE., ' ', OK )
 
      CALL CHCKAD ( 'BUFF2', BUFF2, '=', XBUFF, NITEMS, 0.D0, OK )
 
C
C     Case 2.
C
      CALL TCASE ( 'Test MOVED for a case known to be problematic.' )
 
      IC(1)  = -771000
      IC(2)  = -771900
 
      XIC(1) = -771000
      XIC(2) = -771900
 
      CALL MOVED  ( BUFF, 1, BUFF2 )
      CALL CHCKXC ( .FALSE., ' ', OK )
 
      CALL CHCKAI ( 'IC2', IC2, '=', XIC, 2, OK )
 
C
C     Case 3.
C
      CALL TCASE ( 'Test MOVED for a selection of bit patterns ' //
     .             'generated by equivalencing 2-integer arrays '//
     .             'with dp. numbers.'                            )
 
      MAXP = INT (  LOG10( DBLE(INTMAX()) )  )
 
      DO I = -1, MAXP + 1
C
C        Assign the first element of the IC array.
C
         IF ( I .EQ. -1 ) THEN
 
            IC(1) = 0
 
         ELSE IF ( I .EQ. MAXP+1 ) THEN
 
            IC(1) = INTMAX()
 
         ELSE
 
            IC(1) = 10**I
 
         END IF
 
 
         DO J = -1, MAXP + 1
C
C           Assign the second element of the IC array.
C
            IF ( J .EQ. -1 ) THEN
 
               IC(2) = 0
 
            ELSE IF ( J .EQ. MAXP+1 ) THEN
 
               IC(2) = INTMAX()
 
            ELSE
 
               IC(2) = 10**J
 
            END IF
 
C
C           Try every sign combination.
C
            DO K = 1, 2
 
               IC(1) = IC(1) * (-1)**K
 
               DO H = 1, 2
 
                  IC(2) = IC(2) * (-1)**H
C
C                 Test MOVED on the current artificially constructed
C                 d.p. variable.
C
                  CALL MOVEI  ( IC,   2, XIC   )
                  CALL MOVED  ( BUFF, 1, BUFF2 )
 
                  CALL CHCKXC ( .FALSE., ' ', OK )
 
                  CALL CHCKAI ( 'IC2', IC2, '=', XIC, 2, OK )
 
               END DO
 
            END DO
C
C           We're done testing the current pair of integers for each
C           sign combination.
C
         END DO
 
      END DO
 
C
C     Case 4.
C
      CALL TCASE ( 'Test MOVED for NDIM = 0 and -1.'  )
 
      CALL FILLD  ( 1.0D0,    NITEMS, BUFF )
 
      CALL CLEARD ( NITEMS, BUFF2 )
      CALL CLEARD ( NITEMS, XBUFF )
 
      CALL MOVED  ( BUFF,   0,      BUFF2 )
 
      CALL CHCKXC ( .FALSE., ' ', OK )
 
      CALL CHCKAD ( 'BUFF2', BUFF2, '=', XBUFF, NITEMS, 0.D0, OK )
 
      CALL MOVED  ( BUFF,  -1,      BUFF2 )
 
      CALL CHCKXC ( .FALSE., ' ', OK )
 
      CALL CHCKAD ( 'BUFF2', BUFF2, '=', XBUFF, NITEMS, 0.D0, OK )
 
      CALL T_SUCCESS ( OK )
      RETURN
      END
