C$Procedure F_QDERIV ( QDERIV tests )
 
      SUBROUTINE F_QDERIV ( OK )
 
C$ Abstract
C
C     Test family to exercise the SPICELIB routine QDERIV.
C
C$ Copyright
C
C     Copyright (2004), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     None.
C
C$ Keywords
C
C     TEST FAMILY
C
C$ Declarations
 
      IMPLICIT NONE
  
      LOGICAL               OK
 
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     OK         O   logical indicating test status.
C
C$ Detailed_Input
C
C     None.
C
C$ Detailed_Output
C
C     OK         is a logical that indicates the test status to the
C                caller.
C
C$ Parameters
C
C     None.
C
C$ Files
C
C     None.
C
C$ Exceptions
C
C     This routine does not generate any errors. Routines in its
C     call tree may generate errors that are either intentional and
C     trapped or unintentional and need reporting.  The test family
C     utilities manage this.
C
C$ Particulars
C
C     None.
C
C$ Examples
C
C     None.
C
C$ Restrictions
C
C     None.
C
C$ Author_and_Institution
C
C     N.J. Bachman     (JPL)
C
C$ Literature_References
C
C     None.
C
C$ Version
C
C-    TSPICE Version 1.0.0, 24-NOV-2004 (NJB)
C
C
C-&
 
C
C     SPICELIB functions
C
      DOUBLE PRECISION      PI

C
C     Local Parameters
C

C
C     Tolerance levels for various tests.  
C
      DOUBLE PRECISION      DM16  
      PARAMETER           ( DM16   = 1.D-16 )

      DOUBLE PRECISION      DM11  
      PARAMETER           ( DM11   = 1.D-11 )

      DOUBLE PRECISION      DM8
      PARAMETER           ( DM8    = 1.D-8  )


      INTEGER               MAXN
      PARAMETER           ( MAXN = 2 )

C
C     Local Variables
C
      DOUBLE PRECISION      DELTA
      DOUBLE PRECISION      EPSLON
      DOUBLE PRECISION      F0     ( MAXN )
      DOUBLE PRECISION      F2     ( MAXN )
      DOUBLE PRECISION      DFDT   ( MAXN )
      DOUBLE PRECISION      SCALE
      DOUBLE PRECISION      X0
      DOUBLE PRECISION      XD     ( MAXN )

      INTEGER               N
      
C
C     Open the test family.
C
      CALL TOPEN ( 'F_QDERIV' )
 
C
C     Compute machine epsilon and the horizontal scale
C     factor required for determining an appropriate value
C     of DELTA.
C
      EPSLON = 2.0 ** (-53)

      SCALE  = EPSLON ** ( 1.D0 / 3.D0 )

C
C --- Case: ------------------------------------------------------
C
      CALL TCASE ( 'Estimate the derivative of sin(x) at x = 0.'  )


      N     = 1
      DELTA = 1.D-6

      F0(1) = SIN( -DELTA )
      F2(1) = SIN(  DELTA )

      CALL QDERIV ( N, F0, F2, DELTA, DFDT )

      CALL CHCKXC ( .FALSE., ' ', OK )

      XD(1) = 1.D0

      CALL CHCKSD ( 'd(sin(x))/dt at x=0', DFDT(1), '~', 
     .               XD(1),                DM11,    OK   )



C
C --- Case: ------------------------------------------------------
C
      CALL TCASE ( 'Estimate the derivative of sin(x) at x = pi/4.'  )


      N     = 1
      X0    = PI()/4
      DELTA = X0 * SCALE

      F0(1) = SIN( X0 - DELTA )
      F2(1) = SIN( X0 + DELTA )

      CALL QDERIV ( N, F0, F2, DELTA, DFDT )

      CALL CHCKXC ( .FALSE., ' ', OK )

      XD(1) = COS ( X0 )

      CALL CHCKSD ( 'd(sin(x))/dt at x=0', DFDT(1), '~', 
     .               XD(1),                DM11,    OK   )


      CALL TCASE ( 'Estimate the derivative of x2 at x = 2.'  )


      N     = 1
      DELTA = 1.D-3

      F0(1) = ( 2.D0 - DELTA ) ** 2.D0
      F2(1) = ( 2.D0 + DELTA ) ** 2.D0

      CALL QDERIV ( N, F0, F2, DELTA, DFDT )

      CALL CHCKXC ( .FALSE., ' ', OK )

      XD(1) = 4.D0

      CALL CHCKSD ( 'd(x**2)/dt at x=2', DFDT(1), '~', 
     .               XD(1),              DM11,    OK   )




      CALL TCASE ( 'Vector case: combine the previous cases.'  )

      N     = 2
      DELTA = 1.D-6

      F0(1) = SIN( -DELTA )
      F2(1) = SIN(  DELTA )

      F0(2) = ( 2.D0 - DELTA ) ** 2.D0
      F2(2) = ( 2.D0 + DELTA ) ** 2.D0

      CALL QDERIV ( N, F0, F2, DELTA, DFDT )

      CALL CHCKXC ( .FALSE., ' ', OK )

      XD(1) = 1.D0
      XD(2) = 4.D0

      CALL CHCKAD ( 'd(x**2)/dt at x=2', DFDT,    '~', 
     .               XD,                 2,       DM8,    OK        )



      CALL TCASE ( 'DELTA == 0'  )
      
      CALL QDERIV ( N, F0, F2, 0.D0, DFDT )

      CALL CHCKXC ( .TRUE., 'SPICE(DIVIDEBYZERO)', OK )

C
C     Close out the test family.
C
      CALL T_SUCCESS ( OK )
      RETURN 
      END


