
C$Procedure      F_RDPCK ( Text PCK orientation reader tests )

      SUBROUTINE F_RDPCK ( OK )
      IMPLICIT NONE

      LOGICAL               OK

C$ Abstract
C
C     This routine tests the SPICELIB routines
C     
C        BODEUL
C        BODMAT (indirectly, via call to TIPBOD)
C        TIPBOD
C
C     Results of computations done by these routines are compared
C     with results of computations implemented in-line in the 
C     test utility routine T_PCKEQ.  This testing approach attempts
C     to validate orientation computations done using text PCK data
C     by comparing their results to those obtained via an alternate
C     computational approach.  
C
C     These tests also serve to mininize the chance of transcription 
C     error when a new PCK version is created.  Entering the PCK
C     constants both in the new PCK file and in T_PCKEQ enables 
C     double-checking of the constants.
C
C$ Version
C
C-    TSPICE Version 1.0.0, 13-FEB-2004 (NJB)
C
C-&
 
C
C     SPICELIB functions
C
      DOUBLE PRECISION      HALFPI
      DOUBLE PRECISION      B1950
      DOUBLE PRECISION      J2000
      DOUBLE PRECISION      RPD
      DOUBLE PRECISION      SPD
      DOUBLE PRECISION      TWOPI

C
C     Local parameters
C
      DOUBLE PRECISION      TIGHT 
      PARAMETER           ( TIGHT  = 1.D-11 )

      DOUBLE PRECISION      MEDIUM
      PARAMETER           ( MEDIUM = 1.D-10 )

      INTEGER               FILSIZ
      PARAMETER           ( FILSIZ = 255 )

      INTEGER               NBODS
      PARAMETER           ( NBODS  = 75 )

      INTEGER               LNSIZE
      PARAMETER           ( LNSIZE = 80 )

C
C     Local variables
C
      CHARACTER*(LNSIZE)    LINE
      CHARACTER*(FILSIZ)    PCK
      
      DOUBLE PRECISION      B2J    ( 3, 3 )
      DOUBLE PRECISION      DEC
      DOUBLE PRECISION      ET
      DOUBLE PRECISION      LAMBDA
      DOUBLE PRECISION      RA
      DOUBLE PRECISION      TIPM   ( 3, 3 )
      DOUBLE PRECISION      TSIPM  ( 6, 6 )
      DOUBLE PRECISION      W
      DOUBLE PRECISION      XDEC
      DOUBLE PRECISION      XLMBDA
      DOUBLE PRECISION      XRA
      DOUBLE PRECISION      XTIPM  ( 3, 3 )
      DOUBLE PRECISION      XW

      INTEGER               BODLST ( NBODS )
      INTEGER               I
      INTEGER               J
      INTEGER               K
 
      LOGICAL               SKIP   ( NBODS )


C
C     Begin every test family with an open call.
C
      CALL TOPEN ( 'F_RDPCK' )


      CALL TCASE ( 'Setup:  create full text PCK file.' )


      PCK = 'test_0008.tpc'

C
C     Create the PCK file, load it, and delete it.
C      
      CALL T_PCK08 ( PCK, .TRUE., .FALSE. )


      BODLST(  1) = 10
      BODLST(  2) = 199
      BODLST(  3) = 299
      BODLST(  4) = 399
      BODLST(  5) = 301
      BODLST(  6) = 499 
      BODLST(  7) = 401
      BODLST(  8) = 402
      BODLST(  9) = 599
      BODLST( 10) = 501
      BODLST( 11) = 502
      BODLST( 12) = 503
      BODLST( 13) = 504
      BODLST( 14) = 505
      BODLST( 15) = 506
      BODLST( 16) = 507
      BODLST( 17) = 508
      BODLST( 18) = 509
      BODLST( 19) = 510
      BODLST( 20) = 511
      BODLST( 21) = 512
      BODLST( 22) = 513
      BODLST( 23) = 514
      BODLST( 24) = 515
      BODLST( 25) = 516
      BODLST( 26) = 699
      BODLST( 27) = 601
      BODLST( 28) = 602
      BODLST( 29) = 603
      BODLST( 30) = 604
      BODLST( 31) = 605
      BODLST( 32) = 606
      BODLST( 33) = 607
      BODLST( 34) = 608
      BODLST( 35) = 609
      BODLST( 36) = 610
      BODLST( 37) = 611
      BODLST( 38) = 612
      BODLST( 39) = 613
      BODLST( 40) = 614
      BODLST( 41) = 615
      BODLST( 42) = 616
      BODLST( 43) = 617
      BODLST( 44) = 618
      BODLST( 45) = 799
      BODLST( 46) = 701
      BODLST( 47) = 702
      BODLST( 48) = 703
      BODLST( 49) = 704
      BODLST( 50) = 705
      BODLST( 51) = 706
      BODLST( 52) = 707
      BODLST( 53) = 708
      BODLST( 54) = 709
      BODLST( 55) = 710
      BODLST( 56) = 711
      BODLST( 57) = 712
      BODLST( 58) = 713
      BODLST( 59) = 714
      BODLST( 60) = 715
      BODLST( 61) = 899
      BODLST( 62) = 801
      BODLST( 63) = 802
      BODLST( 64) = 803
      BODLST( 65) = 804
      BODLST( 66) = 805
      BODLST( 67) = 806
      BODLST( 68) = 807
      BODLST( 69) = 808
      BODLST( 70) = 999
      BODLST( 71) = 901
      BODLST( 72) = 2431010
      BODLST( 73) = 9511010
      BODLST( 74) = 2000004
      BODLST( 75) = 2000433

      DO I = 1, NBODS
         SKIP(I) = .FALSE.
      END DO

C
C     Certain bodies have no data associated with them.
C

C
C     Bodies 506-513.
C
      SKIP(15) = .TRUE.
      SKIP(16) = .TRUE.
      SKIP(17) = .TRUE.
      SKIP(18) = .TRUE.
      SKIP(19) = .TRUE.
      SKIP(20) = .TRUE.
      SKIP(21) = .TRUE.
      SKIP(22) = .TRUE.

C
C     Body 607.
C     
      SKIP(33)  = .TRUE.
C
C     Body 802.
C
      SKIP(63) = .TRUE.


C
C     Perform BODEUL tests.
C
C     A note concerning the looser tolerance value MEDIUM used
C     in these tests:  converting Euler angles to rotation matrices
C     involves applying the SIN and COS functions to the angles.
C     In the case of the prime meridian angle W, applying trig
C     functions increases the relative error, since W may start
C     out with magnitude much larger than 2*pi.  The error in W
C     is the largest source of error in the matrix TIPM.
C
      DO I = 1, NBODS

         IF ( .NOT. SKIP(I) ) THEN

            ET   = 0.D0
            LINE =  'Check Euler angles for # at ET #.'

            CALL REPMI ( LINE, '#', BODLST(I), LINE )
            CALL REPMD ( LINE, '#', ET,  14,   LINE )
            CALL TCASE ( LINE )

            CALL T_PCKEQ ( BODLST(I), ET,  XRA, XDEC, XW )

            XW = MOD ( XW, TWOPI() )

            IF ( XW .LT. 0 ) THEN
               XW = XW + TWOPI()
            END IF

            CALL BODEUL  ( BODLST(I), ET,  RA,  DEC,  W, LAMBDA )

            CALL CHCKSD ( 'RA',   RA,  '~', XRA,  TIGHT , OK )
            CALL CHCKSD ( 'DEC',  DEC, '~', XDEC, TIGHT , OK )
            CALL CHCKSD ( 'W',    W,   '~', XW,   MEDIUM, OK )

            ET   = -315576000.D0
            LINE =  'Check Euler angles for # at ET #.'

            CALL REPMI ( LINE, '#', BODLST(I), LINE )
            CALL REPMD ( LINE, '#', ET,  14,   LINE )
            CALL TCASE ( LINE )

            CALL T_PCKEQ ( BODLST(I), ET,  XRA, XDEC, XW )

            XW = MOD ( XW, TWOPI() )

            IF ( XW .LT. 0 ) THEN
               XW = XW + TWOPI()
            END IF

            CALL BODEUL  ( BODLST(I), ET,  RA,  DEC,  W, LAMBDA )

            CALL CHCKSD ( 'RA',   RA,  '~', XRA,  TIGHT , OK )
            CALL CHCKSD ( 'DEC',  DEC, '~', XDEC, TIGHT , OK )
            CALL CHCKSD ( 'W',    W,   '~', XW,   MEDIUM, OK )

         END IF

      END DO

C
C     Perform analogous tests on BODMAT.  In order to compare
C     results against those from T_PCKEQ, we represent results
C     from the latter routine as rotation matrices.     
C
      DO I = 1, NBODS

         IF ( .NOT. SKIP(I) ) THEN

            ET   = 0.D0
            LINE =  'Check attitude matrix for # at ET #.'

            CALL REPMI ( LINE, '#', BODLST(I), LINE )
            CALL REPMD ( LINE, '#', ET,  14,   LINE )
            CALL TCASE ( LINE )

            CALL T_PCKEQ ( BODLST(I), ET,  XRA, XDEC, XW )

            CALL EUL2M ( XW, HALFPI()-XDEC, HALFPI()+XRA,
     .                   3,  1,             3,            XTIPM )

            CALL TIPBOD  ( 'J2000', BODLST(I), ET, TIPM )

            CALL CHCKAD ( 'TIPM',  TIPM, '~', XTIPM, 9, MEDIUM, OK )

            ET   = -315576000.D0
            LINE =  'Check attitude matrix for # at ET #.'

            CALL REPMI ( LINE, '#', BODLST(I), LINE )
            CALL REPMD ( LINE, '#', ET,  14,   LINE )
            CALL TCASE ( LINE )

            CALL T_PCKEQ ( BODLST(I), ET,  XRA, XDEC, XW )

            CALL EUL2M ( XW, HALFPI()-XDEC, HALFPI()+XRA,
     .                   3,  1,             3,            XTIPM )

            CALL TIPBOD  ( 'J2000', BODLST(I), ET, TIPM )

            CALL CHCKAD ( 'TIPM',  TIPM, '~', XTIPM, 9, MEDIUM, OK )

         END IF

      END DO


C
C     Perform analogous tests on TISBOD.  In order to compare
C     results against those from T_PCKEQ, we represent results
C     from the latter routine as rotation matrices.     
C
C     We do not examine the derivative portion of the state
C     transformation matrix.
C
      DO I = 1, NBODS

         IF ( .NOT. SKIP(I) ) THEN

            ET   = 0.D0
            LINE =  'Check attitude matrix for # at ET #.'

            CALL REPMI ( LINE, '#', BODLST(I), LINE )
            CALL REPMD ( LINE, '#', ET,  14,   LINE )
            CALL TCASE ( LINE )

            CALL T_PCKEQ ( BODLST(I), ET,  XRA, XDEC, XW )

            CALL EUL2M ( XW, HALFPI()-XDEC, HALFPI()+XRA,
     .                   3,  1,             3,            XTIPM )

            CALL TISBOD  ( 'J2000', BODLST(I), ET, TSIPM )

            DO J = 1, 3
               DO K = 1, 3
                  TIPM(J,K) = TSIPM(J,K)
               END DO
            END DO

            CALL CHCKAD ( 'TIPM',  TIPM, '~', XTIPM, 9, MEDIUM, OK )

            ET   = -315576000.D0
            LINE =  'Check attitude matrix for # at ET #.'

            CALL REPMI ( LINE, '#', BODLST(I), LINE )
            CALL REPMD ( LINE, '#', ET,  14,   LINE )
            CALL TCASE ( LINE )

            CALL T_PCKEQ ( BODLST(I), ET,  XRA, XDEC, XW )

            CALL EUL2M ( XW, HALFPI()-XDEC, HALFPI()+XRA,
     .                   3,  1,             3,            XTIPM )

            CALL TISBOD  ( 'J2000', BODLST(I), ET, TSIPM )

            DO J = 1, 3
               DO K = 1, 3
                  TIPM(J,K) = TSIPM(J,K)
               END DO
            END DO

            CALL CHCKAD ( 'TIPM',  TIPM, '~', XTIPM, 9, MEDIUM, OK )

         END IF

      END DO

C
C     Now check TIPBOD'S ability to deal with non-standard epochs
C     and frames.  Look up data for body -10 at the J1950 epoch
C     in the B1950 frame.  The numbers should match the standard
C     numbers for the sun.
C     
      CALL TCASE ( 'TIPBOD lookup of matrix for body -10' )

      ET  =  ( B1950() - J2000() ) * SPD()

      CALL BODMAT (           10, 0.D0, XTIPM )
      CALL TIPBOD ( 'B1950', -10, ET,   TIPM  )
      CALL CHCKAD ( 'TIPM',  TIPM, '~', XTIPM, 9, MEDIUM, OK )

C
C     Repeat the test for TISBOD.
C
      CALL TCASE ( 'TISBOD lookup of matrix for body -10' )


      CALL TISBOD ( 'B1950', -10, ET, TSIPM  )

      DO J = 1, 3
         DO K = 1, 3
            TIPM(J,K) = TSIPM(J,K)
         END DO
      END DO

      CALL CHCKAD ( 'TIPM',  TIPM, '~', XTIPM, 9, MEDIUM, OK )

C
C     Now check BODMAT's ability to deal with non-standard epochs and
C     frames.  Look up data for body -10 at the B1950 epoch in the
C     B1950 frame.  Since the numbers in the PCK match the standard
C     numbers for the sun, applying the B1950-to-J2000 transformation
C     to the output via right multiplication 
C     should yield the standard matrix for the sun.
     
      CALL TCASE ( 'BODMAT lookup of matrix for body -10' )

      ET  =  ( B1950() - J2000() ) * SPD()

      CALL BODMAT (  10, 0.D0, XTIPM )

      CALL BODMAT ( -10, ET,   TIPM  )

      CALL PXFORM ( 'B1950',  'J2000',  0.D0, B2J )

      CALL MXM ( TIPM, B2J, TIPM ) 

      CALL CHCKAD ( 'TIPM',  TIPM, '~', XTIPM, 9, MEDIUM, OK )

C
C     Now check BODEUL's ability to deal with non-standard epochs and
C     frames.  Look up data for body -10 at the B1950 epoch in the
C     B1950 frame.  Convert the resulting Euler angles to a matrix.
C
C     Since the numbers in the PCK match the standard
C     numbers for the sun, applying the B1950-to-J2000 transformation
C     to the output via right multiplication 
C     should yield the standard matrix for the sun.
C
      CALL TCASE ( 'BODEUL lookup of angles for body -10, epoch B9150' )

      ET  =  ( B1950() - J2000() ) * SPD()

      CALL BODMAT (  10, 0.D0, XTIPM )

      CALL BODEUL  ( -10, ET,  RA,  DEC,  W, LAMBDA )

      CALL EUL2M ( W, HALFPI()-DEC, HALFPI()+RA, 3, 1, 3, TIPM )

      CALL PXFORM ( 'B1950',  'J2000',  0.D0, B2J )

      CALL MXM ( TIPM, B2J, TIPM ) 

      CALL CHCKAD ( 'TIPM',  TIPM, '~', XTIPM, 9, MEDIUM, OK )

C
C     Repeat test for epoch J2000.
C
      CALL TCASE ( 'BODEUL lookup of angles for body -10, epoch J2000' )

      ET  =  ( J2000() - B1950() ) * SPD()

      CALL BODMAT (  10,  ET,  XTIPM )

      CALL BODEUL  ( -10, 0.D0,  RA,  DEC,  W, LAMBDA )

      CALL EUL2M ( W, HALFPI()-DEC, HALFPI()+RA, 3, 1, 3, TIPM )

      CALL PXFORM ( 'B1950',  'J2000',  0.D0, B2J )

      CALL MXM ( TIPM, B2J, TIPM ) 

      CALL CHCKAD ( 'TIPM',  TIPM, '~', XTIPM, 9, MEDIUM, OK )

C
C     Check the LAMBDA value associated with body -10.  We 
C     expect the value to be 99 degrees *RPD().  (The value 
C     459 degrees is set by T_PCK08, which writes the PCK file 
C     we're using.  We expect BODEUL to mod this value by 2*pi.)
C
      XLMBDA = 99.D0 * RPD()
      CALL CHCKSD ( 'LAMBDA',  LAMBDA, '~', XLMBDA, MEDIUM, OK )
      

      CALL T_SUCCESS ( OK )
      RETURN
      END
