C$Procedure      F_SPK10 ( Family of tests for types 10 )
 
      SUBROUTINE F_SPK10 ( OK )
      IMPLICIT NONE
 
      LOGICAL               OK
 
C$ Abstract
C
C     This routine performs tests on SPK type 10 to make sure that
C     the correct routines are called and that subsetting occurs
C     correctly.
C
C$ Version
C
C-    SPICELIB Version 1.1.0, 20-OCT-1999 (WLT)
C
C        Declared PI to be an EXTERNAL Functions.
C
C-&
 
 
C
C     SPICELIB Functions
C
      EXTERNAL              PI
      DOUBLE PRECISION      PI
      DOUBLE PRECISION      SPD
 
C
C     Local Variables
C
      INTEGER               LNSIZE
      PARAMETER           ( LNSIZE = 80 )
 
      INTEGER               IDSIZE
      PARAMETER           ( IDSIZE = 40 )
 
 
 
      CHARACTER*(LNSIZE)    LOW2LN ( 20 )
      CHARACTER*(LNSIZE)    HI2LN  (  2 )
      CHARACTER*(IDSIZE)    IDENT
 
      DOUBLE PRECISION      BEGIN
      DOUBLE PRECISION      CONSTS ( 8 )
      DOUBLE PRECISION      DESCR  ( 6 )
      DOUBLE PRECISION      ELEMS  ( 100 )
      DOUBLE PRECISION      END
      DOUBLE PRECISION      EPOCH  ( 10  )
      DOUBLE PRECISION      ET
      DOUBLE PRECISION      EXPST  ( 6 )
      DOUBLE PRECISION      FIRST
      DOUBLE PRECISION      LAST
      DOUBLE PRECISION      LT
      DOUBLE PRECISION      M      ( 3, 3 )
      DOUBLE PRECISION      DNUT   ( 4 )
      DOUBLE PRECISION      MOB
      DOUBLE PRECISION      DMOB
      DOUBLE PRECISION      NULON
      DOUBLE PRECISION      NUOBL
      DOUBLE PRECISION      NULON1
      DOUBLE PRECISION      NULON2
      DOUBLE PRECISION      NUOBL1
      DOUBLE PRECISION      NUOBL2
      DOUBLE PRECISION      RECORD ( 50 )
      DOUBLE PRECISION      PART1  (  6 )
      DOUBLE PRECISION      PART2  (  6 )
      DOUBLE PRECISION      VEL    (  3 )
      DOUBLE PRECISION      STATE  (  6 )
 
      DOUBLE PRECISION      NUMER
      DOUBLE PRECISION      DENOM
      DOUBLE PRECISION      ARG
      DOUBLE PRECISION      DARGDT
      DOUBLE PRECISION      W
      DOUBLE PRECISION      DWDT
 
      INTEGER               BODY
      INTEGER               CENTER
      INTEGER               FRAME
      INTEGER               HANDLE
      INTEGER               I
      INTEGER               ID
      INTEGER               SPK1
      INTEGER               SPK2
      INTEGER               SPK3
      INTEGER               TYPE
 
      LOGICAL               FOUND
 
C
C     Begin every test family with an open call.
C
      CALL TOPEN ( 'F_SPK10' )
 
 
      CALL TCASE ( 'Preliminaries --- load a leapseconds kernel ' )
 
         CALL TSTLSK
         CALL CHCKXC ( .FALSE., ' ',  OK )
 
      CALL TCASE ( 'Make sure we can create an SPK type 10 '
     .//           'segment from a single set of two-line '
     .//           'elements. ' )
 
         CALL KILFIL ( 'type10.bsp' )
C
C        We'll use the two-line elments for Topex that are
C        given in the header to GETELM.
C
 
         LOW2LN(  1 ) = '1 22076U 92052A   97173.53461370 -.0'
     .   //             '0000038  00000-0  10000-3 0   594'
         LOW2LN(  2 ) = '2 22076  66.0378 163.4372 0008359 27'
     .   //             '8.7732  81.2337 12.80930736227550'
 
C
C        Set the geophysical constants used by SPACE COMMAND in
C        the distributed code.
C
         CONSTS( 1 ) =    1.082616D-3
         CONSTS( 2 ) =   -2.53881D-6
         CONSTS( 3 ) =   -1.65597D-6
         CONSTS( 4 ) =    7.43669161D-2
         CONSTS( 5 ) =  120.0D0
         CONSTS( 6 ) =   78.0D0
         CONSTS( 7 ) = 6378.135D0
         CONSTS( 8 ) =    1.0D0
 
         CALL GETELM ( 1950, LOW2LN, EPOCH, ELEMS )
 
         FIRST = EPOCH(1) - 100.0D0*SPD()
         LAST  = EPOCH(1) + 100.0D0*SPD()
 
         ID    = -122076
 
 
         CALL SPKOPN ( 'type10.bsp', 'TEST_FILE', 1000, HANDLE )
 
         CALL SPKW10 (  HANDLE, ID,   399,   'J2000', FIRST, LAST,
     .                 'Test TOPEX',  CONSTS, 1,      ELEMS, EPOCH )
         CALL SPKCLS (  HANDLE )
 
         CALL CHCKXC ( .FALSE., ' ',  OK )
 
 
      CALL TCASE ( 'Make sure we can read read out of the file '
     .//           'the data we just inserted. ' )
 
         ET = EPOCH(1)
 
         CALL SPKLEF ( 'type10.bsp', SPK1 )
         CALL SPKSFS ( ID, ET, HANDLE, DESCR, IDENT, FOUND )
 
         CALL CHCKXC ( .FALSE., ' ',            OK )
         CALL CHCKSL ( 'FOUND', FOUND, .TRUE.,  OK )
C
C        Unpack the descriptor and make sure it has the correct
C        data in it.
C
         CALL  SPKUDS ( DESCR,
     .                  BODY,  CENTER, FRAME, TYPE,
     .                  FIRST, LAST,   BEGIN, END   )
 
         CALL SPKR10 ( HANDLE, DESCR, ET, RECORD )
 
         CALL CHCKXC ( .FALSE., ' ',  OK )
 
         CALL CHCKAD ( 'CONSTS', CONSTS, '=', RECORD,      8, 0.0D0, OK)
         CALL CHCKAD ( 'ELEM1',  ELEMS,  '=', RECORD(9),  10, 0.0D0, OK)
         CALL CHCKAD ( 'ELEM2',  ELEMS,  '=', RECORD(23), 10, 0.0D0, OK)
 
      CALL TCASE ( 'Make sure the record is evaluated using the '
     .//           'routine EV2LIN. ' )
 
         CALL EV2LIN ( ET, CONSTS, ELEMS,  EXPST )
         CALL ZZWAHR ( ELEMS(10),  DNUT )
 
         NULON = DNUT(1) + (ET-ELEMS(10))*DNUT(3)
         NUOBL = DNUT(2) + (ET-ELEMS(10))*DNUT(4)
 
         CALL ZZMOBLIQ ( ET, MOB, DMOB )
 
         CALL EUL2M (   -MOB-NUOBL, -NULON, MOB, 1, 3, 1, M )
         CALL MTXV  ( M, EXPST(1),   EXPST(1) )
         CALL MTXV  ( M, EXPST(4),   EXPST(4) )
 
         CALL ZZEPRCSS ( ET, M )
         CALL MTXV     ( M,  EXPST(1), EXPST(1) )
         CALL MTXV     ( M,  EXPST(4), EXPST(4) )
 
         CALL SPKE10 ( ET, RECORD,         STATE )
 
         CALL CHCKXC ( .FALSE., ' ',  OK )
         CALL CHCKAD ( 'STATE', STATE, '=', EXPST, 6, 0.0D0, OK )
 
      CALL TCASE ( 'Make sure that SPKEZ agrees with the '
     .//           'previous computation. ' )
 
         CALL SPKEZ ( ID, ET, 'J2000', 'NONE', 399, STATE, LT )
         CALL CHCKXC ( .FALSE., ' ',  OK )
         CALL CHCKAD ( 'STATE', STATE, '=', EXPST, 6, 0.0D0, OK )
 
 
      CALL TCASE ( 'Construct a longer file and make sure that '
     .//           'we get the correct states from SPKEZ. ' )
 
         CALL KILFIL ( 'type10_2.bsp' )
 
         LOW2LN(  1 ) = '1 18123U 87 53  A 87324.61041692 -.0'
     .   //             '0000023  00000-0 -75103-5 0 00675'
         LOW2LN(  2 ) = '2 18123  98.8296 152.0074 0014950 16'
     .   //             '8.7820 191.3688 14.12912554 21686'
         LOW2LN(  3 ) = '1 18123U 87 53  A 87326.73487726  .0'
     .   //             '0000045  00000-0  28709-4 0 00684'
         LOW2LN(  4 ) = '2 18123  98.8335 154.1103 0015643 16'
     .   //             '3.5445 196.6235 14.12912902 21988'
         LOW2LN(  5 ) = '1 18123U 87 53  A 87331.40868801  .0'
     .   //             '0000104  00000-0  60183-4 0 00690'
         LOW2LN(  6 ) = '2 18123  98.8311 158.7160 0015481 14'
     .   //             '9.9848 210.2220 14.12914624 22644'
         LOW2LN(  7 ) = '1 18123U 87 53  A 87334.24129978  .0'
     .   //             '0000086  00000-0  51111-4 0 00702'
         LOW2LN(  8 ) = '2 18123  98.8296 161.5054 0015372 14'
     .   //             '2.4159 217.8089 14.12914879 23045'
         LOW2LN(  9 ) = '1 18123U 87 53  A 87336.93227900 -.0'
     .   //             '0000107  00000-0 -52860-4 0 00713'
         LOW2LN( 10 ) = '2 18123  98.8317 164.1627 0014570 13'
     .   //             '5.9191 224.2321 14.12910572 23425'
         LOW2LN( 11 ) = '1 18123U 87 53  A 87337.28635487  .0'
     .   //             '0000173  00000-0  10226-3 0 00726'
         LOW2LN( 12 ) = '2 18123  98.8284 164.5113 0015289 13'
     .   //             '3.5979 226.6438 14.12916140 23475'
         LOW2LN( 13 ) = '1 18123U 87 53  A 87339.05673569  .0'
     .   //             '0000079  00000-0  47069-4 0 00738'
         LOW2LN( 14 ) = '2 18123  98.8288 166.2585 0015281 12'
     .   //             '7.9985 232.2567 14.12916010 24908'
         LOW2LN( 15 ) = '1 18123U 87 53  A 87345.43010859  .0'
     .   //             '0000022  00000-0  16481-4 0 00758'
         LOW2LN( 16 ) = '2 18123  98.8241 172.5226 0015362 10'
     .   //             '9.1515 251.1323 14.12915487 24626'
         LOW2LN( 17 ) = '1 18123U 87 53  A 87349.04167543  .0'
     .   //             '0000042  00000-0  27370-4 0 00764'
         LOW2LN( 18 ) = '2 18123  98.8301 176.1010 0015565 10'
     .   //             '0.0881 260.2047 14.12916361 25138'
 
 
         DO I = 0, 8
            CALL GETELM(1950, LOW2LN(I*2+1), EPOCH(I+1), ELEMS(I*10+1) )
         END DO
 
         FIRST = EPOCH(1) - 0.5D0*SPD()
         LAST  = EPOCH(9) + 0.5D0*SPD()
 
         ID    = -118123
 
 
         CALL SPKOPN ( 'type10_2.bsp', 'TEST_FILE', 1000, HANDLE )
 
         CALL SPKW10 (  HANDLE, ID,   399,   'J2000', FIRST, LAST,
     .                 'DMSP F8',     CONSTS, 9,      ELEMS, EPOCH )
         CALL SPKCLS (  HANDLE )
 
         CALL CHCKXC ( .FALSE., ' ',  OK )
 
 
         ET = 0.6D0 * EPOCH(5) + 0.4D0 * EPOCH(6)
 
         CALL SPKLEF ( 'type10_2.bsp', SPK2 )
 
         CALL EV2LIN ( ET, CONSTS, ELEMS(41), PART1 )
         CALL EV2LIN ( ET, CONSTS, ELEMS(51), PART2 )
 
         CALL ZZWAHR ( EPOCH(5),  DNUT )
 
         NULON1 = DNUT(1) + (ET-EPOCH(5))*DNUT(3)
         NUOBL1 = DNUT(2) + (ET-EPOCH(5))*DNUT(4)
 
         CALL ZZWAHR ( EPOCH(6),  DNUT )
 
         NULON2 = DNUT(1) + (ET-EPOCH(6))*DNUT(3)
         NUOBL2 = DNUT(2) + (ET-EPOCH(6))*DNUT(4)
 
         CALL ZZMOBLIQ ( ET, MOB, DMOB )
 
 
 
         NUMER  = ET       - EPOCH(5)
         DENOM  = EPOCH(6) - EPOCH(5)
         ARG    = NUMER*PI()/DENOM
         DARGDT =       PI()/DENOM
 
         W      =  0.5D0 + 0.5D0 * DCOS( ARG )
         DWDT   =        - 0.5D0 * DSIN( ARG ) * DARGDT
 
         NUOBL  = W*NUOBL1 + (1.0D0-W)*NUOBL2
         NULON  = W*NULON1 + (1.0D0-W)*NULON2
 
         CALL EUL2M (   -MOB-NUOBL, -NULON, MOB, 1, 3, 1, M )
 
         CALL MTXV  ( M, PART1(1), PART1(1) )
         CALL MTXV  ( M, PART1(4), PART1(4) )
 
         CALL MTXV  ( M, PART2(1), PART2(1) )
         CALL MTXV  ( M, PART2(4), PART2(4) )
 
         CALL VLCOMG ( 6, W,  PART1, 1.0D0-W, PART2, EXPST    )
         CALL VLCOM  ( DWDT,  PART1, -DWDT,   PART2, VEL      )
         CALL VADD   ( VEL,   EXPST(4),              EXPST(4) )
 
         CALL ZZEPRCSS ( ET, M )
         CALL MTXV     ( M,  EXPST(1), EXPST(1) )
         CALL MTXV     ( M,  EXPST(4), EXPST(4) )
 
 
 
         CALL SPKEZ  ( ID, ET, 'J2000', 'NONE', 399, STATE, LT )
         CALL CHCKXC ( .FALSE., ' ',  OK )
         CALL CHCKAD ( 'STATE', STATE, '=', EXPST, 6, 0.0D0, OK )
 
      CALL TCASE ( 'Using the previous file, make sure we get '
     .//           'the correct state at one second after the '
     .//           'beginning of the segment.' )
 
 
         ET = FIRST + 1.0D0
         CALL EV2LIN ( ET, CONSTS, ELEMS(1), EXPST )
 
         CALL ZZWAHR ( ELEMS(10),  DNUT )
 
         NULON = DNUT(1) + (ET-ELEMS(10))*DNUT(3)
         NUOBL = DNUT(2) + (ET-ELEMS(10))*DNUT(4)
 
         CALL ZZMOBLIQ ( ET, MOB, DMOB )
 
         CALL EUL2M (   -MOB-NUOBL, -NULON, MOB, 1, 3, 1, M )
         CALL MTXV  ( M, EXPST(1),   EXPST(1) )
         CALL MTXV  ( M, EXPST(4),   EXPST(4) )
 
         CALL ZZEPRCSS ( ET, M )
         CALL MTXV     ( M,  EXPST(1), EXPST(1) )
         CALL MTXV     ( M,  EXPST(4), EXPST(4) )
 
 
         CALL SPKEZ  ( ID, ET, 'J2000', 'NONE', 399, STATE, LT )
         CALL CHCKXC ( .FALSE., ' ',  OK )
         CALL CHCKAD ( 'STATE', STATE, '=', EXPST, 6, 0.0D0, OK )
 
      CALL TCASE ( 'Using the same file make sure we get the '
     .//           'correct state at one second before the end '
     .//           'of the segment. ' )
 
 
         ET = LAST - 1.0D0
         CALL EV2LIN ( ET, CONSTS, ELEMS(81), EXPST )
 
         CALL ZZWAHR ( ELEMS(90),  DNUT )
 
         NULON = DNUT(1) + (ET-ELEMS(90))*DNUT(3)
         NUOBL = DNUT(2) + (ET-ELEMS(90))*DNUT(4)
 
         CALL ZZMOBLIQ ( ET, MOB, DMOB )
 
         CALL EUL2M (   -MOB-NUOBL, -NULON, MOB, 1, 3, 1, M )
         CALL MTXV  ( M, EXPST(1),   EXPST(1) )
         CALL MTXV  ( M, EXPST(4),   EXPST(4) )
 
         CALL ZZEPRCSS ( ET, M )
         CALL MTXV     ( M,  EXPST(1), EXPST(1) )
         CALL MTXV     ( M,  EXPST(4), EXPST(4) )
 
         CALL SPKEZ  ( ID, ET, 'J2000', 'NONE', 399, STATE, LT )
         CALL CHCKXC ( .FALSE., ' ',  OK )
         CALL CHCKAD ( 'STATE', STATE, '=', EXPST, 6, 0.0D0, OK )
 
      CALL TCASE ( 'Make sure we can perform the same '
     .//           'experiments using a deep space satellite. ' )
 
 
         CALL KILFIL ( 'type10_3.bsp' )
 
         HI2LN(  1 ) = '1 24846U 97031A   97179.08162378 -.0'
     .   //             '0000182  00000-0  00000+0 0   129'
         HI2LN(  2 ) = '2 24846   4.5222  86.7012 6052628 17'
     .   //             '8.7924 183.5048  2.04105068    52'
 
         CALL GETELM ( 1950, HI2LN, EPOCH, ELEMS )
 
         FIRST = EPOCH(1) - 10.0D0*SPD()
         LAST  = EPOCH(1) + 10.0D0*SPD()
 
         ID    = -124846
 
 
         CALL SPKOPN ( 'type10_3.bsp', 'TEST_FILE', 1000, HANDLE )
 
         CALL SPKW10 (  HANDLE, ID,     399,   'J2000', FIRST, LAST,
     .                 'Test INTELSAT', CONSTS, 1,      ELEMS, EPOCH )
         CALL SPKCLS (  HANDLE )
 
         CALL CHCKXC ( .FALSE., ' ',  OK )
 
         ET = EPOCH(1)
         CALL DPSPCE ( ET, CONSTS, ELEMS(1), STATE )
         CALL DPSPCE ( ET, CONSTS, ELEMS(1), EXPST )
         CALL CHCKXC ( .FALSE., ' ',  OK )
         CALL CHCKAD ( 'EXPST', STATE, '=', EXPST, 6, 0.0D0, OK )
 
         CALL ZZWAHR ( ELEMS(10),  DNUT )
 
         NULON = DNUT(1) + (ET-ELEMS(10))*DNUT(3)
         NUOBL = DNUT(2) + (ET-ELEMS(10))*DNUT(4)
 
         CALL ZZMOBLIQ ( ET, MOB, DMOB )
 
         CALL EUL2M (   -MOB-NUOBL, -NULON, MOB, 1, 3, 1, M )
         CALL MTXV  ( M, EXPST(1),   EXPST(1) )
         CALL MTXV  ( M, EXPST(4),   EXPST(4) )
 
         CALL ZZEPRCSS ( ET, M )
         CALL MTXV     ( M,  EXPST(1), EXPST(1) )
         CALL MTXV     ( M,  EXPST(4), EXPST(4) )
 
         CALL SPKLEF ( 'type10_3.bsp', SPK3 )
         CALL SPKEZ  ( ID, ET, 'J2000', 'NONE', 399, STATE, LT )
         CALL CHCKXC ( .FALSE., ' ',  OK )
         CALL CHCKAD ( 'STATE', STATE, '=', EXPST, 6, 0.0D0, OK )
 
 
      CALL SPKUEF ( SPK1 )
      CALL SPKUEF ( SPK2 )
      CALL SPKUEF ( SPK3 )
      CALL KILFIL ( 'type10.bsp'   )
      CALL KILFIL ( 'type10_2.bsp' )
      CALL KILFIL ( 'type10_3.bsp' )
 
 
      CALL T_SUCCESS ( OK )
      RETURN
      END
