C$Procedure      F_SPKEZ ( Family of tests for SPKEZ)
 
      SUBROUTINE F_SPKEZ ( OK )
      IMPLICIT NONE
 
      LOGICAL               OK
 
C$ Abstract
C
C     This routine performs a series of tests on the routine
C     SPKEZ to make sure that it behaves as expected.
C
C$ Version
C
C     TSPICE Version 2.0.0 06-DEC-2001 (NJB)
C-&
 
 
C
C     Test Utility Functions
C
 
 
C
C     SPICELIB Functions
C
 
C
C     Local Variables
C
      INTEGER               LNSIZE
      PARAMETER           ( LNSIZE = 80 )
 
      CHARACTER*(LNSIZE)    ERROR
 
      INTEGER               HANDLE
 
      DOUBLE PRECISION      ET
 
      DOUBLE PRECISION      STATE  ( 6 )
      DOUBLE PRECISION      ELT
      DOUBLE PRECISION      LT
      DOUBLE PRECISION      ESTATE ( 6 )
      DOUBLE PRECISION      TSTATE ( 6 )
      DOUBLE PRECISION      SOBS   ( 6 )
      DOUBLE PRECISION      XFORM  ( 6, 6 )
      DOUBLE PRECISION      CLT
      DOUBLE PRECISION      ISTATE ( 6 )
 
 
 
 
C
C     Begin every test family with an open call.
C
      CALL TOPEN ( 'F_SPKEZ' )
 
      CALL KILFIL ( 'phoenix2.bsp' )
      CALL KILFIL ( 'phoenix2.ker' )
 
      CALL TSTSPK ( 'phoenix2.bsp', .TRUE.,  HANDLE )
 
      CALL TSTPCK ( 'phoenix2.ker', .TRUE., .FALSE. )
      CALL TPARSE ( '1 JAN 1995',   ET,     ERROR )
 
      CALL TCASE ( 'Make sure that SPKEZ and SPKGEO return the '
     .//           'same information when the correction '
     .//           'requested is NONE. ' )
 
      CALL SPKEZ ( 401001, ET, 'IAU_EARTH', 'NONE', 301001,
     .             STATE,  LT )
      CALL CHCKXC ( .FALSE., ' ', OK )
 
      CALL SPKGEO( 401001, ET, 'IAU_EARTH', 301001, ESTATE, ELT )

      CALL CHCKXC ( .FALSE., ' ', OK )
      CALL CHCKAD ( 'STATE', STATE, '=', ESTATE, 6, 0.0D0, OK )
      CALL CHCKSD ( 'LT',    LT,    '=', ELT,       0.0D0, OK )
 
 


      CALL TCASE ( 'Make sure that SPKEZ returns the same thing '
     .//           'as the combination of SPKSSB and SPKAPP when '
     .//           'an inertial frame is the requested output '
     .//           'frame. Light time only correction.' )
 
      CALL SPKEZ ( 301001, ET, 'J2000', 'LT', 399001,
     .             STATE,  LT )
      CALL CHCKXC ( .FALSE., ' ', OK )
 
      CALL SPKSSB( 399001, ET, 'J2000',  SOBS )
      CALL CHCKXC ( .FALSE., ' ', OK )

      CALL SPKAPP( 301001, ET, 'J2000',  SOBS, 'LT', ESTATE, ELT )
      CALL CHCKXC ( .FALSE., ' ', OK )

      CALL CHCKAD ( 'STATE', STATE, '=', ESTATE, 6, 0.0D0, OK )
      CALL CHCKSD ( 'LT',    LT,    '=', ELT,       0.0D0, OK )



      CALL TCASE ( 'Repeat the previous test for the transmission ' //
     .             'case.'                                          )

      CALL SPKEZ ( 301001, ET, 'J2000', 'XLT', 399001,
     .             STATE,  LT )
      CALL CHCKXC ( .FALSE., ' ', OK )
 
      CALL SPKSSB( 399001, ET, 'J2000',  SOBS )
      CALL CHCKXC ( .FALSE., ' ', OK )

      CALL SPKAPP( 301001, ET, 'J2000',  SOBS, 'XLT', ESTATE, ELT )
      CALL CHCKXC ( .FALSE., ' ', OK )
      CALL CHCKAD ( 'STATE', STATE, '=', ESTATE, 6, 0.0D0, OK )
      CALL CHCKSD ( 'LT',    LT,    '=', ELT,       0.0D0, OK )


 
      CALL TCASE ( 'Make sure that SPKEZ returns the same thing '
     .//           'as the combination of SPKSSB and SPKAPP when '
     .//           'an inertial frame is the requested output '
     .//           'frame. Converged Newtonian plus stellar aberation' )
 
      CALL SPKEZ ( 301001, ET, 'J2000', 'CN+S', 399001,
     .             STATE,  LT )
      CALL CHCKXC ( .FALSE., ' ', OK )
 
      CALL SPKSSB( 399001, ET, 'J2000',  SOBS )
      CALL CHCKXC ( .FALSE., ' ', OK )

      CALL SPKAPP( 301001, ET, 'J2000',  SOBS, 'CN+S', ESTATE, ELT )
      CALL CHCKXC ( .FALSE., ' ', OK )
      CALL CHCKAD ( 'STATE', STATE, '=', ESTATE, 6, 0.0D0, OK )
      CALL CHCKSD ( 'LT',    LT,    '=', ELT,       0.0D0, OK )



      CALL TCASE ( 'Repeat the previous test for the transmission ' //
     .             'case.'                                          )

      CALL SPKEZ ( 301001, ET, 'J2000', 'XCN+S', 399001,
     .             STATE,  LT )
      CALL CHCKXC ( .FALSE., ' ', OK )
 
      CALL SPKSSB( 399001, ET, 'J2000',  SOBS )
      CALL CHCKXC ( .FALSE., ' ', OK )

      CALL SPKAPP( 301001, ET, 'J2000',  SOBS, 'XCN+S', ESTATE, ELT )

      CALL CHCKXC ( .FALSE., ' ', OK )
      CALL CHCKAD ( 'STATE', STATE, '=', ESTATE, 6, 0.0D0, OK )
      CALL CHCKSD ( 'LT',    LT,    '=', ELT,       0.0D0, OK )


 
      CALL TCASE ( 'Perform an independent test to see if '
     .//           '"apparent" positions in non-inertial frames '
     .//           'are properly computed. Frame center is not '
     .//           'target or observer.'                         )
 
 
      CALL SPKEZ ( 401001, ET, 'IAU_EARTH', 'CN+S', 301001,
     .             STATE,  LT )
      CALL CHCKXC ( .FALSE., ' ', OK )
 
      CALL SPKSSB( 301001, ET, 'J2000',  SOBS )
      CALL CHCKXC ( .FALSE., ' ', OK )

      CALL SPKAPP( 401001, ET, 'J2000',  SOBS, 'CN+S', ISTATE, ELT )
      CALL CHCKXC ( .FALSE., ' ', OK )

      CALL SPKAPP( 399,    ET, 'J2000',  SOBS, 'CN+S', TSTATE, CLT )
      CALL CHCKXC ( .FALSE., ' ', OK )

      CALL SXFORM( 'J2000', 'IAU_EARTH', ET-CLT,       XFORM       )
      CALL CHCKXC ( .FALSE., ' ', OK )


      CALL MXVG  ( XFORM, ISTATE, 6, 6, ESTATE )

      CALL CHCKXC ( .FALSE., ' ', OK )
      CALL CHCKAD ( 'STATE', STATE, '~/', ESTATE, 6, 1.0D-14, OK )
      CALL CHCKSD ( 'LT',    LT,    '~/', ELT,       1.0D-14, OK )


      CALL TCASE ( 'Repeat the previous test for the transmission ' //
     .             'case.'                                          )
 
      CALL SPKEZ ( 401001, ET, 'IAU_EARTH', 'XCN+S', 301001,
     .             STATE,  LT )
      CALL CHCKXC ( .FALSE., ' ', OK )
 
      CALL SPKSSB( 301001, ET, 'J2000',  SOBS )
      CALL CHCKXC ( .FALSE., ' ', OK )

      CALL SPKAPP( 401001, ET, 'J2000',  SOBS, 'XCN+S', ISTATE, ELT )
      CALL CHCKXC ( .FALSE., ' ', OK )

      CALL SPKAPP( 399,    ET, 'J2000',  SOBS, 'XCN+S', TSTATE, CLT )
      CALL CHCKXC ( .FALSE., ' ', OK )

      CALL SXFORM( 'J2000', 'IAU_EARTH', ET+CLT,        XFORM       )
      CALL CHCKXC ( .FALSE., ' ', OK )


      CALL MXVG  ( XFORM, ISTATE, 6, 6, ESTATE )

      CALL CHCKXC ( .FALSE., ' ', OK )
      CALL CHCKAD ( 'STATE', STATE, '~/', ESTATE, 6, 1.0D-14, OK )
      CALL CHCKSD ( 'LT',    LT,    '~/', ELT,       1.0D-14, OK )




      CALL TCASE ( 'Perform an independent test to see if '
     .//           '"apparent" positions in non-inertial frames '
     .//           'are properly computed. Frame center is '
     .//           'target.'                                    )
 
 
      CALL SPKEZ ( 399, ET, 'IAU_EARTH', 'CN+S', 301001, STATE,  LT )
      CALL CHCKXC ( .FALSE., ' ', OK )
 
      CALL SPKSSB( 301001, ET, 'J2000',  SOBS )
      CALL CHCKXC ( .FALSE., ' ', OK )

      CALL SPKAPP( 399,    ET, 'J2000',  SOBS, 'CN+S', ISTATE, ELT )
      CALL CHCKXC ( .FALSE., ' ', OK )

      CALL SXFORM( 'J2000', 'IAU_EARTH', ET-ELT,       XFORM       )
      CALL CHCKXC ( .FALSE., ' ', OK )


      CALL MXVG  ( XFORM, ISTATE, 6, 6, ESTATE )

      CALL CHCKXC ( .FALSE., ' ', OK )
      CALL CHCKAD ( 'STATE', STATE, '~/', ESTATE, 6, 1.0D-14, OK )
      CALL CHCKSD ( 'LT',    LT,    '~/', ELT,       1.0D-14, OK )


      CALL TCASE ( 'Repeat the previous test for the transmission ' //
     .             'case.'                                          )
 
      CALL SPKEZ ( 399, ET, 'IAU_EARTH', 'XCN+S', 301001, STATE, LT )
      CALL CHCKXC ( .FALSE., ' ', OK )
 
      CALL SPKSSB( 301001, ET, 'J2000',  SOBS )
      CALL CHCKXC ( .FALSE., ' ', OK )

      CALL SPKAPP( 399,    ET, 'J2000',  SOBS, 'XCN+S', ISTATE, ELT )
      CALL CHCKXC ( .FALSE., ' ', OK )

      CALL SXFORM( 'J2000', 'IAU_EARTH', ET+ELT,        XFORM       )
      CALL CHCKXC ( .FALSE., ' ', OK )


      CALL MXVG  ( XFORM, ISTATE, 6, 6, ESTATE )

      CALL CHCKXC ( .FALSE., ' ', OK )
      CALL CHCKAD ( 'STATE', STATE, '~/', ESTATE, 6, 1.0D-14, OK )
      CALL CHCKSD ( 'LT',    LT,    '~/', ELT,       1.0D-14, OK )




      CALL TCASE ( 'Perform an independent test to see if '
     .//           '"apparent" positions in non-inertial frames '
     .//           'are properly computed. Frame center is '
     .//           'observer.'                                    )
 
 
      CALL SPKEZ ( 301001, ET, 'IAU_EARTH', 'CN+S', 399, STATE,  LT )
      CALL CHCKXC ( .FALSE., ' ', OK )
 
      CALL SPKSSB( 399, ET, 'J2000',  SOBS )
      CALL CHCKXC ( .FALSE., ' ', OK )

      CALL SPKAPP( 301001, ET, 'J2000',  SOBS, 'CN+S', ISTATE, ELT )
      CALL CHCKXC ( .FALSE., ' ', OK )

      CALL SXFORM( 'J2000', 'IAU_EARTH', ET,           XFORM       )
      CALL CHCKXC ( .FALSE., ' ', OK )


      CALL MXVG  ( XFORM, ISTATE, 6, 6, ESTATE )

      CALL CHCKXC ( .FALSE., ' ', OK )
      CALL CHCKAD ( 'STATE', STATE, '~/', ESTATE, 6, 1.0D-14, OK )
      CALL CHCKSD ( 'LT',    LT,    '~/', ELT,       1.0D-14, OK )


      CALL TCASE ( 'Repeat the previous test for the transmission ' //
     .             'case.'                                          )
 
      CALL SPKEZ ( 301001, ET, 'IAU_EARTH', 'XCN+S', 399, STATE, LT )
      CALL CHCKXC ( .FALSE., ' ', OK )
 
      CALL SPKSSB( 399, ET, 'J2000',  SOBS )
      CALL CHCKXC ( .FALSE., ' ', OK )

      CALL SPKAPP( 301001,    ET, 'J2000',  SOBS, 'XCN+S', ISTATE, ELT )
      CALL CHCKXC ( .FALSE., ' ', OK )

      CALL SXFORM( 'J2000', 'IAU_EARTH', ET,               XFORM       )
      CALL CHCKXC ( .FALSE., ' ', OK )


      CALL MXVG  ( XFORM, ISTATE, 6, 6, ESTATE )

      CALL CHCKXC ( .FALSE., ' ', OK )
      CALL CHCKAD ( 'STATE', STATE, '~/', ESTATE, 6, 1.0D-14, OK )
      CALL CHCKSD ( 'LT',    LT,    '~/', ELT,       1.0D-14, OK )

      CALL SPKUEF (  HANDLE        )
      CALL CHCKXC ( .FALSE., ' ', OK )

      CALL KILFIL ( 'phoenix2.bsp' )
      CALL CHCKXC ( .FALSE., ' ', OK )
 
  
      CALL T_SUCCESS ( OK )
      RETURN
      END
