C$Procedure      F_SPKEZP (Family of tests for SPKEZP)
 
      SUBROUTINE F_SPKEZP( OK )
      IMPLICIT NONE
 
      LOGICAL               OK
 
C$ Abstract
C
C     This routine performs a series of tests on the routine
C     SPKEZP to make sure that it behaves as expected.
C
C$ Version
C
C     TSPICE Version 2.0.1 11-JAN-2002 (EDW)
C
C        Reduced the vector tolerance for Cases 1 and 6
C        by two orders of magnitude, to 10^12 and 10^-10
C        respectively. Roundoff error resulted in
C        relative differences between test and exp vectors
C        to exceed the original tolerances on some
C        platforms.
C     
C     TSPICE Version 2.0.0 18-DEC-2001 (NJB)
C-&
 
 
C
C     Test Utility Functions
C
 
 
C
C     SPICELIB Functions
C
 
C
C     Local Variables
C
      INTEGER               LNSIZE
      PARAMETER           ( LNSIZE = 80 )
 
      CHARACTER*(LNSIZE)    ERROR
 
      INTEGER               HANDLE
 
      DOUBLE PRECISION      ET
 
      DOUBLE PRECISION      STATE  ( 6 )
      DOUBLE PRECISION      ELT
      DOUBLE PRECISION      LT
      DOUBLE PRECISION      ESTATE ( 6 )
      DOUBLE PRECISION      TSTATE ( 6 )
      DOUBLE PRECISION      SOBS   ( 6 )
      DOUBLE PRECISION      XFORM  ( 6, 6 )
      DOUBLE PRECISION      CLT
      DOUBLE PRECISION      ISTATE ( 6 )
 
 
 
 
C
C     Begin every test family with an open call.
C
      CALL TOPEN ( 'F_SPKEZP' )
 
      CALL KILFIL ( 'phoenix2.bsp' )
      CALL KILFIL ( 'phoenix2.ker' )
 
      CALL TSTSPK ( 'phoenix2.bsp', .TRUE.,  HANDLE )
 
      CALL TSTPCK ( 'phoenix2.ker', .TRUE., .FALSE. )
      CALL TPARSE ( '1 JAN 1995',   ET,     ERROR )


 
      CALL TCASE ( 'Make sure that SPKEZPand SPKGEO return the '
     .//           'same information when the correction '
     .//           'requested is NONE. ' )
 
      CALL SPKEZP( 401001, ET, 'IAU_EARTH', 'NONE', 301001,
     .             STATE,  LT )
 
      CALL SPKGEO( 401001, ET, 'IAU_EARTH', 301001, ESTATE, ELT )
 
      CALL CHCKXC ( .FALSE., ' ', OK )
      CALL CHCKAD ( 'STATE', STATE, '~/', ESTATE, 3, 1.0D-13, OK )
      CALL CHCKSD ( 'LT',    LT,    '~/', ELT,       1.0D-14, OK )
 
 



      CALL TCASE ( 'Make sure that SPKEZP returns the same thing '
     .//           'as the combination of SPKSSB and SPKAPP when '
     .//           'an inertial frame is the requested output '
     .//           'frame. Light time only correction.' )
 
      CALL SPKEZP( 301001, ET, 'J2000', 'LT', 399001,
     .             STATE,  LT )
 
      CALL SPKSSB( 399001, ET, 'J2000',  SOBS )
      CALL SPKAPP( 301001, ET, 'J2000',  SOBS, 'LT', ESTATE, ELT )

      CALL CHCKXC ( .FALSE., ' ', OK )
      CALL CHCKAD ( 'STATE', STATE, '=', ESTATE, 3, 0.0D0, OK )
      CALL CHCKSD ( 'LT',    LT,    '=', ELT,       0.0D0, OK )



      CALL TCASE ( 'Repeat the previous test for the transmission ' //
     .             'case.'                                          )

      CALL SPKEZP( 301001, ET, 'J2000', 'XLT', 399001,
     .             STATE,  LT )
 
      CALL SPKSSB( 399001, ET, 'J2000',  SOBS )
      CALL SPKAPP( 301001, ET, 'J2000',  SOBS, 'XLT', ESTATE, ELT )

      CALL CHCKXC ( .FALSE., ' ', OK )
      CALL CHCKAD ( 'STATE', STATE, '=', ESTATE, 3, 0.0D0, OK )
      CALL CHCKSD ( 'LT',    LT,    '=', ELT,       0.0D0, OK )





      CALL TCASE ( 'Make sure that SPKEZP returns the same thing '
     .//           'as the combination of SPKSSB and SPKAPP when '
     .//           'an inertial frame is the requested output '
     .//           'frame. Converged Newtonian plus stellar aberation' )
 
      CALL SPKEZP( 301001, ET, 'J2000', 'CN+S', 399001,
     .             STATE,  LT )
 
      CALL SPKSSB( 399001, ET, 'J2000',  SOBS )
      CALL SPKAPP( 301001, ET, 'J2000',  SOBS, 'CN+S', ESTATE, ELT )

      CALL CHCKXC ( .FALSE., ' ', OK )
      CALL CHCKAD ( 'STATE', STATE, '=', ESTATE, 3, 0.0D0, OK )
      CALL CHCKSD ( 'LT',    LT,    '=', ELT,       0.0D0, OK )
 


      CALL TCASE ( 'Repeat the previous test for the transmission ' //
     .             'case.'                                          )

      CALL SPKEZP( 301001, ET, 'J2000', 'XCN+S', 399001,
     .             STATE,  LT )
 
      CALL SPKSSB( 399001, ET, 'J2000',  SOBS )
      CALL SPKAPP( 301001, ET, 'J2000',  SOBS, 'XCN+S', ESTATE, ELT )

      CALL CHCKXC ( .FALSE., ' ', OK )
      CALL CHCKAD ( 'STATE', STATE, '=', ESTATE, 3, 0.0D0, OK )
      CALL CHCKSD ( 'LT',    LT,    '=', ELT,       0.0D0, OK )
 



      CALL TCASE ( 'Perform an independent test to see if '
     .//           '"apparent" positions in non-inertial frames '
     .//           'are properly computed. ' )
 
 
      CALL SPKEZP( 401001, ET, 'IAU_EARTH', 'CN+S', 301001,
     .             STATE,  LT )
 
      CALL SPKSSB( 301001, ET, 'J2000',  SOBS )
      CALL SPKAPP( 401001, ET, 'J2000',  SOBS, 'CN+S', ISTATE, ELT )
      CALL SPKAPP( 399,    ET, 'J2000',  SOBS, 'CN+S', TSTATE, CLT )
      CALL SXFORM( 'J2000', 'IAU_EARTH', ET-CLT,       XFORM       )


      CALL MXVG  ( XFORM, ISTATE, 6, 6, ESTATE )

      CALL CHCKXC ( .FALSE., ' ', OK )
      CALL CHCKAD ( 'STATE', STATE, '~/', ESTATE, 3, 1.0D-11, OK )
      CALL CHCKSD ( 'LT',    LT,    '~/', ELT,       1.0D-12, OK )
 
 

      CALL TCASE ( 'Repeat the previous test for the transmission ' //
     .             'case.'                                          )
 
 
      CALL SPKEZP( 401001, ET, 'IAU_EARTH', 'XCN+S', 301001,
     .             STATE,  LT )
 
      CALL SPKSSB( 301001, ET, 'J2000',  SOBS )
      CALL SPKAPP( 401001, ET, 'J2000',  SOBS, 'XCN+S', ISTATE, ELT )
      CALL SPKAPP( 399,    ET, 'J2000',  SOBS, 'XCN+S', TSTATE, CLT )
      CALL SXFORM( 'J2000', 'IAU_EARTH', ET+CLT,        XFORM       )


      CALL MXVG  ( XFORM, ISTATE, 6, 6, ESTATE )

      CALL CHCKXC ( .FALSE., ' ', OK )
      CALL CHCKAD ( 'STATE', STATE, '~/', ESTATE, 3, 1.0D-12, OK )
      CALL CHCKSD ( 'LT',    LT,    '~/', ELT,       1.0D-12, OK )
 
      CALL SPKUEF (  HANDLE        )
      CALL KILFIL ( 'phoenix2.bsp' )
 
      CALL T_SUCCESS ( OK )
      RETURN
      END
