C$Procedure      F_XFNEUL ( State transformations and Euler angles)
 
      SUBROUTINE F_XFNEUL ( OK )
      IMPLICIT NONE
 
      LOGICAL               OK
 
C$ Abstract
C
C     This routine tests the routines XF2EUL and EUL2XF
C-&
 
 
C
C     Test Utility Functions
C
 
 
C
C     SPICELIB Functions
C
 
C
C     Local Variables
C
      DOUBLE PRECISION      CANG
      DOUBLE PRECISION      SANG
 
      DOUBLE PRECISION      OMEGA ( 3, 3, 3 )
      DOUBLE PRECISION      AXIS  ( 3, 3, 3 )
      DOUBLE PRECISION      DIAG  ( 3, 3, 3 )
      DOUBLE PRECISION      PART  ( 3, 3, 3 )
      DOUBLE PRECISION      ROT   ( 3, 3 )
      DOUBLE PRECISION      DRDT  ( 3, 3 )
      DOUBLE PRECISION      TEMP  ( 3, 3 )
      DOUBLE PRECISION      TERM1 ( 3, 3 )
      DOUBLE PRECISION      TERM2 ( 3, 3 )
      DOUBLE PRECISION      TERM3 ( 3, 3 )
 
      DOUBLE PRECISION      XPECT ( 6, 6 )
      DOUBLE PRECISION      XFORM ( 6, 6 )
 
      DOUBLE PRECISION      EULER  ( 6 )
      DOUBLE PRECISION      CEULER ( 6 )
      DOUBLE PRECISION      XEULER ( 6 )
 
      LOGICAL               UNIQUE
 
      INTEGER               A     ( 3 )
      INTEGER               D
 
      INTEGER               I
      INTEGER               J
      INTEGER               K
      INTEGER               M
      INTEGER               N
 
 
 
 
 
      D(I,J) = IABS(  ( IABS(I-J) - 1 ) / ( IABS(I-J) + 1 ) )
 
C
C     Begin every test family with an open call.
C
      CALL TOPEN ( 'F_XFNEUL' )
C     Validate the computation of state transformation from
C     Eular angles and derivatives.
C
 
      DO I = 1,3
         DO J = 1,3
            DO K = 1,3
               OMEGA(I,J,K) = 0.0D0
               AXIS (I,J,K) = 0.0D0
               DIAG (I,J,K) = 0.0D0
            END DO
         END DO
      END DO
 
 
      DO I = 1,3
         DO J = 1, 3
            DIAG(J,J,I) = 1.0D0 - DBLE( D(I,J) )
            AXIS(J,J,I) =         DBLE( D(I,J) )
         END DO
      END DO
 
      OMEGA(1,2,3) =  1.0D0
      OMEGA(2,3,1) =  1.0D0
      OMEGA(3,1,2) =  1.0D0
 
      OMEGA(3,2,1) = -1.0D0
      OMEGA(2,1,3) = -1.0D0
      OMEGA(1,3,2) = -1.0D0
 
 
 
      CALL TCASE ( 'Validate the computation of state '
     .//           'transformation from Eular angles and '
     .//           'derivatives. Every possible combination of '
     .//           'axes is tested. ' )
 
 
         EULER(1) =  0.33D0
         EULER(2) = -0.20D0
         EULER(3) =  0.50D0
         EULER(4) = -0.30D0
         EULER(5) =  0.10D0
         EULER(6) =  0.70D0
 
         DO I = 1, 3
            DO J = 1, 3
 
               IF ( I .NE. J ) THEN
 
                  DO K = 1, 3
 
                     IF ( K .NE. J ) THEN
C
C                       We construct the state transformation matrix
C                       from scratch and compare that to the results
C                       returned by EUL2XF.
C
                        A(1) = I
                        A(2) = J
                        A(3) = K
 
                        DO M = 1,3
                           CANG = DCOS( EULER(M) )
                           SANG = DSIN( EULER(M) )
 
                           CALL VLCOMG ( 9,    CANG, DIAG (1,1,A(M)),
     .                                         SANG, OMEGA(1,1,A(M)),
     .                                         TEMP )
 
                           CALL VADDG  ( TEMP, AXIS(1,1,A(M)), 9,
     .                                         PART(1,1,M)     )
 
                        END DO
 
 
 
                        CALL MXM ( PART(1,1,1),   PART(1,1,2),  TEMP  )
                        CALL MXM ( TEMP(1,1),     PART(1,1,3),  ROT   )
 
                        CALL MXM  ( OMEGA(1,1,I), PART(1,1,1),  TEMP  )
                        CALL MXM  ( TEMP,         PART(1,1,2),  TEMP  )
                        CALL MXM  ( TEMP,         PART(1,1,3),  TERM1 )
                        CALL VSCLG( EULER(4),     TERM1,   9,   TERM1 )
 
                        CALL MXM  ( PART(1,1,1),  OMEGA(1,1,J), TEMP  )
                        CALL MXM  ( TEMP,         PART (1,1,2), TEMP  )
                        CALL MXM  ( TEMP,         PART (1,1,3), TERM2 )
                        CALL VSCLG( EULER(5),     TERM2,   9,   TERM2 )
 
                        CALL MXM  ( PART(1,1,1),  PART (1,1,2), TEMP  )
                        CALL MXM  ( TEMP,         OMEGA(1,1,K), TEMP  )
                        CALL MXM  ( TEMP,         PART (1,1,3), TERM3 )
                        CALL VSCLG( EULER(6),     TERM3,   9,   TERM3 )
 
                        CALL VADDG( TERM1,  TERM2, 9,           TEMP  )
                        CALL VADDG( TEMP,   TERM3, 9,           DRDT  )
 
                        DO M = 1,3
                           DO N = 1,3
                              XPECT(M,  N  ) = ROT (M,N)
                              XPECT(M+3,N  ) = DRDT(M,N)
                              XPECT(M,  N+3) = 0.0D0
                              XPECT(M+3,N+3) = ROT (M,N)
                           END DO
                        END DO
 
 
                        CALL EUL2XF ( EULER, I, J, K, XFORM )
 
                        CALL TSTMSG ( '#', 'Rotation is a #-#-# ' )
                        CALL TSTMSI ( I )
                        CALL TSTMSI ( J )
                        CALL TSTMSI ( K )
 
                        CALL CHCKXC ( .FALSE., ' ', OK )
                        CALL CHCKAD ( 'XFORM', XFORM, '~', XPECT,
     .                                 36,     2.0D-14,    OK  )
 
                     END IF
 
                  END DO
 
               END IF
            END DO
 
         END DO
 
 
      CALL TCASE ( 'Validate the computation of euler angles and '
     .//           'derivatives from the state transformation '
     .//           'matrix. Every combination of rotation axes '
     .//           'is exercised. ' )
 
 
         EULER(1) =  0.33D0
         EULER(2) =  0.20D0
         EULER(3) =  0.50D0
         EULER(4) =  0.30D0
         EULER(5) =  0.10D0
         EULER(6) =  0.70D0
 
         DO I = 1, 3
            DO J = 1, 3
 
               IF ( I .NE. J ) THEN
 
                  DO K = 1, 3
 
                     IF ( K .NE. J ) THEN
 
                        CALL EUL2XF ( EULER, I, J, K, XFORM )
                        CALL XF2EUL ( XFORM, I, J, K, CEULER, UNIQUE )
 
                        CALL TSTMSG ( '#', 'Rotation is a #-#-# ' )
                        CALL TSTMSI ( I )
                        CALL TSTMSI ( J )
                        CALL TSTMSI ( K )
 
                        CALL CHCKXC ( .FALSE., ' ', OK )
                        CALL CHCKSL ( 'UNIQUE', UNIQUE, .TRUE., OK )
                        CALL CHCKAD ( 'XFORM', CEULER, '~', EULER,
     .                                 6,      2.0D-14,    OK  )
 
                     END IF
 
                  END DO
 
               END IF
            END DO
 
         END DO
 
 
      CALL TCASE ( 'Exercise the degenerate cases where the '
     .//           'second angle is nearly zero. ' )
 
 
 
         EULER(1)  =  0.0D0
         EULER(2)  =  1.0D-10
         EULER(3)  =  0.50D0
         EULER(4)  =  0.0D0
         EULER(5)  =  0.10D0
         EULER(6)  =  0.70D0
 
         XEULER(1) =  0.0D0
         XEULER(2) =  0.0D0
         XEULER(3) =  0.50D0
         XEULER(4) =  0.0D0
         XEULER(5) =  0.10D0
         XEULER(6) =  0.70D0
 
 
         DO I = 1, 3
            DO J = 1, 3
 
               IF ( I .NE. J ) THEN
 
                  DO K = 1, 3
 
                     IF ( K .EQ. I ) THEN
 
                        CALL EUL2XF ( EULER, I, J, K, XFORM )
                        CALL XF2EUL ( XFORM, I, J, K, CEULER, UNIQUE )
 
 
                        CALL TSTMSG ( '#', 'Rotation is a #-#-# ' )
                        CALL TSTMSI ( I )
                        CALL TSTMSI ( J )
                        CALL TSTMSI ( K )
 
                        CALL CHCKXC ( .FALSE., ' ', OK )
                        CALL CHCKSL ( 'UNIQUE', UNIQUE, .FALSE., OK )
                        CALL CHCKAD ( 'XFORM', CEULER, '~', XEULER,
     .                                 6,      2.0D-14,    OK  )
 
                     END IF
 
                  END DO
 
               END IF
            END DO
 
         END DO
 
 
      CALL T_SUCCESS ( OK )
      RETURN
      END
