C$Procedure      F_XFRAV ( Frame conversion to angular velocity)
 
      SUBROUTINE F_XFRAV ( OK )
      IMPLICIT NONE
 
      LOGICAL               OK
 
C$ Abstract
C
C     This routine tests the "macro" routines XF2RAV and RAV2XF.
C     The tests performed check
C
C     1)  That the routines are nearly inverses of one another.
C
C     2)  That they produce equivalent objects for converting
C         states from one frame to another.
C
C$ Version
C
C-    SPICELIB Version 1.1.0, 20-OCT-1999 (WLT)
C
C        Declared PI to be an EXTERNAL Functions.
C
C-&
 
 
C
C     Test Utility Functions
C
 
 
C
C     SPICELIB Functions
C
      EXTERNAL              PI
      DOUBLE PRECISION      PI
      DOUBLE PRECISION      HALFPI
 
C
C     Local Variables
C
      INTEGER               I
      INTEGER               J
 
 
      DOUBLE PRECISION      AV1   (    3 )
      DOUBLE PRECISION      AV2   (    3 )
 
      DOUBLE PRECISION      DLAT
      DOUBLE PRECISION      DLONG
      DOUBLE PRECISION      DMAG
 
      DOUBLE PRECISION      LAT
      DOUBLE PRECISION      LONG
      DOUBLE PRECISION      MAG
      DOUBLE PRECISION      R
 
      DOUBLE PRECISION      ROT1  ( 3, 3 )
      DOUBLE PRECISION      ROT2  ( 3, 3 )
 
      DOUBLE PRECISION      STATE ( 6 )
      DOUBLE PRECISION      STATE1( 6 )
      DOUBLE PRECISION      STATE2( 6 )
 
      DOUBLE PRECISION      V1    ( 3 )
      DOUBLE PRECISION      V2    ( 3 )
      DOUBLE PRECISION      VTEMP ( 3 )
 
      DOUBLE PRECISION      X     (    3 )
      DOUBLE PRECISION      XFORM ( 6, 6 )
      DOUBLE PRECISION      XFORM1( 6, 6 )
      DOUBLE PRECISION      XFORM2( 6, 6 )
 
 
C
C     Begin every test family with an open call.
C
      CALL TOPEN ( 'F_XFRAV' )
 
      CALL TCASE ( 'This case tests that converting from a '
     .//           'rotation and angular velocity to a state '
     .//           'transformation and then back to rotation and '
     .//           'angular velocity is very nearly the identity. '
     .//           '200 different sub-cases are examined.' )
 
         R     =  1.0D0
         LAT   = -HALFPI()
         LONG  =  0.0D0
         MAG   =  1.0D-1
 
         DLAT  = PI()/11.0D0
         DLONG = PI()/10.0D0
         DMAG  = 0.1
 
         DO I = 1, 10
 
            LAT  = LAT + DLAT
            LONG = 0.0D0
 
            DO J = 1, 20
 
               CALL TSTMSG ( '#', 'The values of I and J are # '
     .         //                 'and # respectively. ' )
               CALL TSTMSI ( I )
               CALL TSTMSI ( J )
 
               CALL LATREC ( R,  LONG,  LAT,       ROT1(1,1) )
               CALL FRAME  ( ROT1(1,1), ROT1(1,2), ROT1(1,3) )
 
               CALL LATREC ( R,   LAT, LONG, X   )
               CALL VSCL   ( MAG, X,         AV1 )
 
               CALL RAV2XF ( ROT1,  AV1,  XFORM )
               CALL XF2RAV ( XFORM, ROT2, AV2   )
 
               CALL CHCKXC ( .FALSE., ' ',  OK )
               CALL CHCKAD ( 'ROT2', ROT2, '~', ROT1, 9, 1.0D-14, OK )
               CALL CHCKAD ( 'AV2',  AV2,  '~', AV1,  3, 1.0D-14, OK )
 
               CALL XPOSE ( ROT1, ROT2 )
               CALL MXV   ( ROT1, AV1, AV2 )
               CALL VMINUS( AV2,       AV2 )
               CALL RAV2XF( ROT2, AV2, XFORM2 )
               CALL INVSTM( XFORM,     XFORM1 )
 
               CALL CHCKAD('XFORM1',XFORM1, '~', XFORM2, 9, 1.0D-14, OK)
 
 
               LONG = LONG + DLONG
               MAG  = MAG  + DMAG
 
            END DO
 
 
         END DO
 
         CALL TSTMSG ( '#', ' ' )
 
      CALL TCASE ( 'In this case we construct a rotation, '
     .//           'angular velocity and state transformation '
     .//           'matrix.  We use these to compute velocities '
     .//           'in two different ways and compare the '
     .//           'results. 200 sub-cases are examined.' )
 
 
         R        =  1.0D0
         LAT      = -HALFPI()
         LONG     =  0.0D0
         MAG      =  1.0D-1
 
         DLAT     = PI()/11.0D0
         DLONG    = PI()/10.0D0
         DMAG     = 0.1
 
         STATE(1) = 6.0D0
         STATE(2) = 5.0D0
         STATE(3) = 4.0D0
         STATE(4) = 3.0D0
         STATE(5) = 2.0D0
         STATE(6) = 1.0D0
 
         DO I = 1, 10
 
            LAT  = LAT + DLAT
            LONG = 0.0D0
 
            DO J = 1, 20
 
               CALL TSTMSG ( '#', 'The values of I and J are # '
     .         //                 'and # respectively. ' )
               CALL TSTMSI ( I )
               CALL TSTMSI ( J )
 
               CALL LATREC ( R,  LONG,  LAT,       ROT1(1,1) )
               CALL FRAME  ( ROT1(1,1), ROT1(1,2), ROT1(1,3) )
 
               CALL LATREC ( R,   LAT, LONG, X   )
               CALL VSCL   ( MAG, X,         AV1 )
 
               CALL RAV2XF ( ROT1,  AV1,  XFORM )
C
C              First transform states using the state transformation
C              matrix.
C
 
               CALL MXVG   ( XFORM, STATE, 6, 6, STATE1 )
C
C              Now transform states using the rotation and angular
C              velocity.  Recall that the angular velocity of
C              FRAME1 with respect to FRAME2 is the opposite of
C              the angular velocity of FRAME2 with respect to FRAME1.
C
               CALL VMINUS ( AV1,   AV2         )
C
C              A part of the position and velocity is obtained by
C              simply rotating the original position and velocity.
C
               CALL MXV    ( ROT1,  STATE,     STATE2    )
               CALL MXV    ( ROT1,  STATE(4),  V1        )
 
C
C              The rest of the velocity is obtained by crossing
C              the angular velocity with the current position
C              in  FRAME2.
C
               CALL VCRSS  ( AV2,   STATE,    VTEMP        )
               CALL MXV    ( ROT1,  VTEMP,    V2           )
C
C              Add the results together to get the the full velocity.
C
               CALL VADD   ( V1,    V2,       STATE2(4) )
 
 
               CALL CHCKXC ( .FALSE., ' ',  OK )
               CALL CHCKAD ( 'POSITION', STATE1,
     .                       '~~/',      STATE2,
     .                        3,         1.0D-14,   OK )
               CALL CHCKAD ( 'VELOCITY', STATE1(4),
     .                        '~~/',     STATE2(4),
     .                        3,         1.0D-14,   OK )
 
               CALL MOVED ( STATE2, 6, STATE )
 
               LONG = LONG + DLONG
               MAG  = MAG  + DMAG
 
            END DO
 
 
         END DO
 
         CALL TSTMSG ( '#', ' ' )
 
 
      CALL T_SUCCESS ( OK )
      RETURN
      END
