C$Procedure F_XLATEI ( ZZXLATEI Test Family )
 
      SUBROUTINE F_XLATEI ( OK )
 
C$ Abstract
C
C     Test family to exercise the logic and code in the ZZXLATEI
C     routine.
C
C$ Copyright
C
C     Copyright (2001), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     None.
C
C$ Keywords
C
C     TEST FAMILY
C
C$ Declarations
 
      IMPLICIT NONE
 
      INCLUDE              'zzddhman.inc'
 
      LOGICAL               OK
 
 
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     OK         O   logical indicating test status.
C
C$ Detailed_Input
C
C     None.
C
C$ Detailed_Output
C
C     OK         is a logical that indicates the test status to the
C                caller.
C
C$ Parameters
C
C     None.
C
C$ Files
C
C     None.
C
C$ Exceptions
C
C     This routine does not generate any errors. Routines in its
C     call tree may generate errors that are either intentional and
C     trapped or unintentional and need reporting.  The test family
C     utilities manage this.
C
C$ Particulars
C
C     This routine exercises ZZXLATEI's logic.
C
C$ Examples
C
C     None.
C
C$ Restrictions
C
C     None.
C
C$ Author_and_Institution
C
C     F.S. Turner     (JPL)
C
C$ Literature_References
C
C     None.
C
C$ Version
C
C-    TSPICE Version 1.2.0, 03-JAN-2005 (BVS)
C
C        Updated for PC-CYGWIN_C.
C
C-    TSPICE Version 1.1.0, 03-JAN-2005 (BVS)
C
C        Updated for PC-CYGWIN.
C
C-    TSPICE Version 1.0.1, 17-JUL-2002 (BVS)
C
C        Added MAC-OSX environments.
C
C-    TSPICE Version 1.0.0, 15-OCT-2001 (FST)
C
C
C-&
 
C
C     Local Parameters
C
      INTEGER               NUMOUT
      PARAMETER           ( NUMOUT = 256 )
 
C
C     Local Variables
C
      CHARACTER*(1024)      INPUT
 
      INTEGER               COMPAR ( NUMOUT )
      INTEGER               I
      INTEGER               INBFF
      INTEGER               OUTPUT ( NUMOUT )
      INTEGER               SPACE
 
C
C     Start the test family with an open call.
C
      CALL TOPEN ( 'F_XLATEI' )
 
C
C --- Case: ------------------------------------------------------
C
      CALL TCASE ( 'INBFF out of range error' )
 
C
C     Setup the inputs and outputs for checking the lower bound.
C
      INBFF = 0
      SPACE = 10
 
      DO I = 1, NUMOUT
         OUTPUT(I) = 0
         COMPAR(I) = 0
      END DO
 
C
C     Invoke the module.
C
      CALL ZZXLATEI ( INBFF, INPUT, SPACE, OUTPUT )
 
C
C     Check for an exception.
C
      CALL CHCKXC ( .TRUE., 'SPICE(BUG)', OK )
 
C
C     Check to see that OUTPUT was unmodified.
C
      CALL CHCKAI ( 'OUTPUT', OUTPUT, '=', COMPAR, NUMOUT, OK )
 
C
C     Setup the inputs and outputs for checking the upper bound.
C
      INBFF = NUMBFF + 1
      SPACE = 10
 
      DO I = 1, NUMOUT
         OUTPUT(I) = 0
         COMPAR(I) = 0
      END DO
 
C
C     Invoke the module.
C
      CALL ZZXLATEI ( INBFF, INPUT, SPACE, OUTPUT )
 
C
C     Check for an exception.
C
      CALL CHCKXC ( .TRUE., 'SPICE(BUG)', OK )
 
C
C     Check to see that OUTPUT was unmodified.
C
      CALL CHCKAI ( 'OUTPUT', OUTPUT, '=', COMPAR, NUMOUT, OK )
 
C
C --- Case: ------------------------------------------------------
C
      CALL TCASE ( 'Unsupported binary file format' )
 
C
C     Setup the inputs and outputs.
C
      INBFF = BIGI3E
      SPACE = 10
 
      DO I = 1, NUMOUT
         OUTPUT(I) = 0
         COMPAR(I) = 0
      END DO
 
C
C     Invoke the module.
C
      CALL ZZXLATEI ( INBFF, INPUT, SPACE, OUTPUT )
 
C
C     Check for an exception.
C
      CALL CHCKXC ( .TRUE., 'SPICE(BUG)', OK )
 
C
C     Check to see that OUTPUT was unmodified.
C
      CALL CHCKAI ( 'OUTPUT', OUTPUT, '=', COMPAR, NUMOUT, OK )
 
C
C     Close out the test family.
C
      CALL T_SUCCESS ( OK )
      RETURN
 
      END
