C$Procedure F_ZZBDIN ( Body Name/Code Initialization Test Family )
 
      SUBROUTINE F_ZZBDIN ( OK )
 
C$ Abstract
C
C     Test family to exercise the logic and code in the body name-code
C     processing software.
C
C$ Copyright
C
C     Copyright (2002), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     None.
C
C$ Keywords
C
C     TEST FAMILY
C
C$ Declarations
 
      IMPLICIT NONE
 
      INCLUDE              'zzbodtrn.inc'
 
      LOGICAL               OK
 
 
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     OK         O   logical indicating test status.
C
C$ Detailed_Input
C
C     None.
C
C$ Detailed_Output
C
C     OK         is a logical that indicates the test status to the
C                caller.
C
C$ Parameters
C
C     None.
C
C$ Files
C
C     None.
C
C$ Exceptions
C
C     This routine does not generate any errors. Routines in its
C     call tree may generate errors that are either intentional and
C     trapped or unintentional and need reporting.  The test family
C     utilities manage this.
C
C$ Particulars
C
C     This routine exercise the conformance of the body name-code
C     initialization routine, ZZBODINI, to the intended/designed
C     behavior.
C
C     We need not perform any stress tests here, as F_BODCOD
C     attempts to provide these sorts of tests from higher level
C     interfaces.
C
C$ Examples
C
C     None.
C
C$ Restrictions
C
C     None.
C
C$ Author_and_Institution
C
C     F.S. Turner     (JPL)
C
C$ Literature_References
C
C     None.
C
C$ Version
C
C-    TSPICE Version 1.0.0, 26-AUG-2002 (FST)
C
C
C-&
 
C
C     Local Variables
C
      CHARACTER*(MAXL)      NAMES  ( 10 )
      CHARACTER*(MAXL)      NORNAM ( 10 )
 
      INTEGER               CMPOCD ( 10 )
      INTEGER               CMPONM ( 10 )
      INTEGER               CODES  ( 10 )
      INTEGER               NOCDS
      INTEGER               ORDCOD ( 10 )
      INTEGER               ORDNOM ( 10 )
 
C
C     Open the test family.
C
      CALL TOPEN ( 'F_ZZBDIN' )
 
C
C --- Case: ------------------------------------------------------
C
      CALL TCASE ( 'Nominal Behavior -- Simple Test' )
 
      NAMES  (1) = 'A'
      NORNAM (1) = 'A'
      CODES  (1) = 1000
 
      NAMES  (2) = 'B'
      NORNAM (2) = 'B'
      CODES  (2) = 1001
 
      NAMES  (3) = 'C'
      NORNAM (3) = 'C'
      CODES  (3) = 1002
 
C
C     Build the comparison order vectors.
C
      CMPONM (1) = 1
      CMPONM (2) = 2
      CMPONM (3) = 3
 
      CMPOCD (1) = 1
      CMPOCD (2) = 2
      CMPOCD (3) = 3
 
C
C     Toss this at ZZBODINI and see what drops out.
C
      CALL ZZBODINI ( NAMES, NORNAM, CODES, 3, ORDNOM, ORDCOD, NOCDS )
 
      CALL CHCKXC ( .FALSE., ' ', OK )
 
      CALL CHCKSI ( 'NOCDS', NOCDS, '=', 3, 0, OK )
 
      CALL CHCKAI ( 'ORDNOM', ORDNOM, '=', CMPONM, 3,     OK )
      CALL CHCKAI ( 'ORDCOD', ORDCOD, '=', CMPOCD, NOCDS, OK )
 
C
C --- Case: ------------------------------------------------------
C
      CALL TCASE ( 'Nominal Behavior -- Modified Order Vector Test' )
 
      NAMES  (1) = 'A'
      NAMES  (2) = 'B'
      NAMES  (3) = 'C'
      NAMES  (4) = 'D'
      NAMES  (5) = 'E'
      NAMES  (6) = 'F'
      NAMES  (7) = 'G'
      NAMES  (8) = 'H'
 
      NORNAM (1) = 'A'
      NORNAM (2) = 'B'
      NORNAM (3) = 'C'
      NORNAM (4) = 'D'
      NORNAM (5) = 'E'
      NORNAM (6) = 'F'
      NORNAM (7) = 'G'
      NORNAM (8) = 'H'
 
      CODES  (1) = 1000
      CODES  (2) = 1000
      CODES  (3) = 1000
      CODES  (4) = 1001
      CODES  (5) = 1002
      CODES  (6) = 1000
      CODES  (7) = 1003
      CODES  (8) = 1000
 
C
C     Build the comparison order vectors.
C
      CMPONM (1) = 1
      CMPONM (2) = 2
      CMPONM (3) = 3
      CMPONM (4) = 4
      CMPONM (5) = 5
      CMPONM (6) = 6
      CMPONM (7) = 7
      CMPONM (8) = 8
 
      CMPOCD (1) = 8
      CMPOCD (2) = 4
      CMPOCD (3) = 5
      CMPOCD (4) = 7
 
C
C     Toss this at ZZBODINI and see what drops out.
C
      CALL ZZBODINI ( NAMES, NORNAM, CODES, 8, ORDNOM, ORDCOD, NOCDS )
 
      CALL CHCKXC ( .FALSE., ' ', OK )
 
      CALL CHCKSI ( 'NOCDS', NOCDS, '=', 4, 0, OK )
 
      CALL CHCKAI ( 'ORDNOM', ORDNOM, '=', CMPONM, 8,     OK )
      CALL CHCKAI ( 'ORDCOD', ORDCOD, '=', CMPOCD, NOCDS, OK )
 
C
C     Close out the test family.
C
      CALL T_SUCCESS ( OK )
      RETURN
 
      END
