C$Procedure F_ZZBDKR ( Body Kernel Pool Initialization Test Family )
 
      SUBROUTINE F_ZZBDKR ( OK )
 
C$ Abstract
C
C     Test family to exercise the logic and code in the kernel pool
C     name-code mapping processing software.
C
C$ Copyright
C
C     Copyright (2002), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     None.
C
C$ Keywords
C
C     TEST FAMILY
C
C$ Declarations
 
      IMPLICIT NONE
 
      INCLUDE              'zzbodtrn.inc'
 
      LOGICAL               OK
 
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     OK         O   logical indicating test status.
C
C$ Detailed_Input
C
C     None.
C
C$ Detailed_Output
C
C     OK         is a logical that indicates the test status to the
C                caller.
C
C$ Parameters
C
C     None.
C
C$ Files
C
C     None.
C
C$ Exceptions
C
C     This routine does not generate any errors. Routines in its
C     call tree may generate errors that are either intentional and
C     trapped or unintentional and need reporting.  The test family
C     utilities manage this.
C
C$ Particulars
C
C     This routine exercises the conformance of the kernel pool name
C     to code mapping initialization with intended/designed behavior.
C
C     We need not perform any stress tests here, as F_BODCOD attempts
C     to provide these sorts of tests from the higher level interfaces.
C
C$ Examples
C
C     None.
C
C$ Restrictions
C
C     None.
C
C$ Author_and_Institution
C
C     F.S. Turner     (JPL)
C
C$ Literature_References
C
C     None.
C
C$ Version
C
C-    TSPICE Version 1.0.0, 26-AUG-2002 (FST)
C
C
C-&
 
C
C     Local Parameters
C
      INTEGER               LINLEN
      PARAMETER           ( LINLEN = 80 )
 
      INTEGER               BUFLEN
      PARAMETER           ( BUFLEN = 20 )
 
      INTEGER               TKBASE
      PARAMETER           ( TKBASE = 10000 )
 
C
C     Local Variables
C
      CHARACTER*(LINLEN)    BUFFER ( BUFLEN )
      CHARACTER*(MAXL)      CMPNAM ( NROOM  )
      CHARACTER*(MAXL)      CMPNOR ( NROOM  )
      CHARACTER*(MAXL)      NAMES  ( NROOM  )
      CHARACTER*(MAXL)      NORNAM ( NROOM  )
 
      INTEGER               CMPCOD ( NROOM  )
      INTEGER               CMPOCD ( NROOM  )
      INTEGER               CMPONM ( NROOM  )
      INTEGER               CODES  ( NROOM  )
      INTEGER               I
      INTEGER               NOCDS
      INTEGER               NVALS
      INTEGER               ORDCOD ( NROOM  )
      INTEGER               ORDNOM ( NROOM  )
 
      LOGICAL               EXTKER
 
C
C     Open the test family.
C
      CALL TOPEN ( 'F_ZZBDKR' )
 
C
C --- Case: ------------------------------------------------------
C
      CALL TCASE ( 'SPICE(MISSINGKPV) exception' )
 
C
C     First, check behavior if neither of the two kernel pool
C     variables are defined.
C
      CALL CLPOOL ( )
 
      CALL ZZBODKER ( NAMES, NORNAM, CODES, NVALS, ORDNOM, ORDCOD,
     .                NOCDS, EXTKER                                )
 
      CALL CHCKXC ( .FALSE., ' ', OK )
 
      CALL CHCKSL ( 'EXTKER', EXTKER, .FALSE., OK )
 
C
C     Now load up NAIF_BODY_CODE and call ZZBODKER.
C
      BUFFER(  1 ) = 'NAIF_BODY_CODE = 1000'
 
      CALL LMPOOL ( BUFFER, 1 )
 
      EXTKER = .TRUE.
 
      CALL ZZBODKER ( NAMES, NORNAM, CODES, NVALS, ORDNOM, ORDCOD,
     .                NOCDS, EXTKER                                )
 
      CALL CHCKXC ( .TRUE., 'SPICE(MISSINGKPV)', OK )
 
      CALL CHCKSL ( 'EXTKER', EXTKER, .FALSE., OK )
 
C
C     Now try NAIF_BODY_NAME and call ZZBODKER.
C
      CALL CLPOOL ( )
 
      BUFFER(  1 ) = 'NAIF_BODY_NAME = ''TEST_BODY_ZZBODKER'''
 
      CALL LMPOOL ( BUFFER, 1 )
 
      EXTKER = .TRUE.
 
      CALL ZZBODKER ( NAMES, NORNAM, CODES, NVALS, ORDNOM, ORDCOD,
     .                NOCDS, EXTKER                                )
 
      CALL CHCKXC ( .TRUE., 'SPICE(MISSINGKPV)', OK )
 
      CALL CHCKSL ( 'EXTKER', EXTKER, .FALSE., OK )
 
C
C     Clean up
C
      CALL CLPOOL ( )
 
C
C --- Case: ------------------------------------------------------
C
      CALL TCASE ( 'SPICE(KERVARTOOBIG) exception' )
 
C
C     Build up the kernel pool variables to exceed the available
C     space.  Start by overflowing NAIF_BODY_NAME.
C
      DO I = 1, NROOM
 
         BUFFER(  1 ) = 'NAIF_BODY_CODE += #'
         BUFFER(  2 ) = 'NAIF_BODY_NAME += ''NAME_#'''
 
         CALL REPMI ( BUFFER(1), '#', TKBASE+I, BUFFER(1) )
         CALL REPMI ( BUFFER(2), '#', TKBASE+I, BUFFER(2) )
 
         CALL LMPOOL ( BUFFER, 2 )
 
      END DO
 
      BUFFER(  1 ) = 'NAIF_BODY_CODE += #'
 
      CALL REPMI ( BUFFER(1), '#', TKBASE+NROOM+1, BUFFER(1) )
 
      CALL LMPOOL ( BUFFER, 1 )
 
C
C     Invoke ZZBODKER and check for the exception.
C
      EXTKER = .TRUE.
 
      CALL ZZBODKER ( NAMES, NORNAM, CODES, NVALS, ORDNOM, ORDCOD,
     .                NOCDS, EXTKER                                )
 
      CALL CHCKXC ( .TRUE., 'SPICE(KERVARTOOBIG)', OK )
 
      CALL CHCKSL ( 'EXTKER', EXTKER, .FALSE., OK )
 
      CALL CLPOOL ( )
 
C
C     Build up the kernel pool variables to exceed the available
C     space.  Overflow NAIF_BODY_CODE.
C
      DO I = 1, NROOM
 
         BUFFER(  1 ) = 'NAIF_BODY_CODE += #'
         BUFFER(  2 ) = 'NAIF_BODY_NAME += ''NAME_#'''
 
         CALL REPMI ( BUFFER(1), '#', TKBASE+I, BUFFER(1) )
         CALL REPMI ( BUFFER(2), '#', TKBASE+I, BUFFER(2) )
 
         CALL LMPOOL ( BUFFER, 2 )
 
      END DO
 
      BUFFER(  1 ) = 'NAIF_BODY_NAME += ''NAME_#'''
 
      CALL REPMI ( BUFFER(1), '#', TKBASE+NROOM+1, BUFFER(1) )
 
      CALL LMPOOL ( BUFFER, 1 )
 
C
C     Invoke ZZBODKER and check for the exception.
C
      EXTKER = .TRUE.
 
      CALL ZZBODKER ( NAMES, NORNAM, CODES, NVALS, ORDNOM, ORDCOD,
     .                NOCDS, EXTKER                                )
 
      CALL CHCKXC ( .TRUE., 'SPICE(KERVARTOOBIG)', OK )
 
      CALL CHCKSL ( 'EXTKER', EXTKER, .FALSE., OK )
 
      CALL CLPOOL ( )
 
C
C     Build up the kernel pool variables to exceed the available
C     space.  Overflow both keywords.
C
      DO I = 1, NROOM + 1
 
         BUFFER(  1 ) = 'NAIF_BODY_CODE += #'
         BUFFER(  2 ) = 'NAIF_BODY_NAME += ''NAME_#'''
 
         CALL REPMI ( BUFFER(1), '#', TKBASE+I, BUFFER(1) )
         CALL REPMI ( BUFFER(2), '#', TKBASE+I, BUFFER(2) )
 
         CALL LMPOOL ( BUFFER, 2 )
 
      END DO
 
C
C     Invoke ZZBODKER and check for the exception.
C
      EXTKER = .TRUE.
 
      CALL ZZBODKER ( NAMES, NORNAM, CODES, NVALS, ORDNOM, ORDCOD,
     .                NOCDS, EXTKER                                )
 
      CALL CHCKXC ( .TRUE., 'SPICE(KERVARTOOBIG)', OK )
 
      CALL CHCKSL ( 'EXTKER', EXTKER, .FALSE., OK )
 
      CALL CLPOOL ( )
 
C
C --- Case: ------------------------------------------------------
C
      CALL TCASE ( 'SPICE(BADDIMENSIONS) exception' )
 
C
C     To hit this, we have to have mismatched kernel pool
C     arrays with cardinality less than NROOM.
C
      BUFFER(  1 ) = 'NAIF_BODY_CODE += 10001'
      BUFFER(  2 ) = 'NAIF_BODY_NAME += ''TEST_BODY_ZZBODKER'''
      BUFFER(  3 ) = 'NAIF_BODY_CODE += 10002'
 
      CALL LMPOOL ( BUFFER, 3 )
 
C
C     Invoke ZZBODKER and check for the exception.
C
      EXTKER = .TRUE.
 
      CALL ZZBODKER ( NAMES, NORNAM, CODES, NVALS, ORDNOM, ORDCOD,
     .                NOCDS, EXTKER                                )
 
      CALL CHCKXC ( .TRUE., 'SPICE(BADDIMENSIONS)', OK )
 
      CALL CHCKSL ( 'EXTKER', EXTKER, .FALSE., OK )
 
      CALL CLPOOL ( )
 
C
C --- Case: ------------------------------------------------------
C
      CALL TCASE ( 'SPICE(BLANKNAMEASSIGNED) exception' )
 
C
C     To hit this exception, we need only assign a blank name
C     to a code.
C
      BUFFER(  1 ) = 'NAIF_BODY_CODE += 1000'
      BUFFER(  2 ) = 'NAIF_BODY_NAME += '' '''
 
      CALL LMPOOL ( BUFFER, 2 )
 
C
C     Invoke ZZBODKER and check for the exception.
C
      EXTKER = .TRUE.
 
      CALL ZZBODKER ( NAMES, NORNAM, CODES, NVALS, ORDNOM, ORDCOD,
     .                NOCDS, EXTKER                                )
 
      CALL CHCKXC ( .TRUE., 'SPICE(BLANKNAMEASSIGNED)', OK )
 
      CALL CHCKSL ( 'EXTKER', EXTKER, .FALSE., OK )
 
      CALL CLPOOL ( )
 
C
C --- Case: ------------------------------------------------------
C
      CALL TCASE ( 'Check duplicate removal code' )
 
C
C     Mix duplicates and non-duplicates.
C
      BUFFER(  1 ) = 'NAIF_BODY_CODE += 1000'
      BUFFER(  2 ) = 'NAIF_BODY_NAME += ''DUPLICATE'''
      BUFFER(  3 ) = 'NAIF_BODY_CODE += 1001'
      BUFFER(  4 ) = 'NAIF_BODY_NAME += ''dUpLiCaTe'''
      BUFFER(  5 ) = 'NAIF_BODY_CODE += 1002'
      BUFFER(  6 ) = 'NAIF_BODY_NAME += ''Not Duplicate 1'''
      BUFFER(  7 ) = 'NAIF_BODY_CODE += 1003'
      BUFFER(  8 ) = 'NAIF_BODY_NAME += ''Duplicate'''
      BUFFER(  9 ) = 'NAIF_BODY_CODE += 1004'
      BUFFER( 10 ) = 'NAIF_BODY_NAME += ''DuPliCaTe'''
      BUFFER( 11 ) = 'NAIF_BODY_CODE += 1005'
      BUFFER( 12 ) = 'NAIF_BODY_NAME += ''Duplicate with spac'
     .//             'es'''
      BUFFER( 13 ) = 'NAIF_BODY_CODE += 1006'
      BUFFER( 14 ) = 'NAIF_BODY_NAME += ''Not Duplicate 2'''
      BUFFER( 15 ) = 'NAIF_BODY_CODE += 1007'
      BUFFER( 16 ) = 'NAIF_BODY_NAME += ''Duplicate    with  '
     .//             '  spaces'''
      BUFFER( 17 ) = 'NAIF_BODY_CODE += 1008'
      BUFFER( 18 ) = 'NAIF_BODY_NAME += ''Not Duplicate 3'''
 
      CALL LMPOOL ( BUFFER, 18 )
 
C
C     Build the comparison arrays.
C
      CMPNAM (1) = 'Not Duplicate 1'
      CMPNOR (1) = 'NOT DUPLICATE 1'
      CMPCOD (1) = 1002
 
      CMPNAM (2) = 'DuPliCaTe'
      CMPNOR (2) = 'DUPLICATE'
      CMPCOD (2) = 1004
 
      CMPNAM (3) = 'Not Duplicate 2'
      CMPNOR (3) = 'NOT DUPLICATE 2'
      CMPCOD (3) = 1006
 
      CMPNAM (4) = 'Duplicate    with    spaces'
      CMPNOR (4) = 'DUPLICATE WITH SPACES'
      CMPCOD (4) = 1007
 
      CMPNAM (5) = 'Not Duplicate 3'
      CMPNOR (5) = 'NOT DUPLICATE 3'
      CMPCOD (5) = 1008
 
C
C     Build the order vectors.
C
      CALL ORDERC ( CMPNOR, 5, CMPONM )
      CALL ORDERI ( CMPCOD, 5, CMPOCD )
 
C
C     Call ZZBODKER and see what drops out.
C
      EXTKER = .FALSE.
 
      CALL ZZBODKER ( NAMES, NORNAM, CODES, NVALS, ORDNOM, ORDCOD,
     .                NOCDS, EXTKER                                )
 
C
C     Check results.
C
      CALL CHCKSL ( 'EXTKER', EXTKER, .TRUE.,  OK )
      CALL CHCKSI ( 'NVALS', NVALS, '=', 5, 0, OK )
      CALL CHCKSI ( 'NOCDS', NOCDS, '=', 5, 0, OK )
 
      CALL CHCKAC ( 'NAMES',  NAMES,  '=', CMPNAM, NVALS, OK )
      CALL CHCKAC ( 'NORNAM', NORNAM, '=', CMPNOR, NVALS, OK )
 
      CALL CHCKAI ( 'CODES',  CODES,  '=', CMPCOD, NVALS, OK )
      CALL CHCKAI ( 'ORDNOM', ORDNOM, '=', CMPONM, NVALS, OK )
      CALL CHCKAI ( 'ORDCOD', ORDCOD, '=', CMPOCD, NOCDS, OK )
 
      CALL CLPOOL ( )
 
C
C --- Case: ------------------------------------------------------
C
      CALL TCASE ( 'Check alias prioritization (ZZBODINI)' )
 
C
C     Build a list of name-code mappings that contains
C     aliases.
C
      BUFFER(  1 ) = 'NAIF_BODY_CODE += 1000'
      BUFFER(  2 ) = 'NAIF_BODY_NAME += ''ALIAS 1'''
      BUFFER(  3 ) = 'NAIF_BODY_CODE += 1000'
      BUFFER(  4 ) = 'NAIF_BODY_NAME += ''ALIAS 2'''
      BUFFER(  5 ) = 'NAIF_BODY_CODE += 1001'
      BUFFER(  6 ) = 'NAIF_BODY_NAME += ''NOT AN ALIAS'''
      BUFFER(  7 ) = 'NAIF_BODY_CODE += 1000'
      BUFFER(  8 ) = 'NAIF_BODY_NAME += ''ALIAS 3'''
      BUFFER(  9 ) = 'NAIF_BODY_CODE += 1002'
      BUFFER( 10 ) = 'NAIF_BODY_NAME += ''NOT AN ALIAS 2'''
      BUFFER( 11 ) = 'NAIF_BODY_CODE += 1003'
      BUFFER( 12 ) = 'NAIF_BODY_NAME += ''ALIAS A'''
      BUFFER( 13 ) = 'NAIF_BODY_CODE += 1004'
      BUFFER( 14 ) = 'NAIF_BODY_NAME += ''NOT AN ALIAS 3'''
      BUFFER( 15 ) = 'NAIF_BODY_CODE += 1003'
      BUFFER( 16 ) = 'NAIF_BODY_NAME += ''ALIAS B'''
 
      CALL LMPOOL ( BUFFER, 16 )
 
C
C     Build the comparison arrays.
C
      CMPNAM (1) = 'ALIAS 1'
      CMPNOR (1) = 'ALIAS 1'
      CMPCOD (1) = 1000
 
      CMPNAM (2) = 'ALIAS 2'
      CMPNOR (2) = 'ALIAS 2'
      CMPCOD (2) = 1000
 
      CMPNAM (3) = 'NOT AN ALIAS'
      CMPNOR (3) = 'NOT AN ALIAS'
      CMPCOD (3) = 1001
 
      CMPNAM (4) = 'ALIAS 3'
      CMPNOR (4) = 'ALIAS 3'
      CMPCOD (4) = 1000
 
      CMPNAM (5) = 'NOT AN ALIAS 2'
      CMPNOR (5) = 'NOT AN ALIAS 2'
      CMPCOD (5) = 1002
 
      CMPNAM (6) = 'ALIAS A'
      CMPNOR (6) = 'ALIAS A'
      CMPCOD (6) = 1003
 
      CMPNAM (7) = 'NOT AN ALIAS 3'
      CMPNOR (7) = 'NOT AN ALIAS 3'
      CMPCOD (7) = 1004
 
      CMPNAM (8) = 'ALIAS B'
      CMPNOR (8) = 'ALIAS B'
      CMPCOD (8) = 1003
 
C
C     Build the CMPNOM order vector.
C
      CALL ORDERC ( CMPNOR, 8, CMPONM )
 
C
C     Construct the CMPCOD "modified" order vector by hand.
C
      CMPOCD (1) = 4
      CMPOCD (2) = 3
      CMPOCD (3) = 5
      CMPOCD (4) = 8
      CMPOCD (5) = 7
 
C
C     Call ZZBODKER and see what drops out.
C
      EXTKER = .FALSE.
 
      CALL ZZBODKER ( NAMES, NORNAM, CODES, NVALS, ORDNOM, ORDCOD,
     .                NOCDS, EXTKER                                )
 
C
C     Check results
C
      CALL CHCKSL ( 'EXTKER', EXTKER, .TRUE.,  OK )
      CALL CHCKSI ( 'NVALS', NVALS, '=', 8, 0, OK )
      CALL CHCKSI ( 'NOCDS', NOCDS, '=', 5, 0, OK )
 
      CALL CHCKAC ( 'NAMES',  NAMES,  '=', CMPNAM, NVALS, OK )
      CALL CHCKAC ( 'NORNAM', NORNAM, '=', CMPNOR, NVALS, OK )
 
      CALL CHCKAI ( 'CODES',  CODES,  '=', CMPCOD, NVALS, OK )
      CALL CHCKAI ( 'ORDNOM', ORDNOM, '=', CMPONM, NVALS, OK )
      CALL CHCKAI ( 'ORDCOD', ORDCOD, '=', CMPOCD, NOCDS, OK )
 
      CALL CLPOOL ( )
 
C
C     Close out the test family.
C
      CALL T_SUCCESS ( OK )
      RETURN
 
      END
