C$Procedure F_ZZFDAT ( ZZFDAT Test Family )
 
      SUBROUTINE F_ZZFDAT ( OK )
 
C$ Abstract
C
C     Test family to exercise the logic and code in the ZZFDAT
C     routine.
C
C$ Copyright
C
C     Copyright (2001), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     None.
C
C$ Keywords
C
C     TEST FAMILY
C
C$ Declarations
 
      IMPLICIT NONE
 
      INCLUDE              'frmtyp.inc'
      INCLUDE              'ninert.inc'
      INCLUDE              'nninrt.inc'
 
      LOGICAL               OK
 
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     OK         O   logical indicating test status.
C
C$ Detailed_Input
C
C     None.
C
C$ Detailed_Output
C
C     OK         is a logical that indicates the test status to the
C                caller.
C
C$ Parameters
C
C     None.
C
C$ Files
C
C     None.
C
C$ Exceptions
C
C     This routine does not generate any errors. Routines in its
C     call tree may generate errors that are either intentional and
C     trapped or unintentional and need reporting.  The test family
C     utilities manage this.
C
C$ Particulars
C
C     This routine exercises updates to ZZFDAT through the FRAMEX
C     query interfaces.
C
C$ Examples
C
C     None.
C
C$ Restrictions
C
C     None.
C
C$ Author_and_Institution
C
C     F.S. Turner     (JPL)
C
C$ Literature_References
C
C     None.
C
C$ Version
C
C-    TSPICE Version 1.1.0, 12-DEC-2002 (FST)
C
C        Updated to check for correct PAN frame value 618. Added
C        checks for new Jovian satellite frames.
C
C-    TSPICE Version 1.0.0, 02-AUG-2002 (FST)
C
C-&
 
C
C     Local Parameters
C
      INTEGER               NAMLEN
      PARAMETER           ( NAMLEN = 32 )
 
C
C     Local Variables
C
      CHARACTER*(NAMLEN)    ATNAME(NINERT+NNINRT)
      INTEGER               ATCODE(NINERT+NNINRT) 
      INTEGER               ATCENT(NINERT+NNINRT)
      INTEGER               ATCLSS(NINERT+NNINRT)
      INTEGER               ATTYPE(NINERT+NNINRT)
 
      CHARACTER*(NAMLEN)    FRNAME
      INTEGER               FRCODE
      INTEGER               FRCENT
      INTEGER               FRTYPE
      INTEGER               FRCLSS

      INTEGER               BCODE
      INTEGER               NTOCHK
      INTEGER               I
 
      LOGICAL               FOUND

C
C     SPICELIB functions
C
      INTEGER               RTRIM
 
C
C     Start the test family with an open call.
C
      CALL TOPEN ( 'F_ZZFDAT' )

C
C     Set expected values.
C 
      ATNAME(1) = 'IAU_PAN'
      ATCODE(1) = 10082
      ATCENT(1) = 618
      ATCLSS(1) = 618
      ATTYPE(1) = PCK
 
      ATNAME(2) = 'IAU_GASPRA'
      ATCODE(2) = 10083
      ATCENT(2) = 9511010
      ATCLSS(2) = 9511010
      ATTYPE(2) = PCK

      ATNAME(3) = 'IAU_IDA'
      ATCODE(3) = 10084
      ATCENT(3) = 2431010
      ATCLSS(3) = 2431010
      ATTYPE(3) = PCK
 
      ATNAME(4) = 'IAU_EROS'
      ATCODE(4) = 10085
      ATCENT(4) = 2000433
      ATCLSS(4) = 2000433
      ATTYPE(4) = PCK

      ATNAME(5) =  'IAU_CALLIRRHOE'
      ATCODE(5) =  10086
      ATCENT(5) =  517
      ATCLSS(5) =  517
      ATTYPE(5) =  PCK
 
      ATNAME(6) =  'IAU_THEMISTO'
      ATCODE(6) =  10087
      ATCENT(6) =  518
      ATCLSS(6) =  518
      ATTYPE(6) =  PCK
 
      ATNAME(7) =  'IAU_MAGACLITE'
      ATCODE(7) =  10088
      ATCENT(7) =  519
      ATCLSS(7) =  519
      ATTYPE(7) =  PCK
 
      ATNAME(8) =  'IAU_TAYGETE'
      ATCODE(8) =  10089
      ATCENT(8) =  520
      ATCLSS(8) =  520
      ATTYPE(8) =  PCK
 
      ATNAME(9) =  'IAU_CHALDENE'
      ATCODE(9) =  10090
      ATCENT(9) =  521
      ATCLSS(9) =  521
      ATTYPE(9) =  PCK
 
      ATNAME(10) =  'IAU_HARPALYKE'
      ATCODE(10) =  10091
      ATCENT(10) =  522
      ATCLSS(10) =  522
      ATTYPE(10) =  PCK
 
      ATNAME(11) =  'IAU_KALYKE'
      ATCODE(11) =  10092
      ATCENT(11) =  523
      ATCLSS(11) =  523
      ATTYPE(11) =  PCK
 
      ATNAME(12) =  'IAU_IOCASTE'
      ATCODE(12) =  10093
      ATCENT(12) =  524
      ATCLSS(12) =  524
      ATTYPE(12) =  PCK
 
      ATNAME(13) =  'IAU_ERINOME'
      ATCODE(13) =  10094
      ATCENT(13) =  525
      ATCLSS(13) =  525
      ATTYPE(13) =  PCK
 
      ATNAME(14) =  'IAU_ISONOE'
      ATCODE(14) =  10095
      ATCENT(14) =  526
      ATCLSS(14) =  526
      ATTYPE(14) =  PCK
 
      ATNAME(15) =  'IAU_PRAXIDIKE'
      ATCODE(15) =  10096
      ATCENT(15) =  527
      ATCLSS(15) =  527
      ATTYPE(15) =  PCK

      NTOCHK = 15

C
C     Check frames one by one.
C
      DO I = 1, NTOCHK

C
C        Set test case name.
C
         CALL TCASE ( 'ZZFDAT Entries for ' // ATNAME(I) )
 
C
C        Check NAME to CODE and CODE to NAME mappings.
C
         CALL NAMFRM ( ATNAME(I), FRCODE )
         CALL FRMNAM ( ATCODE(I), FRNAME )
 
C
C        Check results.
C
         CALL CHCKXC ( .FALSE., ' ', OK )
         CALL CHCKSI ( 'FRCODE', FRCODE, '=', ATCODE(I), 0, OK )
         CALL CHCKSC ( 'FRNAME', FRNAME, '=', ATNAME(I),    OK )
 
C
C        Now check frame attributes as reported by FRINFO.
C
         CALL FRINFO ( ATCODE(I), FRCENT, FRTYPE, FRCLSS, FOUND )
 
C
C        Check results.
C
         CALL CHCKXC ( .FALSE.,  ' ',                        OK )
         CALL CHCKSL ( 'FOUND',  FOUND,  .TRUE.,             OK )
         CALL CHCKSI ( 'CLSSID', FRCLSS, '=',   ATCLSS(I), 0, OK )
         CALL CHCKSI ( 'CLASS',  FRTYPE, '=',   ATTYPE(I), 0, OK )
         CALL CHCKSI ( 'CENT',   FRCENT, '=',   ATCENT(I), 0, OK )

C
C        If it's an 'IAU_' style PCK frame, check that ID returned
C        for the body from the frame name is the same as the frame
C        center ID.
C
         IF ( ATTYPE(I)      .EQ.  PCK   .AND. 
     .        ATNAME(I)(1:4) .EQ. 'IAU_'       ) THEN

            CALL BODN2C ( ATNAME(I)(5:RTRIM(ATNAME(I))), BCODE, FOUND )

C
C           Check results.
C
            CALL CHCKXC ( .FALSE.,  ' ',                       OK )
            CALL CHCKSL ( 'FOUND',  FOUND,  .TRUE.,            OK )
            CALL CHCKSI ( 'BCODE',  BCODE, '=',  ATCENT(I), 0, OK )

         END IF
 
      END DO
C
C     Close out the test family.
C
      CALL T_SUCCESS ( OK )
      RETURN
 
      END
