C$Procedure T_DAFOPN ( Open a new DAF file for testing )
 
      SUBROUTINE T_DAFOPN ( FNAME, OUTBFF, UNIT )
 
C$ Abstract
C
C     Open a new DAF file.
C
C$ Copyright
C
C     Copyright (2001), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     None.
C
C$ Keywords
C
C     TEST ROUTINE
C
C$ Declarations
 
      IMPLICIT NONE
 
      INCLUDE              'zzddhman.inc'
 
      CHARACTER*(*)         FNAME
      INTEGER               OUTBFF
      INTEGER               UNIT
 
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     FNAME      I   Name of the DAF to open.
C     OUTBFF     I   Binary file format code used to create file.
C     UNIT       O   Logical unit used to open the file.
C
C$ Detailed_Input
C
C     FNAME      is the name of the DAF that is to be created.
C
C     OUTBFF     is an integer code that indicates the binary file
C                format targeted for OUTPUT.  Acceptable values
C                are the parameters:
C
C                   BIGI3E
C                   LTLI3E
C                   VAXGFL
C                   VAXDFL
C
C                as defined in the include file 'zzddhman.inc'.
C
C$ Detailed_Output
C
C     UNIT       is the logical unit used to open FNAME.
C
C$ Parameters
C
C     None.
C
C$ Files
C
C     This module opens FNAME with NEW status.
C
C$ Exceptions
C
C     1) SPICE(FILEOPENFAILED) is signaled if the OPEN statement fails.
C
C$ Particulars
C
C     This routine simply opens a new DAF and returns the logical
C     unit associated with the DAF.
C
C     Note: This code is not a model of perfection.  It is hacked
C     together from pieces of code written elsewhere to support
C     creation of non-native binaries for testing purposes only.
C
C$ Examples
C
C     See F_ZZDGDR for usage.
C
C$ Restrictions
C
C     None.
C
C$ Author_and_Institution
C
C     F.S. Turner     (JPL)
C
C$ Literature_References
C
C     None.
C
C$ Version
C
C-    SPICELIB Version 1.0.0, 28-OCT-2001 (FST)
C
C
C-&
 
C
C     SPICELIB Functions
C
      INTEGER               RTRIM
      LOGICAL               RETURN
 
C
C     Local Variables
C
      INTEGER               IOSTAT
 
C
C     Standard SPICE error handling.
C
      IF ( RETURN() ) THEN
         RETURN
      ELSE
         CALL CHKIN ( 'T_DAFOPN' )
      END IF
 
C
C     First kill FNAME.
C
      CALL KILFIL ( FNAME )
 
C
C     Now fetch a logical unit.
C
      CALL GETLUN ( UNIT )
 
C
C     Open the file.
C
      OPEN ( UNIT   = UNIT,
     .       FILE   = FNAME(1:RTRIM(FNAME)),
     .       ACCESS = 'DIRECT',
     .       RECL   = RECL,
     .       STATUS = 'NEW',
     .       IOSTAT = IOSTAT                 )
 
C
C     Check IOSTAT.
C
      IF ( IOSTAT .NE. 0 ) THEN
         CALL SETMSG ( 'Unable to open file, #.  IOSTAT was #.' )
         CALL ERRCH  ( '#', FNAME                               )
         CALL ERRINT ( '#', IOSTAT                              )
         CALL SIGERR ( 'SPICE(FILEOPENFAILED)'                  )
         CALL CHKOUT ( 'T_DAFOPN'                               )
         RETURN
      END IF
 
      CALL CHKOUT ( 'T_DAFOPN' )
      RETURN
 
      END
