C$Procedure      T_PCK08 (Create a test text PCK based on pck00008.tpc )
 
      SUBROUTINE T_PCK08 ( NAMEPC, LOADPC, KEEPPC )
 
C$ Abstract
C
C     Create and if appropriate load a test PCK kernel.  The kernel
C     created by this routine is meant to contain data consistent with
C     the equations implemented in the test utility routine t_pckeq.
C
C$ Required_Reading
C
C     None.
C
C$ Keywords
C
C     TESTING
C
C$ Declarations
 
      IMPLICIT NONE
      CHARACTER*(*)         NAMEPC
      LOGICAL               LOADPC
      LOGICAL               KEEPPC
 
 
C$ Brief_I/O
C
C      VARIABLE  I/O  DESCRIPTION
C      --------  ---  --------------------------------------------------
C      NAMEPC     I   The name of the PC-kernel to create
C      LOADPC     I   Load the PC-kernel if TRUE
C      KEEPPC     I   Keep the PC-kernel if TRUE, else delete it.
C
C$ Detailed_Input
C
C     NAMEPC      is the name of a PC-kernel to create and load if
C                 LOADPC is set to TRUE.  If a PC-kernel of the same
C                 name already exists it is deleted.
C
C
C     LOADPC      is a logical that indicates whether or not the PCK
C                 file should be loaded after it is created.  If it
C                 has the value TRUE the PC-kernel is loaded after
C                 it is created.  Otherwise it is left un-opened.
C
C
C     KEEPPC      is a logical that indicates whether or not the PCK
C                 file should be deleted after it is loaded.  If KEEPPC
C                 is TRUE the file is not deleted.  If KEEPPC is FALSE
C                 the file is deleted after it is loaded.  NOTE that
C                 unless LOADSC is TRUE, the PCK file is not deleted
C                 by this routine.  This routine deletes the PC-kernel
C                 only if it LOADSC is TRUE and KEEPPC is FALSE.
C
C$ Detailed_Output
C
C     None.
C
C$ Parameters
C
C      None.
C
C$ Files
C
C      This routine creates single PC-kernel. See C$ Particulars
C      for more details.
C
C$ Exceptions
C
C     None.
C
C$ Particulars
C
C     This routine creates a planetary constants file for use in
C     testing.  The data in the PCK are those contained in the
C     draft version of the kernel pck00008.tpc as of 2004-09-10.
C
C$ Examples
C
C     This is intended to be used in those instances when you
C     need a well defined PC-kernel for use in testing.  By using
C     this routine you can avoid having to know in advance where
C     a PCK file is on the system where you plan to do your testing.
C
C$ Restrictions
C
C     None.
C
C$ Author_and_Institution
C
C     N.J. Bachman    (JPL)    
C     W.L. Taber      (JPL)
C
C$ Literature_References
C
C     None.
C
C$ Version
C
C-    Test Utilities 1.0.0, 13-FEB-2004 (WLT) (NJB)
C
C-&
 
C$ Index_Entries
C
C     Create test PCK file.
C
C-&
 
C
C     Spicelib Functions
C
      INTEGER               RTRIM
 
C
C     Test Utility Functions
C
      CHARACTER*(16)        BEGDAT
      CHARACTER*(16)        BEGTXT
 
C
C     Local Variables.
C
      INTEGER               LNSIZE
      PARAMETER           ( LNSIZE = 80 )
 
      INTEGER               NLINES
      PARAMETER           ( NLINES = 2605 )
 
      CHARACTER*(LNSIZE)    PCK  ( NLINES )
 
      INTEGER               I
      INTEGER               R
      INTEGER               UNIT
 
      CALL KILFIL ( NAMEPC )
 
      PCK(  1 ) = 'P_constants (PcK) SPICE kernel file'
      PCK(  2 ) = '=========================================='
     .//          '================================='
      PCK(  3 ) = 'Orientation constants for the Sun and plan'
     .//          'ets'
      PCK(  4 ) = '------------------------------------------'
     .//          '--------------'
      PCK(  5 ) = ' '
      PCK(  6 ) = ' '
      PCK(  7 ) = 'Sun'
      PCK(  8 ) = ' '
      PCK(  9 ) = '     Old values:'
      PCK( 10 ) = ' '
      PCK( 11 ) = '        Values are unchanged in the 2000 I'
     .//          'AU report.'
      PCK( 12 ) = ' '
      PCK( 13 ) = '     Current values:'
      PCK( 14 ) = ' '
      PCK( 15 ) = BEGDAT()
      PCK( 16 ) = ' '
      PCK( 17 ) = '        BODY10_POLE_RA         = (  286.13'
     .//          '       0.          0. )'
      PCK( 18 ) = '        BODY10_POLE_DEC        = (   63.87'
     .//          '       0.          0. )'
      PCK( 19 ) = '        BODY10_PM              = (   84.10'
     .//          '      14.18440     0. )'
      PCK( 20 ) = '        BODY10_LONG_AXIS       = (    0.  '
     .//          '                      )'
      PCK( 21 ) = ' '
      PCK( 22 ) = BEGTXT()
      PCK( 23 ) = ' '
      PCK( 24 ) = 'Mercury'
      PCK( 25 ) = ' '
      PCK( 26 ) = '     Old values:'
      PCK( 27 ) = ' '
      PCK( 28 ) = '        body199_pole_ra          = (  281.'
     .//          '01,     -0.033,      0. )'
      PCK( 29 ) = '        body199_pole_dec         = (   61.'
     .//          '45,     -0.005,      0. )'
      PCK( 30 ) = '        body199_pm               = (  329.'
     .//          '55       6.1385025   0. )'
      PCK( 31 ) = ' '
      PCK( 32 ) = '        body199_long_axis        = (    0.'
     .//          '                        )'
      PCK( 33 ) = ' '
      PCK( 34 ) = ' '
      PCK( 35 ) = '     Current values:'
      PCK( 36 ) = ' '
      PCK( 37 ) = BEGDAT()
      PCK( 38 ) = ' '
      PCK( 39 ) = '        BODY199_POLE_RA          = (  281.'
     .//          '01     -0.033      0. )'
      PCK( 40 ) = '        BODY199_POLE_DEC         = (   61.'
     .//          '45     -0.005      0. )'
      PCK( 41 ) = '        BODY199_PM               = (  329.'
     .//          '548     6.1385025  0. )'
      PCK( 42 ) = ' '
      PCK( 43 ) = '        BODY199_LONG_AXIS        = (    0.'
     .//          '                        )'
      PCK( 44 ) = ' '
      PCK( 45 ) = BEGTXT()
      PCK( 46 ) = ' '
      PCK( 47 ) = ' '
      PCK( 48 ) = 'Venus'
      PCK( 49 ) = ' '
      PCK( 50 ) = '     Old values:'
      PCK( 51 ) = ' '
      PCK( 52 ) = '        Values are unchanged in the 2000 I'
     .//          'AU report.'
      PCK( 53 ) = ' '
      PCK( 54 ) = '     Current values:'
      PCK( 55 ) = ' '
      PCK( 56 ) = BEGDAT()
      PCK( 57 ) = ' '
      PCK( 58 ) = '        BODY299_POLE_RA          = (  272.'
     .//          '76       0.          0. )'
      PCK( 59 ) = '        BODY299_POLE_DEC         = (   67.'
     .//          '16       0.          0. )'
      PCK( 60 ) = '        BODY299_PM               = (  160.'
     .//          '20      -1.4813688   0. )'
      PCK( 61 ) = ' '
      PCK( 62 ) = '        BODY299_LONG_AXIS        = (    0.'
     .//          '                        )'
      PCK( 63 ) = ' '
      PCK( 64 ) = BEGTXT()
      PCK( 65 ) = ' '
      PCK( 66 ) = ' '
      PCK( 67 ) = 'Earth'
      PCK( 68 ) = ' '
      PCK( 69 ) = '     Old values:'
      PCK( 70 ) = ' '
      PCK( 71 ) = '        Values shown are from the 1997 IAU'
     .//          ' report.'
      PCK( 72 ) = ' '
      PCK( 73 ) = '           body399_pole_ra        = (    0'
     .//          '.      -0.641         0. )'
      PCK( 74 ) = '           body399_pole_dec       = (   90'
     .//          '.      -0.557         0. )'
      PCK( 75 ) = '           body399_pm             = (  190'
     .//          '.16   360.9856235     0. )'
      PCK( 76 ) = '           body399_long_axis      = (    0'
     .//          '.                        )'
      PCK( 77 ) = ' '
      PCK( 78 ) = '        Nutation precession angles are unc'
     .//          'hanged in the 2000 report.'
      PCK( 79 ) = ' '
      PCK( 80 ) = ' '
      PCK( 81 ) = '     Current values:'
      PCK( 82 ) = ' '
      PCK( 83 ) = BEGDAT()
      PCK( 84 ) = ' '
      PCK( 85 ) = '        BODY399_POLE_RA        = (    0.  '
     .//          '    -0.641         0. )'
      PCK( 86 ) = '        BODY399_POLE_DEC       = (   90.  '
     .//          '    -0.557         0. )'
      PCK( 87 ) = '        BODY399_PM             = (  190.14'
     .//          '7  360.9856235     0. )'
      PCK( 88 ) = '        BODY399_LONG_AXIS      = (    0.  '
     .//          '                      )'
      PCK( 89 ) = ' '
      PCK( 90 ) = BEGTXT()
      PCK( 91 ) = ' '
      PCK( 92 ) = ' '
      PCK( 93 ) = '        Nutation precession angles for the'
     .//          ' Earth-Moon system:'
      PCK( 94 ) = ' '
      PCK( 95 ) = '           The linear coefficients have be'
     .//          'en scaled up from degrees/day'
      PCK( 96 ) = '           to degrees/century, because the'
     .//          ' SPICELIB PCK reader expects'
      PCK( 97 ) = '           these units.  The original cons'
     .//          'tants were:'
      PCK( 98 ) = ' '
      PCK( 99 ) = '                                    125.04'
     .//          '5D0   -0.0529921D0'
      PCK( 100 ) = '                                    250.0'
     .//           '89D0   -0.1059842D0'
      PCK( 101 ) = '                                    260.0'
     .//           '08D0   13.0120009D0'
      PCK( 102 ) = '                                    176.6'
     .//           '25D0   13.3407154D0'
      PCK( 103 ) = '                                    357.5'
     .//           '29D0    0.9856003D0'
      PCK( 104 ) = '                                    311.5'
     .//           '89D0   26.4057084D0'
      PCK( 105 ) = '                                    134.9'
     .//           '63D0   13.0649930D0'
      PCK( 106 ) = '                                    276.6'
     .//           '17D0    0.3287146D0'
      PCK( 107 ) = '                                     34.2'
     .//           '26D0    1.7484877D0'
      PCK( 108 ) = '                                     15.1'
     .//           '34D0   -0.1589763D0'
      PCK( 109 ) = '                                    119.7'
     .//           '43D0    0.0036096D0'
      PCK( 110 ) = '                                    239.9'
     .//           '61D0    0.1643573D0'
      PCK( 111 ) = '                                     25.0'
     .//           '53D0   12.9590088D0'
      PCK( 112 ) = ' '
      PCK( 113 ) = ' '
      PCK( 114 ) = BEGDAT()
      PCK( 115 ) = ' '
      PCK( 116 ) = ' '
      PCK( 117 ) = '        BODY3_NUT_PREC_ANGLES  = (  125.0'
     .//           '45         -1935.5364525000'
      PCK( 118 ) = '                                    250.0'
     .//           '89         -3871.0729050000'
      PCK( 119 ) = '                                    260.0'
     .//           '08        475263.3328725000'
      PCK( 120 ) = '                                    176.6'
     .//           '25        487269.6299850000'
      PCK( 121 ) = '                                    357.5'
     .//           '29         35999.0509575000'
      PCK( 122 ) = '                                    311.5'
     .//           '89        964468.4993100001'
      PCK( 123 ) = '                                    134.9'
     .//           '63        477198.8693250000'
      PCK( 124 ) = '                                    276.6'
     .//           '17         12006.3007650000'
      PCK( 125 ) = '                                     34.2'
     .//           '26         63863.5132425000'
      PCK( 126 ) = '                                     15.1'
     .//           '34         -5806.6093575000'
      PCK( 127 ) = '                                    119.7'
     .//           '43           131.8406400000'
      PCK( 128 ) = '                                    239.9'
     .//           '61          6003.1503825000'
      PCK( 129 ) = '                                     25.0'
     .//           '53        473327.7964200000 )'
      PCK( 130 ) = ' '
      PCK( 131 ) = ' '
      PCK( 132 ) = BEGTXT()
      PCK( 133 ) = ' '
      PCK( 134 ) = ' '
      PCK( 135 ) = '        Northern hemisphere projection of'
     .//           ' the Earth''s magnetic dipole:'
      PCK( 136 ) = '        Coordinates are planetocentric.  '
     .//           'Values are from [5].'
      PCK( 137 ) = ' '
      PCK( 138 ) = BEGDAT()
      PCK( 139 ) = ' '
      PCK( 140 ) = '        BODY399_MAG_NORTH_POLE_LON  =  ( '
     .//           '-69.761 )'
      PCK( 141 ) = '        BODY399_MAG_NORTH_POLE_LAT  =  ( '
     .//           ' 78.565 )'
      PCK( 142 ) = ' '
      PCK( 143 ) = BEGTXT()
      PCK( 144 ) = ' '
      PCK( 145 ) = ' '
      PCK( 146 ) = 'Mars'
      PCK( 147 ) = ' '
      PCK( 148 ) = '     Old values:'
      PCK( 149 ) = ' '
      PCK( 150 ) = '        Values shown are from the 1997 IA'
     .//           'U report.'
      PCK( 151 ) = ' '
      PCK( 152 ) = '           body499_pole_ra          = (  '
     .//           '317.681     -0.108       0.  )'
      PCK( 153 ) = '           body499_pole_dec         = (  '
     .//           ' 52.886     -0.061       0.  )'
      PCK( 154 ) = '           body499_pm               = (  '
     .//           '176.901    350.8919830   0.  )'
      PCK( 155 ) = ' '
      PCK( 156 ) = '        Nutation precession angles are un'
     .//           'changed in the 2000 IAU report.'
      PCK( 157 ) = ' '
      PCK( 158 ) = '     Current values:'
      PCK( 159 ) = ' '
      PCK( 160 ) = BEGDAT()
      PCK( 161 ) = ' '
      PCK( 162 ) = '        BODY499_POLE_RA          = (  317'
     .//           '.68143   -0.1061      0.  )'
      PCK( 163 ) = '        BODY499_POLE_DEC         = (   52'
     .//           '.88650   -0.0609      0.  )'
      PCK( 164 ) = '        BODY499_PM               = (  176'
     .//           '.630    350.89198226  0.  )'
      PCK( 165 ) = ' '
      PCK( 166 ) = BEGTXT()
      PCK( 167 ) = ' '
      PCK( 168 ) = '        Source [3] specifies the followin'
     .//           'g value for the lambda_a term'
      PCK( 169 ) = '        (BODY4_LONG_AXIS ) for Mars.'
      PCK( 170 ) = ' '
      PCK( 171 ) = '        This term is the POSITIVE WEST LO'
     .//           'NGITUDE, measured from the prime'
      PCK( 172 ) = '        meridian, of the longest axis of '
     .//           'the ellipsoid representing the ``mean'
      PCK( 173 ) = '        planet surface,'''' as the articl'
     .//           'e states.'
      PCK( 174 ) = ' '
      PCK( 175 ) = '           body499_long_axis        = (  '
     .//           '110.  )'
      PCK( 176 ) = ' '
      PCK( 177 ) = '        Source [4] specifies the lambda_a'
     .//           ' value'
      PCK( 178 ) = ' '
      PCK( 179 ) = '           body499_long_axis        = (  '
     .//           '104.9194  )'
      PCK( 180 ) = ' '
      PCK( 181 ) = '        We list these lambda_a values for'
     .//           ' completeness. The IAU gives equal'
      PCK( 182 ) = '        values for both equatorial radii,'
     .//           ' so the lambda_a offset does not'
      PCK( 183 ) = '        apply to the IAU model.'
      PCK( 184 ) = ' '
      PCK( 185 ) = '        The 2000 IAU report defines M2, t'
     .//           'he second nutation precession angle,'
      PCK( 186 ) = '        by:'
      PCK( 187 ) = ' '
      PCK( 188 ) = '                                         '
     .//           '       2'
      PCK( 189 ) = '           192.93  +  1128.4096700 d  +  '
     .//           '8.864 T'
      PCK( 190 ) = ' '
      PCK( 191 ) = '        We truncate the M2 series to a li'
     .//           'near expression, because the PCK'
      PCK( 192 ) = '        software cannot handle the quadra'
     .//           'tic term.'
      PCK( 193 ) = ' '
      PCK( 194 ) = '        Again, the linear terms are scale'
     .//           'd by 36525.0:'
      PCK( 195 ) = ' '
      PCK( 196 ) = '            -0.4357640000000000       -->'
     .//           '     -15916.28010000000'
      PCK( 197 ) = '          1128.409670000000           -->'
     .//           '   41215163.19675000'
      PCK( 198 ) = '            -1.8151000000000000E-02   -->'
     .//           '       -662.9652750000000'
      PCK( 199 ) = ' '
      PCK( 200 ) = '        We also introduce a fourth nutati'
     .//           'on precession angle, which'
      PCK( 201 ) = '        is the pi/2-complement of the thi'
     .//           'rd angle.  This angle is used'
      PCK( 202 ) = '        in computing the prime meridian l'
     .//           'ocation for Deimos.  See the'
      PCK( 203 ) = '        discussion of this angle below in'
     .//           ' the section containing orientation'
      PCK( 204 ) = '        constants for Deimos.'
      PCK( 205 ) = ' '
      PCK( 206 ) = BEGDAT()
      PCK( 207 ) = ' '
      PCK( 208 ) = '        BODY4_NUT_PREC_ANGLES  = (  169.5'
     .//           '1     -15916.2801'
      PCK( 209 ) = '                                    192.9'
     .//           '3   41215163.19675'
      PCK( 210 ) = '                                     53.4'
     .//           '7       -662.965275'
      PCK( 211 ) = '                                     36.5'
     .//           '3        662.965275  )'
      PCK( 212 ) = ' '
      PCK( 213 ) = BEGTXT()
      PCK( 214 ) = ' '
      PCK( 215 ) = ' '
      PCK( 216 ) = 'Jupiter'
      PCK( 217 ) = ' '
      PCK( 218 ) = '     Old values:'
      PCK( 219 ) = ' '
      PCK( 220 ) = '        body599_pole_ra        = (   268.'
     .//           '05    -0.009      0.  )'
      PCK( 221 ) = '        body599_pole_dec       = (   +64.'
     .//           '49    +0.003      0.  )'
      PCK( 222 ) = '        body599_pm             = (   284.'
     .//           '95  +870.5366420  0.  )'
      PCK( 223 ) = '        body599_long_axis      = (     0.'
     .//           '                      )'
      PCK( 224 ) = ' '
      PCK( 225 ) = '        body5_nut_prec_angles  = (   73.3'
     .//           '2   +91472.9'
      PCK( 226 ) = '                                     24.6'
     .//           '2   +45137.2'
      PCK( 227 ) = '                                    283.9'
     .//           '0    +4850.7'
      PCK( 228 ) = '                                    355.8'
     .//           '0    +1191.3'
      PCK( 229 ) = '                                    119.9'
     .//           '0     +262.1'
      PCK( 230 ) = '                                    229.8'
     .//           '0      +64.3'
      PCK( 231 ) = '                                    352.2'
     .//           '5    +2382.6'
      PCK( 232 ) = '                                    113.3'
     .//           '5    +6070.0'
      PCK( 233 ) = '                                    146.6'
     .//           '4  +182945.8'
      PCK( 234 ) = '                                     49.2'
     .//           '4   +90274.4  )'
      PCK( 235 ) = ' '
      PCK( 236 ) = '     Current values:'
      PCK( 237 ) = ' '
      PCK( 238 ) = '        The number of nutation precession'
     .//           ' angles is ten. The ninth and'
      PCK( 239 ) = '        tenth are twice the first and sec'
     .//           'ond, respectively.'
      PCK( 240 ) = ' '
      PCK( 241 ) = BEGDAT()
      PCK( 242 ) = ' '
      PCK( 243 ) = ' '
      PCK( 244 ) = '        BODY599_POLE_RA        = (   268.'
     .//           '05      -0.009       0. )'
      PCK( 245 ) = '        BODY599_POLE_DEC       = (    64.'
     .//           '49       0.003       0. )'
      PCK( 246 ) = '        BODY599_PM             = (   284.'
     .//           '95     870.5366420   0. )'
      PCK( 247 ) = '        BODY599_LONG_AXIS      = (     0.'
     .//           '                        )'
      PCK( 248 ) = ' '
      PCK( 249 ) = '        BODY5_NUT_PREC_ANGLES  = (    73.'
     .//           '32   91472.9'
      PCK( 250 ) = '                                      24.'
     .//           '62   45137.2'
      PCK( 251 ) = '                                     283.'
     .//           '90    4850.7'
      PCK( 252 ) = '                                     355.'
     .//           '80    1191.3'
      PCK( 253 ) = '                                     119.'
     .//           '90     262.1'
      PCK( 254 ) = '                                     229.'
     .//           '80      64.3'
      PCK( 255 ) = '                                     352.'
     .//           '35    2382.6'
      PCK( 256 ) = '                                     113.'
     .//           '35    6070.0'
      PCK( 257 ) = '                                     146.'
     .//           '64  182945.8'
      PCK( 258 ) = '                                      49.'
     .//           '24   90274.4  )'
      PCK( 259 ) = BEGTXT()
      PCK( 260 ) = ' '
      PCK( 261 ) = ' '
      PCK( 262 ) = 'Saturn'
      PCK( 263 ) = ' '
      PCK( 264 ) = '     Old values:'
      PCK( 265 ) = ' '
      PCK( 266 ) = '        Values are unchanged in the 2000 '
     .//           'IAU report.'
      PCK( 267 ) = ' '
      PCK( 268 ) = '     Current values:'
      PCK( 269 ) = ' '
      PCK( 270 ) = BEGDAT()
      PCK( 271 ) = ' '
      PCK( 272 ) = '        BODY699_POLE_RA        = (    40.'
     .//           '589    -0.036      0.  )'
      PCK( 273 ) = '        BODY699_POLE_DEC       = (    83.'
     .//           '537    -0.004      0.  )'
      PCK( 274 ) = '        BODY699_PM             = (    38.'
     .//           '90    810.7939024  0.  )'
      PCK( 275 ) = '        BODY699_LONG_AXIS      = (     0.'
     .//           '                       )'
      PCK( 276 ) = ' '
      PCK( 277 ) = BEGTXT()
      PCK( 278 ) = ' '
      PCK( 279 ) = '        The first seven angles given here'
     .//           ' are the angles S1'
      PCK( 280 ) = '        through S7 from the 2000 report; '
     .//           'the eighth and'
      PCK( 281 ) = '        ninth angles are 2*S1 and 2*S2, r'
     .//           'espectively.'
      PCK( 282 ) = ' '
      PCK( 283 ) = ' '
      PCK( 284 ) = BEGDAT()
      PCK( 285 ) = ' '
      PCK( 286 ) = '        BODY6_NUT_PREC_ANGLES  = (  353.3'
     .//           '2   75706.7'
      PCK( 287 ) = '                                     28.7'
     .//           '2   75706.7'
      PCK( 288 ) = '                                    177.4'
     .//           '0  -36505.5'
      PCK( 289 ) = '                                    300.0'
     .//           '0   -7225.9'
      PCK( 290 ) = '                                    316.4'
     .//           '5     506.2'
      PCK( 291 ) = '                                    345.2'
     .//           '0   -1016.3'
      PCK( 292 ) = '                                     29.8'
     .//           '0     -52.1'
      PCK( 293 ) = '                                    706.6'
     .//           '4  151413.4'
      PCK( 294 ) = '                                     57.4'
     .//           '4  151413.4  )'
      PCK( 295 ) = BEGTXT()
      PCK( 296 ) = ' '
      PCK( 297 ) = ' '
      PCK( 298 ) = 'Uranus'
      PCK( 299 ) = ' '
      PCK( 300 ) = '     Old values:'
      PCK( 301 ) = ' '
      PCK( 302 ) = '        Values are unchanged in the 2000 '
     .//           'IAU report.'
      PCK( 303 ) = ' '
      PCK( 304 ) = '     Current values:'
      PCK( 305 ) = ' '
      PCK( 306 ) = BEGDAT()
      PCK( 307 ) = ' '
      PCK( 308 ) = '        BODY799_POLE_RA        = (  257.3'
     .//           '11     0.         0.  )'
      PCK( 309 ) = '        BODY799_POLE_DEC       = (  -15.1'
     .//           '75     0.         0.  )'
      PCK( 310 ) = '        BODY799_PM             = (  203.8'
     .//           '1   -501.1600928  0.  )'
      PCK( 311 ) = '        BODY799_LONG_AXIS      = (    0. '
     .//           '                      )'
      PCK( 312 ) = ' '
      PCK( 313 ) = BEGTXT()
      PCK( 314 ) = ' '
      PCK( 315 ) = '        The first 16 angles given here ar'
     .//           'e the angles U1'
      PCK( 316 ) = '        through U16 from the 2000 report;'
     .//           ' the 17th and'
      PCK( 317 ) = '        18th angles are 2*U11 and 2*U12, '
     .//           'respectively.'
      PCK( 318 ) = ' '
      PCK( 319 ) = BEGDAT()
      PCK( 320 ) = ' '
      PCK( 321 ) = '        BODY7_NUT_PREC_ANGLES  = (  115.7'
     .//           '5   54991.87'
      PCK( 322 ) = '                                    141.6'
     .//           '9   41887.66'
      PCK( 323 ) = '                                    135.0'
     .//           '3   29927.35'
      PCK( 324 ) = '                                     61.7'
     .//           '7   25733.59'
      PCK( 325 ) = '                                    249.3'
     .//           '2   24471.46'
      PCK( 326 ) = '                                     43.8'
     .//           '6   22278.41'
      PCK( 327 ) = '                                     77.6'
     .//           '6   20289.42'
      PCK( 328 ) = '                                    157.3'
     .//           '6   16652.76'
      PCK( 329 ) = '                                    101.8'
     .//           '1   12872.63'
      PCK( 330 ) = '                                    138.6'
     .//           '4    8061.81'
      PCK( 331 ) = '                                    102.2'
     .//           '3   -2024.22'
      PCK( 332 ) = '                                    316.4'
     .//           '1    2863.96'
      PCK( 333 ) = '                                    304.0'
     .//           '1     -51.94'
      PCK( 334 ) = '                                    308.7'
     .//           '1     -93.17'
      PCK( 335 ) = '                                    340.8'
     .//           '2     -75.32'
      PCK( 336 ) = '                                    259.1'
     .//           '4    -504.81'
      PCK( 337 ) = '                                    204.4'
     .//           '6   -4048.44'
      PCK( 338 ) = '                                    632.8'
     .//           '2    5727.92     )'
      PCK( 339 ) = ' '
      PCK( 340 ) = BEGTXT()
      PCK( 341 ) = ' '
      PCK( 342 ) = ' '
      PCK( 343 ) = ' '
      PCK( 344 ) = 'Neptune'
      PCK( 345 ) = ' '
      PCK( 346 ) = '     Old values:'
      PCK( 347 ) = ' '
      PCK( 348 ) = '        Values are unchanged in the 2000 '
     .//           'IAU report.  However,'
      PCK( 349 ) = '        the kernel variables used to stor'
     .//           'e the values have changed.'
      PCK( 350 ) = '        See note immediately below.'
      PCK( 351 ) = ' '
      PCK( 352 ) = '     Current values:'
      PCK( 353 ) = ' '
      PCK( 354 ) = '        The kernel variables'
      PCK( 355 ) = ' '
      PCK( 356 ) = '           BODY899_NUT_PREC_RA'
      PCK( 357 ) = '           BODY899_NUT_PREC_DEC'
      PCK( 358 ) = '           BODY899_NUT_PREC_PM'
      PCK( 359 ) = ' '
      PCK( 360 ) = '        are new in this PCK version (date'
     .//           'd October 17, 2003).'
      PCK( 361 ) = '        These variables capture trigonmet'
     .//           'ric terms in the expressions'
      PCK( 362 ) = '        for Neptune''s pole direction and'
     .//           ' prime meridian location.'
      PCK( 363 ) = '        Version N0057 of the SPICE Toolki'
     .//           't uses these variables;'
      PCK( 364 ) = '        earlier versions can read them bu'
     .//           't ignore them when'
      PCK( 365 ) = '        computing Neptune''s orientation.'
      PCK( 366 ) = ' '
      PCK( 367 ) = BEGDAT()
      PCK( 368 ) = ' '
      PCK( 369 ) = '           BODY899_POLE_RA        = (  29'
     .//           '9.36     0.         0. )'
      PCK( 370 ) = '           BODY899_POLE_DEC       = (   4'
     .//           '3.46     0.         0. )'
      PCK( 371 ) = '           BODY899_PM             = (  25'
     .//           '3.18   536.3128492  0. )'
      PCK( 372 ) = '           BODY899_LONG_AXIS      = (    '
     .//           '0.                     )'
      PCK( 373 ) = ' '
      PCK( 374 ) = ' '
      PCK( 375 ) = '           BODY899_NUT_PREC_RA    = (  0.'
     .//           '70 0. 0. 0. 0. 0. 0. 0. )'
      PCK( 376 ) = '           BODY899_NUT_PREC_DEC   = ( -0.'
     .//           '51 0. 0. 0. 0. 0. 0. 0. )'
      PCK( 377 ) = '           BODY899_NUT_PREC_PM    = ( -0.'
     .//           '48 0. 0. 0. 0. 0. 0. 0. )'
      PCK( 378 ) = ' '
      PCK( 379 ) = BEGTXT()
      PCK( 380 ) = ' '
      PCK( 381 ) = '           The 2000 report defines the nu'
     .//           'tation precession angles'
      PCK( 382 ) = ' '
      PCK( 383 ) = '              N, N1, N2, ... , N7'
      PCK( 384 ) = ' '
      PCK( 385 ) = '           and also uses the multiples of'
     .//           ' N1 and N7'
      PCK( 386 ) = ' '
      PCK( 387 ) = '              2*N1'
      PCK( 388 ) = ' '
      PCK( 389 ) = '           and'
      PCK( 390 ) = ' '
      PCK( 391 ) = '              2*N7, 3*N7, ..., 9*N7'
      PCK( 392 ) = ' '
      PCK( 393 ) = '           In this file, we treat the ang'
     .//           'les and their multiples as'
      PCK( 394 ) = '           separate angles.  In the kerne'
     .//           'l variable'
      PCK( 395 ) = ' '
      PCK( 396 ) = '              BODY8_NUT_PREC_ANGLES'
      PCK( 397 ) = ' '
      PCK( 398 ) = '           the order of the angles is'
      PCK( 399 ) = ' '
      PCK( 400 ) = '              N, N1, N2, ... , N7, 2*N1, '
     .//           '2*N7, 3*N7, ..., 9*N7'
      PCK( 401 ) = ' '
      PCK( 402 ) = '           Each angle is defined by a lin'
     .//           'ear polynomial, so two'
      PCK( 403 ) = '           consecutive array elements are'
     .//           ' allocated for each'
      PCK( 404 ) = '           angle.  The first term of each'
     .//           ' pair is the constant term,'
      PCK( 405 ) = '           the second is the linear term.'
      PCK( 406 ) = ' '
      PCK( 407 ) = BEGDAT()
      PCK( 408 ) = ' '
      PCK( 409 ) = '              BODY8_NUT_PREC_ANGLES = (  '
     .//           ' 357.85         52.316'
      PCK( 410 ) = '                                         '
     .//           ' 323.92      62606.6'
      PCK( 411 ) = '                                         '
     .//           ' 220.51      55064.2'
      PCK( 412 ) = '                                         '
     .//           ' 354.27      46564.5'
      PCK( 413 ) = '                                         '
     .//           '  75.31      26109.4'
      PCK( 414 ) = '                                         '
     .//           '  35.36      14325.4'
      PCK( 415 ) = '                                         '
     .//           ' 142.61       2824.6'
      PCK( 416 ) = '                                         '
     .//           ' 177.85         52.316'
      PCK( 417 ) = '                                         '
     .//           ' 647.840    125213.200'
      PCK( 418 ) = '                                         '
     .//           ' 355.700       104.632'
      PCK( 419 ) = '                                         '
     .//           ' 533.550       156.948'
      PCK( 420 ) = '                                         '
     .//           ' 711.400       209.264'
      PCK( 421 ) = '                                         '
     .//           ' 889.250       261.580'
      PCK( 422 ) = '                                         '
     .//           '1067.100       313.896'
      PCK( 423 ) = '                                         '
     .//           '1244.950       366.212'
      PCK( 424 ) = '                                         '
     .//           '1422.800       418.528'
      PCK( 425 ) = '                                         '
     .//           '1600.650       470.844   )'
      PCK( 426 ) = ' '
      PCK( 427 ) = BEGTXT()
      PCK( 428 ) = ' '
      PCK( 429 ) = ' '
      PCK( 430 ) = ' '
      PCK( 431 ) = 'Pluto'
      PCK( 432 ) = ' '
      PCK( 433 ) = '     Old values:'
      PCK( 434 ) = ' '
      PCK( 435 ) = '         Values are unchanged in the 2000'
     .//           ' IAU report.'
      PCK( 436 ) = ' '
      PCK( 437 ) = '     Current values:'
      PCK( 438 ) = ' '
      PCK( 439 ) = BEGDAT()
      PCK( 440 ) = ' '
      PCK( 441 ) = '        BODY999_POLE_RA        = (  313.0'
     .//           '2    0.         0.   )'
      PCK( 442 ) = '        BODY999_POLE_DEC       = (    9.0'
     .//           '9    0.         0.   )'
      PCK( 443 ) = '        BODY999_PM             = (  236.7'
     .//           '7  -56.3623195  0.   )'
      PCK( 444 ) = '        BODY999_LONG_AXIS      = (    0. '
     .//           '                    )'
      PCK( 445 ) = ' '
      PCK( 446 ) = BEGTXT()
      PCK( 447 ) = ' '
      PCK( 448 ) = ' '
      PCK( 449 ) = ' '
      PCK( 450 ) = ' '
      PCK( 451 ) = 'Orientation constants for the satellites'
      PCK( 452 ) = '-----------------------------------------'
     .//           '---------------'
      PCK( 453 ) = ' '
      PCK( 454 ) = ' '
      PCK( 455 ) = 'Moon'
      PCK( 456 ) = ' '
      PCK( 457 ) = '     Old values:'
      PCK( 458 ) = ' '
      PCK( 459 ) = '        Values are from the 1988 IAU repo'
     .//           'rt.'
      PCK( 460 ) = ' '
      PCK( 461 ) = '        body301_pole_ra        = (  270.0'
     .//           '00    0.           0. )'
      PCK( 462 ) = '        body301_pole_dec       = (   66.5'
     .//           '34    0.           0. )'
      PCK( 463 ) = '        body301_pm             = (   38.3'
     .//           '14   13.1763581    0. )'
      PCK( 464 ) = '        body301_long_axis      = (    0. '
     .//           '                      )'
      PCK( 465 ) = ' '
      PCK( 466 ) = '        body301_nut_prec_ra  = (  -3.878 '
     .//           ' -0.120   0.070  -0.017   0.    )'
      PCK( 467 ) = '        body301_nut_prec_dec = (   1.543 '
     .//           '  0.024  -0.028   0.007   0.    )'
      PCK( 468 ) = '        body301_nut_prec_pm  = (   3.558 '
     .//           '  0.121  -0.064   0.016   0.025 )'
      PCK( 469 ) = ' '
      PCK( 470 ) = '        BODY301_POLE_RA      = (  269.994'
     .//           '9    0.0031        0.        )'
      PCK( 471 ) = '        BODY301_POLE_DEC     = (   66.539'
     .//           '2    0.0130        0.        )'
      PCK( 472 ) = '        BODY301_PM           = (   38.321'
     .//           '3   13.17635815   -1.4D-12   )'
      PCK( 473 ) = '        BODY301_LONG_AXIS    = (    0.   '
     .//           '                             )'
      PCK( 474 ) = ' '
      PCK( 475 ) = '        BODY301_NUT_PREC_RA  = (  -3.8787'
     .//           '   -0.1204   0.0700  -0.0172'
      PCK( 476 ) = '                                   0.    '
     .//           '    0.0072   0.       0.'
      PCK( 477 ) = '                                   0.    '
     .//           '   -0.0052   0.       0.'
      PCK( 478 ) = '                                   0.0043'
     .//           '                             )'
      PCK( 479 ) = ' '
      PCK( 480 ) = '        BODY301_NUT_PREC_DEC = (   1.5419'
     .//           '   0.0239   -0.0278   0.0068'
      PCK( 481 ) = '                                   0.    '
     .//           '  -0.0029    0.0009   0.'
      PCK( 482 ) = '                                   0.    '
     .//           '   0.0008    0.       0.'
      PCK( 483 ) = '                                  -0.0009'
     .//           '                             )'
      PCK( 484 ) = ' '
      PCK( 485 ) = '        BODY301_NUT_PREC_PM  = (  3.5610 '
     .//           '   0.1208   -0.0642   0.0158'
      PCK( 486 ) = '                                  0.0252 '
     .//           '  -0.0066   -0.0047  -0.0046'
      PCK( 487 ) = '                                  0.0028 '
     .//           '   0.0052    0.0040   0.0019'
      PCK( 488 ) = '                                 -0.0044 '
     .//           '                             )'
      PCK( 489 ) = ' '
      PCK( 490 ) = '     New values:'
      PCK( 491 ) = ' '
      PCK( 492 ) = BEGDAT()
      PCK( 493 ) = ' '
      PCK( 494 ) = ' '
      PCK( 495 ) = ' '
      PCK( 496 ) = ' '
      PCK( 497 ) = ' '
      PCK( 498 ) = '        BODY301_POLE_RA      = (  269.994'
     .//           '9        0.0031        0.      )'
      PCK( 499 ) = '        BODY301_POLE_DEC     = (   66.539'
     .//           '2        0.0130        0.      )'
      PCK( 500 ) = '        BODY301_PM           = (   38.321'
     .//           '3       13.17635815   -1.4D-12 )'
      PCK( 501 ) = '        BODY301_LONG_AXIS    = (    0.   '
     .//           '                               )'
      PCK( 502 ) = ' '
      PCK( 503 ) = '        BODY301_NUT_PREC_RA  = (   -3.878'
     .//           '7   -0.1204   0.0700   -0.0172'
      PCK( 504 ) = '                                    0.0  '
     .//           '     0.0072   0.0       0.0'
      PCK( 505 ) = '                                    0.0  '
     .//           '    -0.0052   0.0       0.0'
      PCK( 506 ) = '                                    0.004'
     .//           '3                              )'
      PCK( 507 ) = ' '
      PCK( 508 ) = '        BODY301_NUT_PREC_DEC = (   1.5419'
     .//           '     0.0239  -0.0278    0.0068'
      PCK( 509 ) = '                                   0.0   '
     .//           '    -0.0029   0.0009    0.0'
      PCK( 510 ) = '                                   0.0   '
     .//           '     0.0008   0.0       0.0'
      PCK( 511 ) = '                                  -0.0009'
     .//           '                               )'
      PCK( 512 ) = ' '
      PCK( 513 ) = '        BODY301_NUT_PREC_PM  = (   3.5610'
     .//           '     0.1208  -0.0642    0.0158'
      PCK( 514 ) = '                                   0.0252'
     .//           '    -0.0066  -0.0047   -0.0046'
      PCK( 515 ) = '                                   0.0028'
     .//           '     0.0052   0.0040    0.0019'
      PCK( 516 ) = '                                  -0.0044'
     .//           '                               )'
      PCK( 517 ) = BEGTXT()
      PCK( 518 ) = ' '
      PCK( 519 ) = ' '
      PCK( 520 ) = ' '
      PCK( 521 ) = 'Satellites of Mars'
      PCK( 522 ) = ' '
      PCK( 523 ) = ' '
      PCK( 524 ) = '     Phobos'
      PCK( 525 ) = ' '
      PCK( 526 ) = '          Old values:'
      PCK( 527 ) = ' '
      PCK( 528 ) = '             Values are unchanged in the '
     .//           '2000 IAU report.'
      PCK( 529 ) = ' '
      PCK( 530 ) = '          Current values:'
      PCK( 531 ) = ' '
      PCK( 532 ) = '            The quadratic prime meridian '
     .//           'term is scaled by 1/36525**2:'
      PCK( 533 ) = ' '
      PCK( 534 ) = '               8.864000000000000   --->  '
     .//           ' 6.6443009930565219E-09'
      PCK( 535 ) = ' '
      PCK( 536 ) = BEGDAT()
      PCK( 537 ) = ' '
      PCK( 538 ) = '          BODY401_POLE_RA  = ( 317.68    '
     .//           '-0.108     0.                     )'
      PCK( 539 ) = '          BODY401_POLE_DEC = (  52.90    '
     .//           '-0.061     0.                     )'
      PCK( 540 ) = '          BODY401_PM       = (  35.06  11'
     .//           '28.8445850 6.6443009930565219E-09 )'
      PCK( 541 ) = ' '
      PCK( 542 ) = '          BODY401_LONG_AXIS     = (    0.'
     .//           '       )'
      PCK( 543 ) = ' '
      PCK( 544 ) = '          BODY401_NUT_PREC_RA   = (   1.7'
     .//           '9    0.    0.   0. )'
      PCK( 545 ) = '          BODY401_NUT_PREC_DEC  = (  -1.0'
     .//           '8    0.    0.   0. )'
      PCK( 546 ) = '          BODY401_NUT_PREC_PM   = (  -1.4'
     .//           '2   -0.78  0.   0. )'
      PCK( 547 ) = ' '
      PCK( 548 ) = ' '
      PCK( 549 ) = BEGTXT()
      PCK( 550 ) = ' '
      PCK( 551 ) = ' '
      PCK( 552 ) = '     Deimos'
      PCK( 553 ) = ' '
      PCK( 554 ) = '        Old values:'
      PCK( 555 ) = ' '
      PCK( 556 ) = '           Values are unchanged in the 20'
     .//           '00 IAU report.'
      PCK( 557 ) = ' '
      PCK( 558 ) = ' '
      PCK( 559 ) = '        New values:'
      PCK( 560 ) = ' '
      PCK( 561 ) = '           The Deimos prime meridian expr'
     .//           'ession is:'
      PCK( 562 ) = ' '
      PCK( 563 ) = ' '
      PCK( 564 ) = '                                         '
     .//           '            2'
      PCK( 565 ) = '              W = 79.41  +  285.1618970 d'
     .//           '  -  0.520 T  -  2.58 sin M'
      PCK( 566 ) = '                                         '
     .//           '                           3'
      PCK( 567 ) = ' '
      PCK( 568 ) = '                                         '
     .//           '              +  0.19 cos M .'
      PCK( 569 ) = '                                         '
     .//           '                           3'
      PCK( 570 ) = ' '
      PCK( 571 ) = ' '
      PCK( 572 ) = '           At the present time, the PCK k'
     .//           'ernel software (the routine'
      PCK( 573 ) = '           BODEUL in particular) cannot h'
     .//           'andle the cosine term directly,'
      PCK( 574 ) = '           but we can represent it as'
      PCK( 575 ) = ' '
      PCK( 576 ) = '              0.19 sin M'
      PCK( 577 ) = '                        4'
      PCK( 578 ) = ' '
      PCK( 579 ) = '           where'
      PCK( 580 ) = ' '
      PCK( 581 ) = '              M   =  90.D0 - M'
      PCK( 582 ) = '               4              3'
      PCK( 583 ) = ' '
      PCK( 584 ) = '           Therefore, the nutation preces'
     .//           'sion angle assignments for Phobos'
      PCK( 585 ) = '           and Deimos contain four coeffi'
     .//           'cients rather than three.'
      PCK( 586 ) = ' '
      PCK( 587 ) = '           The quadratic prime meridian t'
     .//           'erm is scaled by 1/36525**2:'
      PCK( 588 ) = ' '
      PCK( 589 ) = '              -0.5200000000000000  --->  '
     .//           ' -3.8978300049519307E-10'
      PCK( 590 ) = ' '
      PCK( 591 ) = BEGDAT()
      PCK( 592 ) = ' '
      PCK( 593 ) = '           BODY402_POLE_RA       = (  316'
     .//           '.65     -0.108       0.           )'
      PCK( 594 ) = '           BODY402_POLE_DEC      = (   53'
     .//           '.52     -0.061       0.           )'
      PCK( 595 ) = '           BODY402_PM            = (   79'
     .//           '.41    285.1618970  -3.897830D-10 )'
      PCK( 596 ) = '           BODY402_LONG_AXIS     = (    0'
     .//           '.                                 )'
      PCK( 597 ) = ' '
      PCK( 598 ) = '           BODY402_NUT_PREC_RA   = (    0'
     .//           '.   0.   2.98    0.   )'
      PCK( 599 ) = '           BODY402_NUT_PREC_DEC  = (    0'
     .//           '.   0.  -1.78    0.   )'
      PCK( 600 ) = '           BODY402_NUT_PREC_PM   = (    0'
     .//           '.   0.  -2.58    0.19 )'
      PCK( 601 ) = ' '
      PCK( 602 ) = BEGTXT()
      PCK( 603 ) = ' '
      PCK( 604 ) = ' '
      PCK( 605 ) = ' '
      PCK( 606 ) = ' '
      PCK( 607 ) = 'Satellites of Jupiter'
      PCK( 608 ) = ' '
      PCK( 609 ) = ' '
      PCK( 610 ) = '     Io'
      PCK( 611 ) = ' '
      PCK( 612 ) = '          Old values:'
      PCK( 613 ) = ' '
      PCK( 614 ) = '             Values are unchanged in the '
     .//           '2000 IAU report.'
      PCK( 615 ) = ' '
      PCK( 616 ) = '          Current values:'
      PCK( 617 ) = ' '
      PCK( 618 ) = BEGDAT()
      PCK( 619 ) = ' '
      PCK( 620 ) = '        BODY501_POLE_RA       = (  268.05'
     .//           '          -0.009      0. )'
      PCK( 621 ) = '        BODY501_POLE_DEC      = (   64.50'
     .//           '           0.003      0. )'
      PCK( 622 ) = '        BODY501_PM            = (  200.39'
     .//           '         203.4889538  0. )'
      PCK( 623 ) = '        BODY501_LONG_AXIS     = (    0.  '
     .//           '                         )'
      PCK( 624 ) = ' '
      PCK( 625 ) = '        BODY501_NUT_PREC_RA   = (    0.  '
     .//           ' 0.     0.094    0.024   )'
      PCK( 626 ) = '        BODY501_NUT_PREC_DEC  = (    0.  '
     .//           ' 0.     0.040    0.011   )'
      PCK( 627 ) = '        BODY501_NUT_PREC_PM   = (    0.  '
     .//           ' 0.    -0.085   -0.022   )'
      PCK( 628 ) = ' '
      PCK( 629 ) = BEGTXT()
      PCK( 630 ) = ' '
      PCK( 631 ) = ' '
      PCK( 632 ) = ' '
      PCK( 633 ) = '     Europa'
      PCK( 634 ) = ' '
      PCK( 635 ) = ' '
      PCK( 636 ) = '        Old values:'
      PCK( 637 ) = ' '
      PCK( 638 ) = '        body502_pole_ra       = (  268.08'
     .//           '          -0.009      0.   )'
      PCK( 639 ) = '        body502_pole_dec      = (   64.51'
     .//           '           0.003      0.   )'
      PCK( 640 ) = '        body502_pm            = (   35.67'
     .//           '         101.3747235  0.   )'
      PCK( 641 ) = '        body502_long_axis     = (    0.  '
     .//           '                           )'
      PCK( 642 ) = ' '
      PCK( 643 ) = '        body502_nut_prec_ra   = ( 0. 0. 0'
     .//           '.   1.086   0.060   0.015   0.009 )'
      PCK( 644 ) = '        body502_nut_prec_dec  = ( 0. 0. 0'
     .//           '.   0.468   0.026   0.007   0.002 )'
      PCK( 645 ) = '        body502_nut_prec_pm   = ( 0. 0. 0'
     .//           '.  -0.980  -0.054  -0.014  -0.008 )'
      PCK( 646 ) = ' '
      PCK( 647 ) = '        Current values:'
      PCK( 648 ) = ' '
      PCK( 649 ) = BEGDAT()
      PCK( 650 ) = ' '
      PCK( 651 ) = '        BODY502_POLE_RA       = (  268.08'
     .//           '          -0.009      0.   )'
      PCK( 652 ) = '        BODY502_POLE_DEC      = (   64.51'
     .//           '           0.003      0.   )'
      PCK( 653 ) = '        BODY502_PM            = (   36.02'
     .//           '2        101.3747235  0.   )'
      PCK( 654 ) = '        BODY502_LONG_AXIS     = (    0.  '
     .//           '                           )'
      PCK( 655 ) = ' '
      PCK( 656 ) = '        BODY502_NUT_PREC_RA   = ( 0. 0. 0'
     .//           '.   1.086   0.060   0.015   0.009 )'
      PCK( 657 ) = '        BODY502_NUT_PREC_DEC  = ( 0. 0. 0'
     .//           '.   0.468   0.026   0.007   0.002 )'
      PCK( 658 ) = '        BODY502_NUT_PREC_PM   = ( 0. 0. 0'
     .//           '.  -0.980  -0.054  -0.014  -0.008 )'
      PCK( 659 ) = ' '
      PCK( 660 ) = BEGTXT()
      PCK( 661 ) = ' '
      PCK( 662 ) = ' '
      PCK( 663 ) = '     Ganymede'
      PCK( 664 ) = ' '
      PCK( 665 ) = '        Old values:'
      PCK( 666 ) = ' '
      PCK( 667 ) = '        body503_pole_ra       = (  268.20'
     .//           '          -0.009      0.   )'
      PCK( 668 ) = '        body503_pole_dec      = (  +64.57'
     .//           '          +0.003      0.   )'
      PCK( 669 ) = '        body503_pm            = (   44.04'
     .//           '         +50.3176081  0.   )'
      PCK( 670 ) = '        body503_long_axis     = (    0.  '
     .//           '                           )'
      PCK( 671 ) = ' '
      PCK( 672 ) = '        body503_nut_prec_ra   = ( 0. 0. 0'
     .//           '.  -0.037  +0.431  +0.091   )'
      PCK( 673 ) = '        body503_nut_prec_dec  = ( 0. 0. 0'
     .//           '.  -0.016  +0.186  +0.039   )'
      PCK( 674 ) = '        body503_nut_prec_pm   = ( 0. 0. 0'
     .//           '.  +0.033  -0.389  -0.082   )'
      PCK( 675 ) = ' '
      PCK( 676 ) = '        Current values:'
      PCK( 677 ) = ' '
      PCK( 678 ) = BEGDAT()
      PCK( 679 ) = ' '
      PCK( 680 ) = '        BODY503_POLE_RA       = (  268.20'
     .//           '         -0.009       0.  )'
      PCK( 681 ) = '        BODY503_POLE_DEC      = (   64.57'
     .//           '          0.003       0.  )'
      PCK( 682 ) = '        BODY503_PM            = (   44.06'
     .//           '4        50.3176081   0.  )'
      PCK( 683 ) = '        BODY503_LONG_AXIS     = (    0.  '
     .//           '                          )'
      PCK( 684 ) = ' '
      PCK( 685 ) = '        BODY503_NUT_PREC_RA   = ( 0. 0. 0'
     .//           '.  -0.037   0.431   0.091   )'
      PCK( 686 ) = '        BODY503_NUT_PREC_DEC  = ( 0. 0. 0'
     .//           '.  -0.016   0.186   0.039   )'
      PCK( 687 ) = '        BODY503_NUT_PREC_PM   = ( 0. 0. 0'
     .//           '.   0.033  -0.389  -0.082   )'
      PCK( 688 ) = ' '
      PCK( 689 ) = BEGTXT()
      PCK( 690 ) = ' '
      PCK( 691 ) = ' '
      PCK( 692 ) = '     Callisto'
      PCK( 693 ) = ' '
      PCK( 694 ) = ' '
      PCK( 695 ) = '        Old values:'
      PCK( 696 ) = ' '
      PCK( 697 ) = '        body504_pole_ra       = (   268.7'
     .//           '2   -0.009      0.  )'
      PCK( 698 ) = '        body504_pole_dec      = (   +64.8'
     .//           '3   +0.003      0.  )'
      PCK( 699 ) = '        body504_pm            = (   259.7'
     .//           '3  +21.5710715  0.  )'
      PCK( 700 ) = '        body504_long_axis     = (     0. '
     .//           '                    )'
      PCK( 701 ) = ' '
      PCK( 702 ) = '        body504_nut_prec_ra   = ( 0. 0. 0'
     .//           '. 0. -0.068 +0.590  0. +0.010 )'
      PCK( 703 ) = '        body504_nut_prec_dec  = ( 0. 0. 0'
     .//           '. 0. -0.029 +0.254  0. -0.004 )'
      PCK( 704 ) = '        body504_nut_prec_pm   = ( 0. 0. 0'
     .//           '. 0. +0.061 -0.533  0. -0.009 )'
      PCK( 705 ) = ' '
      PCK( 706 ) = '        Current values:'
      PCK( 707 ) = ' '
      PCK( 708 ) = ' '
      PCK( 709 ) = BEGDAT()
      PCK( 710 ) = ' '
      PCK( 711 ) = '        BODY504_POLE_RA       = (   268.7'
     .//           '2    -0.009       0.  )'
      PCK( 712 ) = '        BODY504_POLE_DEC      = (    64.8'
     .//           '3     0.003       0.  )'
      PCK( 713 ) = '        BODY504_PM            = (   259.5'
     .//           '1    21.5710715   0.  )'
      PCK( 714 ) = '        BODY504_LONG_AXIS     = (     0. '
     .//           '                      )'
      PCK( 715 ) = ' '
      PCK( 716 ) = '        BODY504_NUT_PREC_RA   = ( 0. 0. 0'
     .//           '. 0.  -0.068   0.590  0.   0.010 )'
      PCK( 717 ) = '        BODY504_NUT_PREC_DEC  = ( 0. 0. 0'
     .//           '. 0.  -0.029   0.254  0.  -0.004 )'
      PCK( 718 ) = '        BODY504_NUT_PREC_PM   = ( 0. 0. 0'
     .//           '. 0.   0.061  -0.533  0.  -0.009 )'
      PCK( 719 ) = ' '
      PCK( 720 ) = BEGTXT()
      PCK( 721 ) = ' '
      PCK( 722 ) = ' '
      PCK( 723 ) = '     Amalthea'
      PCK( 724 ) = ' '
      PCK( 725 ) = ' '
      PCK( 726 ) = '        Old values:'
      PCK( 727 ) = ' '
      PCK( 728 ) = '           Values are unchanged in the 20'
     .//           '00 IAU report.'
      PCK( 729 ) = ' '
      PCK( 730 ) = '        Current values:'
      PCK( 731 ) = ' '
      PCK( 732 ) = BEGDAT()
      PCK( 733 ) = ' '
      PCK( 734 ) = '        BODY505_POLE_RA       = (   268.0'
     .//           '5    -0.009      0.  )'
      PCK( 735 ) = '        BODY505_POLE_DEC      = (    64.4'
     .//           '9     0.003      0.  )'
      PCK( 736 ) = '        BODY505_PM            = (   231.6'
     .//           '7   722.6314560  0.  )'
      PCK( 737 ) = '        BODY505_LONG_AXIS     = (     0. '
     .//           '                     )'
      PCK( 738 ) = ' '
      PCK( 739 ) = '        BODY505_NUT_PREC_RA  = ( -0.84  0'
     .//           '. 0. 0. 0. 0. 0. 0.   0.01  0. )'
      PCK( 740 ) = '        BODY505_NUT_PREC_DEC = ( -0.36  0'
     .//           '. 0. 0. 0. 0. 0. 0.   0.    0. )'
      PCK( 741 ) = '        BODY505_NUT_PREC_PM  = (  0.76  0'
     .//           '. 0. 0. 0. 0. 0. 0.  -0.01  0. )'
      PCK( 742 ) = ' '
      PCK( 743 ) = BEGTXT()
      PCK( 744 ) = ' '
      PCK( 745 ) = ' '
      PCK( 746 ) = '     Thebe'
      PCK( 747 ) = ' '
      PCK( 748 ) = ' '
      PCK( 749 ) = '        Old values:'
      PCK( 750 ) = ' '
      PCK( 751 ) = '           Values are unchanged in the 20'
     .//           '00 IAU report.'
      PCK( 752 ) = ' '
      PCK( 753 ) = '        Current values:'
      PCK( 754 ) = ' '
      PCK( 755 ) = BEGDAT()
      PCK( 756 ) = ' '
      PCK( 757 ) = '        BODY514_POLE_RA       = (  268.05'
     .//           '     -0.009       0.  )'
      PCK( 758 ) = '        BODY514_POLE_DEC      = (   64.49'
     .//           '      0.003       0.  )'
      PCK( 759 ) = '        BODY514_PM            = (    8.56'
     .//           '    533.7004100   0.  )'
      PCK( 760 ) = '        BODY514_LONG_AXIS     = (    0.  '
     .//           '                      )'
      PCK( 761 ) = ' '
      PCK( 762 ) = '        BODY514_NUT_PREC_RA  = ( 0.  -2.1'
     .//           '1  0. 0. 0. 0. 0. 0. 0.  0.04 )'
      PCK( 763 ) = '        BODY514_NUT_PREC_DEC = ( 0.  -0.9'
     .//           '1  0. 0. 0. 0. 0. 0. 0.  0.01 )'
      PCK( 764 ) = '        BODY514_NUT_PREC_PM  = ( 0.   1.9'
     .//           '1  0. 0. 0. 0. 0. 0. 0. -0.04 )'
      PCK( 765 ) = ' '
      PCK( 766 ) = BEGTXT()
      PCK( 767 ) = ' '
      PCK( 768 ) = ' '
      PCK( 769 ) = '     Adrastea'
      PCK( 770 ) = ' '
      PCK( 771 ) = '        Old values:'
      PCK( 772 ) = ' '
      PCK( 773 ) = '           Values are unchanged in the 20'
     .//           '00 IAU report.'
      PCK( 774 ) = ' '
      PCK( 775 ) = '        Current values:'
      PCK( 776 ) = ' '
      PCK( 777 ) = BEGDAT()
      PCK( 778 ) = ' '
      PCK( 779 ) = ' '
      PCK( 780 ) = ' '
      PCK( 781 ) = '        BODY515_POLE_RA       = (  268.05'
     .//           '     -0.009       0.  )'
      PCK( 782 ) = '        BODY515_POLE_DEC      = (   64.49'
     .//           '      0.003       0.  )'
      PCK( 783 ) = '        BODY515_PM            = (   33.29'
     .//           '   1206.9986602   0.  )'
      PCK( 784 ) = '        BODY515_LONG_AXIS     = (    0.  '
     .//           '                      )'
      PCK( 785 ) = ' '
      PCK( 786 ) = BEGTXT()
      PCK( 787 ) = ' '
      PCK( 788 ) = ' '
      PCK( 789 ) = '     Metis'
      PCK( 790 ) = ' '
      PCK( 791 ) = '        Old values:'
      PCK( 792 ) = ' '
      PCK( 793 ) = '           Values are unchanged in the 20'
     .//           '00 IAU report.'
      PCK( 794 ) = ' '
      PCK( 795 ) = '        Current values:'
      PCK( 796 ) = ' '
      PCK( 797 ) = BEGDAT()
      PCK( 798 ) = ' '
      PCK( 799 ) = '        BODY516_POLE_RA       = (  268.05'
     .//           '     -0.009       0.  )'
      PCK( 800 ) = '        BODY516_POLE_DEC      = (   64.49'
     .//           '      0.003       0.  )'
      PCK( 801 ) = '        BODY516_PM            = (  346.09'
     .//           '   1221.2547301   0.  )'
      PCK( 802 ) = '        BODY516_LONG_AXIS     = (    0.  '
     .//           '                      )'
      PCK( 803 ) = ' '
      PCK( 804 ) = BEGTXT()
      PCK( 805 ) = ' '
      PCK( 806 ) = ' '
      PCK( 807 ) = ' '
      PCK( 808 ) = 'Satellites of Saturn'
      PCK( 809 ) = ' '
      PCK( 810 ) = ' '
      PCK( 811 ) = '     Mimas'
      PCK( 812 ) = ' '
      PCK( 813 ) = '        Old values:'
      PCK( 814 ) = ' '
      PCK( 815 ) = '           Values are unchanged in the 20'
     .//           '00 IAU report.'
      PCK( 816 ) = ' '
      PCK( 817 ) = '        Current values:'
      PCK( 818 ) = ' '
      PCK( 819 ) = BEGDAT()
      PCK( 820 ) = ' '
      PCK( 821 ) = '           BODY601_POLE_RA       = (   40'
     .//           '.66     -0.036      0.  )'
      PCK( 822 ) = '           BODY601_POLE_DEC      = (   83'
     .//           '.52     -0.004      0.  )'
      PCK( 823 ) = '           BODY601_PM            = (  337'
     .//           '.46    381.9945550  0.  )'
      PCK( 824 ) = '           BODY601_LONG_AXIS     = (     '
     .//           '0.                      )'
      PCK( 825 ) = ' '
      PCK( 826 ) = '           BODY601_NUT_PREC_RA   = ( 0. 0'
     .//           '.   13.56  0.    0.    0. 0. 0. 0. )'
      PCK( 827 ) = '           BODY601_NUT_PREC_DEC  = ( 0. 0'
     .//           '.   -1.53  0.    0.    0. 0. 0. 0. )'
      PCK( 828 ) = '           BODY601_NUT_PREC_PM   = ( 0. 0'
     .//           '.  -13.48  0.  -44.85  0. 0. 0. 0. )'
      PCK( 829 ) = ' '
      PCK( 830 ) = BEGTXT()
      PCK( 831 ) = ' '
      PCK( 832 ) = ' '
      PCK( 833 ) = '     Enceladus'
      PCK( 834 ) = ' '
      PCK( 835 ) = ' '
      PCK( 836 ) = '        Old values:'
      PCK( 837 ) = ' '
      PCK( 838 ) = '           Values are unchanged in the 20'
     .//           '00 IAU report.'
      PCK( 839 ) = ' '
      PCK( 840 ) = '        Current values:'
      PCK( 841 ) = ' '
      PCK( 842 ) = BEGDAT()
      PCK( 843 ) = ' '
      PCK( 844 ) = '           BODY602_POLE_RA       = (   40'
     .//           '.66    -0.036       0. )'
      PCK( 845 ) = '           BODY602_POLE_DEC      = (   83'
     .//           '.52    -0.004       0. )'
      PCK( 846 ) = '           BODY602_PM            = (    2'
     .//           '.82   262.7318996   0. )'
      PCK( 847 ) = '           BODY602_LONG_AXIS     = (    0'
     .//           '.                      )'
      PCK( 848 ) = ' '
      PCK( 849 ) = BEGTXT()
      PCK( 850 ) = ' '
      PCK( 851 ) = ' '
      PCK( 852 ) = ' '
      PCK( 853 ) = '     Tethys'
      PCK( 854 ) = ' '
      PCK( 855 ) = ' '
      PCK( 856 ) = '        Old values:'
      PCK( 857 ) = ' '
      PCK( 858 ) = '           Values are unchanged in the 20'
     .//           '00 IAU report.'
      PCK( 859 ) = ' '
      PCK( 860 ) = '        Current values:'
      PCK( 861 ) = ' '
      PCK( 862 ) = BEGDAT()
      PCK( 863 ) = ' '
      PCK( 864 ) = '           BODY603_POLE_RA       = (   40'
     .//           '.66    -0.036       0. )'
      PCK( 865 ) = '           BODY603_POLE_DEC      = (   83'
     .//           '.52    -0.004       0. )'
      PCK( 866 ) = '           BODY603_PM            = (   10'
     .//           '.45   190.6979085   0. )'
      PCK( 867 ) = '           BODY603_LONG_AXIS     = (    0'
     .//           '.                      )'
      PCK( 868 ) = ' '
      PCK( 869 ) = '           BODY603_NUT_PREC_RA   = ( 0. 0'
     .//           '. 0.   9.66   0.    0.  0.  0.  0. )'
      PCK( 870 ) = '           BODY603_NUT_PREC_DEC  = ( 0. 0'
     .//           '. 0.  -1.09   0.    0.  0.  0.  0. )'
      PCK( 871 ) = '           BODY603_NUT_PREC_PM   = ( 0. 0'
     .//           '. 0.  -9.60   2.23  0.  0.  0.  0. )'
      PCK( 872 ) = ' '
      PCK( 873 ) = BEGTXT()
      PCK( 874 ) = ' '
      PCK( 875 ) = ' '
      PCK( 876 ) = '     Dione'
      PCK( 877 ) = ' '
      PCK( 878 ) = ' '
      PCK( 879 ) = '        Old values:'
      PCK( 880 ) = ' '
      PCK( 881 ) = '           Values are unchanged in the 20'
     .//           '00 IAU report.'
      PCK( 882 ) = ' '
      PCK( 883 ) = '        Current values:'
      PCK( 884 ) = ' '
      PCK( 885 ) = BEGDAT()
      PCK( 886 ) = ' '
      PCK( 887 ) = '           BODY604_POLE_RA       = (  40.'
     .//           '66      -0.036      0.  )'
      PCK( 888 ) = '           BODY604_POLE_DEC      = (  83.'
     .//           '52      -0.004      0.  )'
      PCK( 889 ) = '           BODY604_PM            = (  357'
     .//           '.00    131.5349316  0.  )'
      PCK( 890 ) = '           BODY604_LONG_AXIS     = (    0'
     .//           '.                       )'
      PCK( 891 ) = ' '
      PCK( 892 ) = BEGTXT()
      PCK( 893 ) = ' '
      PCK( 894 ) = ' '
      PCK( 895 ) = ' '
      PCK( 896 ) = '     Rhea'
      PCK( 897 ) = ' '
      PCK( 898 ) = ' '
      PCK( 899 ) = '        Old values:'
      PCK( 900 ) = ' '
      PCK( 901 ) = '           Values are unchanged in the 20'
     .//           '00 IAU report.'
      PCK( 902 ) = ' '
      PCK( 903 ) = '        Current values:'
      PCK( 904 ) = ' '
      PCK( 905 ) = BEGDAT()
      PCK( 906 ) = ' '
      PCK( 907 ) = '           BODY605_POLE_RA       = (   40'
     .//           '.38   -0.036       0. )'
      PCK( 908 ) = '           BODY605_POLE_DEC      = (   83'
     .//           '.55   -0.004       0. )'
      PCK( 909 ) = '           BODY605_PM            = (  235'
     .//           '.16   79.6900478   0. )'
      PCK( 910 ) = '           BODY605_LONG_AXIS     = (    0'
     .//           '.                     )'
      PCK( 911 ) = ' '
      PCK( 912 ) = '           BODY605_NUT_PREC_RA   = ( 0. 0'
     .//           '. 0. 0. 0.   3.10   0. 0. 0. )'
      PCK( 913 ) = '           BODY605_NUT_PREC_DEC  = ( 0. 0'
     .//           '. 0. 0. 0.  -0.35   0. 0. 0. )'
      PCK( 914 ) = '           BODY605_NUT_PREC_PM   = ( 0. 0'
     .//           '. 0. 0. 0.  -3.08   0. 0. 0. )'
      PCK( 915 ) = ' '
      PCK( 916 ) = BEGTXT()
      PCK( 917 ) = ' '
      PCK( 918 ) = ' '
      PCK( 919 ) = ' '
      PCK( 920 ) = '     Titan'
      PCK( 921 ) = ' '
      PCK( 922 ) = ' '
      PCK( 923 ) = '        Old values:'
      PCK( 924 ) = ' '
      PCK( 925 ) = '           Values are unchanged in the 20'
     .//           '00 IAU report.'
      PCK( 926 ) = ' '
      PCK( 927 ) = '        Current values:'
      PCK( 928 ) = ' '
      PCK( 929 ) = BEGDAT()
      PCK( 930 ) = ' '
      PCK( 931 ) = '           BODY606_POLE_RA       = (    3'
     .//           '6.41   -0.036      0. )'
      PCK( 932 ) = '           BODY606_POLE_DEC      = (    8'
     .//           '3.94   -0.004      0. )'
      PCK( 933 ) = '           BODY606_PM            = (   18'
     .//           '9.64   22.5769768  0. )'
      PCK( 934 ) = '           BODY606_LONG_AXIS     = (     '
     .//           '0.                    )'
      PCK( 935 ) = ' '
      PCK( 936 ) = '           BODY606_NUT_PREC_RA   = ( 0. 0'
     .//           '. 0. 0. 0. 0.  2.66  0. 0 )'
      PCK( 937 ) = '           BODY606_NUT_PREC_DEC  = ( 0. 0'
     .//           '. 0. 0. 0. 0. -0.30  0. 0 )'
      PCK( 938 ) = '           BODY606_NUT_PREC_PM   = ( 0. 0'
     .//           '. 0. 0. 0. 0. -2.64  0. 0 )'
      PCK( 939 ) = ' '
      PCK( 940 ) = BEGTXT()
      PCK( 941 ) = ' '
      PCK( 942 ) = ' '
      PCK( 943 ) = ' '
      PCK( 944 ) = '     Hyperion'
      PCK( 945 ) = ' '
      PCK( 946 ) = '         The IAU report does not give an '
     .//           'orientation model for Hyperion.'
      PCK( 947 ) = ' '
      PCK( 948 ) = ' '
      PCK( 949 ) = ' '
      PCK( 950 ) = '     Iapetus'
      PCK( 951 ) = ' '
      PCK( 952 ) = ' '
      PCK( 953 ) = '        Old values:'
      PCK( 954 ) = ' '
      PCK( 955 ) = '           Values are unchanged in the 20'
     .//           '00 IAU report.'
      PCK( 956 ) = ' '
      PCK( 957 ) = '        Current values:'
      PCK( 958 ) = ' '
      PCK( 959 ) = BEGDAT()
      PCK( 960 ) = ' '
      PCK( 961 ) = '           BODY608_POLE_RA       = (   31'
     .//           '8.16  -3.949      0.  )'
      PCK( 962 ) = '           BODY608_POLE_DEC      = (    7'
     .//           '5.03  -1.143      0.  )'
      PCK( 963 ) = '           BODY608_PM            = (   35'
     .//           '0.20   4.5379572  0.  )'
      PCK( 964 ) = '           BODY608_LONG_AXIS     = (     '
     .//           '0.                    )'
      PCK( 965 ) = ' '
      PCK( 966 ) = BEGTXT()
      PCK( 967 ) = ' '
      PCK( 968 ) = ' '
      PCK( 969 ) = ' '
      PCK( 970 ) = '     Phoebe'
      PCK( 971 ) = ' '
      PCK( 972 ) = ' '
      PCK( 973 ) = '        Old values:'
      PCK( 974 ) = ' '
      PCK( 975 ) = '           Values are unchanged in the 20'
     .//           '00 IAU report.'
      PCK( 976 ) = ' '
      PCK( 977 ) = '        Current values:'
      PCK( 978 ) = ' '
      PCK( 979 ) = BEGDAT()
      PCK( 980 ) = ' '
      PCK( 981 ) = '           BODY609_POLE_RA       = ( 355.'
     .//           '00       0.         0.  )'
      PCK( 982 ) = '           BODY609_POLE_DEC      = (  68.'
     .//           '70       0.         0.  )'
      PCK( 983 ) = '           BODY609_PM            = ( 304.'
     .//           '70     930.8338720  0.  )'
      PCK( 984 ) = '           BODY609_LONG_AXIS     = (    0'
     .//           '.                       )'
      PCK( 985 ) = ' '
      PCK( 986 ) = BEGTXT()
      PCK( 987 ) = ' '
      PCK( 988 ) = ' '
      PCK( 989 ) = '     Janus'
      PCK( 990 ) = ' '
      PCK( 991 ) = ' '
      PCK( 992 ) = '        Old values:'
      PCK( 993 ) = ' '
      PCK( 994 ) = '           Values are unchanged in the 20'
     .//           '00 IAU report.'
      PCK( 995 ) = ' '
      PCK( 996 ) = '        Current values:'
      PCK( 997 ) = ' '
      PCK( 998 ) = BEGDAT()
      PCK( 999 ) = ' '
      PCK( 1000 ) = '           BODY610_POLE_RA       = (  40'
     .//            '.58    -0.036       0. )'
      PCK( 1001 ) = '           BODY610_POLE_DEC      = (  83'
     .//            '.52    -0.004       0. )'
      PCK( 1002 ) = '           BODY610_PM            = (  58'
     .//            '.83   518.2359876   0. )'
      PCK( 1003 ) = '           BODY610_LONG_AXIS     = (   0'
     .//            '.                      )'
      PCK( 1004 ) = ' '
      PCK( 1005 ) = '           BODY610_NUT_PREC_RA   = ( 0. '
     .//            '-1.623  0. 0. 0. 0. 0. 0.  0.023 )'
      PCK( 1006 ) = '           BODY610_NUT_PREC_DEC  = ( 0. '
     .//            '-0.183  0. 0. 0. 0. 0. 0.  0.001 )'
      PCK( 1007 ) = '           BODY610_NUT_PREC_PM   = ( 0. '
     .//            ' 1.613  0. 0. 0. 0. 0. 0. -0.023 )'
      PCK( 1008 ) = ' '
      PCK( 1009 ) = BEGTXT()
      PCK( 1010 ) = ' '
      PCK( 1011 ) = ' '
      PCK( 1012 ) = ' '
      PCK( 1013 ) = '     Epimetheus'
      PCK( 1014 ) = ' '
      PCK( 1015 ) = ' '
      PCK( 1016 ) = '        Old values:'
      PCK( 1017 ) = ' '
      PCK( 1018 ) = '           Values are unchanged in the 2'
     .//            '000 IAU report.'
      PCK( 1019 ) = ' '
      PCK( 1020 ) = '        Current values:'
      PCK( 1021 ) = ' '
      PCK( 1022 ) = BEGDAT()
      PCK( 1023 ) = ' '
      PCK( 1024 ) = '           BODY611_POLE_RA       = (  40'
     .//            '.58    -0.036        0. )'
      PCK( 1025 ) = '           BODY611_POLE_DEC      = (  83'
     .//            '.52    -0.004        0. )'
      PCK( 1026 ) = '           BODY611_PM            = ( 293'
     .//            '.87   518.4907239    0. )'
      PCK( 1027 ) = '           BODY611_LONG_AXIS     = (   0'
     .//            '.                       )'
      PCK( 1028 ) = ' '
      PCK( 1029 ) = '           BODY611_NUT_PREC_RA   = ( -3.'
     .//            '153   0. 0. 0. 0. 0. 0.   0.086  0. )'
      PCK( 1030 ) = '           BODY611_NUT_PREC_DEC  = ( -0.'
     .//            '356   0. 0. 0. 0. 0. 0.   0.005  0. )'
      PCK( 1031 ) = '           BODY611_NUT_PREC_PM   = (  3.'
     .//            '133   0. 0. 0. 0. 0. 0.  -0.086  0. )'
      PCK( 1032 ) = ' '
      PCK( 1033 ) = BEGTXT()
      PCK( 1034 ) = ' '
      PCK( 1035 ) = ' '
      PCK( 1036 ) = ' '
      PCK( 1037 ) = '     Helene'
      PCK( 1038 ) = ' '
      PCK( 1039 ) = ' '
      PCK( 1040 ) = '        Old values:'
      PCK( 1041 ) = ' '
      PCK( 1042 ) = '           Values are unchanged in the 2'
     .//            '000 IAU report.'
      PCK( 1043 ) = ' '
      PCK( 1044 ) = '        Current values:'
      PCK( 1045 ) = ' '
      PCK( 1046 ) = BEGDAT()
      PCK( 1047 ) = ' '
      PCK( 1048 ) = '           BODY612_POLE_RA       = (  40'
     .//            '.85     -0.036        0. )'
      PCK( 1049 ) = '           BODY612_POLE_DEC      = (  83'
     .//            '.34     -0.004        0. )'
      PCK( 1050 ) = '           BODY612_PM            = ( 245'
     .//            '.12    131.6174056    0. )'
      PCK( 1051 ) = '           BODY612_LONG_AXIS     = (   0'
     .//            '.                        )'
      PCK( 1052 ) = ' '
      PCK( 1053 ) = BEGTXT()
      PCK( 1054 ) = ' '
      PCK( 1055 ) = ' '
      PCK( 1056 ) = ' '
      PCK( 1057 ) = '     Telesto'
      PCK( 1058 ) = ' '
      PCK( 1059 ) = ' '
      PCK( 1060 ) = '        Old values:'
      PCK( 1061 ) = ' '
      PCK( 1062 ) = '           Values are unchanged in the 2'
     .//            '000 IAU report.'
      PCK( 1063 ) = ' '
      PCK( 1064 ) = '        Current values:'
      PCK( 1065 ) = ' '
      PCK( 1066 ) = BEGDAT()
      PCK( 1067 ) = ' '
      PCK( 1068 ) = '           BODY613_POLE_RA       = ( 50.'
     .//            '51    -0.036      0.  )'
      PCK( 1069 ) = '           BODY613_POLE_DEC      = ( 84.'
     .//            '06    -0.004      0.  )'
      PCK( 1070 ) = '           BODY613_PM            = ( 56.'
     .//            '88   190.6979332  0.  )'
      PCK( 1071 ) = '           BODY613_LONG_AXIS     = (  0.'
     .//            '                      )'
      PCK( 1072 ) = ' '
      PCK( 1073 ) = BEGTXT()
      PCK( 1074 ) = ' '
      PCK( 1075 ) = ' '
      PCK( 1076 ) = ' '
      PCK( 1077 ) = '     Calypso'
      PCK( 1078 ) = ' '
      PCK( 1079 ) = ' '
      PCK( 1080 ) = '        Old values:'
      PCK( 1081 ) = ' '
      PCK( 1082 ) = '           Values are unchanged in the 2'
     .//            '000 IAU report.'
      PCK( 1083 ) = ' '
      PCK( 1084 ) = '        Current values:'
      PCK( 1085 ) = ' '
      PCK( 1086 ) = BEGDAT()
      PCK( 1087 ) = ' '
      PCK( 1088 ) = '           BODY614_POLE_RA       = (   3'
     .//            '6.41    -0.036        0.  )'
      PCK( 1089 ) = '           BODY614_POLE_DEC      = (   8'
     .//            '5.04    -0.004        0.  )'
      PCK( 1090 ) = '           BODY614_PM            = (  15'
     .//            '3.51   190.6742373    0.  )'
      PCK( 1091 ) = '           BODY614_LONG_AXIS     = (    '
     .//            '0.                        )'
      PCK( 1092 ) = ' '
      PCK( 1093 ) = BEGTXT()
      PCK( 1094 ) = ' '
      PCK( 1095 ) = ' '
      PCK( 1096 ) = ' '
      PCK( 1097 ) = '     Atlas'
      PCK( 1098 ) = ' '
      PCK( 1099 ) = ' '
      PCK( 1100 ) = '        Old values:'
      PCK( 1101 ) = ' '
      PCK( 1102 ) = '           Values are unchanged in the 2'
     .//            '000 IAU report.'
      PCK( 1103 ) = ' '
      PCK( 1104 ) = '        Current values:'
      PCK( 1105 ) = ' '
      PCK( 1106 ) = BEGDAT()
      PCK( 1107 ) = ' '
      PCK( 1108 ) = '           BODY615_POLE_RA       = (   4'
     .//            '0.58     -0.036      0. )'
      PCK( 1109 ) = '           BODY615_POLE_DEC      = (   8'
     .//            '3.53     -0.004      0. )'
      PCK( 1110 ) = '           BODY615_PM            = (  13'
     .//            '7.88    598.3060000  0. )'
      PCK( 1111 ) = '           BODY615_LONG_AXIS     = (    '
     .//            '0.                      )'
      PCK( 1112 ) = ' '
      PCK( 1113 ) = BEGTXT()
      PCK( 1114 ) = ' '
      PCK( 1115 ) = ' '
      PCK( 1116 ) = ' '
      PCK( 1117 ) = '     Prometheus'
      PCK( 1118 ) = ' '
      PCK( 1119 ) = ' '
      PCK( 1120 ) = '        Old values:'
      PCK( 1121 ) = ' '
      PCK( 1122 ) = '           Values are unchanged in the 2'
     .//            '000 IAU report.'
      PCK( 1123 ) = ' '
      PCK( 1124 ) = '        Current values:'
      PCK( 1125 ) = ' '
      PCK( 1126 ) = BEGDAT()
      PCK( 1127 ) = ' '
      PCK( 1128 ) = '           BODY616_POLE_RA       = (  40'
     .//            '.58      -0.036    )'
      PCK( 1129 ) = '           BODY616_POLE_DEC      = (  83'
     .//            '.53      -0.004    )'
      PCK( 1130 ) = '           BODY616_PM            = ( 296'
     .//            '.14     587.289000 )'
      PCK( 1131 ) = '           BODY616_LONG_AXIS     = (   0'
     .//            '.                  )'
      PCK( 1132 ) = ' '
      PCK( 1133 ) = BEGTXT()
      PCK( 1134 ) = ' '
      PCK( 1135 ) = ' '
      PCK( 1136 ) = ' '
      PCK( 1137 ) = '     Pandora'
      PCK( 1138 ) = ' '
      PCK( 1139 ) = ' '
      PCK( 1140 ) = '        Old values:'
      PCK( 1141 ) = ' '
      PCK( 1142 ) = '           Values are unchanged in the 2'
     .//            '000 IAU report.'
      PCK( 1143 ) = ' '
      PCK( 1144 ) = '        Current values:'
      PCK( 1145 ) = ' '
      PCK( 1146 ) = BEGDAT()
      PCK( 1147 ) = ' '
      PCK( 1148 ) = '           BODY617_POLE_RA       = (   4'
     .//            '0.58     -0.036      0.  )'
      PCK( 1149 ) = '           BODY617_POLE_DEC      = (   8'
     .//            '3.53     -0.004      0.  )'
      PCK( 1150 ) = '           BODY617_PM            = (  16'
     .//            '2.92    572.7891000  0.  )'
      PCK( 1151 ) = '           BODY617_LONG_AXIS     = (    '
     .//            ' 0.                      )'
      PCK( 1152 ) = ' '
      PCK( 1153 ) = BEGTXT()
      PCK( 1154 ) = ' '
      PCK( 1155 ) = ' '
      PCK( 1156 ) = ' '
      PCK( 1157 ) = '     Pan'
      PCK( 1158 ) = ' '
      PCK( 1159 ) = ' '
      PCK( 1160 ) = '        Old values:'
      PCK( 1161 ) = ' '
      PCK( 1162 ) = '           Values are unchanged in the 2'
     .//            '000 IAU report.'
      PCK( 1163 ) = ' '
      PCK( 1164 ) = '        Current values:'
      PCK( 1165 ) = ' '
      PCK( 1166 ) = BEGDAT()
      PCK( 1167 ) = ' '
      PCK( 1168 ) = '           BODY618_POLE_RA       = (   4'
     .//            '0.6     -0.036       0. )'
      PCK( 1169 ) = '           BODY618_POLE_DEC      = (   8'
     .//            '3.5     -0.004       0. )'
      PCK( 1170 ) = '           BODY618_PM            = (   4'
     .//            '8.8    626.0440000   0. )'
      PCK( 1171 ) = '           BODY618_LONG_AXIS     = (    '
     .//            '0.                      )'
      PCK( 1172 ) = ' '
      PCK( 1173 ) = BEGTXT()
      PCK( 1174 ) = ' '
      PCK( 1175 ) = ' '
      PCK( 1176 ) = ' '
      PCK( 1177 ) = ' '
      PCK( 1178 ) = ' '
      PCK( 1179 ) = 'Satellites of Uranus'
      PCK( 1180 ) = ' '
      PCK( 1181 ) = ' '
      PCK( 1182 ) = ' '
      PCK( 1183 ) = '     Ariel'
      PCK( 1184 ) = ' '
      PCK( 1185 ) = '        Old values:'
      PCK( 1186 ) = ' '
      PCK( 1187 ) = '           Values are unchanged in the 2'
     .//            '000 IAU report.'
      PCK( 1188 ) = ' '
      PCK( 1189 ) = '        Current values:'
      PCK( 1190 ) = ' '
      PCK( 1191 ) = BEGDAT()
      PCK( 1192 ) = ' '
      PCK( 1193 ) = '           BODY701_POLE_RA       = ( 257'
     .//            '.43     0.          0. )'
      PCK( 1194 ) = '           BODY701_POLE_DEC      = ( -15'
     .//            '.10     0.          0. )'
      PCK( 1195 ) = '           BODY701_PM            = ( 156'
     .//            '.22  -142.8356681   0. )'
      PCK( 1196 ) = '           BODY701_LONG_AXIS     = (   0'
     .//            '.                      )'
      PCK( 1197 ) = ' '
      PCK( 1198 ) = '           BODY701_NUT_PREC_RA   = (  0.'
     .//            ' 0. 0. 0. 0.'
      PCK( 1199 ) = '                                      0.'
     .//            ' 0. 0. 0. 0.  0.    0.    0.29 )'
      PCK( 1200 ) = ' '
      PCK( 1201 ) = '           BODY701_NUT_PREC_DEC  = (  0.'
     .//            ' 0. 0. 0. 0.'
      PCK( 1202 ) = '                                      0.'
     .//            ' 0. 0. 0. 0.  0.    0.    0.28 )'
      PCK( 1203 ) = ' '
      PCK( 1204 ) = '           BODY701_NUT_PREC_PM   = (  0.'
     .//            ' 0. 0. 0. 0.'
      PCK( 1205 ) = '                                      0.'
     .//            ' 0. 0. 0. 0.  0.   0.05   0.08 )'
      PCK( 1206 ) = BEGTXT()
      PCK( 1207 ) = ' '
      PCK( 1208 ) = ' '
      PCK( 1209 ) = ' '
      PCK( 1210 ) = '     Umbriel'
      PCK( 1211 ) = ' '
      PCK( 1212 ) = '        Old values:'
      PCK( 1213 ) = ' '
      PCK( 1214 ) = '           Values are unchanged in the 2'
     .//            '000 IAU report.'
      PCK( 1215 ) = ' '
      PCK( 1216 ) = '        Current values:'
      PCK( 1217 ) = ' '
      PCK( 1218 ) = BEGDAT()
      PCK( 1219 ) = ' '
      PCK( 1220 ) = '           BODY702_POLE_RA       = (  25'
     .//            '7.43     0.          0. )'
      PCK( 1221 ) = '           BODY702_POLE_DEC      = (  -1'
     .//            '5.10     0.          0. )'
      PCK( 1222 ) = '           BODY702_PM            = (  10'
     .//            '8.05   -86.8688923   0. )'
      PCK( 1223 ) = '           BODY702_LONG_AXIS     = (    '
     .//            '0.                      )'
      PCK( 1224 ) = ' '
      PCK( 1225 ) = '           BODY702_NUT_PREC_RA   = ( 0. '
     .//            '0. 0. 0. 0.'
      PCK( 1226 ) = '                                     0. '
     .//            '0. 0. 0. 0.   0.   0.    0.   0.21 )'
      PCK( 1227 ) = ' '
      PCK( 1228 ) = '           BODY702_NUT_PREC_DEC  = ( 0. '
     .//            '0. 0. 0. 0.'
      PCK( 1229 ) = '                                     0. '
     .//            '0. 0. 0. 0.   0.   0.    0.   0.20 )'
      PCK( 1230 ) = ' '
      PCK( 1231 ) = '           BODY702_NUT_PREC_PM   = ( 0. '
     .//            '0. 0. 0. 0.'
      PCK( 1232 ) = '                                     0. '
     .//            '0. 0. 0. 0.   0.  -0.09  0.   0.06 )'
      PCK( 1233 ) = ' '
      PCK( 1234 ) = BEGTXT()
      PCK( 1235 ) = ' '
      PCK( 1236 ) = ' '
      PCK( 1237 ) = ' '
      PCK( 1238 ) = '     Titania'
      PCK( 1239 ) = ' '
      PCK( 1240 ) = '        Old values:'
      PCK( 1241 ) = ' '
      PCK( 1242 ) = '           Values are unchanged in the 2'
     .//            '000 IAU report.'
      PCK( 1243 ) = ' '
      PCK( 1244 ) = '        Current values:'
      PCK( 1245 ) = ' '
      PCK( 1246 ) = BEGDAT()
      PCK( 1247 ) = ' '
      PCK( 1248 ) = '           BODY703_POLE_RA       = (  25'
     .//            '7.43    0.          0. )'
      PCK( 1249 ) = '           BODY703_POLE_DEC      = (  -1'
     .//            '5.10    0.          0. )'
      PCK( 1250 ) = '           BODY703_PM            = (   7'
     .//            '7.74  -41.3514316   0. )'
      PCK( 1251 ) = '           BODY703_LONG_AXIS     = (    '
     .//            '0.                     )'
      PCK( 1252 ) = ' '
      PCK( 1253 ) = '           BODY703_NUT_PREC_RA   = ( 0. '
     .//            '0. 0. 0. 0.'
      PCK( 1254 ) = '                                     0. '
     .//            '0. 0. 0. 0.   0. 0. 0. 0.   0.29 )'
      PCK( 1255 ) = ' '
      PCK( 1256 ) = '           BODY703_NUT_PREC_DEC  = ( 0. '
     .//            '0. 0. 0. 0.'
      PCK( 1257 ) = '                                     0. '
     .//            '0. 0. 0. 0.   0. 0. 0. 0.   0.28 )'
      PCK( 1258 ) = ' '
      PCK( 1259 ) = '           BODY703_NUT_PREC_PM   = ( 0. '
     .//            '0. 0. 0. 0.'
      PCK( 1260 ) = '                                     0. '
     .//            '0. 0. 0. 0.   0. 0. 0. 0.   0.08 )'
      PCK( 1261 ) = BEGTXT()
      PCK( 1262 ) = ' '
      PCK( 1263 ) = ' '
      PCK( 1264 ) = ' '
      PCK( 1265 ) = '     Oberon'
      PCK( 1266 ) = ' '
      PCK( 1267 ) = '        Old values:'
      PCK( 1268 ) = ' '
      PCK( 1269 ) = '           Values are unchanged in the 2'
     .//            '000 IAU report.'
      PCK( 1270 ) = ' '
      PCK( 1271 ) = '        Current values:'
      PCK( 1272 ) = ' '
      PCK( 1273 ) = BEGDAT()
      PCK( 1274 ) = ' '
      PCK( 1275 ) = '           BODY704_POLE_RA       = (  25'
     .//            '7.43    0.          0. )'
      PCK( 1276 ) = '           BODY704_POLE_DEC      = (  -1'
     .//            '5.10    0.          0. )'
      PCK( 1277 ) = '           BODY704_PM            = (    '
     .//            '6.77  -26.7394932   0. )'
      PCK( 1278 ) = '           BODY704_LONG_AXIS     = (    '
     .//            '0.                     )'
      PCK( 1279 ) = ' '
      PCK( 1280 ) = ' '
      PCK( 1281 ) = '           BODY704_NUT_PREC_RA   = ( 0. '
     .//            '0. 0. 0. 0.'
      PCK( 1282 ) = '                                     0. '
     .//            '0. 0. 0. 0.'
      PCK( 1283 ) = '                                     0. '
     .//            '0. 0. 0. 0.   0.16 )'
      PCK( 1284 ) = ' '
      PCK( 1285 ) = '           BODY704_NUT_PREC_DEC  = ( 0. '
     .//            '0. 0. 0. 0.'
      PCK( 1286 ) = '                                     0. '
     .//            '0. 0. 0. 0.'
      PCK( 1287 ) = '                                     0. '
     .//            '0. 0. 0. 0.   0.16 )'
      PCK( 1288 ) = ' '
      PCK( 1289 ) = '           BODY704_NUT_PREC_PM   = ( 0. '
     .//            '0. 0. 0. 0.'
      PCK( 1290 ) = '                                     0. '
     .//            '0. 0. 0. 0.'
      PCK( 1291 ) = '                                     0. '
     .//            '0. 0. 0. 0.   0.04 )'
      PCK( 1292 ) = BEGTXT()
      PCK( 1293 ) = ' '
      PCK( 1294 ) = ' '
      PCK( 1295 ) = ' '
      PCK( 1296 ) = '     Miranda'
      PCK( 1297 ) = ' '
      PCK( 1298 ) = '        Old values:'
      PCK( 1299 ) = ' '
      PCK( 1300 ) = '           Values are unchanged in the 2'
     .//            '000 IAU report.'
      PCK( 1301 ) = ' '
      PCK( 1302 ) = '        Current values:'
      PCK( 1303 ) = ' '
      PCK( 1304 ) = BEGDAT()
      PCK( 1305 ) = ' '
      PCK( 1306 ) = ' '
      PCK( 1307 ) = '           BODY705_POLE_RA      = (  257'
     .//            '.43     0.         0. )'
      PCK( 1308 ) = '           BODY705_POLE_DEC     = (  -15'
     .//            '.08     0.         0. )'
      PCK( 1309 ) = '           BODY705_PM           = (   30'
     .//            '.70  -254.6906892  0. )'
      PCK( 1310 ) = '           BODY705_LONG_AXIS    = (    0'
     .//            '.                     )'
      PCK( 1311 ) = ' '
      PCK( 1312 ) = '           BODY705_NUT_PREC_RA  = ( 0.  '
     .//            '   0.     0.    0.    0.'
      PCK( 1313 ) = '                                    0.  '
     .//            '   0.     0.    0.    0.'
      PCK( 1314 ) = '                                    4.41'
     .//            '   0.     0.    0.    0.'
      PCK( 1315 ) = '                                    0.  '
     .//            '  -0.04   0.             )'
      PCK( 1316 ) = ' '
      PCK( 1317 ) = '           BODY705_NUT_PREC_DEC = ( 0.  '
     .//            '   0.     0.    0.    0.'
      PCK( 1318 ) = '                                    0.  '
     .//            '   0.     0.    0.    0.'
      PCK( 1319 ) = '                                    4.25'
     .//            '   0.     0.    0.    0.'
      PCK( 1320 ) = '                                    0.  '
     .//            '  -0.02   0.             )'
      PCK( 1321 ) = ' '
      PCK( 1322 ) = '           BODY705_NUT_PREC_PM  = ( 0.  '
     .//            '   0.     0.    0.    0.'
      PCK( 1323 ) = '                                    0.  '
     .//            '   0.     0.    0.    0.'
      PCK( 1324 ) = '                                    1.15'
     .//            '  -1.27   0.    0.    0.'
      PCK( 1325 ) = '                                    0.  '
     .//            '  -0.09   0.15           )'
      PCK( 1326 ) = BEGTXT()
      PCK( 1327 ) = ' '
      PCK( 1328 ) = ' '
      PCK( 1329 ) = ' '
      PCK( 1330 ) = '     Cordelia'
      PCK( 1331 ) = ' '
      PCK( 1332 ) = '        Old values:'
      PCK( 1333 ) = ' '
      PCK( 1334 ) = '           Values are unchanged in the 2'
     .//            '000 IAU report.'
      PCK( 1335 ) = ' '
      PCK( 1336 ) = '        Current values:'
      PCK( 1337 ) = ' '
      PCK( 1338 ) = BEGDAT()
      PCK( 1339 ) = ' '
      PCK( 1340 ) = '           BODY706_POLE_RA      = (   25'
     .//            '7.31      0.         0.  )'
      PCK( 1341 ) = '           BODY706_POLE_DEC     = (   -1'
     .//            '5.18      0.         0.  )'
      PCK( 1342 ) = '           BODY706_PM           = (   12'
     .//            '7.69  -1074.5205730  0.  )'
      PCK( 1343 ) = '           BODY706_LONG_AXIS    = (     '
     .//            '0.                       )'
      PCK( 1344 ) = ' '
      PCK( 1345 ) = '           BODY706_NUT_PREC_RA  = (   -0'
     .//            '.15    0.     0.    0.    0.'
      PCK( 1346 ) = '                                       0'
     .//            '.      0.     0.    0.    0.'
      PCK( 1347 ) = '                                       0'
     .//            '.      0.     0.    0.    0.'
      PCK( 1348 ) = '                                       0'
     .//            '.      0.     0.             )'
      PCK( 1349 ) = ' '
      PCK( 1350 ) = '           BODY706_NUT_PREC_DEC = (    0'
     .//            '.14    0.     0.    0.    0.'
      PCK( 1351 ) = '                                       0'
     .//            '.      0.     0.    0.    0.'
      PCK( 1352 ) = '                                       0'
     .//            '.      0.     0.    0.    0.'
      PCK( 1353 ) = '                                       0'
     .//            '.      0.     0.             )'
      PCK( 1354 ) = ' '
      PCK( 1355 ) = '           BODY706_NUT_PREC_PM  = (   -0'
     .//            '.04    0.     0.    0.    0.'
      PCK( 1356 ) = '                                       0'
     .//            '.      0.     0.    0.    0.'
      PCK( 1357 ) = '                                       0'
     .//            '.      0.     0.    0.    0.'
      PCK( 1358 ) = '                                       0'
     .//            '.      0.     0.             )'
      PCK( 1359 ) = ' '
      PCK( 1360 ) = BEGTXT()
      PCK( 1361 ) = ' '
      PCK( 1362 ) = ' '
      PCK( 1363 ) = ' '
      PCK( 1364 ) = '     Ophelia'
      PCK( 1365 ) = ' '
      PCK( 1366 ) = ' '
      PCK( 1367 ) = '        Old values:'
      PCK( 1368 ) = ' '
      PCK( 1369 ) = '           Values are unchanged in the 2'
     .//            '000 IAU report.'
      PCK( 1370 ) = ' '
      PCK( 1371 ) = '        Current values:'
      PCK( 1372 ) = ' '
      PCK( 1373 ) = BEGDAT()
      PCK( 1374 ) = ' '
      PCK( 1375 ) = '           BODY707_POLE_RA      = (  257'
     .//            '.31     0.         0. )'
      PCK( 1376 ) = '           BODY707_POLE_DEC     = (  -15'
     .//            '.18     0.         0. )'
      PCK( 1377 ) = '           BODY707_PM           = (  130'
     .//            '.35  -956.4068150  0. )'
      PCK( 1378 ) = '           BODY707_LONG_AXIS    = (    0'
     .//            '.                     )'
      PCK( 1379 ) = ' '
      PCK( 1380 ) = '           BODY707_NUT_PREC_RA  = (    0'
     .//            '.     -0.09   0.    0.    0.'
      PCK( 1381 ) = '                                       0'
     .//            '.      0.     0.    0.    0.'
      PCK( 1382 ) = '                                       0'
     .//            '.      0.     0.    0.    0.'
      PCK( 1383 ) = '                                       0'
     .//            '.      0.     0.             )'
      PCK( 1384 ) = ' '
      PCK( 1385 ) = '           BODY707_NUT_PREC_DEC = (    0'
     .//            '.      0.09   0.    0.    0.'
      PCK( 1386 ) = '                                       0'
     .//            '.      0.     0.    0.    0.'
      PCK( 1387 ) = '                                       0'
     .//            '.      0.     0.    0.    0.'
      PCK( 1388 ) = '                                       0'
     .//            '.      0.     0.             )'
      PCK( 1389 ) = ' '
      PCK( 1390 ) = '           BODY707_NUT_PREC_PM  = (    0'
     .//            '.     -0.03   0.    0.    0.'
      PCK( 1391 ) = '                                       0'
     .//            '.      0.     0.    0.    0.'
      PCK( 1392 ) = '                                       0'
     .//            '.      0.     0.    0.    0.'
      PCK( 1393 ) = '                                       0'
     .//            '.      0.     0.             )'
      PCK( 1394 ) = ' '
      PCK( 1395 ) = BEGTXT()
      PCK( 1396 ) = ' '
      PCK( 1397 ) = ' '
      PCK( 1398 ) = ' '
      PCK( 1399 ) = '     Bianca'
      PCK( 1400 ) = ' '
      PCK( 1401 ) = '        Old values:'
      PCK( 1402 ) = ' '
      PCK( 1403 ) = '           Values are unchanged in the 2'
     .//            '000 IAU report.'
      PCK( 1404 ) = ' '
      PCK( 1405 ) = '        Current values:'
      PCK( 1406 ) = ' '
      PCK( 1407 ) = BEGDAT()
      PCK( 1408 ) = ' '
      PCK( 1409 ) = '           BODY708_POLE_RA      = (  257'
     .//            '.31     0.         0.  )'
      PCK( 1410 ) = '           BODY708_POLE_DEC     = (  -15'
     .//            '.18     0.         0.  )'
      PCK( 1411 ) = '           BODY708_PM           = (  105'
     .//            '.46  -828.3914760  0.  )'
      PCK( 1412 ) = '           BODY708_LONG_AXIS    = (    0'
     .//            '.                      )'
      PCK( 1413 ) = ' '
      PCK( 1414 ) = '           BODY708_NUT_PREC_RA  = (    0'
     .//            '.      0.    -0.16    0.    0.'
      PCK( 1415 ) = '                                       0'
     .//            '.      0.     0.      0.    0.'
      PCK( 1416 ) = '                                       0'
     .//            '.      0.     0.      0.    0.'
      PCK( 1417 ) = '                                       0'
     .//            '.      0.     0.               )'
      PCK( 1418 ) = ' '
      PCK( 1419 ) = '           BODY708_NUT_PREC_DEC = (    0'
     .//            '.      0.     0.16    0.    0.'
      PCK( 1420 ) = '                                       0'
     .//            '.      0.     0.      0.    0.'
      PCK( 1421 ) = '                                       0'
     .//            '.      0.     0.      0.    0.'
      PCK( 1422 ) = '                                       0'
     .//            '.      0.     0.               )'
      PCK( 1423 ) = ' '
      PCK( 1424 ) = '           BODY708_NUT_PREC_PM  = (    0'
     .//            '.      0.    -0.04    0.    0.'
      PCK( 1425 ) = '                                       0'
     .//            '.      0.     0.      0.    0.'
      PCK( 1426 ) = '                                       0'
     .//            '.      0.     0.      0.    0.'
      PCK( 1427 ) = '                                       0'
     .//            '.      0.     0.               )'
      PCK( 1428 ) = ' '
      PCK( 1429 ) = BEGTXT()
      PCK( 1430 ) = ' '
      PCK( 1431 ) = ' '
      PCK( 1432 ) = ' '
      PCK( 1433 ) = '     Cressida'
      PCK( 1434 ) = ' '
      PCK( 1435 ) = '        Old values:'
      PCK( 1436 ) = ' '
      PCK( 1437 ) = '           Values are unchanged in the 2'
     .//            '000 IAU report.'
      PCK( 1438 ) = ' '
      PCK( 1439 ) = '        Current values:'
      PCK( 1440 ) = ' '
      PCK( 1441 ) = BEGDAT()
      PCK( 1442 ) = ' '
      PCK( 1443 ) = ' '
      PCK( 1444 ) = '           BODY709_POLE_RA      = (  257'
     .//            '.31      0.          0.  )'
      PCK( 1445 ) = '           BODY709_POLE_DEC     = (  -15'
     .//            '.18      0.          0.  )'
      PCK( 1446 ) = '           BODY709_PM           = (   59'
     .//            '.16   -776.5816320   0.  )'
      PCK( 1447 ) = '           BODY709_LONG_AXIS    = (    0'
     .//            '.                        )'
      PCK( 1448 ) = ' '
      PCK( 1449 ) = ' '
      PCK( 1450 ) = '           BODY709_NUT_PREC_RA  = (    0'
     .//            '.      0.     0.     -0.04   0.'
      PCK( 1451 ) = '                                       0'
     .//            '.      0.     0.      0.     0.'
      PCK( 1452 ) = '                                       0'
     .//            '.      0.     0.      0.     0.'
      PCK( 1453 ) = '                                       0'
     .//            '.      0.     0.                )'
      PCK( 1454 ) = ' '
      PCK( 1455 ) = ' '
      PCK( 1456 ) = '           BODY709_NUT_PREC_DEC = (    0'
     .//            '.      0.     0.      0.04   0.'
      PCK( 1457 ) = '                                       0'
     .//            '.      0.     0.      0.     0.'
      PCK( 1458 ) = '                                       0'
     .//            '.      0.     0.      0.     0.'
      PCK( 1459 ) = '                                       0'
     .//            '.      0.     0.                )'
      PCK( 1460 ) = ' '
      PCK( 1461 ) = ' '
      PCK( 1462 ) = '           BODY709_NUT_PREC_PM  = (    0'
     .//            '.      0.     0.     -0.01   0.'
      PCK( 1463 ) = '                                       0'
     .//            '.      0.     0.      0.     0.'
      PCK( 1464 ) = '                                       0'
     .//            '.      0.     0.      0.     0.'
      PCK( 1465 ) = '                                       0'
     .//            '.      0.     0.                )'
      PCK( 1466 ) = ' '
      PCK( 1467 ) = ' '
      PCK( 1468 ) = BEGTXT()
      PCK( 1469 ) = ' '
      PCK( 1470 ) = ' '
      PCK( 1471 ) = ' '
      PCK( 1472 ) = '     Desdemona'
      PCK( 1473 ) = ' '
      PCK( 1474 ) = '        Old values:'
      PCK( 1475 ) = ' '
      PCK( 1476 ) = '           Values are unchanged in the 2'
     .//            '000 IAU report.'
      PCK( 1477 ) = ' '
      PCK( 1478 ) = '        Current values:'
      PCK( 1479 ) = ' '
      PCK( 1480 ) = BEGDAT()
      PCK( 1481 ) = ' '
      PCK( 1482 ) = '           BODY710_POLE_RA      = ( 257.'
     .//            '31      0.           0.  )'
      PCK( 1483 ) = '           BODY710_POLE_DEC     = ( -15.'
     .//            '18      0.           0.  )'
      PCK( 1484 ) = '           BODY710_PM           = (  95.'
     .//            '08   -760.0531690    0.  )'
      PCK( 1485 ) = '           BODY710_LONG_AXIS    = (   0.'
     .//            '                         )'
      PCK( 1486 ) = ' '
      PCK( 1487 ) = '           BODY710_NUT_PREC_RA  = (   0.'
     .//            '      0.     0.      0.    -0.17'
      PCK( 1488 ) = '                                      0.'
     .//            '      0.     0.      0.     0.'
      PCK( 1489 ) = '                                      0.'
     .//            '      0.     0.      0.     0.'
      PCK( 1490 ) = '                                      0.'
     .//            '      0.     0.                  )'
      PCK( 1491 ) = ' '
      PCK( 1492 ) = '           BODY710_NUT_PREC_DEC = (   0.'
     .//            '      0.     0.      0.     0.16'
      PCK( 1493 ) = '                                      0.'
     .//            '      0.     0.      0.     0.'
      PCK( 1494 ) = '                                      0.'
     .//            '      0.     0.      0.     0.'
      PCK( 1495 ) = '                                      0.'
     .//            '      0.     0.                  )'
      PCK( 1496 ) = ' '
      PCK( 1497 ) = '           BODY710_NUT_PREC_PM  = (   0.'
     .//            '      0.     0.      0.    -0.04'
      PCK( 1498 ) = '                                      0.'
     .//            '      0.     0.      0.     0.'
      PCK( 1499 ) = '                                      0.'
     .//            '      0.     0.      0.     0.'
      PCK( 1500 ) = '                                      0.'
     .//            '      0.     0.                 )'
      PCK( 1501 ) = ' '
      PCK( 1502 ) = BEGTXT()
      PCK( 1503 ) = ' '
      PCK( 1504 ) = ' '
      PCK( 1505 ) = ' '
      PCK( 1506 ) = '     Juliet'
      PCK( 1507 ) = ' '
      PCK( 1508 ) = '        Old values:'
      PCK( 1509 ) = ' '
      PCK( 1510 ) = '           Values are unchanged in the 2'
     .//            '000 IAU report.'
      PCK( 1511 ) = ' '
      PCK( 1512 ) = '        Current values:'
      PCK( 1513 ) = ' '
      PCK( 1514 ) = BEGDAT()
      PCK( 1515 ) = ' '
      PCK( 1516 ) = '           BODY711_POLE_RA      = (  257'
     .//            '.31     0.           0.   )'
      PCK( 1517 ) = '           BODY711_POLE_DEC     = (  -15'
     .//            '.18     0.           0.   )'
      PCK( 1518 ) = '           BODY711_PM           = (  302'
     .//            '.56  -730.1253660    0.   )'
      PCK( 1519 ) = '           BODY711_LONG_AXIS    = (    0'
     .//            '.                         )'
      PCK( 1520 ) = ' '
      PCK( 1521 ) = '           BODY711_NUT_PREC_RA  = (   0.'
     .//            '      0.     0.      0.     0.'
      PCK( 1522 ) = '                                     -0.'
     .//            '06    0.     0.      0.     0.'
      PCK( 1523 ) = '                                      0.'
     .//            '      0.     0.      0.     0.'
      PCK( 1524 ) = '                                      0.'
     .//            '      0.     0.                 )'
      PCK( 1525 ) = ' '
      PCK( 1526 ) = '           BODY711_NUT_PREC_DEC = (   0.'
     .//            '      0.     0.      0.     0.'
      PCK( 1527 ) = '                                      0.'
     .//            '06    0.     0.      0.     0.'
      PCK( 1528 ) = '                                      0.'
     .//            '      0.     0.      0.     0.'
      PCK( 1529 ) = '                                      0.'
     .//            '      0.     0.                 )'
      PCK( 1530 ) = ' '
      PCK( 1531 ) = '           BODY711_NUT_PREC_PM  = (   0.'
     .//            '      0.     0.      0.     0.'
      PCK( 1532 ) = '                                     -0.'
     .//            '02    0.     0.      0.     0.'
      PCK( 1533 ) = '                                      0.'
     .//            '      0.     0.      0.     0.'
      PCK( 1534 ) = '                                      0.'
     .//            '      0.     0.                 )'
      PCK( 1535 ) = ' '
      PCK( 1536 ) = BEGTXT()
      PCK( 1537 ) = ' '
      PCK( 1538 ) = ' '
      PCK( 1539 ) = ' '
      PCK( 1540 ) = '     Portia'
      PCK( 1541 ) = ' '
      PCK( 1542 ) = '        Old values:'
      PCK( 1543 ) = ' '
      PCK( 1544 ) = '           Values are unchanged in the 2'
     .//            '000 IAU report.'
      PCK( 1545 ) = ' '
      PCK( 1546 ) = '        Current values:'
      PCK( 1547 ) = ' '
      PCK( 1548 ) = BEGDAT()
      PCK( 1549 ) = ' '
      PCK( 1550 ) = '           BODY712_POLE_RA      = (  257'
     .//            '.31      0.           0.   )'
      PCK( 1551 ) = '           BODY712_POLE_DEC     = (  -15'
     .//            '.18      0.           0.   )'
      PCK( 1552 ) = '           BODY712_PM           = (   25'
     .//            '.03   -701.4865870    0.   )'
      PCK( 1553 ) = '           BODY712_LONG_AXIS    = (    0'
     .//            '.                          )'
      PCK( 1554 ) = ' '
      PCK( 1555 ) = '           BODY712_NUT_PREC_RA  = (   0.'
     .//            '      0.     0.      0.     0.'
      PCK( 1556 ) = '                                      0.'
     .//            '     -0.09   0.      0.     0.'
      PCK( 1557 ) = '                                      0.'
     .//            '      0.     0.      0.     0.'
      PCK( 1558 ) = '                                      0.'
     .//            '      0.     0.                )'
      PCK( 1559 ) = ' '
      PCK( 1560 ) = '           BODY712_NUT_PREC_DEC = (   0.'
     .//            '      0.     0.      0.     0.'
      PCK( 1561 ) = '                                      0.'
     .//            '      0.09   0.      0.     0.'
      PCK( 1562 ) = '                                      0.'
     .//            '      0.     0.      0.     0.'
      PCK( 1563 ) = '                                      0.'
     .//            '      0.     0.               )'
      PCK( 1564 ) = ' '
      PCK( 1565 ) = '           BODY712_NUT_PREC_PM  = (   0.'
     .//            '      0.     0.      0.     0.'
      PCK( 1566 ) = '                                      0.'
     .//            '     -0.02   0.      0.     0.'
      PCK( 1567 ) = '                                      0.'
     .//            '      0.     0.      0.     0.'
      PCK( 1568 ) = '                                      0.'
     .//            '      0.     0.               )'
      PCK( 1569 ) = ' '
      PCK( 1570 ) = BEGTXT()
      PCK( 1571 ) = ' '
      PCK( 1572 ) = ' '
      PCK( 1573 ) = ' '
      PCK( 1574 ) = '     Rosalind'
      PCK( 1575 ) = ' '
      PCK( 1576 ) = '        Old values:'
      PCK( 1577 ) = ' '
      PCK( 1578 ) = '           Values are unchanged in the 2'
     .//            '000 IAU report.'
      PCK( 1579 ) = ' '
      PCK( 1580 ) = '        Current values:'
      PCK( 1581 ) = ' '
      PCK( 1582 ) = BEGDAT()
      PCK( 1583 ) = ' '
      PCK( 1584 ) = '           BODY713_POLE_RA      = ( 257.'
     .//            '31      0.          0.  )'
      PCK( 1585 ) = '           BODY713_POLE_DEC     = ( -15.'
     .//            '18      0.          0.  )'
      PCK( 1586 ) = '           BODY713_PM           = ( 314.'
     .//            '90   -644.6311260   0.  )'
      PCK( 1587 ) = '           BODY713_LONG_AXIS    = (   0.'
     .//            '                        )'
      PCK( 1588 ) = ' '
      PCK( 1589 ) = '           BODY713_NUT_PREC_RA  = (   0.'
     .//            '      0.     0.      0.     0.'
      PCK( 1590 ) = '                                      0.'
     .//            '      0.    -0.29    0.     0.'
      PCK( 1591 ) = '                                      0.'
     .//            '      0.     0.      0.     0.'
      PCK( 1592 ) = '                                      0.'
     .//            '      0.     0.               )'
      PCK( 1593 ) = ' '
      PCK( 1594 ) = '           BODY713_NUT_PREC_DEC = (   0.'
     .//            '      0.     0.      0.     0.'
      PCK( 1595 ) = '                                      0.'
     .//            '      0.     0.28    0.     0.'
      PCK( 1596 ) = '                                      0.'
     .//            '      0.     0.      0.     0.'
      PCK( 1597 ) = '                                      0.'
     .//            '      0.     0.              )'
      PCK( 1598 ) = ' '
      PCK( 1599 ) = '           BODY713_NUT_PREC_PM  = (   0.'
     .//            '      0.     0.      0.     0.'
      PCK( 1600 ) = '                                      0.'
     .//            '      0.    -0.08    0.     0.'
      PCK( 1601 ) = '                                      0.'
     .//            '      0.     0.      0.     0.'
      PCK( 1602 ) = '                                      0.'
     .//            '      0.     0.              )'
      PCK( 1603 ) = ' '
      PCK( 1604 ) = BEGTXT()
      PCK( 1605 ) = ' '
      PCK( 1606 ) = ' '
      PCK( 1607 ) = ' '
      PCK( 1608 ) = '     Belinda'
      PCK( 1609 ) = ' '
      PCK( 1610 ) = '       Old values:'
      PCK( 1611 ) = ' '
      PCK( 1612 ) = '           Values are unchanged in the 2'
     .//            '000 IAU report.'
      PCK( 1613 ) = ' '
      PCK( 1614 ) = '        Current values:'
      PCK( 1615 ) = ' '
      PCK( 1616 ) = BEGDAT()
      PCK( 1617 ) = ' '
      PCK( 1618 ) = '           BODY714_POLE_RA      = (   25'
     .//            '7.31      0.         0. )'
      PCK( 1619 ) = '           BODY714_POLE_DEC     = (   -1'
     .//            '5.18      0.         0. )'
      PCK( 1620 ) = '           BODY714_PM           = (   29'
     .//            '7.46   -577.3628170  0. )'
      PCK( 1621 ) = '           BODY714_LONG_AXIS    = (     '
     .//            '0.                      )'
      PCK( 1622 ) = ' '
      PCK( 1623 ) = '           BODY714_NUT_PREC_RA  = (   0.'
     .//            '      0.     0.      0.     0.'
      PCK( 1624 ) = '                                      0.'
     .//            '      0.     0.     -0.03   0.'
      PCK( 1625 ) = '                                      0.'
     .//            '      0.     0.      0.     0.'
      PCK( 1626 ) = '                                      0.'
     .//            '      0.     0.                )'
      PCK( 1627 ) = ' '
      PCK( 1628 ) = '           BODY714_NUT_PREC_DEC = (   0.'
     .//            '      0.     0.      0.     0.'
      PCK( 1629 ) = '                                      0.'
     .//            '      0.     0.      0.03   0.'
      PCK( 1630 ) = '                                      0.'
     .//            '      0.     0.      0.     0.'
      PCK( 1631 ) = '                                      0.'
     .//            '      0.     0.                )'
      PCK( 1632 ) = ' '
      PCK( 1633 ) = '           BODY714_NUT_PREC_PM  = (   0.'
     .//            '      0.     0.      0.     0.'
      PCK( 1634 ) = '                                      0.'
     .//            '      0.     0.     -0.01   0.'
      PCK( 1635 ) = '                                      0.'
     .//            '      0.     0.      0.     0.'
      PCK( 1636 ) = '                                      0.'
     .//            '      0.     0.                )'
      PCK( 1637 ) = BEGTXT()
      PCK( 1638 ) = ' '
      PCK( 1639 ) = ' '
      PCK( 1640 ) = ' '
      PCK( 1641 ) = '     Puck'
      PCK( 1642 ) = ' '
      PCK( 1643 ) = '       Old values:'
      PCK( 1644 ) = ' '
      PCK( 1645 ) = '           Values are unchanged in the 2'
     .//            '000 IAU report.'
      PCK( 1646 ) = ' '
      PCK( 1647 ) = '        Current values:'
      PCK( 1648 ) = ' '
      PCK( 1649 ) = BEGDAT()
      PCK( 1650 ) = ' '
      PCK( 1651 ) = '           BODY715_POLE_RA      = (  257'
     .//            '.31      0.         0.  )'
      PCK( 1652 ) = '           BODY715_POLE_DEC     = (  -15'
     .//            '.18      0.         0.  )'
      PCK( 1653 ) = '           BODY715_PM           = (   91'
     .//            '.24   -472.5450690  0.  )'
      PCK( 1654 ) = '           BODY715_LONG_AXIS    = (    0'
     .//            '.                       )'
      PCK( 1655 ) = ' '
      PCK( 1656 ) = '           BODY715_NUT_PREC_RA  = (   0.'
     .//            '      0.     0.      0.     0.'
      PCK( 1657 ) = '                                      0.'
     .//            '      0.     0.      0.    -0.33'
      PCK( 1658 ) = '                                      0.'
     .//            '      0.     0.      0.     0.'
      PCK( 1659 ) = '                                      0.'
     .//            '      0.     0.                  )'
      PCK( 1660 ) = ' '
      PCK( 1661 ) = '           BODY715_NUT_PREC_DEC = (   0.'
     .//            '      0.     0.      0.     0.'
      PCK( 1662 ) = '                                      0.'
     .//            '      0.     0.      0.     0.31'
      PCK( 1663 ) = '                                      0.'
     .//            '      0.     0.      0.     0.'
      PCK( 1664 ) = '                                      0.'
     .//            '      0.     0.                  )'
      PCK( 1665 ) = ' '
      PCK( 1666 ) = '           BODY715_NUT_PREC_PM  = (   0.'
     .//            '      0.     0.      0.     0.'
      PCK( 1667 ) = '                                      0.'
     .//            '      0.     0.      0.    -0.09'
      PCK( 1668 ) = '                                      0.'
     .//            '      0.     0.      0.     0.'
      PCK( 1669 ) = '                                      0.'
     .//            '      0.     0.                  )'
      PCK( 1670 ) = ' '
      PCK( 1671 ) = BEGTXT()
      PCK( 1672 ) = ' '
      PCK( 1673 ) = ' '
      PCK( 1674 ) = ' '
      PCK( 1675 ) = ' '
      PCK( 1676 ) = 'Satellites of Neptune'
      PCK( 1677 ) = ' '
      PCK( 1678 ) = ' '
      PCK( 1679 ) = '     Triton'
      PCK( 1680 ) = ' '
      PCK( 1681 ) = '       Old values:'
      PCK( 1682 ) = ' '
      PCK( 1683 ) = '           Values are unchanged in the 2'
     .//            '000 IAU report.'
      PCK( 1684 ) = ' '
      PCK( 1685 ) = '        Current values:'
      PCK( 1686 ) = ' '
      PCK( 1687 ) = BEGDAT()
      PCK( 1688 ) = ' '
      PCK( 1689 ) = '           BODY801_POLE_RA       = ( 299'
     .//            '.36     0.         0.  )'
      PCK( 1690 ) = '           BODY801_POLE_DEC      = (  41'
     .//            '.17     0.         0.  )'
      PCK( 1691 ) = '           BODY801_PM            = ( 296'
     .//            '.53   -61.2572637  0.  )'
      PCK( 1692 ) = '           BODY801_LONG_AXIS     = (   0'
     .//            '.                      )'
      PCK( 1693 ) = ' '
      PCK( 1694 ) = ' '
      PCK( 1695 ) = '           BODY801_NUT_PREC_RA   = (  0.'
     .//            '      0.      0.      0.'
      PCK( 1696 ) = '                                      0.'
     .//            '      0.      0.    -32.35'
      PCK( 1697 ) = '                                      0.'
     .//            '     -6.28   -2.08   -0.74'
      PCK( 1698 ) = '                                     -0.'
     .//            '28   -0.11   -0.07   -0.02'
      PCK( 1699 ) = '                                     -0.'
     .//            '01                         )'
      PCK( 1700 ) = ' '
      PCK( 1701 ) = ' '
      PCK( 1702 ) = '           BODY801_NUT_PREC_DEC  = (  0.'
     .//            '      0.      0.      0.'
      PCK( 1703 ) = '                                      0.'
     .//            '      0.      0.     22.55'
      PCK( 1704 ) = '                                      0.'
     .//            '      2.10    0.55    0.16'
      PCK( 1705 ) = '                                      0.'
     .//            '05    0.02    0.01    0.'
      PCK( 1706 ) = '                                      0.'
     .//            '                           )'
      PCK( 1707 ) = ' '
      PCK( 1708 ) = ' '
      PCK( 1709 ) = '           BODY801_NUT_PREC_PM   = (  0.'
     .//            '      0.      0.      0.'
      PCK( 1710 ) = '                                      0.'
     .//            '      0.      0.     22.25'
      PCK( 1711 ) = '                                      0.'
     .//            '      6.73    2.05    0.74'
      PCK( 1712 ) = '                                      0.'
     .//            '28    0.11    0.05    0.02'
      PCK( 1713 ) = '                                      0.'
     .//            '01                         )'
      PCK( 1714 ) = ' '
      PCK( 1715 ) = BEGTXT()
      PCK( 1716 ) = ' '
      PCK( 1717 ) = ' '
      PCK( 1718 ) = ' '
      PCK( 1719 ) = ' '
      PCK( 1720 ) = '     Nereid'
      PCK( 1721 ) = ' '
      PCK( 1722 ) = '        Old values:'
      PCK( 1723 ) = ' '
      PCK( 1724 ) = '           Values are from the 1988 IAU '
     .//            'report.'
      PCK( 1725 ) = ' '
      PCK( 1726 ) = '           body802_pole_ra       = (    '
     .//            '273.48    0.        0.  )'
      PCK( 1727 ) = '           body802_pole_dec      = (    '
     .//            ' 67.22    0.        0.  )'
      PCK( 1728 ) = '           body802_pm            = (    '
     .//            '237.22    0.9996465 0.  )'
      PCK( 1729 ) = '           body802_long_axis     = (    '
     .//            '  0.                    )'
      PCK( 1730 ) = ' '
      PCK( 1731 ) = ' '
      PCK( 1732 ) = '           The report seems to have a ty'
     .//            'po:  in the nut_prec_ra expression,'
      PCK( 1733 ) = '           where the report gives  -0.51'
     .//            ' sin 3N3, we use -0.51 3N2.'
      PCK( 1734 ) = ' '
      PCK( 1735 ) = '           body802_nut_prec_ra   = (  0.'
     .//            '    -17.81'
      PCK( 1736 ) = '                                      0.'
     .//            '      0.     0.      0.'
      PCK( 1737 ) = '                                      0.'
     .//            '      0.     0.'
      PCK( 1738 ) = '                                      2.'
     .//            '56   -0.51   0.11   -0.03  )'
      PCK( 1739 ) = ' '
      PCK( 1740 ) = '           body802_nut_prec_dec  = (  0.'
     .//            '     -6.67'
      PCK( 1741 ) = '                                      0.'
     .//            '      0.     0.      0.'
      PCK( 1742 ) = '                                      0.'
     .//            '      0.     0.'
      PCK( 1743 ) = '                                      0.'
     .//            '47   -0.07   0.01          )'
      PCK( 1744 ) = ' '
      PCK( 1745 ) = '           body802_nut_prec_pm   = (  0.'
     .//            '     16.48'
      PCK( 1746 ) = '                                      0.'
     .//            '      0.     0.      0.'
      PCK( 1747 ) = '                                      0.'
     .//            '      0.     0.'
      PCK( 1748 ) = '                                     -2.'
     .//            '57    0.51 -0.11    0.02  )'
      PCK( 1749 ) = ' '
      PCK( 1750 ) = ' '
      PCK( 1751 ) = ' '
      PCK( 1752 ) = '        Current values:'
      PCK( 1753 ) = ' '
      PCK( 1754 ) = '           The 2000 report does not give'
     .//            ' values for Nereid.  In order'
      PCK( 1755 ) = '           to obtain rotational elements'
     .//            ' for Nereid, a separate PCK'
      PCK( 1756 ) = '           file must be loaded.'
      PCK( 1757 ) = ' '
      PCK( 1758 ) = ' '
      PCK( 1759 ) = ' '
      PCK( 1760 ) = '     Naiad'
      PCK( 1761 ) = ' '
      PCK( 1762 ) = '        Old values:'
      PCK( 1763 ) = ' '
      PCK( 1764 ) = '           Values are unchanged in the 2'
     .//            '000 IAU report.'
      PCK( 1765 ) = ' '
      PCK( 1766 ) = '        Current values:'
      PCK( 1767 ) = ' '
      PCK( 1768 ) = ' '
      PCK( 1769 ) = BEGDAT()
      PCK( 1770 ) = ' '
      PCK( 1771 ) = '           BODY803_POLE_RA       = (  29'
     .//            '9.36      0.          0.  )'
      PCK( 1772 ) = '           BODY803_POLE_DEC      = (   4'
     .//            '3.36      0.          0.  )'
      PCK( 1773 ) = '           BODY803_PM            = (  25'
     .//            '4.06  +1222.8441209   0.  )'
      PCK( 1774 ) = '           BODY803_LONG_AXIS     = (    '
     .//            '0.                        )'
      PCK( 1775 ) = ' '
      PCK( 1776 ) = ' '
      PCK( 1777 ) = '           BODY803_NUT_PREC_RA   = (    '
     .//            '0.70     -6.49     0.      0.'
      PCK( 1778 ) = '                                        '
     .//            '0.        0.       0.      0.'
      PCK( 1779 ) = '                                        '
     .//            '0.25      0.       0.      0.'
      PCK( 1780 ) = '                                        '
     .//            '0.        0.       0.      0.'
      PCK( 1781 ) = '                                        '
     .//            '0.                            )'
      PCK( 1782 ) = ' '
      PCK( 1783 ) = '           BODY803_NUT_PREC_DEC  = (   -'
     .//            '0.51     -4.75     0.      0.'
      PCK( 1784 ) = '                                        '
     .//            '0.        0.       0.      0.'
      PCK( 1785 ) = '                                        '
     .//            '0.09      0.       0.      0.'
      PCK( 1786 ) = '                                        '
     .//            '0.        0.       0.      0.'
      PCK( 1787 ) = '                                        '
     .//            '0.                            )'
      PCK( 1788 ) = ' '
      PCK( 1789 ) = '           BODY803_NUT_PREC_PM   = (   -'
     .//            '0.48      4.40     0.      0.'
      PCK( 1790 ) = '                                        '
     .//            '0.        0.       0.      0.'
      PCK( 1791 ) = '                                       -'
     .//            '0.27      0.       0.      0.'
      PCK( 1792 ) = '                                        '
     .//            '0.        0.       0.      0.'
      PCK( 1793 ) = '                                        '
     .//            '0.                            )'
      PCK( 1794 ) = ' '
      PCK( 1795 ) = BEGTXT()
      PCK( 1796 ) = ' '
      PCK( 1797 ) = ' '
      PCK( 1798 ) = ' '
      PCK( 1799 ) = ' '
      PCK( 1800 ) = '     Thalassa'
      PCK( 1801 ) = ' '
      PCK( 1802 ) = ' '
      PCK( 1803 ) = '        Old values:'
      PCK( 1804 ) = ' '
      PCK( 1805 ) = '           Values are unchanged in the 2'
     .//            '000 IAU report.'
      PCK( 1806 ) = ' '
      PCK( 1807 ) = '        Current values:'
      PCK( 1808 ) = ' '
      PCK( 1809 ) = BEGDAT()
      PCK( 1810 ) = ' '
      PCK( 1811 ) = '           BODY804_POLE_RA       = (  29'
     .//            '9.36      0.          0. )'
      PCK( 1812 ) = '           BODY804_POLE_DEC      = (   4'
     .//            '3.45      0.          0. )'
      PCK( 1813 ) = '           BODY804_PM            = (  10'
     .//            '2.06   1155.7555612   0. )'
      PCK( 1814 ) = '           BODY804_LONG_AXIS     = (    '
     .//            '0.                       )'
      PCK( 1815 ) = ' '
      PCK( 1816 ) = ' '
      PCK( 1817 ) = '           BODY804_NUT_PREC_RA   = (    '
     .//            '0.70      0.      -0.28    0.'
      PCK( 1818 ) = '                                        '
     .//            '0.        0.       0.      0.'
      PCK( 1819 ) = '                                        '
     .//            '0.        0.       0.      0.'
      PCK( 1820 ) = '                                        '
     .//            '0.        0.       0.      0.'
      PCK( 1821 ) = '                                        '
     .//            '0.                             )'
      PCK( 1822 ) = ' '
      PCK( 1823 ) = ' '
      PCK( 1824 ) = '           BODY804_NUT_PREC_DEC  = (   -'
     .//            '0.51      0.      -0.21    0.'
      PCK( 1825 ) = '                                        '
     .//            '0.        0.       0.      0.'
      PCK( 1826 ) = '                                        '
     .//            '0.        0.       0.      0.'
      PCK( 1827 ) = '                                        '
     .//            '0.        0.       0.      0.'
      PCK( 1828 ) = '                                        '
     .//            '0.                             )'
      PCK( 1829 ) = ' '
      PCK( 1830 ) = '           BODY804_NUT_PREC_PM   = (   -'
     .//            '0.48      0.       0.19    0.'
      PCK( 1831 ) = '                                        '
     .//            '0.        0.       0.      0.'
      PCK( 1832 ) = '                                        '
     .//            '0.        0.       0.      0.'
      PCK( 1833 ) = '                                        '
     .//            '0.        0.       0.      0.'
      PCK( 1834 ) = '                                        '
     .//            '0.                             )'
      PCK( 1835 ) = ' '
      PCK( 1836 ) = BEGTXT()
      PCK( 1837 ) = ' '
      PCK( 1838 ) = ' '
      PCK( 1839 ) = ' '
      PCK( 1840 ) = '     Despina'
      PCK( 1841 ) = ' '
      PCK( 1842 ) = '        Old values:'
      PCK( 1843 ) = ' '
      PCK( 1844 ) = '           Values are unchanged in the 2'
     .//            '000 IAU report.'
      PCK( 1845 ) = ' '
      PCK( 1846 ) = '        Current values:'
      PCK( 1847 ) = ' '
      PCK( 1848 ) = ' '
      PCK( 1849 ) = BEGDAT()
      PCK( 1850 ) = ' '
      PCK( 1851 ) = '           BODY805_POLE_RA       = (  29'
     .//            '9.36      0.          0. )'
      PCK( 1852 ) = '           BODY805_POLE_DEC      = (   4'
     .//            '3.45      0.          0. )'
      PCK( 1853 ) = '           BODY805_PM            = (  30'
     .//            '6.51  +1075.7341562   0. )'
      PCK( 1854 ) = '           BODY805_LONG_AXIS     = (    '
     .//            '0.                       )'
      PCK( 1855 ) = ' '
      PCK( 1856 ) = ' '
      PCK( 1857 ) = '           BODY805_NUT_PREC_RA   = (    '
     .//            '0.70      0.       0.     -0.09'
      PCK( 1858 ) = '                                        '
     .//            '0.        0.       0.      0.'
      PCK( 1859 ) = '                                        '
     .//            '0.        0.       0.      0.'
      PCK( 1860 ) = '                                        '
     .//            '0.        0.       0.      0.'
      PCK( 1861 ) = '                                        '
     .//            '0.                              )'
      PCK( 1862 ) = ' '
      PCK( 1863 ) = '           BODY805_NUT_PREC_DEC  = (   -'
     .//            '0.51      0.       0.     -0.07'
      PCK( 1864 ) = '                                        '
     .//            '0.        0.       0.      0.'
      PCK( 1865 ) = '                                        '
     .//            '0.        0.       0.      0.'
      PCK( 1866 ) = '                                        '
     .//            '0.        0.       0.      0.'
      PCK( 1867 ) = '                                        '
     .//            '0.                              )'
      PCK( 1868 ) = ' '
      PCK( 1869 ) = '           BODY805_NUT_PREC_PM   = (   -'
     .//            '0.49      0.       0.      0.06'
      PCK( 1870 ) = '                                        '
     .//            '0.        0.       0.      0.'
      PCK( 1871 ) = '                                        '
     .//            '0.        0.       0.      0.'
      PCK( 1872 ) = '                                        '
     .//            '0.        0.       0.      0.'
      PCK( 1873 ) = '                                        '
     .//            '0.                              )'
      PCK( 1874 ) = BEGTXT()
      PCK( 1875 ) = ' '
      PCK( 1876 ) = ' '
      PCK( 1877 ) = ' '
      PCK( 1878 ) = '     Galatea'
      PCK( 1879 ) = ' '
      PCK( 1880 ) = ' '
      PCK( 1881 ) = '        Old values:'
      PCK( 1882 ) = ' '
      PCK( 1883 ) = '           Values are unchanged in the 2'
     .//            '000 IAU report.'
      PCK( 1884 ) = ' '
      PCK( 1885 ) = '        Current values:'
      PCK( 1886 ) = ' '
      PCK( 1887 ) = ' '
      PCK( 1888 ) = BEGDAT()
      PCK( 1889 ) = ' '
      PCK( 1890 ) = '           BODY806_POLE_RA       = (   2'
     .//            '99.36      0.          0. )'
      PCK( 1891 ) = '           BODY806_POLE_DEC      = (    '
     .//            '43.43      0.          0. )'
      PCK( 1892 ) = '           BODY806_PM            = (   2'
     .//            '58.09    839.6597686   0. )'
      PCK( 1893 ) = '           BODY806_LONG_AXIS     = (    '
     .//            ' 0.                       )'
      PCK( 1894 ) = ' '
      PCK( 1895 ) = ' '
      PCK( 1896 ) = '           BODY806_NUT_PREC_RA   = (    '
     .//            '0.70      0.       0.      0.'
      PCK( 1897 ) = '                                       -'
     .//            '0.07      0.       0.      0.'
      PCK( 1898 ) = '                                        '
     .//            '0.        0.       0.      0.'
      PCK( 1899 ) = '                                        '
     .//            '0.        0.       0.      0.'
      PCK( 1900 ) = '                                        '
     .//            '0.                             )'
      PCK( 1901 ) = ' '
      PCK( 1902 ) = '           BODY806_NUT_PREC_DEC  = (   -'
     .//            '0.51      0.       0.      0.'
      PCK( 1903 ) = '                                       -'
     .//            '0.05      0.       0.      0.'
      PCK( 1904 ) = '                                        '
     .//            '0.        0.       0.      0.'
      PCK( 1905 ) = '                                        '
     .//            '0.        0.       0.      0.'
      PCK( 1906 ) = '                                        '
     .//            '0.                             )'
      PCK( 1907 ) = ' '
      PCK( 1908 ) = '           BODY806_NUT_PREC_PM   = (   -'
     .//            '0.48      0.       0.      0.'
      PCK( 1909 ) = '                                        '
     .//            '0.05      0.       0.      0.'
      PCK( 1910 ) = '                                        '
     .//            '0.        0.       0.      0.'
      PCK( 1911 ) = '                                        '
     .//            '0.        0.       0.      0.'
      PCK( 1912 ) = '                                        '
     .//            '0.                             )'
      PCK( 1913 ) = BEGTXT()
      PCK( 1914 ) = ' '
      PCK( 1915 ) = ' '
      PCK( 1916 ) = '     Larissa'
      PCK( 1917 ) = ' '
      PCK( 1918 ) = ' '
      PCK( 1919 ) = '        Old values:'
      PCK( 1920 ) = ' '
      PCK( 1921 ) = '           Values are unchanged in the 2'
     .//            '000 IAU report.'
      PCK( 1922 ) = ' '
      PCK( 1923 ) = '        Current values:'
      PCK( 1924 ) = ' '
      PCK( 1925 ) = BEGDAT()
      PCK( 1926 ) = ' '
      PCK( 1927 ) = '           BODY807_POLE_RA       = (   2'
     .//            '99.36     0.           0. )'
      PCK( 1928 ) = '           BODY807_POLE_DEC      = (    '
     .//            '43.41     0.           0. )'
      PCK( 1929 ) = '           BODY807_PM            = (   1'
     .//            '79.41  +649.0534470    0. )'
      PCK( 1930 ) = '           BODY807_LONG_AXIS     = (    '
     .//            ' 0.                       )'
      PCK( 1931 ) = ' '
      PCK( 1932 ) = ' '
      PCK( 1933 ) = '           BODY807_NUT_PREC_RA   = (    '
     .//            '0.70      0.       0.      0.'
      PCK( 1934 ) = '                                        '
     .//            '0.       -0.27     0.      0.'
      PCK( 1935 ) = '                                        '
     .//            '0.        0.       0.      0.'
      PCK( 1936 ) = '                                        '
     .//            '0.        0.       0.      0.'
      PCK( 1937 ) = '                                        '
     .//            '0.                            )'
      PCK( 1938 ) = ' '
      PCK( 1939 ) = '           BODY807_NUT_PREC_DEC  = (   -'
     .//            '0.51      0.       0.      0.'
      PCK( 1940 ) = '                                        '
     .//            '0.       -0.20     0.      0.'
      PCK( 1941 ) = '                                        '
     .//            '0.        0.       0.      0.'
      PCK( 1942 ) = '                                        '
     .//            '0.        0.       0.      0.'
      PCK( 1943 ) = '                                        '
     .//            '0.                            )'
      PCK( 1944 ) = ' '
      PCK( 1945 ) = '           BODY807_NUT_PREC_PM   = (   -'
     .//            '0.48      0.       0.      0.'
      PCK( 1946 ) = '                                        '
     .//            '0.        0.19     0.      0.'
      PCK( 1947 ) = '                                        '
     .//            '0.        0.       0.      0.'
      PCK( 1948 ) = '                                        '
     .//            '0.        0.       0.      0.'
      PCK( 1949 ) = '                                        '
     .//            '0.                            )'
      PCK( 1950 ) = BEGTXT()
      PCK( 1951 ) = ' '
      PCK( 1952 ) = ' '
      PCK( 1953 ) = ' '
      PCK( 1954 ) = '     Proteus'
      PCK( 1955 ) = ' '
      PCK( 1956 ) = ' '
      PCK( 1957 ) = '        Old values:'
      PCK( 1958 ) = ' '
      PCK( 1959 ) = '           Values are unchanged in the 2'
     .//            '000 IAU report.'
      PCK( 1960 ) = ' '
      PCK( 1961 ) = '        Current values:'
      PCK( 1962 ) = ' '
      PCK( 1963 ) = BEGDAT()
      PCK( 1964 ) = ' '
      PCK( 1965 ) = '           BODY808_POLE_RA       = (  29'
     .//            '9.27      0.          0.  )'
      PCK( 1966 ) = '           BODY808_POLE_DEC      = (   4'
     .//            '2.91      0.          0.  )'
      PCK( 1967 ) = '           BODY808_PM            = (   9'
     .//            '3.38   +320.7654228   0.  )'
      PCK( 1968 ) = '           BODY808_LONG_AXIS     = (    '
     .//            '0.                        )'
      PCK( 1969 ) = ' '
      PCK( 1970 ) = ' '
      PCK( 1971 ) = '           BODY808_NUT_PREC_RA   = (    '
     .//            '0.70      0.       0.      0.'
      PCK( 1972 ) = '                                        '
     .//            '0.        0.      -0.05    0.'
      PCK( 1973 ) = '                                        '
     .//            '0.        0.       0.      0.'
      PCK( 1974 ) = '                                        '
     .//            '0.        0.       0.      0.'
      PCK( 1975 ) = '                                        '
     .//            '0.                             )'
      PCK( 1976 ) = ' '
      PCK( 1977 ) = '           BODY808_NUT_PREC_DEC  = (   -'
     .//            '0.51      0.       0.      0.'
      PCK( 1978 ) = '                                        '
     .//            '0.        0.      -0.04    0.'
      PCK( 1979 ) = '                                        '
     .//            '0.        0.       0.      0.'
      PCK( 1980 ) = '                                        '
     .//            '0.        0.       0.      0.'
      PCK( 1981 ) = '                                        '
     .//            '0.                             )'
      PCK( 1982 ) = ' '
      PCK( 1983 ) = '           BODY808_NUT_PREC_PM   = (   -'
     .//            '0.48      0.       0.      0.'
      PCK( 1984 ) = '                                        '
     .//            '0.        0.       0.04    0.'
      PCK( 1985 ) = '                                        '
     .//            '0.        0.       0.      0.'
      PCK( 1986 ) = '                                        '
     .//            '0.        0.       0.      0.'
      PCK( 1987 ) = '                                        '
     .//            '0.                             )'
      PCK( 1988 ) = ' '
      PCK( 1989 ) = BEGTXT()
      PCK( 1990 ) = ' '
      PCK( 1991 ) = ' '
      PCK( 1992 ) = ' '
      PCK( 1993 ) = ' '
      PCK( 1994 ) = ' '
      PCK( 1995 ) = 'Satellites of Pluto'
      PCK( 1996 ) = ' '
      PCK( 1997 ) = '     Charon'
      PCK( 1998 ) = ' '
      PCK( 1999 ) = '        Old values:'
      PCK( 2000 ) = ' '
      PCK( 2001 ) = '           Values are unchanged in the 2'
     .//            '000 IAU report.'
      PCK( 2002 ) = ' '
      PCK( 2003 ) = '        Current values:'
      PCK( 2004 ) = ' '
      PCK( 2005 ) = BEGDAT()
      PCK( 2006 ) = ' '
      PCK( 2007 ) = '           BODY901_POLE_RA       = (   3'
     .//            '13.02     0.         0. )'
      PCK( 2008 ) = '           BODY901_POLE_DEC      = (    '
     .//            ' 9.09     0.         0. )'
      PCK( 2009 ) = '           BODY901_PM            = (    '
     .//            '56.77   -56.3623195  0. )'
      PCK( 2010 ) = '           BODY901_LONG_AXIS     = (    '
     .//            ' 0.                     )'
      PCK( 2011 ) = ' '
      PCK( 2012 ) = BEGTXT()
      PCK( 2013 ) = ' '
      PCK( 2014 ) = ' '
      PCK( 2015 ) = ' '
      PCK( 2016 ) = 'Orientation constants for Asteroids Gasp'
     .//            'ra and Ida'
      PCK( 2017 ) = '----------------------------------------'
     .//            '----------------'
      PCK( 2018 ) = ' '
      PCK( 2019 ) = ' '
      PCK( 2020 ) = 'Gaspra'
      PCK( 2021 ) = ' '
      PCK( 2022 ) = '        Old values:'
      PCK( 2023 ) = ' '
      PCK( 2024 ) = '           Values are unchanged in the 2'
     .//            '000 IAU report.'
      PCK( 2025 ) = ' '
      PCK( 2026 ) = '        Current values:'
      PCK( 2027 ) = ' '
      PCK( 2028 ) = BEGDAT()
      PCK( 2029 ) = ' '
      PCK( 2030 ) = '           BODY9511010_POLE_RA       = ('
     .//            '   9.47     0.         0. )'
      PCK( 2031 ) = '           BODY9511010_POLE_DEC      = ('
     .//            '  26.70     0.         0. )'
      PCK( 2032 ) = '           BODY9511010_PM            = ('
     .//            '  83.67  1226.9114850  0. )'
      PCK( 2033 ) = '           BODY9511010_LONG_AXIS     = ('
     .//            '   0.                     )'
      PCK( 2034 ) = ' '
      PCK( 2035 ) = BEGTXT()
      PCK( 2036 ) = ' '
      PCK( 2037 ) = ' '
      PCK( 2038 ) = 'Ida'
      PCK( 2039 ) = ' '
      PCK( 2040 ) = '        Old values:'
      PCK( 2041 ) = ' '
      PCK( 2042 ) = '           Values are unchanged in the 2'
     .//            '000 IAU report.'
      PCK( 2043 ) = ' '
      PCK( 2044 ) = '        Current values:'
      PCK( 2045 ) = ' '
      PCK( 2046 ) = BEGDAT()
      PCK( 2047 ) = ' '
      PCK( 2048 ) = '           BODY2431010_POLE_RA       = ('
     .//            '  348.76      0.         0. )'
      PCK( 2049 ) = '           BODY2431010_POLE_DEC      = ('
     .//            '   87.12      0.         0. )'
      PCK( 2050 ) = '           BODY2431010_PM            = ('
     .//            '  265.95  -1864.6280070  0. )'
      PCK( 2051 ) = '           BODY2431010_LONG_AXIS     = ('
     .//            '    0.                      )'
      PCK( 2052 ) = ' '
      PCK( 2053 ) = BEGTXT()
      PCK( 2054 ) = ' '
      PCK( 2055 ) = ' '
      PCK( 2056 ) = 'Vesta'
      PCK( 2057 ) = ' '
      PCK( 2058 ) = '        Current values:'
      PCK( 2059 ) = ' '
      PCK( 2060 ) = BEGDAT()
      PCK( 2061 ) = ' '
      PCK( 2062 ) = '           BODY2000004_POLE_RA       = ('
     .//            '   301.      0.         0.  )'
      PCK( 2063 ) = '           BODY2000004_POLE_DEC      = ('
     .//            '    41.      0.         0.  )'
      PCK( 2064 ) = '           BODY2000004_PM            = ('
     .//            '   292.   1617.332776   0.  )'
      PCK( 2065 ) = '           BODY2000004_LONG_AXIS     = ('
     .//            '     0.                     )'
      PCK( 2066 ) = ' '
      PCK( 2067 ) = BEGTXT()
      PCK( 2068 ) = ' '
      PCK( 2069 ) = ' '
      PCK( 2070 ) = 'Eros'
      PCK( 2071 ) = ' '
      PCK( 2072 ) = '        Current values:'
      PCK( 2073 ) = ' '
      PCK( 2074 ) = BEGDAT()
      PCK( 2075 ) = ' '
      PCK( 2076 ) = '           BODY2000433_POLE_RA       = ('
     .//            '   11.35       0.           0. )'
      PCK( 2077 ) = '           BODY2000433_POLE_DEC      = ('
     .//            '   17.22       0.           0. )'
      PCK( 2078 ) = '           BODY2000433_PM            = ('
     .//            '  326.07    1639.38864745   0. )'
      PCK( 2079 ) = '           BODY2000433_LONG_AXIS     = ('
     .//            '    0.                         )'
      PCK( 2080 ) = ' '
      PCK( 2081 ) = BEGTXT()
      PCK( 2082 ) = ' '
      PCK( 2083 ) = ' '
      PCK( 2084 ) = ' '
      PCK( 2085 ) = ' '
      PCK( 2086 ) = 'Radii of Sun and Planets'
      PCK( 2087 ) = '----------------------------------------'
     .//            '----------------'
      PCK( 2088 ) = ' '
      PCK( 2089 ) = ' '
      PCK( 2090 ) = 'Sun'
      PCK( 2091 ) = ' '
      PCK( 2092 ) = '     Value for the Sun is from the [2], '
     .//            'page K7.'
      PCK( 2093 ) = ' '
      PCK( 2094 ) = BEGDAT()
      PCK( 2095 ) = ' '
      PCK( 2096 ) = '        BODY10_RADII      = (   696000. '
     .//            '    696000.      696000.     )'
      PCK( 2097 ) = ' '
      PCK( 2098 ) = BEGTXT()
      PCK( 2099 ) = ' '
      PCK( 2100 ) = ' '
      PCK( 2101 ) = 'Mercury'
      PCK( 2102 ) = ' '
      PCK( 2103 ) = '     Old values:'
      PCK( 2104 ) = ' '
      PCK( 2105 ) = '        Values are unchanged in the 2000'
     .//            ' IAU report.'
      PCK( 2106 ) = ' '
      PCK( 2107 ) = '     Current values:'
      PCK( 2108 ) = ' '
      PCK( 2109 ) = BEGDAT()
      PCK( 2110 ) = ' '
      PCK( 2111 ) = '        BODY199_RADII     = ( 2439.7   2'
     .//            '439.7   2439.7 )'
      PCK( 2112 ) = ' '
      PCK( 2113 ) = BEGTXT()
      PCK( 2114 ) = ' '
      PCK( 2115 ) = ' '
      PCK( 2116 ) = 'Venus'
      PCK( 2117 ) = ' '
      PCK( 2118 ) = '     Old values:'
      PCK( 2119 ) = ' '
      PCK( 2120 ) = '        Values are unchanged in the 2000'
     .//            ' IAU report.'
      PCK( 2121 ) = ' '
      PCK( 2122 ) = '     Current values:'
      PCK( 2123 ) = ' '
      PCK( 2124 ) = BEGDAT()
      PCK( 2125 ) = ' '
      PCK( 2126 ) = '        BODY299_RADII     = ( 6051.8   6'
     .//            '051.8   6051.8 )'
      PCK( 2127 ) = ' '
      PCK( 2128 ) = BEGTXT()
      PCK( 2129 ) = ' '
      PCK( 2130 ) = ' '
      PCK( 2131 ) = 'Earth'
      PCK( 2132 ) = ' '
      PCK( 2133 ) = '     Old values:'
      PCK( 2134 ) = ' '
      PCK( 2135 ) = '        Values are unchanged in the 2000'
     .//            ' IAU report.'
      PCK( 2136 ) = ' '
      PCK( 2137 ) = '     Current values:'
      PCK( 2138 ) = ' '
      PCK( 2139 ) = BEGDAT()
      PCK( 2140 ) = ' '
      PCK( 2141 ) = '        BODY399_RADII     = ( 6378.14   '
     .//            '6378.14   6356.75 )'
      PCK( 2142 ) = ' '
      PCK( 2143 ) = BEGTXT()
      PCK( 2144 ) = ' '
      PCK( 2145 ) = ' '
      PCK( 2146 ) = 'Mars'
      PCK( 2147 ) = ' '
      PCK( 2148 ) = ' '
      PCK( 2149 ) = '     Old values:'
      PCK( 2150 ) = ' '
      PCK( 2151 ) = '        body499_radii       = (     3397'
     .//            '.      3397.         3375.     )'
      PCK( 2152 ) = ' '
      PCK( 2153 ) = '     Current values:'
      PCK( 2154 ) = ' '
      PCK( 2155 ) = ' '
      PCK( 2156 ) = '        The IAU report gives separate va'
     .//            'lues for the north and south'
      PCK( 2157 ) = '        polar radii:'
      PCK( 2158 ) = ' '
      PCK( 2159 ) = '           north:  3373.19'
      PCK( 2160 ) = '           south:  3379.21'
      PCK( 2161 ) = ' '
      PCK( 2162 ) = '        We use the average of these valu'
     .//            'es as the polar radius for'
      PCK( 2163 ) = '        the triaxial model.'
      PCK( 2164 ) = ' '
      PCK( 2165 ) = BEGDAT()
      PCK( 2166 ) = ' '
      PCK( 2167 ) = '        BODY499_RADII       = ( 3396.19 '
     .//            '  3396.19   3376.20 )'
      PCK( 2168 ) = ' '
      PCK( 2169 ) = BEGTXT()
      PCK( 2170 ) = ' '
      PCK( 2171 ) = ' '
      PCK( 2172 ) = ' '
      PCK( 2173 ) = 'Jupiter'
      PCK( 2174 ) = ' '
      PCK( 2175 ) = '     Old values:'
      PCK( 2176 ) = ' '
      PCK( 2177 ) = '        Values are unchanged in the 2000'
     .//            ' IAU report.'
      PCK( 2178 ) = ' '
      PCK( 2179 ) = '     Current values:'
      PCK( 2180 ) = ' '
      PCK( 2181 ) = BEGDAT()
      PCK( 2182 ) = ' '
      PCK( 2183 ) = '        BODY599_RADII     = ( 71492   71'
     .//            '492   66854 )'
      PCK( 2184 ) = ' '
      PCK( 2185 ) = BEGTXT()
      PCK( 2186 ) = ' '
      PCK( 2187 ) = ' '
      PCK( 2188 ) = ' '
      PCK( 2189 ) = 'Saturn'
      PCK( 2190 ) = ' '
      PCK( 2191 ) = '     Old values:'
      PCK( 2192 ) = ' '
      PCK( 2193 ) = '        Values are unchanged in the 2000'
     .//            ' IAU report.'
      PCK( 2194 ) = ' '
      PCK( 2195 ) = '     Current values:'
      PCK( 2196 ) = ' '
      PCK( 2197 ) = BEGDAT()
      PCK( 2198 ) = ' '
      PCK( 2199 ) = '        BODY699_RADII     = ( 60268   60'
     .//            '268   54364 )'
      PCK( 2200 ) = ' '
      PCK( 2201 ) = BEGTXT()
      PCK( 2202 ) = ' '
      PCK( 2203 ) = ' '
      PCK( 2204 ) = ' '
      PCK( 2205 ) = 'Uranus'
      PCK( 2206 ) = ' '
      PCK( 2207 ) = '     Old values:'
      PCK( 2208 ) = ' '
      PCK( 2209 ) = '        Values are unchanged in the 2000'
     .//            ' IAU report.'
      PCK( 2210 ) = ' '
      PCK( 2211 ) = '     Current values:'
      PCK( 2212 ) = ' '
      PCK( 2213 ) = BEGDAT()
      PCK( 2214 ) = ' '
      PCK( 2215 ) = '        BODY799_RADII     = ( 25559   25'
     .//            '559   24973 )'
      PCK( 2216 ) = ' '
      PCK( 2217 ) = BEGTXT()
      PCK( 2218 ) = ' '
      PCK( 2219 ) = ' '
      PCK( 2220 ) = ' '
      PCK( 2221 ) = 'Neptune'
      PCK( 2222 ) = ' '
      PCK( 2223 ) = '     Old values:'
      PCK( 2224 ) = ' '
      PCK( 2225 ) = '        Values are unchanged in the 2000'
     .//            ' IAU report.'
      PCK( 2226 ) = ' '
      PCK( 2227 ) = '     Current values:'
      PCK( 2228 ) = ' '
      PCK( 2229 ) = '        (Values are for the 1 bar pressu'
     .//            're level.)'
      PCK( 2230 ) = ' '
      PCK( 2231 ) = BEGDAT()
      PCK( 2232 ) = ' '
      PCK( 2233 ) = '        BODY899_RADII     = ( 24764   24'
     .//            '764  24341 )'
      PCK( 2234 ) = ' '
      PCK( 2235 ) = BEGTXT()
      PCK( 2236 ) = ' '
      PCK( 2237 ) = ' '
      PCK( 2238 ) = ' '
      PCK( 2239 ) = 'Pluto'
      PCK( 2240 ) = ' '
      PCK( 2241 ) = '     Old values:'
      PCK( 2242 ) = ' '
      PCK( 2243 ) = '        Values are unchanged in the 2000'
     .//            ' IAU report.'
      PCK( 2244 ) = ' '
      PCK( 2245 ) = '     Current values:'
      PCK( 2246 ) = ' '
      PCK( 2247 ) = BEGDAT()
      PCK( 2248 ) = ' '
      PCK( 2249 ) = '        BODY999_RADII     = ( 1195   119'
     .//            '5   1195 )'
      PCK( 2250 ) = ' '
      PCK( 2251 ) = BEGTXT()
      PCK( 2252 ) = ' '
      PCK( 2253 ) = ' '
      PCK( 2254 ) = ' '
      PCK( 2255 ) = ' '
      PCK( 2256 ) = 'Radii of Satellites'
      PCK( 2257 ) = '----------------------------------------'
     .//            '----------------'
      PCK( 2258 ) = ' '
      PCK( 2259 ) = ' '
      PCK( 2260 ) = 'Moon'
      PCK( 2261 ) = ' '
      PCK( 2262 ) = '     Old values:'
      PCK( 2263 ) = ' '
      PCK( 2264 ) = '        Values are unchanged in the 2000'
     .//            ' IAU report.'
      PCK( 2265 ) = ' '
      PCK( 2266 ) = '     Current values:'
      PCK( 2267 ) = ' '
      PCK( 2268 ) = BEGDAT()
      PCK( 2269 ) = ' '
      PCK( 2270 ) = '        BODY301_RADII     = ( 1737.4   1'
     .//            '737.4   1737.4 )'
      PCK( 2271 ) = ' '
      PCK( 2272 ) = BEGTXT()
      PCK( 2273 ) = ' '
      PCK( 2274 ) = ' '
      PCK( 2275 ) = ' '
      PCK( 2276 ) = 'Satellites of Mars'
      PCK( 2277 ) = ' '
      PCK( 2278 ) = '     Old values:'
      PCK( 2279 ) = ' '
      PCK( 2280 ) = '        Values are unchanged in the 2000'
     .//            ' IAU report.'
      PCK( 2281 ) = ' '
      PCK( 2282 ) = '     Current values:'
      PCK( 2283 ) = ' '
      PCK( 2284 ) = BEGDAT()
      PCK( 2285 ) = ' '
      PCK( 2286 ) = '        BODY401_RADII     = ( 13.4    11'
     .//            '.2    9.2 )'
      PCK( 2287 ) = '        BODY402_RADII     = (  7.5     6'
     .//            '.1    5.2 )'
      PCK( 2288 ) = ' '
      PCK( 2289 ) = BEGTXT()
      PCK( 2290 ) = ' '
      PCK( 2291 ) = ' '
      PCK( 2292 ) = ' '
      PCK( 2293 ) = 'Satellites of Jupiter'
      PCK( 2294 ) = ' '
      PCK( 2295 ) = '     Old values:'
      PCK( 2296 ) = ' '
      PCK( 2297 ) = '        Old values for Io, Europa, Ganym'
     .//            'ede, Callisto and Amalthea.'
      PCK( 2298 ) = '        These are from the 1997 IAU repo'
     .//            'rt.'
      PCK( 2299 ) = ' '
      PCK( 2300 ) = '        body501_radii     = (     1826. '
     .//            '      1815.        1812.     )'
      PCK( 2301 ) = '        body502_radii     = (     1562. '
     .//            '      1560.        1559.     )'
      PCK( 2302 ) = '        body503_radii     = (     2635. '
     .//            '      2633.        2633.     )'
      PCK( 2303 ) = '        body504_radii     = (     2409. '
     .//            '      2409.        2409.     )'
      PCK( 2304 ) = '        body505_radii     = (      131. '
     .//            '        73.          67.     )'
      PCK( 2305 ) = '        body506_radii    = (  85      85'
     .//            '      85   )'
      PCK( 2306 ) = '        body507_radii    = (  40      40'
     .//            '      40   )'
      PCK( 2307 ) = '        body508_radii    = (  18      18'
     .//            '      18   )'
      PCK( 2308 ) = '        body509_radii    = (  14      14'
     .//            '      14   )'
      PCK( 2309 ) = '        body510_radii    = (  12      12'
     .//            '      12   )'
      PCK( 2310 ) = '        body511_radii    = (  15      15'
     .//            '      15   )'
      PCK( 2311 ) = '        body512_radii    = (  10      10'
     .//            '      10   )'
      PCK( 2312 ) = '        body513_radii    = (   5       5'
     .//            '       5   )'
      PCK( 2313 ) = '        body514_radii    = (  50      50'
     .//            '      50   )'
      PCK( 2314 ) = '        body515_radii    = (  13      10'
     .//            '       8   )'
      PCK( 2315 ) = '        body516_radii    = (  20      20'
     .//            '    20   )'
      PCK( 2316 ) = ' '
      PCK( 2317 ) = ' '
      PCK( 2318 ) = '     Current values:'
      PCK( 2319 ) = ' '
      PCK( 2320 ) = BEGDAT()
      PCK( 2321 ) = ' '
      PCK( 2322 ) = '        BODY501_RADII     = ( 1829.4   1'
     .//            '819.3   1815.7  )'
      PCK( 2323 ) = '        BODY502_RADII     = ( 1564.13  1'
     .//            '561.23  1560.93 )'
      PCK( 2324 ) = '        BODY503_RADII     = ( 2632.4   2'
     .//            '632.29  2632.35 )'
      PCK( 2325 ) = '        BODY504_RADII     = ( 2409.4   2'
     .//            '409.2   2409.3  )'
      PCK( 2326 ) = '        BODY505_RADII     = (  125      '
     .//            ' 73       64    )'
      PCK( 2327 ) = ' '
      PCK( 2328 ) = BEGTXT()
      PCK( 2329 ) = ' '
      PCK( 2330 ) = '        Only mean radii are available in'
     .//            ' the 2000 IAU report for bodies'
      PCK( 2331 ) = '        506-513.'
      PCK( 2332 ) = ' '
      PCK( 2333 ) = BEGDAT()
      PCK( 2334 ) = ' '
      PCK( 2335 ) = '        BODY506_RADII    = (    85      '
     .//            ' 85       85   )'
      PCK( 2336 ) = '        BODY507_RADII    = (    40      '
     .//            ' 40       40   )'
      PCK( 2337 ) = '        BODY508_RADII    = (    18      '
     .//            ' 18       18   )'
      PCK( 2338 ) = '        BODY509_RADII    = (    14      '
     .//            ' 14       14   )'
      PCK( 2339 ) = '        BODY510_RADII    = (    12      '
     .//            ' 12       12   )'
      PCK( 2340 ) = '        BODY511_RADII    = (    15      '
     .//            ' 15       15   )'
      PCK( 2341 ) = '        BODY512_RADII    = (    10      '
     .//            ' 10       10   )'
      PCK( 2342 ) = '        BODY513_RADII    = (     5      '
     .//            '  5        5   )'
      PCK( 2343 ) = ' '
      PCK( 2344 ) = BEGTXT()
      PCK( 2345 ) = ' '
      PCK( 2346 ) = BEGDAT()
      PCK( 2347 ) = ' '
      PCK( 2348 ) = '        BODY514_RADII    = (    58      '
     .//            ' 49       42   )'
      PCK( 2349 ) = '        BODY515_RADII    = (    10      '
     .//            '  8        7   )'
      PCK( 2350 ) = ' '
      PCK( 2351 ) = BEGTXT()
      PCK( 2352 ) = ' '
      PCK( 2353 ) = '        The value for the second radius '
     .//            'for body 516 is not given in'
      PCK( 2354 ) = '        2000 IAU report.   The values gi'
     .//            'ven are:'
      PCK( 2355 ) = ' '
      PCK( 2356 ) = '           BODY516_RADII    = (  30   --'
     .//            '-   20   )'
      PCK( 2357 ) = ' '
      PCK( 2358 ) = '        For use within the SPICE system,'
     .//            ' we use only the mean radius.'
      PCK( 2359 ) = BEGDAT()
      PCK( 2360 ) = ' '
      PCK( 2361 ) = '        BODY516_RADII    = (  21.5   21.'
     .//            '5  21.5  )'
      PCK( 2362 ) = ' '
      PCK( 2363 ) = BEGTXT()
      PCK( 2364 ) = ' '
      PCK( 2365 ) = ' '
      PCK( 2366 ) = ' '
      PCK( 2367 ) = 'Satellites of Saturn'
      PCK( 2368 ) = ' '
      PCK( 2369 ) = ' '
      PCK( 2370 ) = '     Old values:'
      PCK( 2371 ) = ' '
      PCK( 2372 ) = '        body601_radii     = (      210.3'
     .//            '       197.4        192.6    )'
      PCK( 2373 ) = '        body602_radii     = (      256.2'
     .//            '       247.3        244.0    )'
      PCK( 2374 ) = '        body603_radii     = (      535.6'
     .//            '       528.2        525.8    )'
      PCK( 2375 ) = '        body604_radii     = (      560. '
     .//            '       560.         560.     )'
      PCK( 2376 ) = '        body605_radii     = (      764. '
     .//            '       764.         764.     )'
      PCK( 2377 ) = '        body606_radii     = (     2575. '
     .//            '      2575.        2575.     )'
      PCK( 2378 ) = '        body607_radii     = (      180. '
     .//            '       140.         112.5    )'
      PCK( 2379 ) = '        body608_radii     = (      718. '
     .//            '       718.         718.     )'
      PCK( 2380 ) = '        body609_radii     = (      115. '
     .//            '       110.         105.     )'
      PCK( 2381 ) = '        body610_radii     = (       97. '
     .//            '        95.          77.     )'
      PCK( 2382 ) = '        body611_radii     = (       69. '
     .//            '        55.          55.     )'
      PCK( 2383 ) = '        body612_radii     = (       16  '
     .//            '        16           16      )'
      PCK( 2384 ) = '        body613_radii     = (       15  '
     .//            '        12.5          7.5    )'
      PCK( 2385 ) = '        body614_radii     = (       15  '
     .//            '         8            8      )'
      PCK( 2386 ) = '        body615_radii     = (       18.5'
     .//            '        17.2         13.5    )'
      PCK( 2387 ) = '        body616_radii     = (       74  '
     .//            '        50           34      )'
      PCK( 2388 ) = '        body617_radii     = (       55  '
     .//            '        44           31      )'
      PCK( 2389 ) = '        body618_radii     = (       10  '
     .//            '        10           10      )'
      PCK( 2390 ) = ' '
      PCK( 2391 ) = ' '
      PCK( 2392 ) = '     Current values:'
      PCK( 2393 ) = ' '
      PCK( 2394 ) = BEGDAT()
      PCK( 2395 ) = ' '
      PCK( 2396 ) = '        BODY601_RADII     = (  209.1   1'
     .//            '96.2   191.4 )'
      PCK( 2397 ) = '        BODY602_RADII     = (  256.3   2'
     .//            '47.3   244.6 )'
      PCK( 2398 ) = '        BODY603_RADII     = (  535.6   5'
     .//            '28.2   525.8 )'
      PCK( 2399 ) = '        BODY604_RADII     = (  560     5'
     .//            '60     560   )'
      PCK( 2400 ) = '        BODY605_RADII     = (  764     7'
     .//            '64     764   )'
      PCK( 2401 ) = '        BODY606_RADII     = ( 2575    25'
     .//            '75    2575   )'
      PCK( 2402 ) = '        BODY607_RADII     = (  164     1'
     .//            '30     107   )'
      PCK( 2403 ) = '        BODY608_RADII     = (  718     7'
     .//            '18     718   )'
      PCK( 2404 ) = '        BODY609_RADII     = (  115     1'
     .//            '10     105   )'
      PCK( 2405 ) = '        BODY610_RADII     = (   97.0    '
     .//            '95.0    77.0 )'
      PCK( 2406 ) = '        BODY611_RADII     = (   69.0    '
     .//            '55.0    55.0 )'
      PCK( 2407 ) = ' '
      PCK( 2408 ) = BEGTXT()
      PCK( 2409 ) = ' '
      PCK( 2410 ) = '        Only the first equatorial radius'
     .//            ' for Helene (body 612) is given in the'
      PCK( 2411 ) = '        2000 IAU report:'
      PCK( 2412 ) = ' '
      PCK( 2413 ) = '            BODY612_RADII     = (       '
     .//            '17.5        ---          ---     )'
      PCK( 2414 ) = ' '
      PCK( 2415 ) = '        The mean radius is 16km; we use '
     .//            'this radius for all three axes, as'
      PCK( 2416 ) = '        we do for the satellites for whi'
     .//            'ch only the mean radius is available.'
      PCK( 2417 ) = ' '
      PCK( 2418 ) = ' '
      PCK( 2419 ) = BEGDAT()
      PCK( 2420 ) = ' '
      PCK( 2421 ) = '        BODY612_RADII     = (   16      '
     .//            '16       16  )'
      PCK( 2422 ) = '        BODY613_RADII     = (   15      '
     .//            '12.5     7.5 )'
      PCK( 2423 ) = '        BODY614_RADII     = (   15.0    '
     .//            ' 8.0     8.0 )'
      PCK( 2424 ) = '        BODY615_RADII     = (   18.5    '
     .//            '17.2    13.5 )'
      PCK( 2425 ) = '        BODY616_RADII     = (   74.0    '
     .//            '50.0    34.0 )'
      PCK( 2426 ) = '        BODY617_RADII     = (   55.0    '
     .//            '44.0    31.0 )'
      PCK( 2427 ) = ' '
      PCK( 2428 ) = BEGTXT()
      PCK( 2429 ) = ' '
      PCK( 2430 ) = ' '
      PCK( 2431 ) = '         For Pan, only a mean radius is '
     .//            'given in the 2000 report.'
      PCK( 2432 ) = ' '
      PCK( 2433 ) = BEGDAT()
      PCK( 2434 ) = ' '
      PCK( 2435 ) = '        BODY618_RADII     = (   10      '
     .//            ' 10     10   )'
      PCK( 2436 ) = ' '
      PCK( 2437 ) = BEGTXT()
      PCK( 2438 ) = ' '
      PCK( 2439 ) = ' '
      PCK( 2440 ) = ' '
      PCK( 2441 ) = 'Satellites of Uranus'
      PCK( 2442 ) = ' '
      PCK( 2443 ) = '     Old values:'
      PCK( 2444 ) = ' '
      PCK( 2445 ) = '        Values are unchanged in the 2000'
     .//            ' IAU report.'
      PCK( 2446 ) = ' '
      PCK( 2447 ) = '     Current values:'
      PCK( 2448 ) = ' '
      PCK( 2449 ) = BEGDAT()
      PCK( 2450 ) = ' '
      PCK( 2451 ) = '        BODY701_RADII     = (  581.1   5'
     .//            '77.9   577.7 )'
      PCK( 2452 ) = '        BODY702_RADII     = (  584.7   5'
     .//            '84.7   584.7 )'
      PCK( 2453 ) = '        BODY703_RADII     = (  788.9   7'
     .//            '88.9   788.9 )'
      PCK( 2454 ) = '        BODY704_RADII     = (  761.4   7'
     .//            '61.4   761.4 )'
      PCK( 2455 ) = '        BODY705_RADII     = (  240.4   2'
     .//            '34.2   232.9 )'
      PCK( 2456 ) = ' '
      PCK( 2457 ) = BEGTXT()
      PCK( 2458 ) = ' '
      PCK( 2459 ) = '        The 2000 report gives only mean '
     .//            'radii for satellites 706--715.'
      PCK( 2460 ) = ' '
      PCK( 2461 ) = BEGDAT()
      PCK( 2462 ) = ' '
      PCK( 2463 ) = '        BODY706_RADII     = (   13      '
     .//            '13      13 )'
      PCK( 2464 ) = '        BODY707_RADII     = (   15      '
     .//            '15      15 )'
      PCK( 2465 ) = '        BODY708_RADII     = (   21      '
     .//            '21      21 )'
      PCK( 2466 ) = '        BODY709_RADII     = (   31      '
     .//            '31      31 )'
      PCK( 2467 ) = '        BODY710_RADII     = (   27      '
     .//            '27      27 )'
      PCK( 2468 ) = '        BODY711_RADII     = (   42      '
     .//            '42      42 )'
      PCK( 2469 ) = '        BODY712_RADII     = (   54      '
     .//            '54      54 )'
      PCK( 2470 ) = '        BODY713_RADII     = (   27      '
     .//            '27      27 )'
      PCK( 2471 ) = '        BODY714_RADII     = (   33      '
     .//            '33      33 )'
      PCK( 2472 ) = '        BODY715_RADII     = (   77      '
     .//            '77      77 )'
      PCK( 2473 ) = ' '
      PCK( 2474 ) = BEGTXT()
      PCK( 2475 ) = ' '
      PCK( 2476 ) = ' '
      PCK( 2477 ) = ' '
      PCK( 2478 ) = ' '
      PCK( 2479 ) = 'Satellites of Neptune'
      PCK( 2480 ) = ' '
      PCK( 2481 ) = ' '
      PCK( 2482 ) = '     Old values:'
      PCK( 2483 ) = ' '
      PCK( 2484 ) = '        Values are unchanged in the 2000'
     .//            ' IAU report.'
      PCK( 2485 ) = ' '
      PCK( 2486 ) = '     Current values:'
      PCK( 2487 ) = ' '
      PCK( 2488 ) = '        The 2000 report gives mean radii'
     .//            ' only for bodies 801-806.'
      PCK( 2489 ) = ' '
      PCK( 2490 ) = BEGDAT()
      PCK( 2491 ) = ' '
      PCK( 2492 ) = '        BODY801_RADII     = ( 1352.6  13'
     .//            '52.6  1352.6 )'
      PCK( 2493 ) = '        BODY802_RADII     = (  170     1'
     .//            '70     170   )'
      PCK( 2494 ) = '        BODY803_RADII     = (   29      '
     .//            '29     29    )'
      PCK( 2495 ) = '        BODY804_RADII     = (   40      '
     .//            '40     40    )'
      PCK( 2496 ) = '        BODY805_RADII     = (   74      '
     .//            '74     74    )'
      PCK( 2497 ) = '        BODY806_RADII     = (   79      '
     .//            '79     79    )'
      PCK( 2498 ) = ' '
      PCK( 2499 ) = BEGTXT()
      PCK( 2500 ) = ' '
      PCK( 2501 ) = ' '
      PCK( 2502 ) = '        The second equatorial radius for'
     .//            ' Larissa is not given in the 2000'
      PCK( 2503 ) = '        report.  The available values ar'
     .//            'e:'
      PCK( 2504 ) = ' '
      PCK( 2505 ) = '            BODY807_RADII     = (   104 '
     .//            '    ---     89   )'
      PCK( 2506 ) = ' '
      PCK( 2507 ) = '        For use within the SPICE system,'
     .//            ' we use only the mean radius.'
      PCK( 2508 ) = BEGDAT()
      PCK( 2509 ) = ' '
      PCK( 2510 ) = '        BODY807_RADII     = (   96      '
     .//            '96     96   )'
      PCK( 2511 ) = '        BODY808_RADII     = (  218     2'
     .//            '08    201   )'
      PCK( 2512 ) = ' '
      PCK( 2513 ) = BEGTXT()
      PCK( 2514 ) = ' '
      PCK( 2515 ) = ' '
      PCK( 2516 ) = ' '
      PCK( 2517 ) = ' '
      PCK( 2518 ) = 'Satellites of Pluto'
      PCK( 2519 ) = ' '
      PCK( 2520 ) = ' '
      PCK( 2521 ) = '     Old values:'
      PCK( 2522 ) = ' '
      PCK( 2523 ) = '        Values are unchanged in the 2000'
     .//            ' IAU report.'
      PCK( 2524 ) = ' '
      PCK( 2525 ) = '     Current values:'
      PCK( 2526 ) = ' '
      PCK( 2527 ) = BEGDAT()
      PCK( 2528 ) = ' '
      PCK( 2529 ) = '        BODY901_RADII     = (  593     5'
     .//            '93    593   )'
      PCK( 2530 ) = ' '
      PCK( 2531 ) = BEGTXT()
      PCK( 2532 ) = ' '
      PCK( 2533 ) = ' '
      PCK( 2534 ) = ' '
      PCK( 2535 ) = 'Radii of Selected Asteroids'
      PCK( 2536 ) = '----------------------------------------'
     .//            '----------------'
      PCK( 2537 ) = ' '
      PCK( 2538 ) = ' '
      PCK( 2539 ) = 'Gaspra'
      PCK( 2540 ) = ' '
      PCK( 2541 ) = ' '
      PCK( 2542 ) = '     Current values:'
      PCK( 2543 ) = ' '
      PCK( 2544 ) = ' '
      PCK( 2545 ) = BEGDAT()
      PCK( 2546 ) = ' '
      PCK( 2547 ) = '        BODY9511010_RADII     = (    9.1'
     .//            '    5.2    4.4 )'
      PCK( 2548 ) = ' '
      PCK( 2549 ) = BEGTXT()
      PCK( 2550 ) = ' '
      PCK( 2551 ) = ' '
      PCK( 2552 ) = ' '
      PCK( 2553 ) = ' '
      PCK( 2554 ) = 'Ida'
      PCK( 2555 ) = ' '
      PCK( 2556 ) = ' '
      PCK( 2557 ) = '     Current values:'
      PCK( 2558 ) = ' '
      PCK( 2559 ) = ' '
      PCK( 2560 ) = BEGDAT()
      PCK( 2561 ) = ' '
      PCK( 2562 ) = '        BODY2431010_RADII     = (   26.8'
     .//            '   12.0    7.6 )'
      PCK( 2563 ) = ' '
      PCK( 2564 ) = BEGTXT()
      PCK( 2565 ) = ' '
      PCK( 2566 ) = ' '
      PCK( 2567 ) = ' '
      PCK( 2568 ) = ' '
      PCK( 2569 ) = 'Kleopatra'
      PCK( 2570 ) = ' '
      PCK( 2571 ) = ' '
      PCK( 2572 ) = '     Current values:'
      PCK( 2573 ) = ' '
      PCK( 2574 ) = ' '
      PCK( 2575 ) = BEGDAT()
      PCK( 2576 ) = ' '
      PCK( 2577 ) = '        BODY2000216_RADII     = (   108.'
     .//            '5      47    40.5  )'
      PCK( 2578 ) = ' '
      PCK( 2579 ) = BEGTXT()
      PCK( 2580 ) = ' '
      PCK( 2581 ) = ' '
      PCK( 2582 ) = ' '
      PCK( 2583 ) = 'Eros'
      PCK( 2584 ) = ' '
      PCK( 2585 ) = '     Current values:'
      PCK( 2586 ) = ' '
      PCK( 2587 ) = ' '
      PCK( 2588 ) = BEGDAT()
      PCK( 2589 ) = ' '
      PCK( 2590 ) = '        BODY2000433_RADII     = (  7.311'
     .//            '  7.311  7.311  )'
      PCK( 2591 ) = ' '
      PCK( 2592 ) = BEGTXT()
      PCK( 2593 ) = ' '
      PCK( 2594 ) = BEGDAT()
      PCK( 2595 ) = ' '
      PCK( 2596  ) = 'BODY-10_CONSTANTS_REF_FRAME = 2'
      PCK( 2597  ) = 'BODY-10_CONSTANTS_JED_EPOCH = 2433282.42345905D0'
      PCK( 2598  ) = ' '
      PCK( 2599  ) = 'BODY-10_POLE_RA         = (  286.13       '
     .//          '0.          0. )'
      PCK( 2600  ) = 'BODY-10_POLE_DEC        = (   63.87       '
     .//          '0.          0. )'
      PCK( 2601  ) = 'BODY-10_PM              = (   84.10      1'
     .//          '4.18440     0. )'
      PCK( 2602  ) = 'BODY-10_LONG_AXIS       = (  459.00       '
     .//          '               )'
      PCK( 2603 ) = ' '
      PCK( 2604 ) = BEGTXT()
      PCK( 2605 ) = ' '
 
C
C     Create the PCK kernel.
C
      CALL TXTOPN ( NAMEPC, UNIT )
 
      DO I = 1, NLINES
         R =     RTRIM ( PCK(I) )

         CALL WRITLN ( PCK(I)(1:R), UNIT )
      END DO
 
      CLOSE ( UNIT )
C
C     If this file needs to be loaded.  Do it now.  If not we are
C     done and can return.
C
      IF ( LOADPC ) THEN
         CALL LDPOOL ( NAMEPC )
 
         IF ( KEEPPC ) THEN
C
C           If we are keeping this file, we need to register it
C           with FILREG.
C
            CALL TFILES ( NAMEPC )
            RETURN
         END IF
 
      ELSE
C
C        We are keeping this file, so we need to register it
C        with FILREG.
C
         CALL TFILES ( NAMEPC )
         RETURN
      END IF
 
 
      CALL KILFIL ( NAMEPC )
 
      RETURN
      END
